@@ -18,8 +18,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #include <tqwidget.h>
@@ -199,7 +199,7 @@ void ActionManagerImpl::slotTagAdded(const Tag& tag)
 
     if (!d->tagActions.contains(tag.id()))
     {
-        d->tagActions[tag.id()] = new TagAction(tag, d->view, TQT_SLOT(slotAssignTag(const Tag&, bool)), d->tagMenu);
+        d->tagActions[tag.id()] = new TagAction(tag, TQT_TQOBJECT(d->view), TQT_SLOT(slotAssignTag(const Tag&, bool)), d->tagMenu);
         d->tagMenu->insert(d->tagActions[tag.id()]);
     }
 }
@@ -281,51 +281,51 @@ void ActionManagerImpl::initView(View* view)
         d->view = view;
 
     // tag actions
-    new KAction(i18n("&New Tag..."), "", "", d->view, TQT_SLOT(slotNewTag()), actionCollection(), "tag_new");
+    new KAction(i18n("&New Tag..."), "", "",  TQT_TQOBJECT(d->view), TQT_SLOT(slotNewTag()), actionCollection(), "tag_new");
 
     // Feed/Feed Group popup menu
-    new KAction(i18n("&Open Homepage"), "", "Ctrl+H", d->view, TQT_SLOT(slotOpenHomepage()), actionCollection(), "feed_homepage");
-    new KAction(i18n("&Add Feed..."), "bookmark_add", "Insert", d->view, TQT_SLOT(slotFeedAdd()), actionCollection(), "feed_add");
-    new KAction(i18n("Ne&w Folder..."), "folder_new", "Shift+Insert", d->view, TQT_SLOT(slotFeedAddGroup()), actionCollection(), "feed_add_group");
-    new KAction(i18n("&Delete Feed"), "editdelete", "Alt+Delete", d->view, TQT_SLOT(slotFeedRemove()), actionCollection(), "feed_remove");
-    new KAction(i18n("&Edit Feed..."), "edit", "F2", d->view, TQT_SLOT(slotFeedModify()), actionCollection(), "feed_modify");
+    new KAction(i18n("&Open Homepage"), "", "Ctrl+H",  TQT_TQOBJECT(d->view), TQT_SLOT(slotOpenHomepage()), actionCollection(), "feed_homepage");
+    new KAction(i18n("&Add Feed..."), "bookmark_add", "Insert", TQT_TQOBJECT(d->view), TQT_SLOT(slotFeedAdd()), actionCollection(), "feed_add");
+    new KAction(i18n("Ne&w Folder..."), "folder_new", "Shift+Insert", TQT_TQOBJECT(d->view), TQT_SLOT(slotFeedAddGroup()), actionCollection(), "feed_add_group");
+    new KAction(i18n("&Delete Feed"), "editdelete", "Alt+Delete", TQT_TQOBJECT(d->view), TQT_SLOT(slotFeedRemove()), actionCollection(), "feed_remove");
+    new KAction(i18n("&Edit Feed..."), "edit", "F2", TQT_TQOBJECT(d->view), TQT_SLOT(slotFeedModify()), actionCollection(), "feed_modify");
         KActionMenu* vm = new KActionMenu( i18n( "&View Mode" ), actionCollection(), "view_mode" );
 
-    KRadioAction *ra = new KRadioAction(i18n("&Normal View"), "view_top_bottom", "Ctrl+Shift+1", d->view, TQT_SLOT(slotNormalView()), actionCollection(), "normal_view");
+    KRadioAction *ra = new KRadioAction(i18n("&Normal View"), "view_top_bottom", "Ctrl+Shift+1", TQT_TQOBJECT(d->view), TQT_SLOT(slotNormalView()), actionCollection(), "normal_view");
     ra->setExclusiveGroup( "ViewMode" );
     vm->insert(ra);
 
-    ra = new KRadioAction(i18n("&Widescreen View"), "view_left_right", "Ctrl+Shift+2", d->view, TQT_SLOT(slotWidescreenView()), actionCollection(), "widescreen_view");
+    ra = new KRadioAction(i18n("&Widescreen View"), "view_left_right", "Ctrl+Shift+2", TQT_TQOBJECT(d->view), TQT_SLOT(slotWidescreenView()), actionCollection(), "widescreen_view");
     ra->setExclusiveGroup( "ViewMode" );
     vm->insert(ra);
 
-    ra = new KRadioAction(i18n("C&ombined View"), "view_text", "Ctrl+Shift+3", d->view, TQT_SLOT(slotCombinedView()), actionCollection(), "combined_view");
+    ra = new KRadioAction(i18n("C&ombined View"), "view_text", "Ctrl+Shift+3", TQT_TQOBJECT(d->view), TQT_SLOT(slotCombinedView()), actionCollection(), "combined_view");
     ra->setExclusiveGroup( "ViewMode" );
     vm->insert(ra);
 
     // toolbar / feed menu
-    new KAction(i18n("&Fetch Feed"), "down", KStdAccel::shortcut(KStdAccel::Reload), d->view, TQT_SLOT(slotFetchCurrentFeed()), actionCollection(), "feed_fetch");
-    new KAction(i18n("Fe&tch All Feeds"), "bottom", "Ctrl+L", d->view, TQT_SLOT(slotFetchAllFeeds()), actionCollection(), "feed_fetch_all");
+    new KAction(i18n("&Fetch Feed"), "down", KStdAccel::shortcut(KStdAccel::Reload), TQT_TQOBJECT(d->view), TQT_SLOT(slotFetchCurrentFeed()), actionCollection(), "feed_fetch");
+    new KAction(i18n("Fe&tch All Feeds"), "bottom", "Ctrl+L", TQT_TQOBJECT(d->view), TQT_SLOT(slotFetchAllFeeds()), actionCollection(), "feed_fetch_all");
 
     KAction* stopAction = new KAction(i18n( "&Abort Fetches" ), "stop", Key_Escape, Kernel::self()->fetchQueue(), TQT_SLOT(slotAbort()), actionCollection(), "feed_stop");
     stopAction->setEnabled(false);
 
-    new KAction(i18n("&Mark Feed as Read"), "goto", "Ctrl+R", d->view, TQT_SLOT(slotMarkAllRead()), actionCollection(), "feed_mark_all_as_read");
-    new KAction(i18n("Ma&rk All Feeds as Read"), "goto", "Ctrl+Shift+R", d->view, TQT_SLOT(slotMarkAllFeedsRead()), actionCollection(), "feed_mark_all_feeds_as_read");
+    new KAction(i18n("&Mark Feed as Read"), "goto", "Ctrl+R", TQT_TQOBJECT(d->view), TQT_SLOT(slotMarkAllRead()), actionCollection(), "feed_mark_all_as_read");
+    new KAction(i18n("Ma&rk All Feeds as Read"), "goto", "Ctrl+Shift+R", TQT_TQOBJECT(d->view), TQT_SLOT(slotMarkAllFeedsRead()), actionCollection(), "feed_mark_all_feeds_as_read");
 
     // Settings menu
-    KToggleAction* sqf = new KToggleAction(i18n("Show Quick Filter"), TQString::null, 0, d->view, TQT_SLOT(slotToggleShowQuickFilter()), actionCollection(), "show_quick_filter");
+    KToggleAction* sqf = new KToggleAction(i18n("Show Quick Filter"), TQString(), 0, TQT_TQOBJECT(d->view), TQT_SLOT(slotToggleShowQuickFilter()), actionCollection(), "show_quick_filter");
     sqf->setChecked( Settings::showQuickFilter() );
 
-    new KAction( i18n("Open in Tab"), "tab_new", "Shift+Return", d->view, TQT_SLOT(slotOpenCurrentArticle()), actionCollection(), "article_open" );
-    new KAction( i18n("Open in Background Tab"), TQString::null, "tab_new", d->view, TQT_SLOT(slotOpenCurrentArticleBackgroundTab()), actionCollection(), "article_open_background_tab" );
-    new KAction( i18n("Open in External Browser"), "window_new", "Ctrl+Shift+Return", d->view, TQT_SLOT(slotOpenCurrentArticleExternal()), actionCollection(), "article_open_external" );
-    new KAction( i18n("Copy Link Address"), TQString::null, TQString::null, d->view, TQT_SLOT(slotCopyLinkAddress()), actionCollection(), "article_copy_link_address" );
+    new KAction( i18n("Open in Tab"), "tab_new", "Shift+Return", TQT_TQOBJECT(d->view), TQT_SLOT(slotOpenCurrentArticle()), actionCollection(), "article_open" );
+    new KAction( i18n("Open in Background Tab"), TQString(), "tab_new", TQT_TQOBJECT(d->view), TQT_SLOT(slotOpenCurrentArticleBackgroundTab()), actionCollection(), "article_open_background_tab" );
+    new KAction( i18n("Open in External Browser"), "window_new", "Ctrl+Shift+Return", TQT_TQOBJECT(d->view), TQT_SLOT(slotOpenCurrentArticleExternal()), actionCollection(), "article_open_external" );
+    new KAction( i18n("Copy Link Address"), TQString(), TQString(), TQT_TQOBJECT(d->view), TQT_SLOT(slotCopyLinkAddress()), actionCollection(), "article_copy_link_address" );
 
-    new KAction(i18n("Pre&vious Unread Article"), "", Key_Minus, d->view, TQT_SLOT(slotPrevUnreadArticle()),actionCollection(), "go_prev_unread_article");
-    new KAction(i18n("Ne&xt Unread Article"), "", Key_Plus, d->view, TQT_SLOT(slotNextUnreadArticle()),actionCollection(), "go_next_unread_article");
+    new KAction(i18n("Pre&vious Unread Article"), "", Key_Minus, TQT_TQOBJECT(d->view), TQT_SLOT(slotPrevUnreadArticle()),actionCollection(), "go_prev_unread_article");
+    new KAction(i18n("Ne&xt Unread Article"), "", Key_Plus, TQT_TQOBJECT(d->view), TQT_SLOT(slotNextUnreadArticle()),actionCollection(), "go_next_unread_article");
 
-    new KAction(i18n("&Delete"), "editdelete", "Delete", d->view, TQT_SLOT(slotArticleDelete()), actionCollection(), "article_delete");
+    new KAction(i18n("&Delete"), "editdelete", "Delete", TQT_TQOBJECT(d->view), TQT_SLOT(slotArticleDelete()), actionCollection(), "article_delete");
 
     if (Settings::showTaggingGUI())
     {
@@ -335,7 +335,7 @@ void ActionManagerImpl::initView(View* view)
     KActionMenu* statusMenu = new KActionMenu ( i18n( "&Mark As" ),
                                     actionCollection(), "article_set_status" );
 
-    d->speakSelectedArticlesAction = new KAction(i18n("&Speak Selected Articles"), "kttsd", "", d->view, TQT_SLOT(slotTextToSpeechRequest()), actionCollection(), "akr_texttospeech");
+    d->speakSelectedArticlesAction = new KAction(i18n("&Speak Selected Articles"), "kttsd", "", TQT_TQOBJECT(d->view), TQT_SLOT(slotTextToSpeechRequest()), actionCollection(), "akr_texttospeech");
 
     KAction* abortTTS = new KAction(i18n( "&Stop Speaking" ), "player_stop", Key_Escape, SpeechClient::self(), TQT_SLOT(slotAbortJobs()), actionCollection(), "akr_aborttexttospeech");
     abortTTS->setEnabled(false);
@@ -345,29 +345,29 @@ void ActionManagerImpl::initView(View* view)
 
     statusMenu->insert(new KAction(KGuiItem(i18n("as in: mark as read","&Read"), "",
                        i18n("Mark selected article as read")),
-    "Ctrl+E", d->view, TQT_SLOT(slotSetSelectedArticleRead()),
+    "Ctrl+E", TQT_TQOBJECT(d->view), TQT_SLOT(slotSetSelectedArticleRead()),
     actionCollection(), "article_set_status_read"));
 
     statusMenu->insert(new KAction(KGuiItem(i18n("&New"), "",
                         i18n("Mark selected article as new")),
-    "Ctrl+N", d->view, TQT_SLOT(slotSetSelectedArticleNew()),
+    "Ctrl+N", TQT_TQOBJECT(d->view), TQT_SLOT(slotSetSelectedArticleNew()),
     actionCollection(), "article_set_status_new" ));
 
 
     statusMenu->insert(new KAction(KGuiItem(i18n("&Unread"), "",
                        i18n("Mark selected article as unread")),
-    "Ctrl+U", d->view, TQT_SLOT(slotSetSelectedArticleUnread()),
+    "Ctrl+U", TQT_TQOBJECT(d->view), TQT_SLOT(slotSetSelectedArticleUnread()),
     actionCollection(), "article_set_status_unread"));
 
     KToggleAction* importantAction = new KToggleAction(i18n("&Mark as Important"), "flag", "Ctrl+I", actionCollection(), "article_set_status_important");
     importantAction->setCheckedState(i18n("Remove &Important Mark"));
-    connect(importantAction, TQT_SIGNAL(toggled(bool)), d->view, TQT_SLOT(slotArticleToggleKeepFlag(bool)));
+    connect(importantAction, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(d->view), TQT_SLOT(slotArticleToggleKeepFlag(bool)));
 
 
-    new KAction( i18n("Move Node Up"), TQString::null, "Shift+Alt+Up", view, TQT_SLOT(slotMoveCurrentNodeUp()), d->actionCollection, "feedstree_move_up" );
-    new KAction( i18n("Move Node Down"), TQString::null,  "Shift+Alt+Down", view, TQT_SLOT(slotMoveCurrentNodeDown()), d->actionCollection, "feedstree_move_down" );
-    new KAction( i18n("Move Node Left"), TQString::null, "Shift+Alt+Left", view, TQT_SLOT(slotMoveCurrentNodeLeft()), d->actionCollection, "feedstree_move_left" );
-    new KAction( i18n("Move Node Right"), TQString::null, "Shift+Alt+Right", view, TQT_SLOT(slotMoveCurrentNodeRight()), d->actionCollection, "feedstree_move_right");
+    new KAction( i18n("Move Node Up"), TQString(), "Shift+Alt+Up", TQT_TQOBJECT(view), TQT_SLOT(slotMoveCurrentNodeUp()), d->actionCollection, "feedstree_move_up" );
+    new KAction( i18n("Move Node Down"), TQString(),  "Shift+Alt+Down", TQT_TQOBJECT(view), TQT_SLOT(slotMoveCurrentNodeDown()), d->actionCollection, "feedstree_move_down" );
+    new KAction( i18n("Move Node Left"), TQString(), "Shift+Alt+Left", TQT_TQOBJECT(view), TQT_SLOT(slotMoveCurrentNodeLeft()), d->actionCollection, "feedstree_move_left" );
+    new KAction( i18n("Move Node Right"), TQString(), "Shift+Alt+Right", TQT_TQOBJECT(view), TQT_SLOT(slotMoveCurrentNodeRight()), d->actionCollection, "feedstree_move_right");
 }
 
 void ActionManagerImpl::initArticleViewer(ArticleViewer* articleViewer)
@@ -385,8 +385,8 @@ void ActionManagerImpl::initArticleListView(ArticleListView* articleList)
     else
         d->articleList = articleList;
 
-    new KAction( i18n("&Previous Article"), TQString::null, "Left", articleList, TQT_SLOT(slotPreviousArticle()), actionCollection(), "go_previous_article" );
-    new KAction( i18n("&Next Article"), TQString::null, "Right", articleList, TQT_SLOT(slotNextArticle()), actionCollection(), "go_next_article" );
+    new KAction( i18n("&Previous Article"), TQString(), "Left", TQT_TQOBJECT(articleList), TQT_SLOT(slotPreviousArticle()), actionCollection(), "go_previous_article" );
+    new KAction( i18n("&Next Article"), TQString(), "Right", TQT_TQOBJECT(articleList), TQT_SLOT(slotNextArticle()), actionCollection(), "go_next_article" );
 }
 
 void ActionManagerImpl::initListTabWidget(ListTabWidget* listTabWidget)
@@ -396,17 +396,17 @@ void ActionManagerImpl::initListTabWidget(ListTabWidget* listTabWidget)
     else
         d->listTabWidget = listTabWidget;
 
-    new KAction(i18n("&Previous Feed"), "", "P", listTabWidget,  TQT_SLOT(slotPrevFeed()),actionCollection(), "go_prev_feed");
-    new KAction(i18n("&Next Feed"), "", "N", listTabWidget, TQT_SLOT(slotNextFeed()),actionCollection(), "go_next_feed");
-    new KAction(i18n("N&ext Unread Feed"), "", "Alt+Plus", listTabWidget, TQT_SLOT(slotNextUnreadFeed()),actionCollection(), "go_next_unread_feed");
-    new KAction(i18n("Prev&ious Unread Feed"), "", "Alt+Minus", listTabWidget, TQT_SLOT(slotPrevUnreadFeed()),actionCollection(), "go_prev_unread_feed");
+    new KAction(i18n("&Previous Feed"), "", "P", TQT_TQOBJECT(listTabWidget),  TQT_SLOT(slotPrevFeed()),actionCollection(), "go_prev_feed");
+    new KAction(i18n("&Next Feed"), "", "N", TQT_TQOBJECT(listTabWidget), TQT_SLOT(slotNextFeed()),actionCollection(), "go_next_feed");
+    new KAction(i18n("N&ext Unread Feed"), "", "Alt+Plus", TQT_TQOBJECT(listTabWidget), TQT_SLOT(slotNextUnreadFeed()),actionCollection(), "go_next_unread_feed");
+    new KAction(i18n("Prev&ious Unread Feed"), "", "Alt+Minus", TQT_TQOBJECT(listTabWidget), TQT_SLOT(slotPrevUnreadFeed()),actionCollection(), "go_prev_unread_feed");
 
-    new KAction( i18n("Go to Top of Tree"), TQString::null, "Ctrl+Home", listTabWidget, TQT_SLOT(slotItemBegin()), d->actionCollection, "feedstree_home" );
-    new KAction( i18n("Go to Bottom of Tree"), TQString::null, "Ctrl+End", listTabWidget, TQT_SLOT(slotItemEnd()), d->actionCollection, "feedstree_end" );
-    new KAction( i18n("Go Left in Tree"), TQString::null, "Ctrl+Left", listTabWidget, TQT_SLOT(slotItemLeft()), d->actionCollection, "feedstree_left" );
-    new KAction( i18n("Go Right in Tree"), TQString::null, "Ctrl+Right", listTabWidget, TQT_SLOT(slotItemRight()), d->actionCollection, "feedstree_right" );
-    new KAction( i18n("Go Up in Tree"), TQString::null, "Ctrl+Up", listTabWidget, TQT_SLOT(slotItemUp()), d->actionCollection, "feedstree_up" );
-    new KAction( i18n("Go Down in Tree"), TQString::null, "Ctrl+Down", listTabWidget, TQT_SLOT(slotItemDown()), d->actionCollection, "feedstree_down" );
+    new KAction( i18n("Go to Top of Tree"), TQString(), "Ctrl+Home", TQT_TQOBJECT(listTabWidget), TQT_SLOT(slotItemBegin()), d->actionCollection, "feedstree_home" );
+    new KAction( i18n("Go to Bottom of Tree"), TQString(), "Ctrl+End", TQT_TQOBJECT(listTabWidget), TQT_SLOT(slotItemEnd()), d->actionCollection, "feedstree_end" );
+    new KAction( i18n("Go Left in Tree"), TQString(), "Ctrl+Left", TQT_TQOBJECT(listTabWidget), TQT_SLOT(slotItemLeft()), d->actionCollection, "feedstree_left" );
+    new KAction( i18n("Go Right in Tree"), TQString(), "Ctrl+Right", TQT_TQOBJECT(listTabWidget), TQT_SLOT(slotItemRight()), d->actionCollection, "feedstree_right" );
+    new KAction( i18n("Go Up in Tree"), TQString(), "Ctrl+Up", TQT_TQOBJECT(listTabWidget), TQT_SLOT(slotItemUp()), d->actionCollection, "feedstree_up" );
+    new KAction( i18n("Go Down in Tree"), TQString(), "Ctrl+Down", TQT_TQOBJECT(listTabWidget), TQT_SLOT(slotItemDown()), d->actionCollection, "feedstree_down" );
 }
 
 void ActionManagerImpl::initTabWidget(TabWidget* tabWidget)
@@ -416,11 +416,11 @@ void ActionManagerImpl::initTabWidget(TabWidget* tabWidget)
     else
         d->tabWidget = tabWidget;
 
-    new KAction(i18n("Select Next Tab"), "", "Ctrl+Period", d->tabWidget, TQT_SLOT(slotNextTab()),actionCollection(), "select_next_tab");
-    new KAction(i18n("Select Previous Tab"), "", "Ctrl+Comma", d->tabWidget, TQT_SLOT(slotPreviousTab()),actionCollection(), "select_previous_tab");
-    new KAction( i18n("Detach Tab"), "tab_breakoff", CTRL+SHIFT+Key_B, d->tabWidget, TQT_SLOT(slotDetachTab()), actionCollection(), "tab_detach" );
-    new KAction( i18n("Copy Link Address"), TQString::null, TQString::null, d->tabWidget, TQT_SLOT(slotCopyLinkAddress()), actionCollection(), "tab_copylinkaddress" );
-    new KAction( i18n("&Close Tab"), "tab_remove", KStdAccel::close(), d->tabWidget, TQT_SLOT(slotCloseTab()), actionCollection(), "tab_remove" );
+    new KAction(i18n("Select Next Tab"), "", "Ctrl+Period", TQT_TQOBJECT(d->tabWidget), TQT_SLOT(slotNextTab()),actionCollection(), "select_next_tab");
+    new KAction(i18n("Select Previous Tab"), "", "Ctrl+Comma", TQT_TQOBJECT(d->tabWidget), TQT_SLOT(slotPreviousTab()),actionCollection(), "select_previous_tab");
+    new KAction( i18n("Detach Tab"), "tab_breakoff", CTRL+SHIFT+Key_B, TQT_TQOBJECT(d->tabWidget), TQT_SLOT(slotDetachTab()), actionCollection(), "tab_detach" );
+    new KAction( i18n("Copy Link Address"), TQString(), TQString(), TQT_TQOBJECT(d->tabWidget), TQT_SLOT(slotCopyLinkAddress()), actionCollection(), "tab_copylinkaddress" );
+    new KAction( i18n("&Close Tab"), "tab_remove", KStdAccel::close(), TQT_TQOBJECT(d->tabWidget), TQT_SLOT(slotCloseTab()), actionCollection(), "tab_remove" );
 }
 
 TQWidget* ActionManagerImpl::container(const char* name)
