@@ -19,8 +19,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 #include <dcopclient.h>
 #include <kaboutdata.h>
@@ -54,7 +54,7 @@
 #include <tqstringlist.h>
 #include <tqtimer.h>
 #include <tqwidgetlist.h>
-#include <private/qucomextra_p.h>
+#include <tqucomextra_p.h>
 
 #include <cerrno>
 #include <sys/types.h>
@@ -146,7 +146,7 @@ Part::Part( TQWidget *parentWidget, const char * /*widgetName*/,
    
     TQStringList storageParams;
     
-    storageParams.append(TQString("taggingEnabled=%1").arg(Settings::showTaggingGUI() ? "true" : "false"));
+    storageParams.append(TQString("taggingEnabled=%1").tqarg(Settings::showTaggingGUI() ? "true" : "false"));
     
     if (factory != 0)
     {
@@ -168,7 +168,7 @@ Part::Part( TQWidget *parentWidget, const char * /*widgetName*/,
     {
         m_storage = Backend::StorageFactoryRegistry::self()->getFactory("dummy")->createStorage(storageParams);
 
-        KMessageBox::error(parentWidget, i18n("Unable to load storage backend plugin \"%1\". No feeds are archived.").arg(Settings::archiveBackend()), i18n("Plugin error") );
+        KMessageBox::error(parentWidget, i18n("Unable to load storage backend plugin \"%1\". No feeds are archived.").tqarg(Settings::archiveBackend()), i18n("Plugin error") );
     }
 
     Filters::ArticleFilterList list;
@@ -194,7 +194,7 @@ Part::Part( TQWidget *parentWidget, const char * /*widgetName*/,
     m_extension = new BrowserExtension(this, "ak_extension");
 
     connect(m_view, TQT_SIGNAL(setWindowCaption(const TQString&)), this, TQT_SIGNAL(setWindowCaption(const TQString&)));
-    connect(m_view, TQT_SIGNAL(setStatusBarText(const TQString&)), this, TQT_SIGNAL(setStatusBarText(const TQString&)));
+    connect(m_view, TQT_SIGNAL(seStatusBarText(const TQString&)), this, TQT_SIGNAL(seStatusBarText(const TQString&)));
     connect(m_view, TQT_SIGNAL(setProgress(int)), m_extension, TQT_SIGNAL(loadingProgress(int)));
     connect(m_view, TQT_SIGNAL(signalCanceled(const TQString&)), this, TQT_SIGNAL(canceled(const TQString&)));
     connect(m_view, TQT_SIGNAL(signalStarted(KIO::Job*)), this, TQT_SIGNAL(started(KIO::Job*)));
@@ -232,7 +232,7 @@ Part::Part( TQWidget *parentWidget, const char * /*widgetName*/,
 
     initFonts();
 
-    RSS::FileRetriever::setUserAgent(TQString("Akregator/%1; librss/remnants").arg(AKREGATOR_VERSION));
+    RSS::FileRetriever::setUserAgent(TQString("Akregator/%1; librss/remnants").tqarg(AKREGATOR_VERSION));
 }
 
 void Part::loadPlugins()
@@ -416,7 +416,7 @@ bool Part::openFile()
     {
         if (file.open(IO_ReadOnly))
         {
-            // Read OPML feeds list and build QDom tree.
+            // Read OPML feeds list and build TQDom tree.
             TQTextStream stream(&file);
             stream.setEncoding(TQTextStream::UnicodeUTF8); // FIXME not all opmls are in utf8
             str = stream.read();
@@ -428,11 +428,11 @@ bool Part::openFile()
 
             if (file.size() > 0) // don't backup empty files 
             {
-                TQString backup = m_file + "-backup." +  TQString::number(TQDateTime::currentDateTime().toTime_t());
+                TQString backup = m_file + "-backup." +  TQString::number(TQDateTime::tqcurrentDateTime().toTime_t());
         
                 copyFile(backup);
         
-                KMessageBox::error(m_view, i18n("<qt>The standard feed list is corrupted (invalid XML). A backup was created:<p><b>%2</b></p></qt>").arg(backup), i18n("XML Parsing Error") );
+                KMessageBox::error(m_view, i18n("<qt>The standard feed list is corrupted (invalid XML). A backup was created:<p><b>%2</b></p></qt>").tqarg(backup), i18n("XML Parsing Error") );
             }
 
             if (!doc.setContent(listBackup))
@@ -444,15 +444,15 @@ bool Part::openFile()
     {
         if (file.size() > 0) // don't backup empty files 
         {
-            TQString backup = m_file + "-backup." +  TQString::number(TQDateTime::currentDateTime().toTime_t());
+            TQString backup = m_file + "-backup." +  TQString::number(TQDateTime::tqcurrentDateTime().toTime_t());
             copyFile(backup);
 
-            KMessageBox::error(m_view, i18n("<qt>The standard feed list is corrupted (no valid OPML). A backup was created:<p><b>%2</b></p></qt>").arg(backup), i18n("OPML Parsing Error") );
+            KMessageBox::error(m_view, i18n("<qt>The standard feed list is corrupted (no valid OPML). A backup was created:<p><b>%2</b></p></qt>").tqarg(backup), i18n("OPML Parsing Error") );
         }
         m_view->loadFeeds(createDefaultFeedList());
     }
 
-    emit setStatusBarText(TQString::null);
+    emit setStatusBarText(TQString());
     
 
     if( Settings::markAllFeedsReadOnStartup() )
@@ -486,7 +486,7 @@ void Part::slotSaveFeedList()
     if (file.open(IO_WriteOnly) == false)
     {
         //FIXME: allow to save the feedlist into different location -tpr 20041118
-        KMessageBox::error(m_view, i18n("Access denied: cannot save feed list (%1)").arg(m_file), i18n("Write error") );
+        KMessageBox::error(m_view, i18n("Access denied: cannot save feed list (%1)").tqarg(m_file), i18n("Write error") );
         return;
     }
 
@@ -538,7 +538,7 @@ TQWidget* Part::getMainWindow()
 {
     // this is a dirty fix to get the main window used for the tray icon
     
-    TQWidgetList *l = kapp->topLevelWidgets();
+    TQWidgetList *l = kapp->tqtopLevelWidgets();
     TQWidgetListIt it( *l );
     TQWidget *wid;
 
@@ -575,7 +575,7 @@ void Part::loadTagSet(const TQString& path)
     TQFile file(path);
     if (file.open(IO_ReadOnly))
     {
-        doc.setContent(file.readAll());
+        doc.setContent(TQByteArray(file.readAll()));
         file.close();
     }
     // if we can't load the tagset from the xml file, check for the backup in the backend
@@ -634,15 +634,15 @@ void Part::importFile(const KURL& url)
     TQFile file(filename);
     if (file.open(IO_ReadOnly))
     {
-        // Read OPML feeds list and build QDom tree.
+        // Read OPML feeds list and build TQDom tree.
         TQDomDocument doc;
-        if (doc.setContent(file.readAll()))
+        if (doc.setContent(TQByteArray(file.readAll())))
             m_view->importFeeds(doc);
         else
-            KMessageBox::error(m_view, i18n("Could not import the file %1 (no valid OPML)").arg(filename), i18n("OPML Parsing Error") );
+            KMessageBox::error(m_view, i18n("Could not import the file %1 (no valid OPML)").tqarg(filename), i18n("OPML Parsing Error") );
     }
     else
-        KMessageBox::error(m_view, i18n("The file %1 could not be read, check if it exists or if it is readable for the current user.").arg(filename), i18n("Read Error"));
+        KMessageBox::error(m_view, i18n("The file %1 could not be read, check if it exists or if it is readable for the current user.").tqarg(filename), i18n("Read Error"));
 
     if (isRemote)
         KIO::NetAccess::removeTempFile(filename);
@@ -656,7 +656,7 @@ void Part::exportFile(const KURL& url)
 
         if ( file.exists() &&
                 KMessageBox::questionYesNo(m_view,
-            i18n("The file %1 already exists; do you want to overwrite it?").arg(file.name()),
+            i18n("The file %1 already exists; do you want to overwrite it?").tqarg(file.name()),
             i18n("Export"),
             i18n("Overwrite"),
             KStdGuiItem::cancel()) == KMessageBox::No )
@@ -664,7 +664,7 @@ void Part::exportFile(const KURL& url)
 
         if ( !file.open(IO_WriteOnly) )
         {
-            KMessageBox::error(m_view, i18n("Access denied: cannot write to file %1").arg(file.name()), i18n("Write Error") );
+            KMessageBox::error(m_view, i18n("Access denied: cannot write to file %1").tqarg(file.name()), i18n("Write Error") );
             return;
         }
 
@@ -692,7 +692,7 @@ void Part::exportFile(const KURL& url)
 
 void Part::fileImport()
 {
-    KURL url = KFileDialog::getOpenURL( TQString::null,
+    KURL url = KFileDialog::getOpenURL( TQString(),
                         "*.opml *.xml|" + i18n("OPML Outlines (*.opml, *.xml)")
                         +"\n*|" + i18n("All Files") );
 
@@ -702,7 +702,7 @@ void Part::fileImport()
 
     void Part::fileExport()
 {
-    KURL url= KFileDialog::getSaveURL( TQString::null,
+    KURL url= KFileDialog::getSaveURL( TQString(),
                         "*.opml *.xml|" + i18n("OPML Outlines (*.opml, *.xml)")
                         +"\n*|" + i18n("All Files") );
 
@@ -978,11 +978,11 @@ bool Part::tryToLock(const TQString& backendName)
                         "can cause the loss of archived articles and crashes at startup.</b> "
                         "You should disable the archive for now "
                         "unless you are sure that %2 is not already running.</qt>")
-                        .arg( programName, programName, backendName );
+                        .tqarg( programName, programName, backendName );
               // TQString::arg( st ) only replaces the first occurrence of %1
               // with st while TQString::arg( s1, s2 ) replacess all occurrences
               // of %1 with s1 and all occurrences of %2 with s2. So don't
-              // even think about changing the above to .arg( programName ).
+              // even think about changing the above to .tqarg( programName ).
             else
                 msg = i18n("<qt>%1 seems to be running on another display on this "
                         "machine. <b>Running %1 and %2 at the same "
@@ -990,7 +990,7 @@ bool Part::tryToLock(const TQString& backendName)
                         "the loss of archived articles and crashes at startup.</b> "
                         "You should disable the archive for now "
                         "unless you are sure that %2 is not already running.</qt>")
-                        .arg( oldProgramName, programName, backendName );
+                        .tqarg( oldProgramName, programName, backendName );
         }
         else
         {
@@ -1001,7 +1001,7 @@ bool Part::tryToLock(const TQString& backendName)
                         "You should disable the archive for now "
                         "unless you are sure that it is "
                         "not already running on %2.</qt>")
-                        .arg( programName, oldHostName, backendName );
+                        .tqarg( programName, oldHostName, backendName );
             else
                 msg = i18n("<qt>%1 seems to be running on %3. <b>Running %1 and %2 at the "
                         "same time is not supported by the %4 backend and can cause "
@@ -1009,12 +1009,12 @@ bool Part::tryToLock(const TQString& backendName)
                         "You should disable the archive for now "
                         "unless you are sure that %1 is "
                         "not running on %3.</qt>")
-                        .arg( oldProgramName, programName, oldHostName, backendName );
+                        .tqarg( oldProgramName, programName, oldHostName, backendName );
         }
 
         KCursorSaver idle( KBusyPtr::idle() );
         if ( KMessageBox::No ==
-             KMessageBox::warningYesNo( 0, msg, TQString::null,
+             KMessageBox::warningYesNo( 0, msg, TQString(),
                                         i18n("Force Access"),
                                         i18n("Disable Archive")) )
                                         {
