@@ -20,8 +20,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #include "actionmanagerimpl.h"
@@ -145,7 +145,7 @@ class View::DeleteNodeVisitor : public TreeNodeVisitor
 
         virtual bool visitTagNode(TagNode* node)
         {
-            TQString msg = i18n("<qt>Are you sure you want to delete tag <b>%1</b>? The tag will be removed from all articles.</qt>").arg(node->title());
+            TQString msg = i18n("<qt>Are you sure you want to delete tag <b>%1</b>? The tag will be removed from all articles.</qt>").tqarg(node->title());
             if (KMessageBox::warningContinueCancel(0, msg, i18n("Delete Tag"), KStdGuiItem::del()) == KMessageBox::Continue)
             {
                 Tag tag = node->tag();
@@ -166,7 +166,7 @@ class View::DeleteNodeVisitor : public TreeNodeVisitor
             if (node->title().isEmpty())
                 msg = i18n("<qt>Are you sure you want to delete this folder and its feeds and subfolders?</qt>");
             else
-                msg = i18n("<qt>Are you sure you want to delete folder <b>%1</b> and its feeds and subfolders?</qt>").arg(node->title());
+                msg = i18n("<qt>Are you sure you want to delete folder <b>%1</b> and its feeds and subfolders?</qt>").tqarg(node->title());
 
             if (KMessageBox::warningContinueCancel(0, msg, i18n("Delete Folder"), KStdGuiItem::del()) == KMessageBox::Continue)
             {
@@ -182,7 +182,7 @@ class View::DeleteNodeVisitor : public TreeNodeVisitor
             if (node->title().isEmpty())
                 msg = i18n("<qt>Are you sure you want to delete this feed?</qt>");
             else
-                msg = i18n("<qt>Are you sure you want to delete feed <b>%1</b>?</qt>").arg(node->title());
+                msg = i18n("<qt>Are you sure you want to delete feed <b>%1</b>?</qt>").tqarg(node->title());
 
             if (KMessageBox::warningContinueCancel(0, msg, i18n("Delete Feed"), KStdGuiItem::del()) == KMessageBox::Continue)
             {
@@ -222,11 +222,11 @@ View::View( Part *part, TQWidget *parent, ActionManagerImpl* actionManager, cons
     m_shuttingDown = false;
     m_displayingAboutPage = false;
     m_currentFrame = 0L;
-    setFocusPolicy(TQWidget::StrongFocus);
+    setFocusPolicy(TQ_StrongFocus);
 
     TQVBoxLayout *lt = new TQVBoxLayout( this );
 
-    m_horizontalSplitter = new TQSplitter(TQSplitter::Horizontal, this);
+    m_horizontalSplitter = new TQSplitter(Qt::Horizontal, this);
 
     m_horizontalSplitter->setOpaqueResize(true);
     lt->addWidget(m_horizontalSplitter);
@@ -285,7 +285,7 @@ View::View( Part *part, TQWidget *parent, ActionManagerImpl* actionManager, cons
 
     mainTabLayout->addWidget(m_searchBar);
 
-    m_articleSplitter = new TQSplitter(TQSplitter::Vertical, m_mainTab, "panner2");
+    m_articleSplitter = new TQSplitter(Qt::Vertical, m_mainTab, "panner2");
 
     m_articleList = new ArticleListView( m_articleSplitter, "articles" );
     m_actionManager->initArticleListView(m_articleList);
@@ -317,7 +317,7 @@ View::View( Part *part, TQWidget *parent, ActionManagerImpl* actionManager, cons
     TQWhatsThis::add(m_articleViewer->widget(), i18n("Browsing area."));
     mainTabLayout->addWidget( m_articleSplitter );
 
-    m_mainFrame=new Frame(this, m_part, m_mainTab, i18n("Articles"), false);
+    m_mainFrame=new Frame(TQT_TQOBJECT(this), m_part, m_mainTab, i18n("Articles"), false);
     connectFrame(m_mainFrame);
     m_tabs->addFrame(m_mainFrame);
 
@@ -366,7 +366,7 @@ View::View( Part *part, TQWidget *parent, ActionManagerImpl* actionManager, cons
 
     if (!Settings::resetQuickFilterOnNodeChange())
     {
-        m_searchBar->slotSetStatus(Settings::statusFilter());
+        m_searchBar->slotSetqStatus(Settings::statusFilter());
         m_searchBar->slotSetText(Settings::textFilter());
     }
 
@@ -431,7 +431,7 @@ void View::slotOpenNewTab(const KURL& url, bool background)
     connect( page, TQT_SIGNAL(urlClicked(const KURL &, Viewer*, bool, bool)),
             this, TQT_SLOT(slotUrlClickedInViewer(const KURL &, Viewer*, bool, bool)) );
 
-    Frame* frame = new Frame(this, page, page->widget(), i18n("Untitled"));
+    Frame* frame = new Frame(TQT_TQOBJECT(this), page, page->widget(), i18n("Untitled"));
     frame->setAutoDeletePart(true); // delete page viewer when removing the tab
 
     connect(page, TQT_SIGNAL(setWindowCaption (const TQString &)), frame, TQT_SLOT(setTitle (const TQString &)));
@@ -457,7 +457,7 @@ void View::setTabIcon(const TQPixmap& icon)
 
 void View::connectFrame(Frame *f)
 {
-    connect(f, TQT_SIGNAL(statusText(const TQString &)), this, TQT_SLOT(slotStatusText(const TQString&)));
+    connect(f, TQT_SIGNAL(statusText(const TQString &)), this, TQT_SLOT(sloStatusText(const TQString&)));
     connect(f, TQT_SIGNAL(captionChanged (const TQString &)), this, TQT_SLOT(slotCaptionChanged (const TQString &)));
     connect(f, TQT_SIGNAL(loadingProgress(int)), this, TQT_SLOT(slotLoadingProgress(int)) );
     connect(f, TQT_SIGNAL(started()), this, TQT_SLOT(slotStarted()));
@@ -465,10 +465,10 @@ void View::connectFrame(Frame *f)
     connect(f, TQT_SIGNAL(canceled(const TQString &)), this, TQT_SLOT(slotCanceled(const TQString&)));
 }
 
-void View::slotStatusText(const TQString &c)
+void View::sloStatusText(const TQString &c)
 {
     if (sender() == m_currentFrame)
-        emit setStatusBarText(c);
+        emit seStatusBarText(c);
 }
 
 void View::slotCaptionChanged(const TQString &c)
@@ -638,7 +638,7 @@ void View::slotNormalView()
             m_articleViewer->slotShowSummary(m_listTabWidget->activeView()->selectedNode());
     }
 
-    m_articleSplitter->setOrientation(TQSplitter::Vertical);
+    m_articleSplitter->setOrientation(Qt::Vertical);
     m_viewMode = NormalView;
 
     Settings::setViewMode( m_viewMode );
@@ -662,7 +662,7 @@ void View::slotWidescreenView()
             m_articleViewer->slotShowSummary(m_listTabWidget->activeView()->selectedNode());
     }
 
-    m_articleSplitter->setOrientation(TQSplitter::Horizontal);
+    m_articleSplitter->setOrientation(Qt::Horizontal);
     m_viewMode = WidescreenView;
 
     Settings::setViewMode( m_viewMode );
@@ -690,7 +690,7 @@ void View::slotFrameChanged(Frame *f)
 
     emit setWindowCaption(f->caption());
     emit setProgress(f->progress());
-    emit setStatusBarText(f->statusText());
+    emit seStatusBarText(f->statusText());
 
     if (f->part() == m_part)
         m_part->mergePart(m_articleViewer);
@@ -705,7 +705,7 @@ void View::slotFrameChanged(Frame *f)
             emit signalStarted(0);
             break;
         case Frame::Canceled:
-            emit signalCanceled(TQString::null);
+            emit signalCanceled(TQString());
             break;
         case Frame::Idle:
         case Frame::Completed:
@@ -884,9 +884,9 @@ void View::slotFeedAdd()
 
     }
 
-    TreeNode* lastChild = group->children().last();
+    TreeNode* lastChild = group->tqchildren().last();
 
-    addFeed(TQString::null, lastChild, group, false);
+    addFeed(TQString(), lastChild, group, false);
 }
 
 void View::addFeed(const TQString& url, TreeNode *after, Folder* parent, bool autoExec)
@@ -1070,14 +1070,14 @@ void View::slotFetchingStarted()
 {
     m_mainFrame->setState(Frame::Started);
     m_actionManager->action("feed_stop")->setEnabled(true);
-    m_mainFrame->setStatusText(i18n("Fetching Feeds..."));
+    m_mainFrame->seStatusText(i18n("Fetching Feeds..."));
 }
 
 void View::slotFetchingStopped()
 {
     m_mainFrame->setState(Frame::Completed);
     m_actionManager->action("feed_stop")->setEnabled(false);
-    m_mainFrame->setStatusText(TQString::null);
+    m_mainFrame->seStatusText(TQString());
 }
 
 void View::slotFeedFetched(Feed *feed)
@@ -1186,7 +1186,7 @@ void View::slotArticleSelected(const Article& article)
             if (delay > 0)
                 m_markReadTimer->start( delay*1000, true );
             else
-                a.setStatus(Article::Read);
+                a.setqStatus(Article::Read);
         }
     }
 
@@ -1266,9 +1266,9 @@ void View::slotCopyLinkAddress()
             link = article.link().url();
         else
             link = article.guid();
-        QClipboard *cb = TQApplication::clipboard();
-        cb->setText(link, QClipboard::Clipboard);
-        cb->setText(link, QClipboard::Selection);
+        TQClipboard *cb = TQApplication::tqclipboard();
+        cb->setText(link, TQClipboard::Clipboard);
+        cb->setText(link, TQClipboard::Selection);
     }
 }
 
@@ -1312,7 +1312,7 @@ void View::slotArticleDelete()
         case 0:
             return;
         case 1:
-            msg = i18n("<qt>Are you sure you want to delete article <b>%1</b>?</qt>").arg(TQStyleSheet::escape(articles.first().title()));
+            msg = i18n("<qt>Are you sure you want to delete article <b>%1</b>?</qt>").tqarg(TQStyleSheet::escape(articles.first().title()));
             break;
         default:
             msg = i18n("<qt>Are you sure you want to delete the selected article?</qt>",
@@ -1370,7 +1370,7 @@ void View::slotSetSelectedArticleRead()
         return;
 
     for (TQValueList<Article>::Iterator it = articles.begin(); it != articles.end(); ++it)
-        (*it).setStatus(Article::Read);
+        (*it).setqStatus(Article::Read);
 }
 
 void View::slotTextToSpeechRequest()
@@ -1408,7 +1408,7 @@ void View::slotSetSelectedArticleUnread()
         return;
 
     for (TQValueList<Article>::Iterator it = articles.begin(); it != articles.end(); ++it)
-        (*it).setStatus(Article::Unread);
+        (*it).setqStatus(Article::Unread);
 }
 
 void View::slotSetSelectedArticleNew()
@@ -1419,7 +1419,7 @@ void View::slotSetSelectedArticleNew()
         return;
 
     for (TQValueList<Article>::Iterator it = articles.begin(); it != articles.end(); ++it)
-        (*it).setStatus(Article::New);
+        (*it).setqStatus(Article::New);
 }
 
 void View::slotSetCurrentArticleReadDelayed()
@@ -1429,7 +1429,7 @@ void View::slotSetCurrentArticleReadDelayed()
     if (article.isNull())
         return;
 
-    article.setStatus(Article::Read);
+    article.setqStatus(Article::Read);
 }
 
 void View::slotMouseOverInfo(const KFileItem *kifi)
@@ -1437,11 +1437,11 @@ void View::slotMouseOverInfo(const KFileItem *kifi)
     if (kifi)
     {
         KFileItem *k=(KFileItem*)kifi;
-        m_mainFrame->setStatusText(k->url().prettyURL());//getStatusBarInfo());
+        m_mainFrame->seStatusText(k->url().prettyURL());//geStatusBarInfo());
     }
     else
     {
-        m_mainFrame->setStatusText(TQString::null);
+        m_mainFrame->seStatusText(TQString());
     }
 }
 
@@ -1453,7 +1453,7 @@ void View::readProperties(KConfig* config)
         m_searchBar->slotSetText(config->readEntry("searchLine"));
         int statusfilter = config->readNumEntry("searchCombo", -1);
         if (statusfilter != -1)
-            m_searchBar->slotSetStatus(statusfilter);
+            m_searchBar->slotSetqStatus(statusfilter);
     }
 
     int selectedID = config->readNumEntry("selectedNodeID", -1);
