@@ -17,7 +17,7 @@
  * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
  * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
  * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSETQUENTIAL DAMAGES (INCLUDING, BUT
  * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
  * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
  * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
@@ -43,35 +43,35 @@ TQString Criterion::subjectToString(Subject subj)
     switch (subj)
     {
         case Title:
-            return TQString::fromLatin1("Title");
+            return TQString::tqfromLatin1("Title");
         case Link:
-            return TQString::fromLatin1("Link");
+            return TQString::tqfromLatin1("Link");
         case Author:
-            return TQString::fromLatin1("Author");
+            return TQString::tqfromLatin1("Author");
         case Description:
-            return TQString::fromLatin1("Description");
-        case Status:
-            return TQString::fromLatin1("Status");
+            return TQString::tqfromLatin1("Description");
+        case tqStatus:
+            return TQString::tqfromLatin1("Status");
         case KeepFlag:
-            return TQString::fromLatin1("KeepFlag");
+            return TQString::tqfromLatin1("KeepFlag");
         default: // should never happen (TM)
-            return TQString::fromLatin1("Description");
+            return TQString::tqfromLatin1("Description");
     }
 }
 
 Criterion::Subject Criterion::stringToSubject(const TQString& subjStr)
 {
-    if (subjStr == TQString::fromLatin1("Title"))
+    if (subjStr == TQString::tqfromLatin1("Title"))
         return Title;
-    else if (subjStr == TQString::fromLatin1("Link"))
+    else if (subjStr == TQString::tqfromLatin1("Link"))
         return Link;
-    else if (subjStr == TQString::fromLatin1("Description"))
+    else if (subjStr == TQString::tqfromLatin1("Description"))
         return Description;
-    else if (subjStr == TQString::fromLatin1("Author"))
+    else if (subjStr == TQString::tqfromLatin1("Author"))
         return Author;
-    else if (subjStr == TQString::fromLatin1("Status"))
-        return Status;
-    else if (subjStr == TQString::fromLatin1("KeepFlag"))
+    else if (subjStr == TQString::tqfromLatin1("Status"))
+        return tqStatus;
+    else if (subjStr == TQString::tqfromLatin1("KeepFlag"))
         return KeepFlag;
 
     // hopefully never reached
@@ -83,27 +83,27 @@ TQString Criterion::predicateToString(Predicate pred)
     switch (pred)
     {
         case Contains:
-            return TQString::fromLatin1("Contains");
+            return TQString::tqfromLatin1("Contains");
         case Equals:
-            return TQString::fromLatin1("Equals");
+            return TQString::tqfromLatin1("Equals");
         case Matches:
-            return TQString::fromLatin1("Matches");
+            return TQString::tqfromLatin1("Matches");
         case Negation:
-            return TQString::fromLatin1("Negation");
+            return TQString::tqfromLatin1("Negation");
         default:// hopefully never reached
-            return TQString::fromLatin1("Contains");
+            return TQString::tqfromLatin1("Contains");
     }
 }
 
 Criterion::Predicate Criterion::stringToPredicate(const TQString& predStr)
 {
-    if (predStr == TQString::fromLatin1("Contains"))
+    if (predStr == TQString::tqfromLatin1("Contains"))
         return Contains;
-    else if (predStr == TQString::fromLatin1("Equals"))
+    else if (predStr == TQString::tqfromLatin1("Equals"))
         return Equals;
-    else if (predStr == TQString::fromLatin1("Matches"))
+    else if (predStr == TQString::tqfromLatin1("Matches"))
         return Matches;
-    else if (predStr == TQString::fromLatin1("Negation"))
+    else if (predStr == TQString::tqfromLatin1("Negation"))
         return Negation;
     
     // hopefully never reached
@@ -124,24 +124,24 @@ Criterion::Criterion( Subject subject, Predicate predicate, const TQVariant &obj
 
 void Criterion::writeConfig(KConfig* config) const
 {
-    config->writeEntry(TQString::fromLatin1("subject"), subjectToString(m_subject));
+    config->writeEntry(TQString::tqfromLatin1("subject"), subjectToString(m_subject));
 
-    config->writeEntry(TQString::fromLatin1("predicate"), predicateToString(m_predicate));
+    config->writeEntry(TQString::tqfromLatin1("predicate"), predicateToString(m_predicate));
 
-    config->writeEntry(TQString::fromLatin1("objectType"), TQString(m_object.typeName()));
+    config->writeEntry(TQString::tqfromLatin1("objectType"), TQString(m_object.typeName()));
 
-    config->writeEntry(TQString::fromLatin1("objectValue"), m_object);
+    config->writeEntry(TQString::tqfromLatin1("objectValue"), m_object);
 }
 
 void Criterion::readConfig(KConfig* config)
 {
-    m_subject = stringToSubject(config->readEntry(TQString::fromLatin1("subject")));
-    m_predicate = stringToPredicate(config->readEntry(TQString::fromLatin1("predicate")));
-    TQVariant::Type type = TQVariant::nameToType(config->readEntry(TQString::fromLatin1("objType")).ascii());
+    m_subject = stringToSubject(config->readEntry(TQString::tqfromLatin1("subject")));
+    m_predicate = stringToPredicate(config->readEntry(TQString::tqfromLatin1("predicate")));
+    TQVariant::Type type = TQVariant::nameToType(config->readEntry(TQString::tqfromLatin1("objType")).ascii());
 
     if (type != TQVariant::Invalid)
     {
-        m_object = config->readPropertyEntry(TQString::fromLatin1("objectValue"), type);
+        m_object = config->readPropertyEntry(TQString::tqfromLatin1("objectValue"), type);
     }
 }
 
@@ -163,7 +163,7 @@ bool Criterion::satisfiedBy( const Article &article ) const
             // ### Maybe use prettyURL here?
             concreteSubject = TQVariant(article.link().url());
             break;
-        case Status:
+        case tqStatus:
             concreteSubject = TQVariant(article.status());
             break;
         case KeepFlag:
@@ -269,15 +269,15 @@ bool ArticleMatcher::matches( const Article &a ) const
 
 void ArticleMatcher::writeConfig(KConfig* config) const
 {
-    config->writeEntry(TQString::fromLatin1("matcherAssociation"), associationToString(m_association));
+    config->writeEntry(TQString::tqfromLatin1("matcherAssociation"), associationToString(m_association));
     
-    config->writeEntry(TQString::fromLatin1("matcherCriteriaCount"), m_criteria.count());
+    config->writeEntry(TQString::tqfromLatin1("matcherCriteriaCount"), m_criteria.count());
 
     int index = 0;
 
     for (TQValueList<Criterion>::ConstIterator it = m_criteria.begin(); it != m_criteria.end(); ++it)
     {
-        config->setGroup(config->group()+TQString::fromLatin1("_Criterion")+TQString::number(index));
+        config->setGroup(config->group()+TQString::tqfromLatin1("_Criterion")+TQString::number(index));
         (*it).writeConfig(config);
         ++index;
     }
@@ -286,14 +286,14 @@ void ArticleMatcher::writeConfig(KConfig* config) const
 void ArticleMatcher::readConfig(KConfig* config)
 {
     m_criteria.clear();
-    m_association = stringToAssociation(config->readEntry(TQString::fromLatin1("matcherAssociation")));
+    m_association = stringToAssociation(config->readEntry(TQString::tqfromLatin1("matcherAssociation")));
 
-    int count =  config->readNumEntry(TQString::fromLatin1("matcherCriteriaCount"), 0);
+    int count =  config->readNumEntry(TQString::tqfromLatin1("matcherCriteriaCount"), 0);
     
     for (int i = 0; i < count; ++i)
     {
         Criterion c;
-        config->setGroup(config->group()+TQString::fromLatin1("_Criterion")+TQString::number(i));
+        config->setGroup(config->group()+TQString::tqfromLatin1("_Criterion")+TQString::number(i));
         c.readConfig(config);
         m_criteria.append(c);
     }
@@ -343,9 +343,9 @@ bool ArticleMatcher::allCriteriaMatch( const Article &a ) const
 
 ArticleMatcher::Association ArticleMatcher::stringToAssociation(const TQString& assocStr)
 {
-    if (assocStr == TQString::fromLatin1("LogicalAnd"))
+    if (assocStr == TQString::tqfromLatin1("LogicalAnd"))
         return LogicalAnd;
-    else if (assocStr == TQString::fromLatin1("LogicalOr"))
+    else if (assocStr == TQString::tqfromLatin1("LogicalOr"))
         return LogicalOr;
     else
         return None;
@@ -356,11 +356,11 @@ TQString ArticleMatcher::associationToString(Association association)
     switch (association)
     {
         case LogicalAnd:
-            return TQString::fromLatin1("LogicalAnd");
+            return TQString::tqfromLatin1("LogicalAnd");
         case LogicalOr:
-            return TQString::fromLatin1("LogicalOr");
+            return TQString::tqfromLatin1("LogicalOr");
         default:
-            return TQString::fromLatin1("None");
+            return TQString::tqfromLatin1("None");
     }
 }
 
@@ -408,13 +408,13 @@ TagMatcher::TagMatcher(const TagMatcher& other) : AbstractMatcher(other), d(0)
 
 void TagMatcher::writeConfig(KConfig* config) const
 {
-    config->writeEntry(TQString::fromLatin1("matcherType"), TQString::fromLatin1("TagMatcher"));
-    config->writeEntry(TQString::fromLatin1("matcherParams"), d->tagID);
+    config->writeEntry(TQString::tqfromLatin1("matcherType"), TQString::tqfromLatin1("TagMatcher"));
+    config->writeEntry(TQString::tqfromLatin1("matcherParams"), d->tagID);
 }
 
 void TagMatcher::readConfig(KConfig* config)
 {
-    d->tagID = config->readEntry(TQString::fromLatin1("matcherParams"));
+    d->tagID = config->readEntry(TQString::tqfromLatin1("matcherParams"));
 }
 
 bool TagMatcher::operator==(const AbstractMatcher& other) const
@@ -442,41 +442,41 @@ void DeleteAction::exec(Article& article)
         article.setDeleted();
 }
 
-SetStatusAction::SetStatusAction(int status) : m_status(status)
+SeStatusAction::SeStatusAction(int status) : m_status(status)
 {
 }
         
-void SetStatusAction::exec(Article& article)
+void SeStatusAction::exec(Article& article)
 {
     if (!article.isNull())
-        article.setStatus(m_status);
+        article.setqStatus(m_status);
 }
 
-int SetStatusAction::status() const
+int SeStatusAction::status() const
 {
     return m_status;
 }
 
-void SetStatusAction::setStatus(int status)
+void SeStatusAction::setqStatus(int status)
 {
     m_status = status;
 }
 
-void SetStatusAction::writeConfig(KConfig* config) const
+void SeStatusAction::writeConfig(KConfig* config) const
 {
-    config->writeEntry(TQString::fromLatin1("actionType"), TQString::fromLatin1("SetStatusAction"));
-    config->writeEntry(TQString::fromLatin1("actionParams"), m_status);
+    config->writeEntry(TQString::tqfromLatin1("actionType"), TQString::tqfromLatin1("SeStatusAction"));
+    config->writeEntry(TQString::tqfromLatin1("actionParams"), m_status);
 }
 
-void SetStatusAction::readConfig(KConfig* config)
+void SeStatusAction::readConfig(KConfig* config)
 {
-    m_status = config->readNumEntry(TQString::fromLatin1("actionParams"), Article::Read);
+    m_status = config->readNumEntry(TQString::tqfromLatin1("actionParams"), Article::Read);
 }
 
-bool SetStatusAction::operator==(const AbstractAction& other)
+bool SeStatusAction::operator==(const AbstractAction& other)
 {
     AbstractAction* ptr = const_cast<AbstractAction*>(&other);
-    SetStatusAction* o = dynamic_cast<SetStatusAction*>(ptr);
+    SeStatusAction* o = dynamic_cast<SeStatusAction*>(ptr);
     if (!o)
         return false;
     else
@@ -581,12 +581,12 @@ bool ArticleFilter::operator==(const ArticleFilter& other) const
 
 void ArticleFilterList::writeConfig(KConfig* config) const
 {
-    config->setGroup(TQString::fromLatin1("Filters"));
-    config->writeEntry(TQString::fromLatin1("count"), count());
+    config->setGroup(TQString::tqfromLatin1("Filters"));
+    config->writeEntry(TQString::tqfromLatin1("count"), count());
     int index = 0;
     for (ArticleFilterList::ConstIterator it = begin(); it != end(); ++it)
     {
-        config->setGroup(TQString::fromLatin1("Filters_")+TQString::number(index));
+        config->setGroup(TQString::tqfromLatin1("Filters_")+TQString::number(index));
         (*it).writeConfig(config);
         ++index;
     }
@@ -595,11 +595,11 @@ void ArticleFilterList::writeConfig(KConfig* config) const
 void ArticleFilterList::readConfig(KConfig* config)
 {
     clear();
-    config->setGroup(TQString::fromLatin1("Filters"));
-    int count = config->readNumEntry(TQString::fromLatin1("count"), 0);
+    config->setGroup(TQString::tqfromLatin1("Filters"));
+    int count = config->readNumEntry(TQString::tqfromLatin1("count"), 0);
     for (int i = 0; i < count; ++i)
     {
-        config->setGroup(TQString::fromLatin1("Filters_")+TQString::number(i));
+        config->setGroup(TQString::tqfromLatin1("Filters_")+TQString::number(i));
         ArticleFilter filter;
         filter.readConfig(config);
         append(filter);
@@ -609,13 +609,13 @@ void ArticleFilterList::readConfig(KConfig* config)
 
 void AssignTagAction::readConfig(KConfig* config)
 {
-    m_tagID = config->readEntry(TQString::fromLatin1("actionParams"));
+    m_tagID = config->readEntry(TQString::tqfromLatin1("actionParams"));
 }
 
 void AssignTagAction::writeConfig(KConfig* config) const
 {
-    config->writeEntry(TQString::fromLatin1("actionType"), TQString::fromLatin1("AssignTagAction"));
-    config->writeEntry(TQString::fromLatin1("actionParams"), m_tagID);
+    config->writeEntry(TQString::tqfromLatin1("actionType"), TQString::tqfromLatin1("AssignTagAction"));
+    config->writeEntry(TQString::tqfromLatin1("actionParams"), m_tagID);
 }
 
 bool AssignTagAction::operator==(const AbstractAction& other)
@@ -644,7 +644,7 @@ void DeleteAction::readConfig(KConfig* /*config*/)
 
 void DeleteAction::writeConfig(KConfig* config) const
 {
-    config->writeEntry(TQString::fromLatin1("actionType"), TQString::fromLatin1("DeleteAction"));
+    config->writeEntry(TQString::tqfromLatin1("actionType"), TQString::tqfromLatin1("DeleteAction"));
 }
 
 bool DeleteAction::operator==(const AbstractAction& other)
@@ -661,28 +661,28 @@ void ArticleFilter::readConfig(KConfig* config)
     delete d->action;
     d->action = 0;
 
-    d->name = config->readEntry(TQString::fromLatin1("name"));
-    d->id = config->readNumEntry(TQString::fromLatin1("id"), 0);
+    d->name = config->readEntry(TQString::tqfromLatin1("name"));
+    d->id = config->readNumEntry(TQString::tqfromLatin1("id"), 0);
 
-    TQString matcherType = config->readEntry(TQString::fromLatin1("matcherType"));
+    TQString matcherType = config->readEntry(TQString::tqfromLatin1("matcherType"));
 
-    if (matcherType == TQString::fromLatin1("TagMatcher"))
+    if (matcherType == TQString::tqfromLatin1("TagMatcher"))
         d->matcher = new TagMatcher();
-    else if (matcherType == TQString::fromLatin1("ArticleMatcher"))
+    else if (matcherType == TQString::tqfromLatin1("ArticleMatcher"))
         d->matcher = new ArticleMatcher();
 
     if (d->matcher)
         d->matcher->readConfig(config);
 
 
-        TQString actionType = config->readEntry(TQString::fromLatin1("actionType"));
+        TQString actionType = config->readEntry(TQString::tqfromLatin1("actionType"));
 
-    if (actionType == TQString::fromLatin1("AssignTagAction"))
+    if (actionType == TQString::tqfromLatin1("AssignTagAction"))
         d->action = new AssignTagAction();
-    else if (actionType == TQString::fromLatin1("DeleteAction"))
+    else if (actionType == TQString::tqfromLatin1("DeleteAction"))
         d->action = new DeleteAction();
-    else if (actionType == TQString::fromLatin1("SetStatusAction"))
-        d->action = new SetStatusAction();
+    else if (actionType == TQString::tqfromLatin1("SeStatusAction"))
+        d->action = new SeStatusAction();
 
     if (d->action)
         d->action->readConfig(config);
@@ -690,8 +690,8 @@ void ArticleFilter::readConfig(KConfig* config)
 
 void ArticleFilter::writeConfig(KConfig* config) const
 {
-    config->writeEntry(TQString::fromLatin1("name"), d->name);
-    config->writeEntry(TQString::fromLatin1("id"), d->id);
+    config->writeEntry(TQString::tqfromLatin1("name"), d->name);
+    config->writeEntry(TQString::tqfromLatin1("id"), d->id);
     d->matcher->writeConfig(config);
     d->action->writeConfig(config);
 }
