@@ -19,8 +19,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #include <tqtimer.h>
@@ -402,7 +402,7 @@ void Feed::slotMarkAllArticlesAsRead()
         TQValueList<Article>::Iterator en = tarticles.end();
 
         for (it = tarticles.begin(); it != en; ++it)
-            (*it).setStatus(Article::Read);
+            (*it).setqStatus(Article::Read);
         setNotificationMode(true, true);
     }
 }
@@ -412,7 +412,7 @@ void Feed::slotAddToFetchQueue(FetchQueue* queue, bool intervalFetchOnly)
         queue->addFeed(this);
     else
     {
-        uint now = TQDateTime::currentDateTime().toTime_t();
+        uint now = TQDateTime::tqcurrentDateTime().toTime_t();
 
         // workaround for 3.5.x: if the last fetch went wrong, try again after 30 minutes
         // this fixes annoying behaviour of akregator, especially when the host is reachable
@@ -464,9 +464,9 @@ void Feed::appendArticles(const RSS::Document &doc)
             d->addedArticlesNotify.append(mya);
             
             if (!mya.isDeleted() && !markImmediatelyAsRead())
-                mya.setStatus(Article::New);
+                mya.setqStatus(Article::New);
             else
-                mya.setStatus(Article::Read);
+                mya.setqStatus(Article::Read);
                 
             changed = true;
         }
@@ -479,12 +479,12 @@ void Feed::appendArticles(const RSS::Document &doc)
             {
                 mya.setKeep(old.keep());
                 int oldstatus = old.status();
-                old.setStatus(Article::Read);
+                old.setqStatus(Article::Read);
 
                 d->articles.remove(old.guid());
                 appendArticle(mya);
 
-                mya.setStatus(oldstatus);
+                mya.setqStatus(oldstatus);
 
                 d->updatedArticlesNotify.append(mya);
                 changed = true;
@@ -519,7 +519,7 @@ bool Feed::usesExpiryByAge() const
 
 bool Feed::isExpired(const Article& a) const
 {
-    TQDateTime now = TQDateTime::currentDateTime();
+    TQDateTime now = TQDateTime::tqcurrentDateTime();
     int expiryAge = -1;
 // check whether the feed uses the global default and the default is limitArticleAge
     if ( d->archiveMode == globalDefault && Settings::archiveMode() == Settings::EnumArchiveMode::limitArticleAge)
@@ -558,7 +558,7 @@ void Feed::fetch(bool followDiscovery)
     {
         if ((*it).status() == Article::New)
         {
-            (*it).setStatus(Article::Unread);
+            (*it).setqStatus(Article::Unread);
         }
     }
 
@@ -579,7 +579,7 @@ void Feed::tryFetch()
 {
     d->fetchError = false;
 
-    d->loader = RSS::Loader::create( this, TQT_SLOT(fetchCompleted(Loader *, Document, Status)) );
+    d->loader = RSS::Loader::create( this, TQT_SLOT(fetchCompleted(Loader *, Document, tqStatus)) );
     //connect(d->loader, TQT_SIGNAL(progress(unsigned long)), this, TQT_SLOT(slotSetProgress(unsigned long)));
     d->loader->loadFrom( d->xmlUrl, new RSS::FileRetriever );
 }
@@ -595,7 +595,7 @@ void Feed::slotImageFetched(const TQPixmap& image)
     nodeModified();
 }
 
-void Feed::fetchCompleted(RSS::Loader *l, RSS::Document doc, RSS::Status status)
+void Feed::fetchCompleted(RSS::Loader *l, RSS::Document doc, RSS::tqStatus status)
 {
     // Note that loader instances delete themselves
     d->loader = 0;
@@ -618,7 +618,7 @@ void Feed::fetchCompleted(RSS::Loader *l, RSS::Document doc, RSS::Status status)
         else
         {
             d->fetchError = true;
-            d->lastErrorFetch = TQDateTime::currentDateTime().toTime_t();
+            d->lastErrorFetch = TQDateTime::tqcurrentDateTime().toTime_t();
             emit fetchError(this);
         }
         return;
@@ -647,7 +647,7 @@ void Feed::fetchCompleted(RSS::Loader *l, RSS::Document doc, RSS::Status status)
 
     appendArticles(doc);
 
-    d->archive->setLastFetch( TQDateTime::currentDateTime().toTime_t());
+    d->archive->setLastFetch( TQDateTime::tqcurrentDateTime().toTime_t());
     emit fetched(this);
 }
 
@@ -735,14 +735,14 @@ void Feed::setArticleDeleted(Article& a)
     articlesModified();
 }
 
-void Feed::setArticleChanged(Article& a, int oldStatus)
+void Feed::setArticleChanged(Article& a, int oldtqStatus)
 {
-    if (oldStatus != -1)
+    if (oldtqStatus != -1)
     {
-        int newStatus = a.status();
-        if (oldStatus == Article::Read && newStatus != Article::Read)
+        int newtqStatus = a.status();
+        if (oldtqStatus == Article::Read && newtqStatus != Article::Read)
             setUnread(unread()+1);
-        else if (oldStatus != Article::Read && newStatus == Article::Read)
+        else if (oldtqStatus != Article::Read && newtqStatus == Article::Read)
             setUnread(unread()-1);
     }
     d->updatedArticlesNotify.append(a);
