@@ -18,8 +18,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #include "dragobjects.h"
@@ -180,8 +180,8 @@ class NodeListView::DeleteItemVisitor : public TreeNodeVisitor
         virtual bool visitFolder(Folder* node)
         {
             // delete child items recursively before deleting parent
-            TQValueList<TreeNode*> children = node->children();
-            for (TQValueList<TreeNode*>::ConstIterator it =  children.begin(); it != children.end(); ++it )
+            TQValueList<TreeNode*> tqchildren = node->tqchildren();
+            for (TQValueList<TreeNode*>::ConstIterator it =  tqchildren.begin(); it != tqchildren.end(); ++it )
                 visit(*it);
             
             visitTreeNode(node);
@@ -267,10 +267,10 @@ class NodeListView::CreateItemVisitor : public TreeNodeVisitor
 
             }
             m_view->d->itemDict.insert(node, item);
-            TQValueList<TreeNode*> children = node->children();
+            TQValueList<TreeNode*> tqchildren = node->tqchildren();
 
-            // add children recursively
-            for (TQValueList<TreeNode*>::ConstIterator it =  children.begin(); it != children.end(); ++it )
+            // add tqchildren recursively
+            for (TQValueList<TreeNode*>::ConstIterator it =  tqchildren.begin(); it != tqchildren.end(); ++it )
                 visit(*it);
 
             m_view->connectToNode(node);
@@ -305,9 +305,9 @@ class NodeListView::CreateItemVisitor : public TreeNodeVisitor
             }
             m_view->d->itemDict.insert(node, item);
             
-            // add children recursively
-            TQValueList<TreeNode*> children = node->children();
-            for (TQValueList<TreeNode*>::ConstIterator it =  children.begin(); it != children.end(); ++it )
+            // add tqchildren recursively
+            TQValueList<TreeNode*> tqchildren = node->tqchildren();
+            for (TQValueList<TreeNode*>::ConstIterator it =  tqchildren.begin(); it != tqchildren.end(); ++it )
                 visit(*it);
 
             m_view->connectToNode(node);
