@@ -22,7 +22,7 @@ Plugin::addPluginProperty( const TQString& key, const TQString& value )
 }
 
 
-QString
+TQString
 Plugin::pluginProperty( const TQString& key )
 {
     if ( m_properties.find( key.lower() ) == m_properties.end() )
