@@ -31,10 +31,11 @@
 
 class ExecDlg :public TQDialog {
 	Q_OBJECT
+  TQ_OBJECT
 public:
 	TQTimer *cpuusagetimer;
 	TQLabel *cpuusagelabel;
-	TQVBoxLayout *mainlayout,*sliderlayout;
+	TQVBoxLayout *maintqlayout,*slidertqlayout;
 	ExecutableStructure *structure;
 
 	void start();
