@@ -251,17 +251,17 @@ ArtsBuilderWindow::ArtsBuilderWindow(const char *name)
  */
 
 #if 000
-	connect(menubar, TQT_SIGNAL(highlighted(int)), this, TQT_SLOT(activateMenu(int)));
+	connect(menubar, TQT_SIGNAL(highlighted(int)), TQT_TQOBJECT(this), TQT_SLOT(activateMenu(int)));
 	connect(m_view, TQT_SIGNAL(activated(int)), modulewidget, TQT_SLOT(setZoom(int)));
-	connect(m_ports, TQT_SIGNAL(activated(int)), this, TQT_SLOT(addPort(int)));
-	connect(m_file_new, TQT_SIGNAL(activated(int)), this, TQT_SLOT(fileNew(int)));
+	connect(m_ports, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(addPort(int)));
+	connect(m_file_new, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(fileNew(int)));
 
-	//connect(m_modules, TQT_SIGNAL(activated(int)), this, TQT_SLOT(addModule(int)));
+	//connect(m_modules, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(addModule(int)));
 	/*
-	connect(m_modules_synth, TQT_SIGNAL(activated(int)), this, TQT_SLOT(addModule(int)));
-	connect(m_modules_gui, TQT_SIGNAL(activated(int)), this, TQT_SLOT(addModule(int)));
-	connect(m_modules_instruments, TQT_SIGNAL(activated(int)), this, TQT_SLOT(addModule(int)));
-	connect(m_modules_other, TQT_SIGNAL(activated(int)), this, TQT_SLOT(addModule(int)));
+	connect(m_modules_synth, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(addModule(int)));
+	connect(m_modules_gui, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(addModule(int)));
+	connect(m_modules_instruments, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(addModule(int)));
+	connect(m_modules_other, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(addModule(int)));
 	*/
 	connect(kapp, TQT_SIGNAL(lastWindowClosed()), this , TQT_SLOT(quit()));
 
@@ -269,7 +269,7 @@ ArtsBuilderWindow::ArtsBuilderWindow(const char *name)
 #endif
 
 	arts_debug("PORT: activatemenu");
-	connect(menumaker, TQT_SIGNAL(activated(const char *)), this, TQT_SLOT(addModule(const char *)));
+	connect(menumaker, TQT_SIGNAL(activated(const char *)), TQT_TQOBJECT(this), TQT_SLOT(addModule(const char *)));
 	fillModuleMenu();
 	arts_debug("PORT: activatemenu ok");
 	setupActions();
@@ -279,11 +279,11 @@ ArtsBuilderWindow::ArtsBuilderWindow(const char *name)
 	// connect to aboutToShow to correctly show state of dockwidget there:
 	TQPopupMenu *viewmenu = (TQPopupMenu*)factory()->container("view", this);
 	if (viewmenu)
-		connect(viewmenu, TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(viewMenuAboutToShow()));
+		connect(viewmenu, TQT_SIGNAL(aboutToShow()), TQT_TQOBJECT(this), TQT_SLOT(viewMenuAboutToShow()));
 	else
 		arts_debug("view menu not found!");
 
-	m_filename = TQString::null;
+	m_filename = TQString();
 	setModified(false);
 
 	installEventFilter(propertyPanel);
@@ -292,55 +292,55 @@ ArtsBuilderWindow::ArtsBuilderWindow(const char *name)
 void ArtsBuilderWindow::setupActions()
 {
 	// File menu
-	KStdAction::openNew(this, TQT_SLOT(fileNew()), actionCollection());
+	KStdAction::openNew(TQT_TQOBJECT(this), TQT_SLOT(fileNew()), actionCollection());
 
-	(void)new KAction(i18n("Open Session..."), 0, this, TQT_SLOT(openSession()),
+	(void)new KAction(i18n("Open Session..."), 0, TQT_TQOBJECT(this), TQT_SLOT(openSession()),
 					  actionCollection(), "file_open_session");
-	KStdAction::open(this, TQT_SLOT(open()), actionCollection());
-	(void)new KAction(i18n("Open E&xample..."), Qt::CTRL + Qt::Key_X, this, TQT_SLOT(openExample()),
+	KStdAction::open(TQT_TQOBJECT(this), TQT_SLOT(open()), actionCollection());
+	(void)new KAction(i18n("Open E&xample..."), TQt::CTRL + TQt::Key_X, TQT_TQOBJECT(this), TQT_SLOT(openExample()),
 					  actionCollection(), "file_open_example");
-	KStdAction::save(this, TQT_SLOT(save()), actionCollection());
-	KStdAction::saveAs(this, TQT_SLOT(saveAs()), actionCollection());
-	(void)new KAction(i18n("&Retrieve From Server..."), Qt::CTRL + Qt::Key_R, this, TQT_SLOT(retrieve()),
+	KStdAction::save(TQT_TQOBJECT(this), TQT_SLOT(save()), actionCollection());
+	KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(saveAs()), actionCollection());
+	(void)new KAction(i18n("&Retrieve From Server..."), TQt::CTRL + TQt::Key_R, TQT_TQOBJECT(this), TQT_SLOT(retrieve()),
 					  actionCollection(), "file_retrieve_from_server");
-	(void)new KAction(i18n("&Execute Structure"), "artsbuilderexecute", Qt::CTRL + Qt::Key_E, this, TQT_SLOT(execute()),
+	(void)new KAction(i18n("&Execute Structure"), "artsbuilderexecute", TQt::CTRL + TQt::Key_E, TQT_TQOBJECT(this), TQT_SLOT(execute()),
 					  actionCollection(), "file_execute_structure");
-	(void)new KAction(i18n("&Rename Structure..."), Qt::CTRL + Qt::Key_R, this, TQT_SLOT(rename()),
+	(void)new KAction(i18n("&Rename Structure..."), TQt::CTRL + TQt::Key_R, TQT_TQOBJECT(this), TQT_SLOT(rename()),
 					  actionCollection(), "file_rename_structure");
-	(void)new KAction(i18n("&Publish Structure"), Qt::CTRL + Qt::Key_P, this, TQT_SLOT(publish()),
+	(void)new KAction(i18n("&Publish Structure"), TQt::CTRL + TQt::Key_P, TQT_TQOBJECT(this), TQT_SLOT(publish()),
 					  actionCollection(), "file_publish_structure");
-	KStdAction::quit(this, TQT_SLOT(close()), actionCollection());
+	KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection());
 
 	// Edit menu
-	(void)new KAction(i18n("&Delete"), Qt::Key_Delete, modulewidget, TQT_SLOT(delModule()),
+	(void)new KAction(i18n("&Delete"), TQt::Key_Delete, TQT_TQOBJECT(modulewidget), TQT_SLOT(delModule()),
 					  actionCollection(), "edit_delete");
-	KStdAction::selectAll(modulewidget, TQT_SLOT(selectAll()), actionCollection());
+	KStdAction::selectAll(TQT_TQOBJECT(modulewidget), TQT_SLOT(selectAll()), actionCollection());
 
 	// View menu
 	viewPropertiesAction= new KToggleAction(i18n("&Property Panel"), 0,
-											propertyDock, TQT_SLOT(changeHideShowState()),
+											TQT_TQOBJECT(propertyDock), TQT_SLOT(changeHideShowState()),
 											actionCollection(), "view_properties");
-	(void)new KAction(i18n("200%"), 0, this, TQT_SLOT(viewAt200()),
+	(void)new KAction(i18n("200%"), 0, TQT_TQOBJECT(this), TQT_SLOT(viewAt200()),
 					  actionCollection(), "view_200");
-	(void)new KAction(i18n("150%"), 0, this, TQT_SLOT(viewAt150()),
+	(void)new KAction(i18n("150%"), 0, TQT_TQOBJECT(this), TQT_SLOT(viewAt150()),
 					  actionCollection(), "view_150");
-	(void)new KAction(i18n("100%"), 0, this, TQT_SLOT(viewAt100()),
+	(void)new KAction(i18n("100%"), 0, TQT_TQOBJECT(this), TQT_SLOT(viewAt100()),
 					  actionCollection(), "view_100");
-	(void)new KAction(i18n("50%"), 0, this, TQT_SLOT(viewAt50()),
+	(void)new KAction(i18n("50%"), 0, TQT_TQOBJECT(this), TQT_SLOT(viewAt50()),
 					  actionCollection(), "view_50");
 
 	// Ports menu
-	(void)new KAction(i18n("Create IN Audio Signal"), 0, this, TQT_SLOT(createInAudioSignal()),
+	(void)new KAction(i18n("Create IN Audio Signal"), 0, TQT_TQOBJECT(this), TQT_SLOT(createInAudioSignal()),
 					  actionCollection(), "ports_create_in_audio_signal");
-	(void)new KAction(i18n("Create OUT Audio Signal"), 0, this, TQT_SLOT(createOutAudioSignal()),
+	(void)new KAction(i18n("Create OUT Audio Signal"), 0, TQT_TQOBJECT(this), TQT_SLOT(createOutAudioSignal()),
 					  actionCollection(), "ports_create_out_audio_signal");
-	(void)new KAction(i18n("Create IN String Property"), 0, this, TQT_SLOT(createInStringProperty()),
+	(void)new KAction(i18n("Create IN String Property"), 0, TQT_TQOBJECT(this), TQT_SLOT(createInStringProperty()),
 					  actionCollection(), "ports_create_in_string_property");
-	(void)new KAction(i18n("Create IN Audio Property"), 0, this, TQT_SLOT(createInAudioProperty()),
+	(void)new KAction(i18n("Create IN Audio Property"), 0, TQT_TQOBJECT(this), TQT_SLOT(createInAudioProperty()),
 					  actionCollection(), "ports_create_in_audio_property");
-	(void)new KAction(i18n("Implement Interface..."), 0, this, TQT_SLOT(addInterface()),
+	(void)new KAction(i18n("Implement Interface..."), 0, TQT_TQOBJECT(this), TQT_SLOT(addInterface()),
 					  actionCollection(), "ports_implement_interface");
-	(void)new KAction(i18n("Change Positions/Names..."), 0, this, TQT_SLOT(changePortPositions()),
+	(void)new KAction(i18n("Change Positions/Names..."), 0, TQT_TQOBJECT(this), TQT_SLOT(changePortPositions()),
 					  actionCollection(), "ports_change_positions");
 }
 
@@ -441,7 +441,7 @@ void ArtsBuilderWindow::publish()
 	checkName();
 	structure->publish();
 	KMessageBox::information(this,
-		i18n("The structure has been published as: '%1' on the server.").arg( structure->name().c_str() ));
+		i18n("The structure has been published as: '%1' on the server.").tqarg( structure->name().c_str() ));
 }
 
 TQString ArtsBuilderWindow::getOpenFilename(const char *pattern, const char *initialDir)
@@ -474,7 +474,7 @@ void ArtsBuilderWindow::fileNew()
 	propertyPanel->setSelectedComponent(0);
 	structure->clear();
 	modulewidget->reInit();
-	m_filename = TQString::null;
+	m_filename = TQString();
 	setModified(false);
 }
 
@@ -532,7 +532,7 @@ void ArtsBuilderWindow::openSession()
 		execDlg->start();
 		execDlg->show();
 
-		connect(execDlg, TQT_SIGNAL(ready()), this, TQT_SLOT(endexecute()));
+		connect(execDlg, TQT_SIGNAL(ready()), TQT_TQOBJECT(this), TQT_SLOT(endexecute()));
 
 		hide();
 		// m_filename = filename; FIXME: DOESN'T THIS BELONG HERE?
@@ -587,7 +587,7 @@ bool ArtsBuilderWindow::save(TQString filename)
 	if(file.status()) {
 		KMessageBox::sorry(this,
 			i18n("The file '%1' could not be opened for writing: %2")
-			.arg(filename).arg(strerror(file.status())),
+			.tqarg(filename).tqarg(strerror(file.status())),
 			i18n("aRts Warning"));
 		return false;
 	}
@@ -597,7 +597,7 @@ bool ArtsBuilderWindow::save(TQString filename)
 	if(!file.close()) {
 		KMessageBox::sorry(this,
 			i18n("Saving to file '%1' could not be finished correctly: %2")
-			.arg(filename).arg(strerror(file.status())),
+			.tqarg(filename).tqarg(strerror(file.status())),
 			i18n("aRts Warning"));
 		return false;
 	}
@@ -674,7 +674,7 @@ void ArtsBuilderWindow::execute()
 		execDlg->start();
 		execDlg->show();
 
-		connect(execDlg, TQT_SIGNAL(ready()), this, TQT_SLOT(endexecute()));
+		connect(execDlg, TQT_SIGNAL(ready()), TQT_TQOBJECT(this), TQT_SLOT(endexecute()));
 
 		hide();
 	}
@@ -838,7 +838,7 @@ bool ArtsBuilderWindow::promptToSave()
 		return true;
 
 	query = KMessageBox::warningYesNoCancel(this,
-		i18n("The current structure has been modified.\nWould you like to save it?"), TQString::null, KStdGuiItem::save(), KStdGuiItem::discard());
+		i18n("The current structure has been modified.\nWould you like to save it?"), TQString(), KStdGuiItem::save(), KStdGuiItem::discard());
 
 	result = false;
 	switch(query)
@@ -872,7 +872,7 @@ ArtsBuilderApp::ArtsBuilderApp(TQString filename)
 		mainWindow->open(filename);
 	} else {
 		KMessageBox::sorry(0,
-		   i18n("The specified file '%1' does not exist.").arg(filename),
+		   i18n("The specified file '%1' does not exist.").tqarg(filename),
 		   i18n("aRts Warning"));
 	}
 }
