@@ -24,9 +24,10 @@
 class Player;
 class Estate;
 
-class LIBATLANTIC_EXPORT Auction : public QObject
+class LIBATLANTIC_EXPORT Auction : public TQObject
 {
 Q_OBJECT
+  TQ_OBJECT
 
 public:
 	Auction(int auctionId, Estate *estate);
@@ -35,7 +36,7 @@ public:
 	int auctionId() { return m_auctionId; }
 	Estate *estate() { return m_estate; }
 
-	void setStatus(int status);
+	void settqStatus(int status);
 	int status() { return m_status; }
 
 	void newBid(Player *player, int bid);
