@@ -21,9 +21,10 @@
 
 #include "libatlantic_export.h"
 
-class LIBATLANTIC_EXPORT EstateGroup : public QObject
+class LIBATLANTIC_EXPORT EstateGroup : public TQObject
 {
 Q_OBJECT
+  TQ_OBJECT
 
 public:
 	EstateGroup(const int id);
