@@ -15,7 +15,7 @@
 
 #include "autodetailsview.h"
 
-/** Qt */
+/** TQt */
 #include <tqregexp.h>
 #include <tqlistview.h>
 #include <tqwidget.h>
@@ -71,7 +71,7 @@ AutoDetailsView::AutoDetailsView(AutoProjectWidget* widget, AutoProjectPart* par
 	m_listView->setAllColumnsShowFocus( true );
 	m_listView->setRootIsDecorated( true );
 	m_listView->setResizeMode( TQListView::LastColumn );
-	m_listView->addColumn( TQString::null );
+	m_listView->addColumn( TQString() );
 	m_listView->header()->hide();
 	targetOptionsAction->setEnabled( false );
 	addNewFileAction->setEnabled( false );
@@ -177,7 +177,7 @@ void AutoDetailsView::initActions()
 	KActionCollection * actions = new KActionCollection( this );
 
 	targetOptionsAction = new AutoToolsAction( i18n( "Options..." ), "configure", 0,
-	                                   this, TQT_SLOT( slotTargetOptions() ), actions,
+	                                           TQT_TQOBJECT(this), TQT_SLOT( slotTargetOptions() ), actions,
 	                                   "target options" );
 	targetOptionsAction->setWhatsThis(i18n("<b>Options</b><p>Target options dialog that "
 	                                       "provides settings for linker flags and lists "
@@ -188,7 +188,7 @@ void AutoDetailsView::initActions()
 
 	TQToolTip::add( m_button1, tr2i18n( "Create New File..." ) );
 	addNewFileAction = new AutoToolsAction( i18n( "Create New File..." ), "filenew", 0,
-	                                this, TQT_SLOT( slotAddNewFile() ), actions,
+	                                        TQT_TQOBJECT(this), TQT_SLOT( slotAddNewFile() ), actions,
 	                                "add new file" );
 	addNewFileAction->setWhatsThis(i18n("<b>Create new file</b><p>Creates a new file and "
 	                                    "adds it to a currently selected target."));
@@ -197,7 +197,7 @@ void AutoDetailsView::initActions()
 
 	TQToolTip::add( m_button2, tr2i18n( "Add Existing Files..." ) );
 	addExistingFileAction = new AutoToolsAction( i18n( "Add Existing Files..." ), "fileimport", 0,
-	                                     this, TQT_SLOT( slotAddExistingFile() ), actions,
+	                                             TQT_TQOBJECT(this), TQT_SLOT( slotAddExistingFile() ), actions,
 	                                     "add existing file" );
 	addExistingFileAction->setWhatsThis(i18n("<b>Add existing files</b><p>Adds existing "
 	                                         "file to a currently selected target. Header "
@@ -208,12 +208,12 @@ void AutoDetailsView::initActions()
 	addExistingFileAction->setEnabled( false );
 
 	addIconAction = new KAction( i18n( "Add Icon..." ), "iconadd_kdevelop", 0,
-	                             this, TQT_SLOT( slotAddIcon() ), actions, "add icon" );
+	                             TQT_TQOBJECT(this), TQT_SLOT( slotAddIcon() ), actions, "add icon" );
 	addIconAction->setWhatsThis(i18n("<b>Add icon</b><p>Adds an icon to a KDEICON target."));
 
 	TQToolTip::add( m_button4, tr2i18n( "Build Target"));
 	buildTargetAction = new AutoToolsAction( i18n( "Build Target..." ), "launch", 0,
-	                                 this, TQT_SLOT( slotBuildTarget() ), actions,
+	                                         TQT_TQOBJECT(this), TQT_SLOT( slotBuildTarget() ), actions,
 	                                 "build target" );
 	buildTargetAction->setWhatsThis(i18n("<b>Build target</b><p>Constructs a series of "
 	                                     "make commands to build the selected target. "
@@ -223,7 +223,7 @@ void AutoDetailsView::initActions()
 
 	TQToolTip::add( m_button5, tr2i18n( "Execute Target..."));
 	executeTargetAction = new AutoToolsAction( i18n( "Execute Target..." ), "exec", 0,
-	                                   this, TQT_SLOT( slotExecuteTarget() ), actions,
+	                                           TQT_TQOBJECT(this), TQT_SLOT( slotExecuteTarget() ), actions,
 	                                   "execute target" );
 	executeTargetAction->setWhatsThis(i18n("<b>Execute target</b><p>Executes the target "
 	                                       "and tries to build in case it is not built."));
@@ -231,7 +231,7 @@ void AutoDetailsView::initActions()
 	executeTargetAction->setEnabled( false );
 
 	setActiveTargetAction = new KAction( i18n( "Make Target Active" ), "", 0,
-	                                     this, TQT_SLOT( slotSetActiveTarget() ), actions,
+	                                     TQT_TQOBJECT(this), TQT_SLOT( slotSetActiveTarget() ), actions,
 	                                     "set active target" );
 	setActiveTargetAction->setWhatsThis(i18n("<b>Make target active</b><p>Marks the "
 	                                         "currently selected target as 'active'. New "
@@ -241,7 +241,7 @@ void AutoDetailsView::initActions()
 	                                         "command builds it."));
 
 	TQToolTip::add( m_button3, tr2i18n( "Remove"));
-	removeDetailAction = new AutoToolsAction( i18n( "Remove" ), "editdelete", 0, this,
+	removeDetailAction = new AutoToolsAction( i18n( "Remove" ), "editdelete", 0, TQT_TQOBJECT(this),
 	                                  TQT_SLOT( slotRemoveDetail() ), actions,
 	                                  "remove detail" );
 	removeDetailAction->setWhatsThis(i18n("<b>Remove</b><p>Shows a list of targets "
@@ -269,7 +269,7 @@ TQString AutoDetailsView::getUiFileLink(const TQString& relpath, const TQString&
 			return (*it).second;
 	}
 
-	return TQString::null;
+	return TQString();
 }
 
 void AutoDetailsView::slotTargetOptions()
@@ -298,7 +298,7 @@ void AutoDetailsView::slotAddNewFile()
 	if (createFileSupport)
 	{
 		KDevCreateFile::CreatedFile crFile =
-			createFileSupport->createNewFile(TQString::null,
+			createFileSupport->createNewFile(TQString(),
 			                                 m_widget->selectedSubproject()->path);
 /*		if (crFile.status == KDevCreateFile::CreatedFile::STATUS_OK)
         {
@@ -499,7 +499,7 @@ void AutoDetailsView::slotDetailsContextMenu( KListView *, TQListViewItem *item,
 		else
 			caption = titem->name;
 
-		KPopupMenu popup( i18n( "Target: %1" ).arg( caption ), this );
+		KPopupMenu popup( i18n( "Target: %1" ).tqarg( caption ), this );
 
 		if ( titem->primary == "PROGRAMS" || titem->primary == "LIBRARIES"
 		        || titem->primary == "LTLIBRARIES" || titem->primary == "JAVA" )
@@ -554,7 +554,7 @@ void AutoDetailsView::slotDetailsContextMenu( KListView *, TQListViewItem *item,
 			return;
 		}
 
-		KPopupMenu popup( i18n( "File: %1" ).arg( fitem->name ), this );
+		KPopupMenu popup( i18n( "File: %1" ).tqarg( fitem->name ), this );
 
 		removeDetailAction->plug( &popup );
 		KURL::List urls;
@@ -563,7 +563,7 @@ void AutoDetailsView::slotDetailsContextMenu( KListView *, TQListViewItem *item,
 
 		int idSubclassWidget = popup.insertItem(SmallIconSet("qmake_subclass"),
 		                                        i18n("Subclassing Wizard...") );
-		popup.setWhatsThis(idSubclassWidget, i18n("<b>Subclass widget</b><p>Launches "
+		popup.tqsetWhatsThis(idSubclassWidget, i18n("<b>Subclass widget</b><p>Launches "
 		                                          "<b>Subclassing</b> wizard. "
 		                                          "It allows to create a subclass from the "
 		                                          "class defined in .ui file. "
@@ -572,19 +572,19 @@ void AutoDetailsView::slotDetailsContextMenu( KListView *, TQListViewItem *item,
 		                                          "class."));
 		int idUISubclasses = popup.insertItem(SmallIconSet("qmake_subclass"),
 		                                      i18n("List of Subclasses..."));
-		popup.setWhatsThis(idUISubclasses, i18n("<b>List of subclasses</b><p>Shows "
+		popup.tqsetWhatsThis(idUISubclasses, i18n("<b>List of subclasses</b><p>Shows "
 		                                        "subclasses list editor. "
 		                                        "There is possibility to add or remove "
 		                                        "subclasses from the list."));
 		int idUpdateWidgetclass = popup.insertItem(SmallIconSet("qmake_subclass"),
 		                                           i18n("Edit ui-Subclass..."));
-		popup.setWhatsThis(idUpdateWidgetclass, i18n("<b>Edit ui-subclass</b><p>Launches "
+		popup.tqsetWhatsThis(idUpdateWidgetclass, i18n("<b>Edit ui-subclass</b><p>Launches "
 		                                             "<b>Subclassing</b> wizard and prompts "
 		                                             "to implement missing in childclass "
 		                                             "slots and functions."));
 		int idViewUIH = popup.insertItem(SmallIconSet("qmake_ui_h"),
 		                                 i18n("Open ui.h File"));
-		popup.setWhatsThis(idViewUIH, i18n("<b>Open ui.h file</b><p>Opens .ui.h file "
+		popup.tqsetWhatsThis(idViewUIH, i18n("<b>Open ui.h file</b><p>Opens .ui.h file "
 		                                   "associated with the selected .ui."));
 
 		if (!fitem->name.contains(TQRegExp("ui$")) || fitem->is_subst == true)
