@@ -407,16 +407,16 @@ TQString AutoProjectPart::mainProgram() const
             KMessageBox::error( m_widget, i18n("There is no active target.\n"
                                 "Unable to determine the main program."), i18n("No active target found") );
             kdDebug ( 9020 ) << k_funcinfo << "Error! : There's no active target! -> Unable to determine the main program in AutoProjectPart::mainProgram()" << endl;
-            return TQString::null;
+            return TQString();
         }
 
         if ( titem->primary != "PROGRAMS" ) {
             KMessageBox::error( m_widget, i18n("Active target \"%1\" is not binary ( %2 ).\n"
                                 "Unable to determine the main program.  If you want this\n"
                                 "to be the active target, set a main program under\n"
-                                "Project -> Project Options -> Run Options").arg(titem->name).arg(titem->primary), i18n("Active target is not a library") );
+                                "Project -> Project Options -> Run Options").tqarg(titem->name).tqarg(titem->primary), i18n("Active target is not a library") );
             kdDebug ( 9020 ) << k_funcinfo << "Error! : Active target isn't binary (" << titem->primary << ") ! -> Unable to determine the main program in AutoProjectPart::mainProgram()" << endl;
-            return TQString::null;
+            return TQString();
         }
 
         TQString relprojectpath = URLUtil::getRelativePath( topsourceDirectory(), projectDirectory() );
@@ -643,20 +643,20 @@ TQString AutoProjectPart::constructMakeCommandLine(const TQString &dir, const TQ
         {
             int r = KMessageBox::questionYesNo(m_widget, i18n("%1\nThere is no Makefile in this directory\n"
                                                "and no configure script for this project.\n"
-                                               "Run automake & friends and configure first?").arg(buildDirectory()), TQString::null, i18n("Run Them"), i18n("Do Not Run"));
+                                               "Run automake & friends and configure first?").tqarg(buildDirectory()), TQString(), i18n("Run Them"), i18n("Do Not Run"));
             if (r == KMessageBox::No)
-                return TQString::null;
+                return TQString();
             preCommand = makefileCvsCommand();
             if (preCommand.isNull())
-                return TQString::null;
+                return TQString();
             preCommand += " && ";
             preCommand += configureCommand() + " && ";
         }
         else
         {
-            int r = KMessageBox::questionYesNo(m_widget, i18n("%1\nThere is no Makefile in this directory. Run 'configure' first?").arg(dir), TQString::null, i18n("Run configure"), i18n("Do Not Run"));
+            int r = KMessageBox::questionYesNo(m_widget, i18n("%1\nThere is no Makefile in this directory. Run 'configure' first?").tqarg(dir), TQString(), i18n("Run configure"), i18n("Do Not Run"));
             if (r == KMessageBox::No)
-                return TQString::null;
+                return TQString();
             preCommand = configureCommand() + " && ";
         }
     }
@@ -668,7 +668,7 @@ TQString AutoProjectPart::constructMakeCommandLine(const TQString &dir, const TQ
     kdDebug(9020) << k_funcinfo << "nice = " << prio<< endl;
     if (prio != 0)
     {
-        nice = TQString("nice -n%1 ").arg(prio);
+        nice = TQString("nice -n%1 ").tqarg(prio);
     }
 
     if (cmdline.isEmpty())
@@ -792,7 +792,7 @@ bool AutoProjectPart::queueInternalLibDependenciesBuild(TargetItem* titem, TQStr
                     tdir += dependency.left(pos+1);
                     tname = dependency.mid(pos+1);
                 }
-                KMessageBox::error( 0, i18n("Found a circular dependency in the project, between this target and %1.\nCannot build this project until this is resolved.").arg(tname), i18n("Circular Dependency found") );
+                KMessageBox::error( 0, i18n("Found a circular dependency in the project, between this target and %1.\nCannot build this project until this is resolved.").tqarg(tname), i18n("Circular Dependency found") );
                 return false;
             }
         }
@@ -812,7 +812,7 @@ void AutoProjectPart::slotBuild()
         m_needMakefileCvs = false;
     }
 
-    startMakeCommand(buildDirectory(), TQString::fromLatin1(""));
+    startMakeCommand(buildDirectory(), TQString::tqfromLatin1(""));
 }
 
 
@@ -912,28 +912,28 @@ TQString AutoProjectPart::configureCommand() const
     cmdline += "/configure\"";
     TQString cc = DomUtil::readEntry(dom, prefix + "ccompilerbinary");
     if (!cc.isEmpty())
-        cmdline.prepend(TQString("CC=%1 ").arg(cc));
+        cmdline.prepend(TQString("CC=%1 ").tqarg(cc));
     TQString cflags = DomUtil::readEntry(dom, prefix + "cflags");
     if (!cflags.isEmpty())
-        cmdline.prepend(TQString("CFLAGS=\"%1\" ").arg(cflags));
+        cmdline.prepend(TQString("CFLAGS=\"%1\" ").tqarg(cflags));
     TQString cxx = DomUtil::readEntry(dom, prefix + "cxxcompilerbinary");
     if (!cxx.isEmpty())
-        cmdline.prepend(TQString("CXX=%1 ").arg(cxx));
+        cmdline.prepend(TQString("CXX=%1 ").tqarg(cxx));
     TQString cxxflags = DomUtil::readEntry(dom, prefix + "cxxflags");
     if (!cxxflags.isEmpty())
-        cmdline.prepend(TQString("CXXFLAGS=\"%1\" ").arg(cxxflags));
+        cmdline.prepend(TQString("CXXFLAGS=\"%1\" ").tqarg(cxxflags));
     TQString f77 = DomUtil::readEntry(dom, prefix + "f77compilerbinary");
     if (!f77.isEmpty())
-        cmdline.prepend(TQString("F77=%1 ").arg(f77));
+        cmdline.prepend(TQString("F77=%1 ").tqarg(f77));
     TQString fflags = DomUtil::readEntry(dom, prefix + "f77flags");
     if (!fflags.isEmpty())
-        cmdline.prepend(TQString("FFLAGS=\"%1\" ").arg(fflags));
+        cmdline.prepend(TQString("FFLAGS=\"%1\" ").tqarg(fflags));
     TQString cppflags = DomUtil::readEntry(dom, prefix + "cppflags");
     if (!cppflags.isEmpty())
-        cmdline.prepend(TQString("CPPFLAGS=\"%1\" ").arg(cppflags));
+        cmdline.prepend(TQString("CPPFLAGS=\"%1\" ").tqarg(cppflags));
     TQString ldflags = DomUtil::readEntry(dom, prefix + "ldflags");
     if (!ldflags.isEmpty())
-        cmdline.prepend(TQString("LDFLAGS=\"%1\" ").arg(ldflags));
+        cmdline.prepend(TQString("LDFLAGS=\"%1\" ").tqarg(ldflags));
 
     TQString configargs = DomUtil::readEntry(dom, prefix + "configargs");
     if (!configargs.isEmpty()) {
@@ -997,7 +997,7 @@ TQString AutoProjectPart::makefileCvsCommand() const
     TQString nice;
     kdDebug(9020) << "makefileCvsCommand() nice = " << prio<< endl;
     if (prio != 0) {
-        nice = TQString("nice -n%1 ").arg(prio);
+        nice = TQString("nice -n%1 ").tqarg(prio);
     }
 
     if (TQFile::exists(topsourceDirectory() + "/Makefile.cvs"))
@@ -1009,7 +1009,7 @@ TQString AutoProjectPart::makefileCvsCommand() const
     else {
         KMessageBox::sorry(m_widget, i18n("There is neither a Makefile.cvs file nor an "
                                           "autogen.sh script in the project directory."));
-        return TQString::null;
+        return TQString();
     }
 
     cmdline.prepend(nice);
@@ -1034,7 +1034,7 @@ void AutoProjectPart::slotMakefilecvs()
 
 void AutoProjectPart::slotInstall()
 {
-    startMakeCommand(buildDirectory(), TQString::fromLatin1("install"));
+    startMakeCommand(buildDirectory(), TQString::tqfromLatin1("install"));
 }
 
 
@@ -1045,25 +1045,25 @@ void AutoProjectPart::slotInstallWithKdesu()
     slotBuild();
 
     // After that issue "make install" with the root user
-    startMakeCommand(buildDirectory(), TQString::fromLatin1("install"), true);
+    startMakeCommand(buildDirectory(), TQString::tqfromLatin1("install"), true);
 }
 
 
 void AutoProjectPart::slotClean()
 {
-    startMakeCommand(buildDirectory(), TQString::fromLatin1("clean"));
+    startMakeCommand(buildDirectory(), TQString::tqfromLatin1("clean"));
 }
 
 
 void AutoProjectPart::slotDistClean()
 {
-    startMakeCommand(buildDirectory(), TQString::fromLatin1("distclean"));
+    startMakeCommand(buildDirectory(), TQString::tqfromLatin1("distclean"));
 }
 
 
 void AutoProjectPart::slotMakeMessages()
 {
-    startMakeCommand(buildDirectory(), TQString::fromLatin1("package-messages"));
+    startMakeCommand(buildDirectory(), TQString::tqfromLatin1("package-messages"));
 }
 
 
@@ -1103,7 +1103,7 @@ void AutoProjectPart::slotExecute()
         if( DomUtil::readBoolEntry(dom, "/kdevautoproject/run/autokdesu", false) ){
             //slotInstallWithKdesu assumes that it hasn't just been build...
             kdDebug(9020) << "slotExecute: before startMakeCommand" << endl;
-            _auto ? slotInstallWithKdesu() : startMakeCommand(buildDirectory(), TQString::fromLatin1("install"), true);
+            _auto ? slotInstallWithKdesu() : startMakeCommand(buildDirectory(), TQString::tqfromLatin1("install"), true);
         }
         else{
             kdDebug(9020) << "slotExecute: before slotInstall" << endl;
@@ -1171,7 +1171,7 @@ void AutoProjectPart::executeTarget(const TQDir& dir, const TargetItem* titem)
         KMessageBox::error( m_widget, i18n("Active target \"%1\" is not binary ( %2 ).\n"
                                 "Unable to determine the main program. If you want this\n"
                                 "to be the active target, set a main program under\n"
-                                "Project -> Project Options -> Run Options").arg(titem->name).arg(titem->primary), i18n("Active target is not a library") );
+                                "Project -> Project Options -> Run Options").tqarg(titem->name).tqarg(titem->primary), i18n("Active target is not a library") );
         kdDebug ( 9020 ) << k_funcinfo << "Error! : Active target isn't binary (" << titem->primary << ") ! -> Unable to determine the main program in AutoProjectPart::mainProgram()" << endl;
         program += titem->name;
     }else
@@ -1316,7 +1316,7 @@ void AutoProjectPart::slotCommandFinished( const TQString& command )
     if( m_buildCommand != command )
         return;
 
-    m_buildCommand = TQString::null;
+    m_buildCommand = TQString();
 
     m_timestamp.clear();
     TQStringList fileList = allFiles();
