@@ -72,7 +72,7 @@ static TQString nicePrimary( const TQString &primary )
 	else if ( primary == "JAVA" )
 		return i18n( "Java" );
 	else
-		return TQString::null;
+		return TQString();
 }
 
 
@@ -87,7 +87,7 @@ AutoProjectWidget::AutoProjectWidget( AutoProjectPart *part, bool kde )
 	m_choosenTarget = 0;
         m_makefileHandler = new MakefileHandler();
 
-	TQSplitter *splitter = new TQSplitter(Vertical, this);
+	TQSplitter *splitter = new TQSplitter(Qt::Vertical, this);
 
 	initOverview ( splitter );
 	initDetailview ( splitter );
@@ -216,7 +216,7 @@ TQString AutoProjectWidget::pathForTarget(const TargetItem *titem) const
 {
 
 	if (!titem)
-		return TQString::null;
+		return TQString();
 
 	kdDebug(9020) << "Looking for target " << titem->name << endl;
 	int prefixLen = m_part->projectDirectory().length() + 1;
@@ -233,7 +233,7 @@ TQString AutoProjectWidget::pathForTarget(const TargetItem *titem) const
 		}
 	}
 	kdDebug(9020) << "Not found" << endl;
-	return TQString::null;
+	return TQString();
 }
 
 TQStringList AutoProjectWidget::allLibraries()
@@ -314,7 +314,7 @@ TQStringList AutoProjectWidget::allFiles()
 TQString AutoProjectWidget::subprojectDirectory()
 {
 	if ( !selectedSubproject() )
-		return TQString::null;
+		return TQString();
 
 	return selectedSubproject()->path;
 }
@@ -387,7 +387,7 @@ TQString AutoProjectWidget::activeDirectory()
 /*		if ( selectedSubproject() )
 			return selectedSubproject()->path;
 		else*/
-			return TQString::null;
+			return TQString();
 	}
 }
 
@@ -557,7 +557,7 @@ void AutoProjectWidget::slotOverviewSelectionChanged( TQListViewItem *item )
 	// Delete the items from the details view first.
 	if ( m_shownSubproject )
 	{
-		// Remove all TargetItems and all of their children from the view
+		// Remove all TargetItems and all of their tqchildren from the view
 		kdDebug ( 9020 ) << "m_shownSubproject (before takeItem()): " << m_shownSubproject->subdir << endl;
 
 		TQListViewItem* i = m_detailView->listView()->firstChild();
@@ -575,7 +575,7 @@ void AutoProjectWidget::slotOverviewSelectionChanged( TQListViewItem *item )
 	if ( !m_shownSubproject) return;
 	kdDebug ( 9020 ) << "m_shownSubproject (after takeItem()):  " << selectedSubproject()->subdir << endl;
 
-	// Insert all TargetItems and all of their children into the view
+	// Insert all TargetItems and all of their tqchildren into the view
 	TQPtrListIterator<TargetItem> it2( selectedSubproject()->targets );
 	for ( ; it2.current(); ++it2 )
 	{
@@ -632,9 +632,9 @@ TargetItem *AutoProjectWidget::createTargetItem( const TQString &name,
 	if ( docgroup )
 		text = i18n( "Documentation data" );
 	else if ( icongroup )
-		text = i18n( "KDE Icon data" ).arg( prefix );
+		text = i18n( "KDE Icon data" ).tqarg( prefix );
 	else
-		text = i18n( "%1 (%2 in %3)" ).arg( name ).arg( nicePrimary( primary ) ).arg( prefix );
+		text = i18n( "%1 (%2 in %3)" ).tqarg( name ).tqarg( nicePrimary( primary ) ).tqarg( prefix );
 
 	// Workaround because of TQListView not being able to create
 	// items without actually inserting them
