@@ -13,7 +13,7 @@
  ***************************************************************************
 */
 
-/** Qt */
+/** TQt */
 #include <tqregexp.h>
 #include <tqcheckbox.h>
 #include <tqstringlist.h>
@@ -81,11 +81,11 @@ static TQString cleanWhitespace( const TQString &str )
 static void removeDir( const TQString& dirName )
 {
     TQDir d( dirName );
-    const QFileInfoList* fileList = d.entryInfoList();
+    const TQFileInfoList* fileList = d.entryInfoList();
     if( !fileList )
 	return;
 
-    QFileInfoListIterator it( *fileList );
+    TQFileInfoListIterator it( *fileList );
     while( it.current() ){
 	const TQFileInfo* fileInfo = it.current();
 	++it;
@@ -116,7 +116,7 @@ AutoSubprojectView::AutoSubprojectView(AutoProjectWidget* widget, AutoProjectPar
 
 	m_listView->setSorting(-1);
 	m_listView->header()->hide();
-	m_listView->addColumn( TQString::null );
+	m_listView->addColumn( TQString() );
 
 	connect( m_listView, TQT_SIGNAL( selectionChanged( TQListViewItem* ) ),
 	         this, TQT_SLOT( slotSelectionChanged( TQListViewItem* ) ) );
@@ -173,7 +173,7 @@ void AutoSubprojectView::initActions()
 	KActionCollection * actions = new KActionCollection( this );
 
 	subProjectOptionsAction = new AutoToolsAction( i18n( "Options..." ), "configure", 0,
-	                                       this, TQT_SLOT( slotSubprojectOptions() ), actions, "subproject options" );
+	                                               TQT_TQOBJECT(this), TQT_SLOT( slotSubprojectOptions() ), actions, "subproject options" );
 	subProjectOptionsAction->setWhatsThis(i18n("<qt><b>Options</b><p>Shows subproject options dialog "
 	                                           "that provides settings for compiler, include paths, "
 	                                           "prefixes and build order.</qt>"));
@@ -181,24 +181,24 @@ void AutoSubprojectView::initActions()
 
 	TQToolTip::add( m_button1, tr2i18n( "Add new subproject..."));
 	addSubprojectAction = new AutoToolsAction( i18n( "Add new subproject..." ), "folder_new", 0,
-	                                   this, TQT_SLOT( slotAddSubproject() ), actions, "add subproject" );
+	                                           TQT_TQOBJECT(this), TQT_SLOT( slotAddSubproject() ), actions, "add subproject" );
 	addSubprojectAction->setWhatsThis(i18n("<qt><b>Add new subproject</b><p>Creates a new "
 	                                       "subproject in currently selected subproject.</qt>"));
 	addSubprojectAction->plug( m_button1 );
 
 	removeSubprojectAction = new KAction( i18n( "Remove Subproject..." ), "remove_subdir", 0,
-	                                      this, TQT_SLOT( slotRemoveSubproject() ), actions, "remove subproject" );
+	                                      TQT_TQOBJECT(this), TQT_SLOT( slotRemoveSubproject() ), actions, "remove subproject" );
 	removeSubprojectAction->setWhatsThis(i18n("<qt><b>Remove subproject</b><p>Removes the subproject. Asks if the "
 	                                          "subproject should be also removed from disk. Only subprojects "
 	                                          "which do not hold other subprojects can be removed.</qt>"));
 	addExistingSubprojectAction = new KAction( i18n( "Add Existing Subprojects..." ), "fileimport", 0,
-	                                           this, TQT_SLOT( slotAddExistingSubproject() ), actions, "add existing subproject" );
+	                                           TQT_TQOBJECT(this), TQT_SLOT( slotAddExistingSubproject() ), actions, "add existing subproject" );
 	addExistingSubprojectAction->setWhatsThis(i18n("<qt><b>Add existing subprojects</b><p>Imports existing "
 	                                               "subprojects containing Makefile.am.</qt>"));
 
 	TQToolTip::add( m_button2, tr2i18n( "Add Target..."));
 	addTargetAction = new AutoToolsAction( i18n( "Add Target..." ), "targetnew_kdevelop", 0,
-	                               this, TQT_SLOT( slotAddTarget() ), actions, "add target" );
+	                                       TQT_TQOBJECT(this), TQT_SLOT( slotAddTarget() ), actions, "add target" );
 	addTargetAction->setWhatsThis(i18n( "<qt><b>Add target</b><p>Adds a new target to "
 	                                    "the currently selected subproject. Target can be a "
 	                                    "binary program, library, script, also a collection of "
@@ -206,19 +206,19 @@ void AutoSubprojectView::initActions()
 	addTargetAction->plug( m_button2 );
 
 	TQToolTip::add( m_button3, tr2i18n( "Add Service..."));
-	addServiceAction = new AutoToolsAction( i18n( "Add Service..." ), "servicenew_kdevelop", 0, this,
+	addServiceAction = new AutoToolsAction( i18n( "Add Service..." ), "servicenew_kdevelop", 0, TQT_TQOBJECT(this),
 	                                TQT_SLOT( slotAddService() ), actions, "add service" );
 	addServiceAction->setWhatsThis(i18n("<qt><b>Add service</b><p>Creates a .desktop file describing the service.</qt>"));
 	addServiceAction->plug( m_button3 );
 
 	TQToolTip::add( m_button4, tr2i18n( "Add Application..."));
-	addApplicationAction = new AutoToolsAction( i18n( "Add Application..." ), "window_new", 0, this,
+	addApplicationAction = new AutoToolsAction( i18n( "Add Application..." ), "window_new", 0, TQT_TQOBJECT(this),
 	                                    TQT_SLOT( slotAddApplication() ), actions, "add application" );
 	addApplicationAction->setWhatsThis(i18n("<qt><b>Add application</b><p>Creates an application .desktop file.</qt>"));
 	addApplicationAction->plug( m_button4 );
 
 	TQToolTip::add( m_button5, tr2i18n( "Build"));
-	buildSubprojectAction = new AutoToolsAction( i18n( "Build" ), "launch", 0, this,
+	buildSubprojectAction = new AutoToolsAction( i18n( "Build" ), "launch", 0, TQT_TQOBJECT(this),
 	                                     TQT_SLOT( slotBuildSubproject() ), actions, "build subproject" );
 	buildSubprojectAction->setWhatsThis(i18n("<qt><b>Build</b><p>Runs <b>make</b> from the directory of "
 	                                         "the selected subproject.<br> Environment variables and "
@@ -226,11 +226,11 @@ void AutoSubprojectView::initActions()
 	                                         "dialog, <b>Make Options</b> tab.</qt>"));
 	buildSubprojectAction->plug( m_button5 );
 
-	forceReeditSubprojectAction = new KAction( i18n( "Force Reedit" ), 0, 0, this,
+	forceReeditSubprojectAction = new KAction( i18n( "Force Reedit" ), 0, 0, TQT_TQOBJECT(this),
 	                                           TQT_SLOT( slotForceReeditSubproject() ), actions, "force-reedit subproject" );
 	forceReeditSubprojectAction->setWhatsThis(i18n("<qt><b>Force Reedit</b><p>Runs <b>make force-reedit</b> "
 	                                               "from the directory of the selected subproject.<br>This "
-	                                               "recreates makefile (tip: and solves most of .moc related "
+	                                               "recreates makefile (tip: and solves most of .tqmoc related "
 	                                               "problems)<br>Environment variables and make arguments can "
 	                                               "be specified in the project settings dialog, "
 	                                               "<b>Make Options</b> tab.</qt>"));
@@ -238,21 +238,21 @@ void AutoSubprojectView::initActions()
 	if (!m_part->isKDE())
 		forceReeditSubprojectAction->setEnabled(false);
 
-	cleanSubprojectAction = new KAction( i18n( "Clean" ), 0, 0, this,
+	cleanSubprojectAction = new KAction( i18n( "Clean" ), 0, 0, TQT_TQOBJECT(this),
 	                                     TQT_SLOT( slotCleanSubproject() ), actions, "clean subproject" );
 	cleanSubprojectAction->setWhatsThis(i18n("<qt><b>Clean</b><p>Runs <b>make clean</b> from the directory of "
 	                                         "the selected subproject.<br> Environment variables and make "
 	                                         "arguments can be specified in the project settings dialog, "
 	                                         "<b>Make Options</b> tab.</qt>"));
 
-	installSubprojectAction = new KAction( i18n( "Install" ), 0, 0, this,
+	installSubprojectAction = new KAction( i18n( "Install" ), 0, 0, TQT_TQOBJECT(this),
 	                                       TQT_SLOT( slotInstallSubproject() ), actions, "install subproject" );
 	installSubprojectAction->setWhatsThis(i18n("<qt><b>Install</b><p>Runs <b>make install</b> from the directory "
 	                                           "of the selected subproject.<br> Environment variables and "
 	                                           "make arguments can be specified in the project settings "
 	                                           "dialog, <b>Make Options</b> tab.</qt>"));
 	installSuSubprojectAction = new KAction( i18n( "Install (as root user)" ), 0, 0,
-	                                         this, TQT_SLOT( slotInstallSuSubproject() ), actions, "install subproject as root" );
+	                                         TQT_TQOBJECT(this), TQT_SLOT( slotInstallSuSubproject() ), actions, "install subproject as root" );
 	installSuSubprojectAction->setWhatsThis(i18n("<qt><b>Install as root user</b><p>Runs <b>make install</b> "
 	                                             "command from the directory of the selected subproject "
 	                                             "with root privileges.<br> It is executed via kdesu "
@@ -260,12 +260,12 @@ void AutoSubprojectView::initActions()
 	                                             "can be specified in the project settings dialog, "
 	                                             "<b>Make Options</b> tab.</qt>"));
 
-	expandAction = new KAction( i18n( "Expand Subtree" ), 0, 0, this,
+	expandAction = new KAction( i18n( "Expand Subtree" ), 0, 0, TQT_TQOBJECT(this),
 	                            TQT_SLOT(slotExpandTree()), actions, "expandAction" );
-	collapseAction = new KAction( i18n( "Collapse Subtree" ), 0, 0, this,
+	collapseAction = new KAction( i18n( "Collapse Subtree" ), 0, 0, TQT_TQOBJECT(this),
 	                              TQT_SLOT(slotCollapseTree()), actions, "collapseAction" );
 
-	otherAction = new KAction( i18n( "Manage Custom Commands..." ), 0, 0, this,
+	otherAction = new KAction( i18n( "Manage Custom Commands..." ), 0, 0, TQT_TQOBJECT(this),
 	                           TQT_SLOT( slotManageBuildCommands() ), actions, "manage custom commands" );
 	otherAction->setWhatsThis(i18n("<qt><b>Manage custom commands</b><p>Allows to create, edit and "
 	                               "delete custom build commands which appears in the subproject "
@@ -280,7 +280,7 @@ void AutoSubprojectView::slotContextMenu( KListView *, TQListViewItem *item, con
 	if ( !item )
 		return ;
 
-	KPopupMenu popup( i18n( "Subproject: %1" ).arg( item->text( 0 ) ), this );
+	KPopupMenu popup( i18n( "Subproject: %1" ).tqarg( item->text( 0 ) ), this );
 
 	subProjectOptionsAction->plug( &popup );
 	popup.insertSeparator();
@@ -422,7 +422,7 @@ void AutoSubprojectView::slotBuildSubproject()
 
 	TQString relpath = "/" + URLUtil::getRelativePath( m_part->topsourceDirectory(), m_part->projectDirectory() ) + "/" + spitem->path.mid( m_part->projectDirectory().length() );
 
-	m_part->startMakeCommand( m_part->buildDirectory() + relpath, TQString::fromLatin1( "" ) );
+	m_part->startMakeCommand( m_part->buildDirectory() + relpath, TQString::tqfromLatin1( "" ) );
 }
 
 void AutoSubprojectView::slotRemoveSubproject()
@@ -448,13 +448,13 @@ void AutoSubprojectView::slotRemoveSubproject()
     {
         topsubdirs = false;
         if( it == list.end() ){
-            KMessageBox::sorry(this, i18n("There is no subproject %1 in SUBDIRS").arg(spitem->subdir));
+            KMessageBox::sorry(this, i18n("There is no subproject %1 in SUBDIRS").tqarg(spitem->subdir));
             return;
         }
     }
 
-    RemoveSubprojectDialog dlg(i18n("Remove Subproject %1").arg(spitem->text(0)),
-        i18n("Do you really want to remove subproject %1 with all targets and files?").arg(spitem->text(0)));
+    RemoveSubprojectDialog dlg(i18n("Remove Subproject %1").tqarg(spitem->text(0)),
+        i18n("Do you really want to remove subproject %1 with all targets and files?").tqarg(spitem->text(0)));
     if( dlg.exec() ){
 
     bool removeSources = dlg.removeFromDisk();
@@ -466,7 +466,7 @@ void AutoSubprojectView::slotRemoveSubproject()
     }
 
     parent->listView()->setSelected( parent, true );
-    kapp->processEvents( 500 );
+    kapp->tqprocessEvents( 500 );
 
 
     if( removeSources ){
@@ -1045,7 +1045,7 @@ void AutoSubprojectView::slotManageBuildCommands( )
 		{
 			config->writeEntry(widget->commandsTable->text(i, 0),
 				widget->commandsTable->text(i, 1)+":::"+
-				TQString("%1").arg(static_cast<TQComboTableItem*>(widget->
+				TQString("%1").tqarg(static_cast<TQComboTableItem*>(widget->
 				commandsTable->item(i, 2))->currentItem()));
 		}
 		config->sync();
