@@ -231,7 +231,7 @@ void CustomProjectPart::contextMenu( TQPopupMenu *popup, const Context *context
 
     TQString popupstr = fcontext->urls().first().fileName();
 
-    if ( popupstr == TQString::null )
+    if ( popupstr == TQString() )
         popupstr = ".";
 
     if ( fcontext->urls().size() == 1 && URLUtil::isDirectory( fcontext->urls().first() ) && !isInBlacklist( fcontext->urls().first().path() ) )
@@ -242,7 +242,7 @@ void CustomProjectPart::contextMenu( TQPopupMenu *popup, const Context *context
         m_contextDirName = m_contextDirName.mid( project()->projectDirectory().length() + 1 );
         int id = popup->insertItem( i18n( "Make Active Directory" ),
                                     this, TQT_SLOT( slotChooseActiveDirectory() ) );
-        popup->setWhatsThis( id, i18n( "<b>Make active directory</b><p>"
+        popup->tqsetWhatsThis( id, i18n( "<b>Make active directory</b><p>"
                                        "Chooses this directory as the destination for new files created using wizards "
                                        "like the <i>New Class</i> wizard." ) );
     }
@@ -258,7 +258,7 @@ void CustomProjectPart::contextMenu( TQPopupMenu *popup, const Context *context
         {
             id = popup->insertItem( i18n( "Remove from blacklist" ),
                                     this, TQT_SLOT( slotChangeBlacklist() ) );
-            popup->setWhatsThis( id, i18n( "<b>Remove from blacklist</b><p>"
+            popup->tqsetWhatsThis( id, i18n( "<b>Remove from blacklist</b><p>"
                                            "Removes the given file or directory from the "
                                            "blacklist if it is already in it.<br>The blacklist contains files and"
                                            " directories that should be ignored even if they match a project filetype "
@@ -268,7 +268,7 @@ void CustomProjectPart::contextMenu( TQPopupMenu *popup, const Context *context
         {
             id = popup->insertItem( i18n( "Add to blacklist" ),
                                     this, TQT_SLOT( slotChangeBlacklist() ) );
-            popup->setWhatsThis( id, i18n( "<b>Add to blacklist</b><p>"
+            popup->tqsetWhatsThis( id, i18n( "<b>Add to blacklist</b><p>"
                                            "Adds the given file or directory to the blacklist.<br>The blacklist contains files and"
                                            " directories that should be ignored even if they match a project filetype "
                                            "pattern" ) );
@@ -318,13 +318,13 @@ void CustomProjectPart::contextMenu( TQPopupMenu *popup, const Context *context
     {
         int id = popup->insertItem( i18n( "Add Selected File/Dir(s) to Project" ),
                                     this, TQT_SLOT( slotAddToProject() ) );
-        popup->setWhatsThis( id, i18n( "<b>Add to project</b><p>Adds selected file/dir(s) to the list of files in the project. "
+        popup->tqsetWhatsThis( id, i18n( "<b>Add to project</b><p>Adds selected file/dir(s) to the list of files in the project. "
                                        "Note that the files should be manually added to the corresponding makefile or build.xml." ) );
         if ( dirAddRecursive )
         {
             int id = popup->insertItem( i18n( "Add Selected Dir(s) to Project (recursive)" ),
                                         this, TQT_SLOT( slotAddToProjectRecursive() ) );
-            popup->setWhatsThis( id, i18n( "<b>Add to project</b><p>Recursively adds selected dir(s) to the list of files in the project. "
+            popup->tqsetWhatsThis( id, i18n( "<b>Add to project</b><p>Recursively adds selected dir(s) to the list of files in the project. "
                                            "Note that the files should be manually added to the corresponding makefile or build.xml." ) );
         }
     }
@@ -333,14 +333,14 @@ void CustomProjectPart::contextMenu( TQPopupMenu *popup, const Context *context
     {
         int id = popup->insertItem( i18n( "Remove Selected File/Dir(s) From Project" ),
                                     this, TQT_SLOT( slotRemoveFromProject() ) );
-        popup->setWhatsThis( id, i18n( "<b>Remove from project</b><p>Removes selected file/dir(s) from the list of files in the project. "
+        popup->tqsetWhatsThis( id, i18n( "<b>Remove from project</b><p>Removes selected file/dir(s) from the list of files in the project. "
                                        "Note that the files should be manually excluded from the corresponding makefile or build.xml." ) );
 
         if ( dirDelRecursive )
         {
             int id = popup->insertItem( i18n( "Remove Selected Dir(s) From Project (recursive)" ),
                                         this, TQT_SLOT( slotRemoveFromProjectRecursive() ) );
-            popup->setWhatsThis( id, i18n( "<b>Remove from project</b><p>Recursively removes selected dir(s) from the list of files in the project. "
+            popup->tqsetWhatsThis( id, i18n( "<b>Remove from project</b><p>Recursively removes selected dir(s) from the list of files in the project. "
                                            "Note that the files should be manually excluded from the corresponding makefile or build.xml." ) );
         }
     }
@@ -460,7 +460,7 @@ void CustomProjectPart::openProject( const TQString &dirName, const TQString &pr
         int r = KMessageBox::questionYesNo( mainWindow()->main(),
                                             i18n( "This project does not contain any files yet.\n"
                                                   "Populate it with all C/C++/Java files below "
-                                                  "the project directory?" ), TQString::null, i18n( "Populate" ), i18n( "Do Not Populate" ) );
+                                                  "the project directory?" ), TQString(), i18n( "Populate" ), i18n( "Do Not Populate" ) );
         if ( r == KMessageBox::Yes )
             populateProject();
     }
@@ -568,7 +568,7 @@ void CustomProjectPart::populateProject()
         setFiletypes( lb->items() );
     }
 
-    TQApplication::setOverrideCursor( Qt::waitCursor );
+    TQApplication::setOverrideCursor( TQt::waitCursor );
     removeFiles( allFiles() );
     updateBlacklist( TQStringList() );
 
@@ -944,7 +944,7 @@ void CustomProjectPart::startMakeCommand( const TQString &dir, const TQString &t
     TQString nice;
     if ( prio != 0 )
     {
-        nice = TQString( "nice -n%1 " ).arg( prio );
+        nice = TQString( "nice -n%1 " ).tqarg( prio );
     }
 
     cmdline.prepend( nice );
@@ -1013,12 +1013,12 @@ void CustomProjectPart::slotCompileFile()
 
 void CustomProjectPart::slotInstallActiveDir()
 {
-    startMakeCommand( buildDirectory() + "/" + activeDirectory(), TQString::fromLatin1( "install" ) );
+    startMakeCommand( buildDirectory() + "/" + activeDirectory(), TQString::tqfromLatin1( "install" ) );
 }
 
 void CustomProjectPart::slotInstall()
 {
-    startMakeCommand( buildDirectory(), TQString::fromLatin1( "install" ) );
+    startMakeCommand( buildDirectory(), TQString::tqfromLatin1( "install" ) );
 }
 
 
@@ -1029,12 +1029,12 @@ void CustomProjectPart::slotInstallWithKdesu()
     slotBuild();
 
     // After that issue "make install" with the root user
-    startMakeCommand( buildDirectory(), TQString::fromLatin1( "install" ), true );
+    startMakeCommand( buildDirectory(), TQString::tqfromLatin1( "install" ), true );
 }
 
 void CustomProjectPart::slotClean()
 {
-    startMakeCommand( buildDirectory(), TQString::fromLatin1( "clean" ) );
+    startMakeCommand( buildDirectory(), TQString::tqfromLatin1( "clean" ) );
 }
 
 
@@ -1056,7 +1056,7 @@ void CustomProjectPart::slotExecute()
         // Use kdesu??
         if ( DomUtil::readBoolEntry( *projectDom(), "/kdevcustomproject/run/autokdesu", false ) )
             //slotInstallWithKdesu assumes that it hasn't just been build...
-            _auto ? slotInstallWithKdesu() : startMakeCommand( buildDirectory(), TQString::fromLatin1( "install" ), true );
+            _auto ? slotInstallWithKdesu() : startMakeCommand( buildDirectory(), TQString::tqfromLatin1( "install" ), true );
         else
             slotInstall();
         _auto = true;
@@ -1322,7 +1322,7 @@ void CustomProjectPart::slotCommandFinished( const TQString& command )
     if ( m_buildCommand != command )
         return;
 
-    m_buildCommand = TQString::null;
+    m_buildCommand = TQString();
 
     m_timestamp.clear();
     TQStringList fileList = allFiles();
