@@ -33,7 +33,7 @@
    version 2.2 of Bison.  */
 
 // Take the name prefix into account.
-#define yylex   QMakelex
+#define yylex   TQMakelex
 
 #include "qmake_yacc.hpp"
 
@@ -41,7 +41,7 @@
 
 
 /* Line 317 of lalr1.cc.  */
-#line 45 "qmake_yacc.cpp"
+#line 45 "tqmake_yacc.cpp"
 
 #ifndef YY_
 # if YYENABLE_NLS
@@ -100,7 +100,7 @@ do {					\
 #define YYABORT		goto yyabortlab
 #define YYERROR		goto yyerrorlab
 
-namespace QMake
+namespace TQMake
 {
 #if YYERROR_VERBOSE
 
@@ -144,7 +144,7 @@ namespace QMake
 #endif
 
   /// Build a parser object.
-  Parser::Parser (QMake::Lexer* lexer_yyarg, TQValueStack<ProjectAST*>& projects_yyarg, int depth_yyarg)
+  Parser::Parser (TQMake::Lexer* lexer_yyarg, TQValueStack<ProjectAST*>& projects_yyarg, int depth_yyarg)
     : yydebug_ (false),
       yycdebug_ (&std::cerr),
       lexer (lexer_yyarg),
@@ -752,7 +752,7 @@ namespace QMake
 
 
     /* Line 675 of lalr1.cc.  */
-#line 756 "qmake_yacc.cpp"
+#line 756 "tqmake_yacc.cpp"
 	default: break;
       }
     YY_SYMBOL_PRINT ("-> $$ =", yyr1_[yyn], &yyval, &yyloc);
@@ -1227,13 +1227,13 @@ namespace QMake
   const unsigned int Parser::yyuser_token_number_max_ = 278;
   const Parser::token_number_type Parser::yyundef_token_ = 2;
 
-} // namespace QMake
+} // namespace TQMake
 
 #line 421 "qmake.yy"
 
 
 
-namespace QMake
+namespace TQMake
 {
     void Parser::error(const location_type& /*l*/, const std::string& m)
     {
