@@ -100,17 +100,17 @@ TQString CustomVarListItem::key(int column, bool ascending) const
 }
 
 ProjectConfigurationDlg::ProjectConfigurationDlg( TQListView *_prjList, TrollProjectWidget* _prjWidget, TQWidget* parent, const char* name, bool modal, WFlags fl )
-        : ProjectConfigurationDlgBase( parent, name, modal, fl | Qt::WStyle_Tool ), myProjectItem(0)
+        : ProjectConfigurationDlgBase( parent, name, modal, fl | TQt::WStyle_Tool ), myProjectItem(0)
 {
     prjList = _prjList;
     prjWidget = _prjWidget;
     //  m_projectConfiguration = conf;
     m_targetLibraryVersion->setValidator( new TQRegExpValidator(
-                                              TQRegExp( "\\d+(\\.\\d+)?(\\.\\d+)" ), this ) );
+                                              TQRegExp( "\\d+(\\.\\d+)?(\\.\\d+)" ), TQT_TQOBJECT(this) ) );
     customVariables->setSortColumn(0);
-    customVariables->setSortOrder(Qt::Ascending);
-    mocdir_url->completionObject()->setMode(KURLCompletion::DirCompletion);
-    mocdir_url->setMode( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
+    customVariables->setSortOrder(TQt::Ascending);
+    tqmocdir_url->completionObject()->setMode(KURLCompletion::DirCompletion);
+    tqmocdir_url->setMode( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
     objdir_url->completionObject()->setMode(KURLCompletion::DirCompletion);
     objdir_url->setMode( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
     rccdir_url->completionObject()->setMode(KURLCompletion::DirCompletion);
@@ -327,8 +327,8 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
     else
         myProjectItem->removeValue( "CONFIG", "windows" );
 
-    //Qt4 libs
-    if ( prjWidget->m_part->isQt4Project() )
+    //TQt4 libs
+    if ( prjWidget->m_part->isTQt4Project() )
     {
         if ( checkDebugReleaseMode->isChecked() )
             myProjectItem->addValue( "CONFIG", "debug_and_release" );
@@ -603,7 +603,7 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
     // intermediate locations
     myProjectItem->scope->setEqualOp( "OBJECTS_DIR", TQStringList( objdir_url->url() ) );
     myProjectItem->scope->setEqualOp( "UI_DIR", TQStringList( uidir_url->url() ) );
-    myProjectItem->scope->setEqualOp( "MOC_DIR", TQStringList( mocdir_url->url() ) );
+    myProjectItem->scope->setEqualOp( "QMOC_DIR", TQStringList( tqmocdir_url->url() ) );
     myProjectItem->scope->setEqualOp( "RCC_DIR", TQStringList( rccdir_url->url() ) );
 
     //CORBA
@@ -667,7 +667,7 @@ void ProjectConfigurationDlg::updateControls()
         {
             sharedRadio->setChecked( true );
             checkPlugin->setEnabled( true );
-            if( prjWidget->m_part->isQt4Project() )
+            if( prjWidget->m_part->isTQt4Project() )
                 checkDesigner->setEnabled( true );
             m_targetLibraryVersion->setText( myProjectItem->scope->variableValues( "VERSION" ).front() );
         }
@@ -805,8 +805,8 @@ void ProjectConfigurationDlg::updateControls()
     else
         checkWindows->setChecked( false );
 
-    //Qt4 libs
-    if ( prjWidget->m_part->isQt4Project() )
+    //TQt4 libs
+    if ( prjWidget->m_part->isTQt4Project() )
     {
 
         if ( configValues.findIndex( "assistant" ) != -1 )
@@ -971,17 +971,17 @@ void ProjectConfigurationDlg::updateControls()
         uidir_url->fileDialog()->setURL( KURL( dir ) );
     }
     uidir_url->setURL( dir );
-    dir = myProjectItem->scope->variableValues( "MOC_DIR" ).front();
+    dir = myProjectItem->scope->variableValues( "QMOC_DIR" ).front();
     if( TQFileInfo(dir).isRelative() )
     {
-        mocdir_url->completionObject()->setDir( myProjectItem->scope->projectDir() );
-        mocdir_url->fileDialog()->setURL( KURL( myProjectItem->scope->projectDir()+"/"+dir ) );
+        tqmocdir_url->completionObject()->setDir( myProjectItem->scope->projectDir() );
+        tqmocdir_url->fileDialog()->setURL( KURL( myProjectItem->scope->projectDir()+"/"+dir ) );
     }else
     {
-        mocdir_url->completionObject()->setDir( dir );
-        mocdir_url->fileDialog()->setURL( KURL( dir ) );
+        tqmocdir_url->completionObject()->setDir( dir );
+        tqmocdir_url->fileDialog()->setURL( KURL( dir ) );
     }
-    mocdir_url->setURL( dir );
+    tqmocdir_url->setURL( dir );
     dir = myProjectItem->scope->variableValues( "RC_DIR" ).front();
     if( TQFileInfo(dir).isRelative() )
     {
@@ -1379,7 +1379,7 @@ void ProjectConfigurationDlg::outsideIncAddClicked()
 {
     KURLRequesterDlg dialog( "", i18n( "Add include directory:" ), 0, 0 );
     dialog.urlRequester() ->setMode( KFile::Directory | KFile::LocalOnly );
-    dialog.urlRequester() ->setURL( TQString::null );
+    dialog.urlRequester() ->setURL( TQString() );
     dialog.urlRequester() ->completionObject() ->setDir( myProjectItem->scope->projectDir() );
     dialog.urlRequester() ->fileDialog() ->setURL( KURL( myProjectItem->scope->projectDir() ) );
     if ( dialog.exec() != TQDialog::Accepted )
@@ -1463,7 +1463,7 @@ void ProjectConfigurationDlg::outsideLibAddClicked()
     KURLRequesterDlg dialog( "", i18n( "Add Library: Either choose the .a/.so file or give -l<libname>" ), 0, 0 );
     dialog.urlRequester() ->setMode( KFile::File | KFile::ExistingOnly | KFile::LocalOnly );
     dialog.urlRequester() ->setFilter( "*.so|"+i18n("Shared Library (*.so)")+"\n*.a|"+i18n("Static Library (*.a)") );
-    dialog.urlRequester() ->setURL( TQString::null );
+    dialog.urlRequester() ->setURL( TQString() );
     dialog.urlRequester() ->completionObject() ->setDir( myProjectItem->scope->projectDir() );
     dialog.urlRequester() ->fileDialog() ->setURL( KURL( myProjectItem->scope->projectDir() ) );
     if ( dialog.exec() != TQDialog::Accepted )
@@ -1546,7 +1546,7 @@ void ProjectConfigurationDlg::outsideLibDirAddClicked()
 {
     KURLRequesterDlg dialog( "", i18n( "Add library directory:" ), 0, 0 );
     dialog.urlRequester() ->setMode( KFile::Directory | KFile::LocalOnly );
-    dialog.urlRequester() ->setURL( TQString::null );
+    dialog.urlRequester() ->setURL( TQString() );
     dialog.urlRequester() ->completionObject() ->setDir( myProjectItem->scope->projectDir() );
     dialog.urlRequester() ->fileDialog() ->setURL( KURL( myProjectItem->scope->projectDir() ) );
     if ( dialog.exec() != TQDialog::Accepted )
@@ -1686,7 +1686,7 @@ void ProjectConfigurationDlg::extAdd_button_clicked( )
 {
     KURLRequesterDlg dialog( "", i18n( "Add target:" ), 0, 0 );
     dialog.urlRequester() ->setMode( KFile::File | KFile::LocalOnly );
-    dialog.urlRequester() ->setURL( TQString::null );
+    dialog.urlRequester() ->setURL( TQString() );
     dialog.urlRequester() ->completionObject() ->setDir( myProjectItem->scope->projectDir() );
     dialog.urlRequester() ->fileDialog() ->setURL( KURL( myProjectItem->scope->projectDir() ) );
     if ( dialog.exec() != TQDialog::Accepted )
@@ -1882,7 +1882,7 @@ void ProjectConfigurationDlg::groupLibrariesChanged( int )
         checkPlugin->setEnabled( true );
         checkDesigner->setEnabled( checkPlugin->isChecked() );
     }
-    else if ( checkPlugin->isChecked() && prjWidget->m_part->isQt4Project() )
+    else if ( checkPlugin->isChecked() && prjWidget->m_part->isTQt4Project() )
     {
         checkDesigner->setEnabled( true );
     }
@@ -1978,7 +1978,7 @@ void ProjectConfigurationDlg::groupTemplateChanged( int )
 
 void ProjectConfigurationDlg::groupRequirementsChanged( int )
 {
-    if ( checkQt->isChecked() && prjWidget->m_part->isQt4Project() )
+    if ( checkQt->isChecked() && prjWidget->m_part->isTQt4Project() )
     {
         groupQt4Libs->setEnabled( true );
     }
