@@ -9,8 +9,8 @@
 *                                                                         *
 ***************************************************************************/
 
-#ifndef QMAKEOPTIONSWIDGET_H
-#define QMAKEOPTIONSWIDGET_H
+#ifndef TQMAKEOPTIONSWIDGET_H
+#define TQMAKEOPTIONSWIDGET_H
 
 #include "qmakeoptionswidgetbase.h"
 
@@ -19,6 +19,7 @@
 class QMakeOptionsWidget : public QMakeOptionsWidgetBase
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     QMakeOptionsWidget( const TQString& projectdir, TQDomDocument &dom, const TQString &configGroup,
                         TQWidget *parent = 0, const char *name = 0 );
