@@ -1,8 +1,9 @@
+
 /***************************************************************************
 *   Copyright (C) 2006 by Andreas Pakulat                                 *
 *   apaku@gmx.de                                                          *
 *                                                                         *
-*   Part of this file is taken from Qt Designer.                          *
+*   Part of this file is taken from TQt Designer.                          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -308,7 +309,7 @@ FileItem::FileItem( TQListView *lv, const TQString &text )
 QMakeScopeItem::QMakeScopeItem( TQListView *parent, const TQString &text, Scope* s, TrollProjectWidget* widget )
         : qProjectItem( Subproject, parent, text ), scope( s ), m_widget( widget )
 {
-    //   configuration.m_template = QTMP_APPLICATION;
+    //   configuration.m_template = TQTMP_APPLICATION;
     init();
 }
 
@@ -648,7 +649,7 @@ void QMakeScopeItem::buildGroups()
         item->files.append( createFileItem( *it ) );
     }
 
-    if ( scope->isQt4Project() )
+    if ( scope->isTQt4Project() )
     {
         values = scope->variableValues( "RESOURCES" );
         item = createGroupItem( GroupItem::Resources, "RESOURCES", this );
