@@ -31,7 +31,7 @@
 #include "trollprojectpart.h"
 #include "qmakedefaultopts.h"
 
-const TQStringList Scope::KnownVariables = TQStringList() << "QT" << "CONFIG" << "TEMPLATE" << "SUBDIRS" << "VERSION" << "LIBS" << "target.path" << "INSTALLS" << "MAKEFILE" << "TARGETDEPS" << "INCLUDEPATH" << "TARGET" << "DESTDIR" << "DEFINES" << "QMAKE_CXXFLAGS_DEBUG" << "QMAKE_CXXFLAGS_RELEASE" << "OBJECTS_DIR" << "UI_DIR" << "MOC_DIR" << "IDL_COMPILER" << "IDL_OPTIONS" << "RCC_DIR" << "IDLS" << "RESOURCES" << "IMAGES" << "LEXSOURCES" << "DISTFILES" << "YACCSOURCES" << "TRANSLATIONS" << "HEADERS" << "SOURCES" << "INTERFACES" << "FORMS" ;
+const TQStringList Scope::KnownVariables = TQStringList() << "QT" << "CONFIG" << "TEMPLATE" << "SUBDIRS" << "VERSION" << "LIBS" << "target.path" << "INSTALLS" << "MAKEFILE" << "TARGETDEPS" << "INCLUDEPATH" << "TARGET" << "DESTDIR" << "DEFINES" << "QMAKE_CXXFLAGS_DEBUG" << "QMAKE_CXXFLAGS_RELEASE" << "OBJECTS_DIR" << "UI_DIR" << "QMOC_DIR" << "IDL_COMPILER" << "IDL_OPTIONS" << "RCC_DIR" << "IDLS" << "RESOURCES" << "IMAGES" << "LEXSOURCES" << "DISTFILES" << "YACCSOURCES" << "TRANSLATIONS" << "HEADERS" << "SOURCES" << "INTERFACES" << "FORMS" ;
 
 const TQStringList Scope::KnownConfigValues = TQStringList() << "debug" << "release" << "debug_and_release" << "warn_on" << "warn_off" << "staticlib" << "dll" << "plugin" << "designer" << "create_pkgconf" << "create_libtool" << "qt" << "console" << "windows" << "x11" << "thread" << "exceptions" << "stl" << "rtti" << "opengl" << "thread" << "ordered" << "precompile_header" << "qtestlib" << "uitools" << "dbus" << "assistant" << "build_all" << "help";
 
@@ -42,7 +42,7 @@ Scope::Scope( const TQMap<TQString, TQString>& env, const TQString &filename, Tr
     {
         if( !TQFileInfo( filename ).exists() )
         {
-            m_root = new QMake::ProjectAST();
+            m_root = new TQMake::ProjectAST();
             m_root->setFileName( filename );
         }else
         {
@@ -80,8 +80,8 @@ Scope::~Scope()
 }
 
 // Simple/Function Scopes
-Scope::Scope( const TQMap<TQString, TQString>& env, unsigned int num, Scope* parent, QMake::ProjectAST* scope,
-              QMakeDefaultOpts* defaultopts, TrollProjectPart* part )
+Scope::Scope( const TQMap<TQString, TQString>& env, unsigned int num, Scope* parent, TQMake::ProjectAST* scope,
+              TQMakeDefaultOpts* defaultopts, TrollProjectPart* part )
     : m_root( scope ), m_incast( 0 ), m_parent( parent ), m_num(num), m_isEnabled( true ),
         m_part(part), m_defaultopts(defaultopts), m_environment( env )
 {
@@ -98,7 +98,7 @@ Scope::Scope( const TQMap<TQString, TQString>& env, unsigned int num, Scope* par
     {
         if( !TQFileInfo( filename ).exists() && TQFileInfo( TQFileInfo( filename ).dirPath( true ) ).exists() )
         {
-            m_root = new QMake::ProjectAST();
+            m_root = new TQMake::ProjectAST();
             m_root->setFileName( filename );
         }else
         {
@@ -114,8 +114,8 @@ Scope::Scope( const TQMap<TQString, TQString>& env, unsigned int num, Scope* par
 }
 
 //Include Scope
-Scope::Scope( const TQMap<TQString, TQString>& env, unsigned int num, Scope* parent, QMake::IncludeAST* incast, const TQString& path,
-              const TQString& incfile, QMakeDefaultOpts* defaultopts, TrollProjectPart* part )
+Scope::Scope( const TQMap<TQString, TQString>& env, unsigned int num, Scope* parent, TQMake::IncludeAST* incast, const TQString& path,
+              const TQString& incfile, TQMakeDefaultOpts* defaultopts, TrollProjectPart* part )
     : m_root( 0 ), m_incast( incast ), m_parent( parent ), m_num(num), m_isEnabled( true ),
     m_part(part), m_defaultopts(defaultopts), m_environment( env )
 {
@@ -136,7 +136,7 @@ Scope::Scope( const TQMap<TQString, TQString>& env, unsigned int num, Scope* par
     {
         if( !TQFileInfo( absfilename ).exists() && TQFileInfo( TQFileInfo( absfilename ).dirPath( true ) ).exists() )
         {
-            m_root = new QMake::ProjectAST();
+            m_root = new TQMake::ProjectAST();
             m_root->setFileName( absfilename );
         }else
         {
@@ -152,13 +152,13 @@ Scope::Scope( const TQMap<TQString, TQString>& env, unsigned int num, Scope* par
 
 bool Scope::loadFromFile( const TQString& filename )
 {
-    if ( !TQFileInfo(filename).exists() || QMake::Driver::parseFile( filename, &m_root, 0 ) != 0 )
+    if ( !TQFileInfo(filename).exists() || TQMake::Driver::parseFile( filename, &m_root, 0 ) != 0 )
     {
         kdDebug( 9024 ) << "Couldn't parse project: " << filename << endl;
         if( DomUtil::readBoolEntry( *m_part->projectDom(),
             "/kdevtrollproject/qmake/showParseErrors", true ) )
         {
-            KMessageBox::error( 0, i18n( "Could not parse project file: %1" ).arg( filename ),
+            KMessageBox::error( 0, i18n( "Could not parse project file: %1" ).tqarg( filename ),
                     i18n( "Could not parse project file" ) );
         }
         m_root = 0;
@@ -198,7 +198,7 @@ void Scope::saveToFile() const
         file.close();
     }else
     {
-        KMessageBox::error( 0, i18n( "Could not write project file: %1" ).arg( filename ),
+        KMessageBox::error( 0, i18n( "Could not write project file: %1" ).tqarg( filename ),
                 i18n( "Could not write project file" ) );
     }
 #ifdef DEBUG
@@ -291,13 +291,13 @@ TQStringList Scope::variableValuesForOp( const TQString& variable , const TQStri
     if( !m_root )
         return result;
 
-    TQValueList<QMake::AST*>::const_iterator it;
-    for ( it = m_root->m_children.begin(); it != m_root->m_children.end(); ++it )
+    TQValueList<TQMake::AST*>::const_iterator it;
+    for ( it = m_root->m_tqchildren.begin(); it != m_root->m_tqchildren.end(); ++it )
     {
-        QMake::AST* ast = *it;
-        if ( ast->nodeType() == QMake::AST::AssignmentAST )
+        TQMake::AST* ast = *it;
+        if ( ast->nodeType() == TQMake::AST::AssignmentAST )
         {
-            QMake::AssignmentAST * assign = static_cast<QMake::AssignmentAST*>( ast );
+            TQMake::AssignmentAST * assign = static_cast<TQMake::AssignmentAST*>( ast );
             if ( assign->scopedID == variable && assign->op == op )
             {
                 result += assign->values;
@@ -329,7 +329,7 @@ TQStringList Scope::variableValues( const TQString& variable, bool checkIncParen
     return result;
 }
 
-void Scope::calcValuesFromStatements( const TQString& variable, TQStringList& result, bool checkIncParent, QMake::AST* stopHere, bool fetchFromParent, bool setDefault, bool evaluateSubScopes ) const
+void Scope::calcValuesFromStatements( const TQString& variable, TQStringList& result, bool checkIncParent, TQMake::AST* stopHere, bool fetchFromParent, bool setDefault, bool evaluateSubScopes ) const
 {
     if( !m_root )
         return;
@@ -351,15 +351,15 @@ void Scope::calcValuesFromStatements( const TQString& variable, TQStringList& re
         m_parent->calcValuesFromStatements( variable, result, true, this->m_incast, fetchFromParent, setDefault, evaluateSubScopes );
     }
 
-    TQValueList<QMake::AST*>::const_iterator it;
-    for ( it = m_root->m_children.begin(); it != m_root->m_children.end(); ++it )
+    TQValueList<TQMake::AST*>::const_iterator it;
+    for ( it = m_root->m_tqchildren.begin(); it != m_root->m_tqchildren.end(); ++it )
     {
         if ( stopHere && *it == stopHere )
             return ;
-        QMake::AST* ast = *it;
-        if ( ast->nodeType() == QMake::AST::AssignmentAST )
+        TQMake::AST* ast = *it;
+        if ( ast->nodeType() == TQMake::AST::AssignmentAST )
         {
-            QMake::AssignmentAST * assign = static_cast<QMake::AssignmentAST*>( ast );
+            TQMake::AssignmentAST * assign = static_cast<TQMake::AssignmentAST*>( ast );
             if ( assign->scopedID == variable )
             {
                 if ( assign->op == "=" )
@@ -385,9 +385,9 @@ void Scope::calcValuesFromStatements( const TQString& variable, TQStringList& re
             }
         }else if( evaluateSubScopes )
         {
-            if( ast->nodeType() == QMake::AST::IncludeAST )
+            if( ast->nodeType() == TQMake::AST::IncludeAST )
             {
-                QMake::IncludeAST* iast = static_cast<QMake::IncludeAST*>(ast);
+                TQMake::IncludeAST* iast = static_cast<TQMake::IncludeAST*>(ast);
                 TQValueList<unsigned int> l = m_scopes.keys();
                 for( unsigned int i = 0; i < l.count(); ++i )
                 {
@@ -403,9 +403,9 @@ void Scope::calcValuesFromStatements( const TQString& variable, TQStringList& re
                 }
 
             }
-            else if( ast->nodeType() == QMake::AST::ProjectAST )
+            else if( ast->nodeType() == TQMake::AST::ProjectAST )
             {
-                QMake::ProjectAST* past = static_cast<QMake::ProjectAST*>(ast);
+                TQMake::ProjectAST* past = static_cast<TQMake::ProjectAST*>(ast);
                 if( past->isFunctionScope() || past->isScope() )
                 {
                     TQValueList<unsigned int> l = m_scopes.keys();
@@ -486,13 +486,13 @@ Scope* Scope::createFunctionScope( const TQString& funcName, const TQString& arg
     if ( !m_root )
         return 0;
 
-    QMake::ProjectAST* ast = new QMake::ProjectAST( QMake::ProjectAST::FunctionScope );
+    TQMake::ProjectAST* ast = new TQMake::ProjectAST( TQMake::ProjectAST::FunctionScope );
     ast->scopedID = funcName;
     ast->args = args;
     ast->setDepth( m_root->depth() );
-    ast->addChildAST( new QMake::NewLineAST() );
+    ast->addChildAST( new TQMake::NewLineAST() );
     m_root->addChildAST( ast );
-    m_root->addChildAST( new QMake::NewLineAST() );
+    m_root->addChildAST( new TQMake::NewLineAST() );
     Scope* funcScope = new Scope( m_environment, getNextScopeNum(), this, ast, m_defaultopts, m_part );
     if( funcScope->scopeType() != Scope::InvalidScope )
     {
@@ -508,14 +508,14 @@ Scope* Scope::createSimpleScope( const TQString& scopename )
     if ( !m_root )
         return 0;
 
-    QMake::ProjectAST* ast = new QMake::ProjectAST( QMake::ProjectAST::Scope );
+    TQMake::ProjectAST* ast = new TQMake::ProjectAST( TQMake::ProjectAST::Scope );
     ast->scopedID = scopename;
-    ast->addChildAST( new QMake::NewLineAST() );
+    ast->addChildAST( new TQMake::NewLineAST() );
     ast->setDepth( m_root->depth() );
     m_root->addChildAST( ast );
-    m_root->addChildAST( new QMake::NewLineAST() );
+    m_root->addChildAST( new TQMake::NewLineAST() );
     /* We can't unconditionally add the scope name to CONFIG, scope might be win32 which may only be in CONFIG under windows.
-    if ( m_part->isQt4Project() )
+    if ( m_part->isTQt4Project() )
         addToPlusOp( "CONFIG", TQStringList( scopename ) );
     */
     Scope* simpleScope = new Scope( m_environment, getNextScopeNum(), this, ast, m_defaultopts, m_part );
@@ -547,7 +547,7 @@ Scope* Scope::createIncludeScope( const TQString& includeFile, bool negate )
     if( funcScope == 0 )
         return 0;
 
-    QMake::IncludeAST* ast = new QMake::IncludeAST();
+    TQMake::IncludeAST* ast = new TQMake::IncludeAST();
     ast->setDepth( m_root->depth() );
     ast->projectName = includeFile;
     Scope* incScope = new Scope( m_environment, funcScope->getNextScopeNum(), funcScope, ast, projectDir(), resolveVariables( ast->projectName ), m_defaultopts, m_part );
@@ -628,7 +628,7 @@ bool Scope::deleteFunctionScope( unsigned int num )
     Scope* funcScope = m_scopes[ num ];
     if ( funcScope )
     {
-        QMake::AST* ast = m_root->m_children[ m_root->m_children.findIndex( funcScope->m_root ) ];
+        TQMake::AST* ast = m_root->m_tqchildren[ m_root->m_tqchildren.findIndex( funcScope->m_root ) ];
         if( !ast )
             return false;
         m_scopes.remove( num );
@@ -648,7 +648,7 @@ bool Scope::deleteSimpleScope( unsigned int num )
     Scope* simpleScope = m_scopes[ num ];
     if ( simpleScope )
     {
-        QMake::AST* ast = m_root->m_children[ m_root->m_children.findIndex( simpleScope->m_root ) ];
+        TQMake::AST* ast = m_root->m_tqchildren[ m_root->m_tqchildren.findIndex( simpleScope->m_root ) ];
         if( !ast )
             return false;
         m_scopes.remove( num );
@@ -669,7 +669,7 @@ bool Scope::deleteIncludeScope( unsigned int num )
     Scope * incScope = m_scopes[ num ];
     if( !incScope )
         return false;
-    QMake::AST* ast = incScope->m_incast;
+    TQMake::AST* ast = incScope->m_incast;
     if( !ast )
         return false;
     m_scopes.remove( num );
@@ -685,11 +685,11 @@ bool Scope::deleteSubProject( unsigned int num, bool deleteSubdir )
     if ( !m_root || !m_scopes.contains( num ) )
         return false;
 
-    TQValueList<QMake::AST*>::iterator it = findExistingVariable( "TEMPLATE" );
-    if ( it != m_root->m_children.end() )
+    TQValueList<TQMake::AST*>::iterator it = findExistingVariable( "TEMPLATE" );
+    if ( it != m_root->m_tqchildren.end() )
     {
-        QMake::AssignmentAST * tempast = static_cast<QMake::AssignmentAST*>( *it );
-        if ( tempast->values.findIndex( "subdirs" ) != -1 || findExistingVariable( "TEMPLATE" ) != m_root->m_children.end() )
+        TQMake::AssignmentAST * tempast = static_cast<TQMake::AssignmentAST*>( *it );
+        if ( tempast->values.findIndex( "subdirs" ) != -1 || findExistingVariable( "TEMPLATE" ) != m_root->m_tqchildren.end() )
         {
             Scope* project = m_scopes[ num ];
             if( !project )
@@ -722,10 +722,10 @@ bool Scope::deleteSubProject( unsigned int num, bool deleteSubdir )
                     kdDebug(9024) << "removed subproject?:" << d.remove( dir ) << endl;
                 }
             }
-            TQValueList<QMake::AST*>::iterator foundit = findExistingVariable( "SUBDIRS" );
-            if ( foundit != m_root->m_children.end() )
+            TQValueList<TQMake::AST*>::iterator foundit = findExistingVariable( "SUBDIRS" );
+            if ( foundit != m_root->m_tqchildren.end() )
             {
-                QMake::AssignmentAST * ast = static_cast<QMake::AssignmentAST*>( *foundit );
+                TQMake::AssignmentAST * ast = static_cast<TQMake::AssignmentAST*>( *foundit );
                 updateValues( ast->values, TQStringList( projdir ), true, ast->indent );
                 if( m_varCache.contains( "SUBDIRS" ) )
                     m_varCache.erase( "SUBDIRS" );
@@ -804,11 +804,11 @@ void Scope::updateVariable( const TQString& variable, const TQString& op, const
     if( m_varCache.contains( variable ) )
         m_varCache.erase( variable );
 
-    for ( int i = m_root->m_children.count() - 1; i >= 0; --i )
+    for ( int i = m_root->m_tqchildren.count() - 1; i >= 0; --i )
     {
-        if ( m_root->m_children[ i ] ->nodeType() == QMake::AST::AssignmentAST )
+        if ( m_root->m_tqchildren[ i ] ->nodeType() == TQMake::AST::AssignmentAST )
         {
-            QMake::AssignmentAST * assignment = static_cast<QMake::AssignmentAST*>( m_root->m_children[ i ] );
+            TQMake::AssignmentAST * assignment = static_cast<TQMake::AssignmentAST*>( m_root->m_tqchildren[ i ] );
             if ( assignment->scopedID == variable && Scope::isCompatible( assignment->op, op ) )
             {
                 updateValues( assignment->values, values, removeFromOp, assignment->indent );
@@ -876,7 +876,7 @@ void Scope::updateVariable( const TQString& variable, const TQString& op, const
 
     if ( !removeFromOp )
     {
-        QMake::AssignmentAST * ast = new QMake::AssignmentAST();
+        TQMake::AssignmentAST * ast = new TQMake::AssignmentAST();
         ast->scopedID = variable;
         ast->op = op;
         updateValues( ast->values, values );
@@ -892,24 +892,24 @@ void Scope::updateVariable( const TQString& variable, const TQString& op, const
     }
 }
 
-TQValueList<QMake::AST*>::iterator Scope::findExistingVariable( const TQString& variable )
+TQValueList<TQMake::AST*>::iterator Scope::findExistingVariable( const TQString& variable )
 {
-    TQValueList<QMake::AST*>::iterator it;
+    TQValueList<TQMake::AST*>::iterator it;
     TQStringList ops;
     ops << "=" << "+=";
 
-    for ( it = m_root->m_children.begin(); it != m_root->m_children.end() ; ++it )
+    for ( it = m_root->m_tqchildren.begin(); it != m_root->m_tqchildren.end() ; ++it )
     {
-        if ( ( *it ) ->nodeType() == QMake::AST::AssignmentAST )
+        if ( ( *it ) ->nodeType() == TQMake::AST::AssignmentAST )
         {
-            QMake::AssignmentAST * assignment = static_cast<QMake::AssignmentAST*>( *it );
+            TQMake::AssignmentAST * assignment = static_cast<TQMake::AssignmentAST*>( *it );
             if ( assignment->scopedID == variable && ops.findIndex( assignment->op ) != -1 )
             {
                 return it;
             }
         }
     }
-    return m_root->m_children.end();
+    return m_root->m_tqchildren.end();
 }
 
 void Scope::init()
@@ -920,17 +920,17 @@ void Scope::init()
     kdDebug(9024) << "Initializing Scope: " << scopeName() << this << endl;
     m_maxCustomVarNum = 1;
 
-    TQValueList<QMake::AST*>::const_iterator it;
-    for ( it = m_root->m_children.begin(); it != m_root->m_children.end(); ++it )
+    TQValueList<TQMake::AST*>::const_iterator it;
+    for ( it = m_root->m_tqchildren.begin(); it != m_root->m_tqchildren.end(); ++it )
     {
-        if ( ( *it ) ->nodeType() == QMake::AST::ProjectAST )
+        if ( ( *it ) ->nodeType() == TQMake::AST::ProjectAST )
         {
-            QMake::ProjectAST * p = static_cast<QMake::ProjectAST*>( *it );
+            TQMake::ProjectAST * p = static_cast<TQMake::ProjectAST*>( *it );
             m_scopes.insert( getNextScopeNum(), new Scope( m_environment, getNextScopeNum(), this, p, m_defaultopts, m_part ) );
         }
-        else if ( ( *it ) ->nodeType() == QMake::AST::IncludeAST )
+        else if ( ( *it ) ->nodeType() == TQMake::AST::IncludeAST )
         {
-            QMake::IncludeAST * i = static_cast<QMake::IncludeAST*>( *it );
+            TQMake::IncludeAST * i = static_cast<TQMake::IncludeAST*>( *it );
             TQString filename = i->projectName;
             if( i->projectName.stripWhiteSpace().startsWith("$") )
             {
@@ -938,9 +938,9 @@ void Scope::init()
             }
             m_scopes.insert( getNextScopeNum(), new Scope( m_environment, getNextScopeNum(), this, i, projectDir(), filename, m_defaultopts, m_part ) );
         }
-        else if ( ( *it ) ->nodeType() == QMake::AST::AssignmentAST )
+        else if ( ( *it ) ->nodeType() == TQMake::AST::AssignmentAST )
         {
-            QMake::AssignmentAST * m = static_cast<QMake::AssignmentAST*>( *it );
+            TQMake::AssignmentAST * m = static_cast<TQMake::AssignmentAST*>( *it );
             // Check wether TEMPLATE==subdirs here too!
             if ( m->scopedID == "SUBDIRS" && variableValues("TEMPLATE").findIndex("subdirs") != -1 )
             {
@@ -1040,7 +1040,7 @@ const TQMap<unsigned int, TQMap<TQString, TQString> > Scope::customVariables() c
     if( !m_root )
         return result;
 
-    TQMap<unsigned int, QMake::AssignmentAST*>::const_iterator it = m_customVariables.begin();
+    TQMap<unsigned int, TQMake::AssignmentAST*>::const_iterator it = m_customVariables.begin();
     for ( ; it != m_customVariables.end(); ++it )
     {
         TQMap<TQString,TQString> temp;
@@ -1069,7 +1069,7 @@ void Scope::updateCustomVariable( unsigned int id, const TQString& name, const T
 
 unsigned int Scope::addCustomVariable( const TQString& var, const TQString& op, const TQString& values )
 {
-    QMake::AssignmentAST* newast = new QMake::AssignmentAST();
+    TQMake::AssignmentAST* newast = new TQMake::AssignmentAST();
     newast->scopedID = var;
     newast->op = op;
     newast->values.append(values.stripWhiteSpace());
@@ -1086,9 +1086,9 @@ void Scope::removeCustomVariable( unsigned int id )
 {
     if( m_customVariables.contains(id) )
     {
-        QMake::AssignmentAST* m = m_customVariables[id];
+        TQMake::AssignmentAST* m = m_customVariables[id];
         m_customVariables.remove(id);
-        m_root->m_children.remove( m );
+        m_root->m_tqchildren.remove( m );
     }
 }
 
@@ -1097,12 +1097,12 @@ bool Scope::isVariableReset( const TQString& var )
     bool result = false;
     if( !m_root )
         return result;
-    TQValueList<QMake::AST*>::const_iterator it = m_root->m_children.begin();
-    for ( ; it != m_root->m_children.end(); ++it )
+    TQValueList<TQMake::AST*>::const_iterator it = m_root->m_tqchildren.begin();
+    for ( ; it != m_root->m_tqchildren.end(); ++it )
     {
-        if ( ( *it ) ->nodeType() == QMake::AST::AssignmentAST )
+        if ( ( *it ) ->nodeType() == TQMake::AST::AssignmentAST )
         {
-            QMake::AssignmentAST * ast = static_cast<QMake::AssignmentAST*>( *it );
+            TQMake::AssignmentAST * ast = static_cast<TQMake::AssignmentAST*>( *it );
             if ( ast->scopedID == var && ast->op == "=" )
             {
                 result = true;
@@ -1118,18 +1118,18 @@ void Scope::removeVariable( const TQString& var, const TQString& op )
     if ( !m_root )
         return ;
 
-    QMake::AssignmentAST* ast = 0;
+    TQMake::AssignmentAST* ast = 0;
 
-    TQValueList<QMake::AST*>::iterator it = m_root->m_children.begin();
-    for ( ; it != m_root->m_children.end(); ++it )
+    TQValueList<TQMake::AST*>::iterator it = m_root->m_tqchildren.begin();
+    for ( ; it != m_root->m_tqchildren.end(); ++it )
     {
-        if ( ( *it ) ->nodeType() == QMake::AST::AssignmentAST )
+        if ( ( *it ) ->nodeType() == TQMake::AST::AssignmentAST )
         {
-            ast = static_cast<QMake::AssignmentAST*>( *it );
+            ast = static_cast<TQMake::AssignmentAST*>( *it );
             if ( ast->scopedID == var && ast->op == op )
             {
-                m_root->m_children.remove( ast );
-                it = m_root->m_children.begin();
+                m_root->m_tqchildren.remove( ast );
+                it = m_root->m_tqchildren.begin();
             }
         }
     }
@@ -1182,9 +1182,9 @@ TQStringList Scope::cleanStringList(const TQStringList& list) const
     return result;
 }
 
-bool Scope::isQt4Project() const
+bool Scope::isTQt4Project() const
 {
-    return m_part->isQt4Project();
+    return m_part->isTQt4Project();
 }
 
 void Scope::reloadProject()
@@ -1209,7 +1209,7 @@ void Scope::reloadProject()
         delete m_root;
     if ( !loadFromFile( filename ) && !TQFileInfo( filename ).exists() )
     {
-        m_root = new QMake::ProjectAST();
+        m_root = new TQMake::ProjectAST();
         m_root->setFileName( filename );
     }
     init();
@@ -1255,12 +1255,12 @@ TQString Scope::resolveVariables( const TQString& value ) const
 }
 
 
-TQString Scope::resolveVariables( const TQString& value, QMake::AST* stopHere ) const
+TQString Scope::resolveVariables( const TQString& value, TQMake::AST* stopHere ) const
 {
     return resolveVariables(TQStringList(value),  stopHere).front();
 }
 
-TQStringList Scope::variableValues( const TQString& variable, QMake::AST* stopHere, bool fetchFromParent ) const
+TQStringList Scope::variableValues( const TQString& variable, TQMake::AST* stopHere, bool fetchFromParent ) const
 {
     TQStringList result;
 
@@ -1272,7 +1272,7 @@ TQStringList Scope::variableValues( const TQString& variable, QMake::AST* stopHe
     return result;
 }
 
-TQStringList Scope::resolveVariables( const TQStringList& values, QMake::AST* stopHere ) const
+TQStringList Scope::resolveVariables( const TQStringList& values, TQMake::AST* stopHere ) const
 {
     TQStringList result = values;
     TQMap<TQString, TQStringList> variables;
@@ -1426,7 +1426,7 @@ void Scope::allFiles( const TQString& projectDirectory, std::set<TQString>& res
             }
         }
 
-        if ( isQt4Project() )
+        if ( isTQt4Project() )
         {
             values = variableValues( "RESOURCES" ,false, false );
             for ( it = values.begin(); it != values.end(); ++it )
@@ -1481,7 +1481,7 @@ void Scope::allFiles( const TQString& projectDirectory, std::set<TQString>& res
                 file = resolveVariables( file );
                 res.insert( TQDir::cleanDirPath( file ) );
 
-                if( !m_part->isQt4Project())
+                if( !m_part->isTQt4Project())
                 {
                     header = projectDir()+TQString(TQChar(TQDir::separator())) + *it+".h";
                     if( TQFileInfo(header).exists() )
@@ -1541,7 +1541,7 @@ TQString Scope::findCustomVarForPath( const TQString& path )
     if( !m_root )
         return result;
 
-    TQMap<unsigned int, QMake::AssignmentAST*>::const_iterator it = m_customVariables.begin();
+    TQMap<unsigned int, TQMake::AssignmentAST*>::const_iterator it = m_customVariables.begin();
     for( ; it != m_customVariables.end(); ++it )
     {
         kdDebug(9024) << "Checking " << path << " against " << cleanStringList(it.data()->values) << endl;
@@ -1561,7 +1561,7 @@ void Scope::loadDefaultOpts()
 {
     if( !m_defaultopts && m_root )
     {
-        m_defaultopts = new QMakeDefaultOpts();
+        m_defaultopts = new TQMakeDefaultOpts();
         if( DomUtil::readBoolEntry( *m_part->projectDom(), "/kdevtrollproject/qmake/disableDefaultOpts", true ) )
         {
             m_defaultopts->readVariables( m_part->qmakePath(), TQFileInfo( m_root->fileName() ).dirPath( true ) );
@@ -1576,13 +1576,13 @@ TQString Scope::getLineEndingString() const
     {
         switch( m_root->lineEnding() )
         {
-            case QMake::ProjectAST::Windows:
+            case TQMake::ProjectAST::Windows:
                 return TQString("\r\n");
                 break;
-            case QMake::ProjectAST::MacOS:
+            case TQMake::ProjectAST::MacOS:
                 return TQString("\r");
                 break;
-            case QMake::ProjectAST::Unix:
+            case TQMake::ProjectAST::Unix:
                 return TQString("\n");
                 break;
         }
@@ -1616,56 +1616,56 @@ void Scope::printTree()
     p.processProject(m_root);
 }
 
-Scope::PrintAST::PrintAST() : QMake::ASTVisitor()
+Scope::PrintAST::PrintAST() : TQMake::ASTVisitor()
 {
     indent = 0;
 }
 
-void Scope::PrintAST::processProject( QMake::ProjectAST* p )
+void Scope::PrintAST::processProject( TQMake::ProjectAST* p )
 {
-    QMake::ASTVisitor::processProject(p);
+    TQMake::ASTVisitor::processProject(p);
 }
 
-void Scope::PrintAST::enterRealProject( QMake::ProjectAST* p )
+void Scope::PrintAST::enterRealProject( TQMake::ProjectAST* p )
 {
     kdDebug(9024) << getIndent() << "--------- Entering Project: " << replaceWs(p->fileName()) << " --------------" << endl;
     indent += 4;
-    QMake::ASTVisitor::enterRealProject(p);
+    TQMake::ASTVisitor::enterRealProject(p);
 }
 
-void Scope::PrintAST::leaveRealProject( QMake::ProjectAST* p )
+void Scope::PrintAST::leaveRealProject( TQMake::ProjectAST* p )
 {
     indent -= 4;
     kdDebug(9024) << getIndent() << "--------- Leaving Project: " << replaceWs(p->fileName()) << " --------------" << endl;
-    QMake::ASTVisitor::leaveRealProject(p);
+    TQMake::ASTVisitor::leaveRealProject(p);
 }
 
-void Scope::PrintAST::enterScope( QMake::ProjectAST* p )
+void Scope::PrintAST::enterScope( TQMake::ProjectAST* p )
 {
     kdDebug(9024) << getIndent() << "--------- Entering Scope: " << replaceWs(p->scopedID) << " --------------" << endl;
     indent += 4;
-    QMake::ASTVisitor::enterScope(p);
+    TQMake::ASTVisitor::enterScope(p);
 }
 
-void Scope::PrintAST::leaveScope( QMake::ProjectAST* p )
+void Scope::PrintAST::leaveScope( TQMake::ProjectAST* p )
 {
     indent -= 4;
     kdDebug(9024) << getIndent() << "--------- Leaving Scope: " << replaceWs(p->scopedID) << " --------------" << endl;
-    QMake::ASTVisitor::leaveScope(p);
+    TQMake::ASTVisitor::leaveScope(p);
 }
 
-void Scope::PrintAST::enterFunctionScope( QMake::ProjectAST* p )
+void Scope::PrintAST::enterFunctionScope( TQMake::ProjectAST* p )
 {
     kdDebug(9024) << getIndent() << "--------- Entering FunctionScope: " << replaceWs(p->scopedID) << "(" << replaceWs(p->args) << ")"<< " --------------" << endl;
     indent += 4;
-    QMake::ASTVisitor::enterFunctionScope(p);
+    TQMake::ASTVisitor::enterFunctionScope(p);
 }
 
-void Scope::PrintAST::leaveFunctionScope( QMake::ProjectAST* p )
+void Scope::PrintAST::leaveFunctionScope( TQMake::ProjectAST* p )
 {
     indent -= 4;
     kdDebug(9024) << getIndent() << "--------- Leaving FunctionScope: " << replaceWs(p->scopedID) << "(" << replaceWs(p->args) << ")"<< " --------------" << endl;
-    QMake::ASTVisitor::leaveFunctionScope(p);
+    TQMake::ASTVisitor::leaveFunctionScope(p);
 }
 
 TQString Scope::PrintAST::replaceWs(TQString s)
@@ -1673,29 +1673,29 @@ TQString Scope::PrintAST::replaceWs(TQString s)
     return s.replace("\n", "%nl").replace("\t", "%tab").replace(" ", "%spc");
 }
 
-void Scope::PrintAST::processAssignment( QMake::AssignmentAST* a)
+void Scope::PrintAST::processAssignment( TQMake::AssignmentAST* a)
 {
     kdDebug(9024) << getIndent() << "Assignment: " << replaceWs(a->scopedID) << " " << replaceWs(a->op) << " "
         << replaceWs(a->values.join("|"))<< endl;
-    QMake::ASTVisitor::processAssignment(a);
+    TQMake::ASTVisitor::processAssignment(a);
 }
 
-void Scope::PrintAST::processNewLine( QMake::NewLineAST* n)
+void Scope::PrintAST::processNewLine( TQMake::NewLineAST* n)
 {
     kdDebug(9024) << getIndent() << "Newline " << endl;
-    QMake::ASTVisitor::processNewLine(n);
+    TQMake::ASTVisitor::processNewLine(n);
 }
 
-void Scope::PrintAST::processComment( QMake::CommentAST* a)
+void Scope::PrintAST::processComment( TQMake::CommentAST* a)
 {
     kdDebug(9024) << getIndent() << "Comment: " << replaceWs(a->comment) << endl;
-    QMake::ASTVisitor::processComment(a);
+    TQMake::ASTVisitor::processComment(a);
 }
 
-void Scope::PrintAST::processInclude( QMake::IncludeAST* a)
+void Scope::PrintAST::processInclude( TQMake::IncludeAST* a)
 {
     kdDebug(9024) << getIndent() << "Include: " << replaceWs(a->projectName) << endl;
-    QMake::ASTVisitor::processInclude(a);
+    TQMake::ASTVisitor::processInclude(a);
 }
 
 TQString Scope::PrintAST::getIndent()
