@@ -20,11 +20,11 @@
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
+    the TQt library by Trolltech AS, Norway (or with modified versions
+    of TQt that use the same license as TQt), and distribute linked
     combinations including the two.  You must obey the GNU General
     Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
+    TQt.  If you modify this file, you may extend this exception to
     your version of the file, but you are not obligated to do so.  If
     you do not wish to do so, delete this exception statement from
     your version.
@@ -106,7 +106,7 @@ namespace {
     KURL::List m;
   public:
     to( const TQVariant & v ) {
-      // wow, KURL::List is broken... it lacks conversion from and to QVL<KURL>...
+      // wow, KURL::List is broken... it lacks conversion from and to TQVL<KURL>...
       m += to< TQValueList<KURL> >( v );
     }
     operator KURL::List() const { return m; }
@@ -224,9 +224,9 @@ namespace {
         return TQVariant( data.defaults.boolean.value, int() );
     case ArgType_String:
       if ( isList() )
-        return TQStringList( TQString::fromLatin1( data.defaults.string ) );
+        return TQStringList( TQString::tqfromLatin1( data.defaults.string ) );
       else
-        return TQString::fromLatin1( data.defaults.string );
+        return TQString::tqfromLatin1( data.defaults.string );
     case ArgType_Int:
       if ( isList() )
         return TQValueList<TQVariant>() << data.defaults.integer;
@@ -240,15 +240,15 @@ namespace {
     case ArgType_Path:
     case ArgType_DirPath:
       if ( isList() )
-        return TQValueList<TQVariant>() << TQString::fromLatin1( data.defaults.path );
+        return TQValueList<TQVariant>() << TQString::tqfromLatin1( data.defaults.path );
       else
-        return TQString::fromLatin1( data.defaults.path );
+        return TQString::tqfromLatin1( data.defaults.path );
     case ArgType_URL:
     case ArgType_LDAPURL:
       if ( isList() )
-        return TQValueList<TQVariant>() << TQString::fromLatin1( data.defaults.url );
+        return TQValueList<TQVariant>() << TQString::tqfromLatin1( data.defaults.url );
       else
-        return TQString::fromLatin1( data.defaults.url );
+        return TQString::tqfromLatin1( data.defaults.url );
     }
   }
 
@@ -432,13 +432,13 @@ Kleo::CryptoBackend::Protocol * Kleo::ChiasmusBackend::protocol( const char * na
 
 bool Kleo::ChiasmusBackend::checkForOpenPGP( TQString * reason ) const {
   if ( reason )
-    *reason = i18n( "Unsupported protocol \"%1\"" ).arg( "OpenPGP" );
+    *reason = i18n( "Unsupported protocol \"%1\"" ).tqarg( "OpenPGP" );
   return false;
 }
 
 bool Kleo::ChiasmusBackend::checkForSMIME( TQString * reason ) const {
   if ( reason )
-    *reason = i18n( "Unsupported protocol \"%1\"" ).arg( "SMIME" );
+    *reason = i18n( "Unsupported protocol \"%1\"" ).tqarg( "SMIME" );
   return false;
 }
 
@@ -454,7 +454,7 @@ bool Kleo::ChiasmusBackend::checkForChiasmus( TQString * reason ) const {
   const TQFileInfo fi( KShell::tildeExpand( chiasmus ) );
   if ( !fi.isExecutable() ) {
     if ( reason )
-      *reason = i18n( "File \"%1\" does not exist or is not executable." ).arg( chiasmus );
+      *reason = i18n( "File \"%1\" does not exist or is not executable." ).tqarg( chiasmus );
     return false;
   }
 
@@ -467,7 +467,7 @@ bool Kleo::ChiasmusBackend::checkForProtocol( const char * name, TQString * reas
   if ( qstricmp( name, "Chiasmus" ) == 0 )
     return checkForChiasmus( reason );
   if ( reason )
-    *reason = i18n( "Unsupported protocol \"%1\"" ).arg( name );
+    *reason = i18n( "Unsupported protocol \"%1\"" ).tqarg( name );
   return 0;
 }
 
