@@ -209,24 +209,24 @@ public:
     return _unknownAttrsHandlingChar;
   }
 
-  TQValueList< QPair<TQString,TQString> > reorder( const TQValueList< QPair<TQString,TQString> > & dn ) const
+  TQValueList< TQPair<TQString,TQString> > reorder( const TQValueList< TQPair<TQString,TQString> > & dn ) const
   {
     return reorder( dn, _attrOrder, _unknownAttrsHandling );
   }
 
 
-  static TQValueList< QPair<TQString,TQString> > reorder(
-    const TQValueList< QPair<TQString,TQString> > & dn,
+  static TQValueList< TQPair<TQString,TQString> > reorder(
+    const TQValueList< TQPair<TQString,TQString> > & dn,
     TQStringList attrOrder,
     UnknownAttrsHandling unknownAttrsHandling )
   {
     if( !attrOrder.isEmpty() ){
-      TQPtrList<   QPair<TQString,TQString> > unknownEntries;
-      TQValueList< QPair<TQString,TQString> > dnNew;
+      TQPtrList<   TQPair<TQString,TQString> > unknownEntries;
+      TQValueList< TQPair<TQString,TQString> > dnNew;
 
-      QPair<TQString,TQString>* unknownEntry;
+      TQPair<TQString,TQString>* unknownEntry;
       TQStringList::ConstIterator itOrder;
-      TQValueList< QPair<TQString,TQString> >::ConstIterator itDN;
+      TQValueList< TQPair<TQString,TQString> >::ConstIterator itDN;
       bool bFound;
 
       if( unknownAttrsHandling != unknownAttrsHide ){
@@ -424,7 +424,7 @@ CryptPlugWrapper::CryptPlugWrapper( const TQString& name,
     _libName( libName ),
     _updateURL( update ),
     _active(  active  ),
-    _initStatus( InitStatus_undef ),
+    _initqStatus( IniStatus_undef ),
     _cp( 0 ),
     _config( 0 ),
     _cryptoConfig( 0 )
@@ -472,7 +472,7 @@ TQString CryptPlugWrapper::protocol() const
     return "SMIME";
   if ( _libName.contains( "openpgp" ) )
     return "OpenPGP";
-  return TQString::null;
+  return TQString();
 }
 
 void CryptPlugWrapper::setDisplayName( const TQString& name )
@@ -492,15 +492,15 @@ TQString CryptPlugWrapper::displayName() const
     return i18n("(Unknown Protocol)");
 }
 
-bool CryptPlugWrapper::initialize( InitStatus* initStatus, TQString* errorMsg )
+bool CryptPlugWrapper::initialize( InitqStatus* initqStatus, TQString* errorMsg )
 {
     if ( _cp )
       return true;
 
-    _initStatus = InitStatus_undef;
+    _initqStatus = IniStatus_undef;
     /* make sure we have a lib name */
     if ( _libName.isEmpty() ) {
-      _initStatus = InitStatus_NoLibName;
+      _initqStatus = IniStatus_NoLibName;
       kdDebug(5150) << "No library name was given.\n" << endl;
     } else {
       if ( _libName.contains( "smime" ) ) {
@@ -515,26 +515,26 @@ bool CryptPlugWrapper::initialize( InitStatus* initStatus, TQString* errorMsg )
       }
 
       if ( !_cp ) {
-	_initStatus = InitStatus_LoadError;
+	_initqStatus = IniStatus_LoadError;
 	kdDebug(5150) << "Couldn't create '" << _libName.latin1() << "'" << endl;
       } else {
 	/* now call the init function */
 	if( !_cp->initialize() ) {
-	  _initStatus = InitStatus_InitError;
+	  _initqStatus = IniStatus_InitError;
 	  kdDebug(5150) << "Error while executing function 'initialize' on plugin " << _libName << endl;
-	  _lastError = i18n("Error while initializing plugin \"%1\"").arg( _libName );
+	  _lastError = i18n("Error while initializing plugin \"%1\"").tqarg( _libName );
 	  if ( errorMsg )
 	    *errorMsg = _lastError;
 	  delete _cp; _cp = 0;
 	  delete _config; _config = 0;
 	} else {
-	  _initStatus  = InitStatus_Ok;
+	  _initqStatus  = IniStatus_Ok;
 	}
       }
     }
-    if( initStatus )
-        *initStatus = _initStatus;
-    return _initStatus == InitStatus_Ok;
+    if( initqStatus )
+        *initqStatus = _initqStatus;
+    return _initqStatus == IniStatus_Ok;
 }
 
 
@@ -547,11 +547,11 @@ void CryptPlugWrapper::deinitialize()
 }
 
 
-CryptPlugWrapper::InitStatus CryptPlugWrapper::initStatus( TQString* errorMsg ) const
+CryptPlugWrapper::InitqStatus CryptPlugWrapper::initqStatus( TQString* errorMsg ) const
 {
     if( errorMsg )
         *errorMsg = _lastError;
-    return _initStatus;
+    return _initqStatus;
 }
 
 
