@@ -20,11 +20,11 @@
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
+    the TQt library by Trolltech AS, Norway (or with modified versions
+    of TQt that use the same license as TQt), and distribute linked
     combinations including the two.  You must obey the GNU General
     Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
+    TQt.  If you modify this file, you may extend this exception to
     your version of the file, but you are not obligated to do so.  If
     you do not wish to do so, delete this exception statement from
     your version.
@@ -81,8 +81,8 @@ namespace {
     if ( !item )
       return;
 
-    const TQRect itemRect = mKeyListView->itemRect( item );
-    if ( !itemRect.isValid() )
+    const TQRect tqitemRect = mKeyListView->tqitemRect( item );
+    if ( !tqitemRect.isValid() )
       return;
 
     const int col = mKeyListView->header()->sectionAt( p.x() );
@@ -93,8 +93,8 @@ namespace {
     if ( !headerRect.isValid() )
       return;
 
-    const TQRect cellRect( headerRect.left(), itemRect.top(),
-			  headerRect.width(), itemRect.height() );
+    const TQRect cellRect( headerRect.left(), tqitemRect.top(),
+			  headerRect.width(), tqitemRect.height() );
 
     TQString tipStr;
     if ( const Kleo::KeyListViewItem * klvi = Kleo::lvi_cast<Kleo::KeyListViewItem>( item ) )
@@ -173,7 +173,7 @@ Kleo::KeyListView::KeyListView( const ColumnStrategy * columnStrategy, const Dis
 
 Kleo::KeyListView::~KeyListView() {
   d->updateTimer->stop();
-  // need to clear here, since in ~TQListView, our children won't have
+  // need to clear here, since in ~TQListView, our tqchildren won't have
   // a valid listView() pointing to us anymore, and their dtors try to
   // unregister from us.
   clear();
@@ -395,8 +395,8 @@ Kleo::KeyListViewItem::KeyListViewItem( KeyListViewItem * parent, KeyListViewIte
 }
 
 Kleo::KeyListViewItem::~KeyListViewItem() {
-  // delete the children first... When children are deleted in the
-  // QLVI dtor, they don't have listView() anymore, thus they don't
+  // delete the tqchildren first... When tqchildren are deleted in the
+  // TQLVI dtor, they don't have listView() anymore, thus they don't
   // call deregister( this ), leading to stale entries in the
   // itemMap...
   while ( TQListViewItem * item = firstChild() )
@@ -428,13 +428,13 @@ void Kleo::KeyListViewItem::setKey( const GpgME::Key & key ) {
     if ( const TQPixmap * pix = cs->pixmap( key, i ) )
       setPixmap( i, *pix );
   }
-  repaint();
+  tqrepaint();
 }
 
 TQString Kleo::KeyListViewItem::toolTip( int col ) const {
   return listView() && listView()->columnStrategy()
     ? listView()->columnStrategy()->toolTip( key(), col )
-    : TQString::null ;
+    : TQString() ;
 }
 
 int Kleo::KeyListViewItem::compare( TQListViewItem * item, int col, bool ascending ) const {
@@ -444,10 +444,10 @@ int Kleo::KeyListViewItem::compare( TQListViewItem * item, int col, bool ascendi
   return listView()->columnStrategy()->compare( this->key(), that->key(), col );
 }
 
-void Kleo::KeyListViewItem::paintCell( TQPainter * p, const TQColorGroup & cg, int column, int width, int alignment ) {
+void Kleo::KeyListViewItem::paintCell( TQPainter * p, const TQColorGroup & cg, int column, int width, int tqalignment ) {
   const KeyListView::DisplayStrategy * ds = listView() ? listView()->displayStrategy() : 0 ;
   if ( !ds ) {
-    TQListViewItem::paintCell( p, cg, column, width, alignment );
+    TQListViewItem::paintCell( p, cg, column, width, tqalignment );
     return;
   }
   const TQColor fg = ds->keyForeground( key(), cg.text() );
@@ -459,7 +459,7 @@ void Kleo::KeyListViewItem::paintCell( TQPainter * p, const TQColorGroup & cg, i
   _cg.setColor( TQColorGroup::Text, fg );
   _cg.setColor( TQColorGroup::Base, bg );
 
-  TQListViewItem::paintCell( p, _cg, column, width, alignment );
+  TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
 }
 
 void Kleo::KeyListViewItem::insertItem( TQListViewItem * qlvi ) {
@@ -515,13 +515,13 @@ void Kleo::SubkeyKeyListViewItem::setSubkey( const GpgME::Subkey & subkey ) {
 TQString Kleo::SubkeyKeyListViewItem::text( int col ) const {
   return listView() && listView()->columnStrategy()
     ? listView()->columnStrategy()->subkeyText( subkey(), col )
-    : TQString::null ;
+    : TQString() ;
 }
 
 TQString Kleo::SubkeyKeyListViewItem::toolTip( int col ) const {
   return listView() && listView()->columnStrategy()
     ? listView()->columnStrategy()->subkeyToolTip( subkey(), col )
-    : TQString::null ;
+    : TQString() ;
 }
 
 const TQPixmap * Kleo::SubkeyKeyListViewItem::pixmap( int col ) const {
@@ -536,10 +536,10 @@ int Kleo::SubkeyKeyListViewItem::compare( TQListViewItem * item, int col, bool a
   return listView()->columnStrategy()->subkeyCompare( this->subkey(), that->subkey(), col );
 }
 
-void Kleo::SubkeyKeyListViewItem::paintCell( TQPainter * p, const TQColorGroup & cg, int column, int width, int alignment ) {
+void Kleo::SubkeyKeyListViewItem::paintCell( TQPainter * p, const TQColorGroup & cg, int column, int width, int tqalignment ) {
   const KeyListView::DisplayStrategy * ds = listView() ? listView()->displayStrategy() : 0 ;
   if ( !ds ) {
-    TQListViewItem::paintCell( p, cg, column, width, alignment );
+    TQListViewItem::paintCell( p, cg, column, width, tqalignment );
     return;
   }
   const TQColor fg = ds->subkeyForeground( subkey(), cg.text() );
@@ -551,7 +551,7 @@ void Kleo::SubkeyKeyListViewItem::paintCell( TQPainter * p, const TQColorGroup &
   _cg.setColor( TQColorGroup::Text, fg );
   _cg.setColor( TQColorGroup::Base, bg );
 
-  TQListViewItem::paintCell( p, _cg, column, width, alignment );
+  TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
 }
 
 
@@ -593,13 +593,13 @@ void Kleo::UserIDKeyListViewItem::setUserID( const GpgME::UserID & userID ) {
 TQString Kleo::UserIDKeyListViewItem::text( int col ) const {
   return listView() && listView()->columnStrategy()
     ? listView()->columnStrategy()->userIDText( userID(), col )
-    : TQString::null ;
+    : TQString() ;
 }
 
 TQString Kleo::UserIDKeyListViewItem::toolTip( int col ) const {
   return listView() && listView()->columnStrategy()
     ? listView()->columnStrategy()->userIDToolTip( userID(), col )
-    : TQString::null ;
+    : TQString() ;
 }
 
 const TQPixmap * Kleo::UserIDKeyListViewItem::pixmap( int col ) const {
@@ -615,10 +615,10 @@ int Kleo::UserIDKeyListViewItem::compare( TQListViewItem * item, int col, bool a
 }
 
 
-void Kleo::UserIDKeyListViewItem::paintCell( TQPainter * p, const TQColorGroup & cg, int column, int width, int alignment ) {
+void Kleo::UserIDKeyListViewItem::paintCell( TQPainter * p, const TQColorGroup & cg, int column, int width, int tqalignment ) {
   const KeyListView::DisplayStrategy * ds = listView() ? listView()->displayStrategy() : 0 ;
   if ( !ds ) {
-    TQListViewItem::paintCell( p, cg, column, width, alignment );
+    TQListViewItem::paintCell( p, cg, column, width, tqalignment );
     return;
   }
   const TQColor fg = ds->useridForeground( userID(), cg.text() );
@@ -630,7 +630,7 @@ void Kleo::UserIDKeyListViewItem::paintCell( TQPainter * p, const TQColorGroup &
   _cg.setColor( TQColorGroup::Text, fg );
   _cg.setColor( TQColorGroup::Base, bg );
 
-  TQListViewItem::paintCell( p, _cg, column, width, alignment );
+  TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
 }
 
 
@@ -672,13 +672,13 @@ void Kleo::SignatureKeyListViewItem::setSignature( const GpgME::UserID::Signatur
 TQString Kleo::SignatureKeyListViewItem::text( int col ) const {
   return listView() && listView()->columnStrategy()
     ? listView()->columnStrategy()->signatureText( signature(), col )
-    : TQString::null ;
+    : TQString() ;
 }
 
 TQString Kleo::SignatureKeyListViewItem::toolTip( int col ) const {
   return listView() && listView()->columnStrategy()
     ? listView()->columnStrategy()->signatureToolTip( signature(), col )
-    : TQString::null ;
+    : TQString() ;
 }
 
 const TQPixmap * Kleo::SignatureKeyListViewItem::pixmap( int col ) const {
@@ -693,10 +693,10 @@ int Kleo::SignatureKeyListViewItem::compare( TQListViewItem * item, int col, boo
   return listView()->columnStrategy()->signatureCompare( this->signature(), that->signature(), col );
 }
 
-void Kleo::SignatureKeyListViewItem::paintCell( TQPainter * p, const TQColorGroup & cg, int column, int width, int alignment ) {
+void Kleo::SignatureKeyListViewItem::paintCell( TQPainter * p, const TQColorGroup & cg, int column, int width, int tqalignment ) {
   const KeyListView::DisplayStrategy * ds = listView() ? listView()->displayStrategy() : 0 ;
   if ( !ds ) {
-    TQListViewItem::paintCell( p, cg, column, width, alignment );
+    TQListViewItem::paintCell( p, cg, column, width, tqalignment );
     return;
   }
   const TQColor fg = ds->signatureForeground( signature(), cg.text() );
@@ -708,7 +708,7 @@ void Kleo::SignatureKeyListViewItem::paintCell( TQPainter * p, const TQColorGrou
   _cg.setColor( TQColorGroup::Text, fg );
   _cg.setColor( TQColorGroup::Base, bg );
 
-  TQListViewItem::paintCell( p, _cg, column, width, alignment );
+  TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
 }
 
 
