@@ -24,11 +24,11 @@
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
+    the TQt library by Trolltech AS, Norway (or with modified versions
+    of TQt that use the same license as TQt), and distribute linked
     combinations including the two.  You must obey the GNU General
     Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
+    TQt.  If you modify this file, you may extend this exception to
     your version of the file, but you are not obligated to do so.  If
     you do not wish to do so, delete this exception statement from
     your version.
@@ -64,7 +64,7 @@
 #include <kactivelabel.h>
 #include <kurl.h>
 
-// Qt
+// TQt
 #include <tqcheckbox.h>
 #include <tqtoolbutton.h>
 #include <tqlabel.h>
@@ -198,7 +198,7 @@ namespace {
     switch ( col ) {
     case 0: return i18n("Key ID");
     case 1: return i18n("User ID");
-    default: return TQString::null;
+    default: return TQString();
     }
   }
 
@@ -227,12 +227,12 @@ namespace {
       {
 	const char * uid = key.userID(0).id();
 	if ( key.protocol() == GpgME::Context::OpenPGP )
-	  return uid && *uid ? TQString::fromUtf8( uid ) : TQString::null ;
+	  return uid && *uid ? TQString::fromUtf8( uid ) : TQString() ;
 	else // CMS
 	  return Kleo::DN( uid ).prettyDN();
       }
       break;
-    default: return TQString::null;
+    default: return TQString();
     }
   }
 
@@ -248,19 +248,19 @@ namespace {
 		   "Created: %2\n"
 		   "Expiry: %3\n"
 		   "Fingerprint: %4" )
-	.arg( uid ? TQString::fromUtf8( uid ) : i18n("unknown"),
+	.tqarg( uid ? TQString::fromUtf8( uid ) : i18n("unknown"),
 	      creation, expiry,
-	      fpr ? TQString::fromLatin1( fpr ) : i18n("unknown") );
+	      fpr ? TQString::tqfromLatin1( fpr ) : i18n("unknown") );
     else
       return i18n( "S/MIME key for %1\n"
 		   "Created: %2\n"
 		   "Expiry: %3\n"
 		   "Fingerprint: %4\n"
 		   "Issuer: %5" )
-	.arg( uid ? Kleo::DN( uid ).prettyDN() : i18n("unknown"),
+	.tqarg( uid ? Kleo::DN( uid ).prettyDN() : i18n("unknown"),
 	      creation, expiry,
-	      fpr ? TQString::fromLatin1( fpr ) : i18n("unknown") )
-	.arg( issuer ? Kleo::DN( issuer ).prettyDN() : i18n("unknown") );
+	      fpr ? TQString::tqfromLatin1( fpr ) : i18n("unknown") )
+	.tqarg( issuer ? Kleo::DN( issuer ).prettyDN() : i18n("unknown") );
   }
 
   const TQPixmap * ColumnStrategy::pixmap( const GpgME::Key & key, int col ) const {
@@ -311,7 +311,7 @@ Kleo::KeySelectionDialog::KeySelectionDialog( const TQString & title,
     mKeyUsage( keyUsage ),
     mCurrentContextMenuItem( 0 )
 {
-  init( rememberChoice, extendedSelection, text, TQString::null );
+  init( rememberChoice, extendedSelection, text, TQString() );
 }
 
 Kleo::KeySelectionDialog::KeySelectionDialog( const TQString & title,
@@ -374,11 +374,11 @@ void Kleo::KeySelectionDialog::init( bool rememberChoice, bool extendedSelection
       KActiveLabel *textLabel = new KActiveLabel( text, page );
       disconnect( textLabel, TQT_SIGNAL(linkClicked(const TQString&)), textLabel, TQT_SLOT(openLink(const TQString&)) );
       connect( textLabel, TQT_SIGNAL(linkClicked(const TQString&)), TQT_SLOT(slotStartCertificateManager(const TQString&)) );
-      textLabel->setAlignment( textLabel->alignment() | TQt::WordBreak );
+      textLabel->tqsetAlignment( textLabel->tqalignment() | TQt::WordBreak );
       mTopLayout->addWidget( textLabel );
     } else {
       KActiveLabel *textLabel = new KActiveLabel( text, page );
-      textLabel->setAlignment( textLabel->alignment() | TQt::WordBreak );
+      textLabel->tqsetAlignment( textLabel->tqalignment() | TQt::WordBreak );
       mTopLayout->addWidget( textLabel );
     }
   }
@@ -567,7 +567,7 @@ static void showKeyListError( TQWidget * parent, const GpgME::Error & err ) {
   const TQString msg = i18n( "<qt><p>An error occurred while fetching "
 			    "the keys from the backend:</p>"
 			    "<p><b>%1</b></p></qt>" )
-    .arg( TQString::fromLocal8Bit( err.asString() ) );
+    .tqarg( TQString::fromLocal8Bit( err.asString() ) );
 
   KMessageBox::error( parent, msg, i18n( "Key Listing Failed" ) );
 }
