@@ -34,9 +34,10 @@ struct LogInfo;
 }
 
 
-class AnnotateView : public QListView
+class AnnotateView : public TQListView
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
 
@@ -45,7 +46,7 @@ public:
     void addLine(const Cervisia::LogInfo& logInfo, const TQString& content,
                  bool odd);
 
-    virtual TQSize sizeHint() const;
+    virtual TQSize tqsizeHint() const;
 
 private slots:
 
