@@ -58,7 +58,7 @@
 
 
 LogDialog::LogDialog(KConfig& cfg, TQWidget *parent, const char *name)
-    : KDialogBase(parent, name, false, TQString::null,
+    : KDialogBase(parent, name, false, TQString(),
                   Ok | Apply | Close | Help | User1 | User2 | User3, Close, true,
                   KGuiItem(i18n("&Annotate")),
                   KGuiItem(i18n("&Diff"), "vcs_diff"),
@@ -110,7 +110,7 @@ LogDialog::LogDialog(KConfig& cfg, TQWidget *parent, const char *name)
     tags.setAutoDelete(true);
 
     TQWidget *mainWidget = new TQWidget(splitter);
-    TQBoxLayout *layout = new TQVBoxLayout(mainWidget, 0, spacingHint());
+    TQBoxLayout *tqlayout = new TQVBoxLayout(mainWidget, 0, spacingHint());
 
     for (int i = 0; i < 2; ++i)
     {
@@ -118,10 +118,10 @@ LogDialog::LogDialog(KConfig& cfg, TQWidget *parent, const char *name)
         {
             TQFrame *frame = new TQFrame(mainWidget);
             frame->setFrameStyle(TQFrame::HLine | TQFrame::Sunken);
-            layout->addWidget(frame);
+            tqlayout->addWidget(frame);
         }
 
-        TQGridLayout *grid = new TQGridLayout(layout);
+        TQGridLayout *grid = new TQGridLayout(tqlayout);
         grid->setRowStretch(0, 0);
         grid->setRowStretch(1, 0);
         grid->setRowStretch(2, 1);
@@ -137,7 +137,7 @@ LogDialog::LogDialog(KConfig& cfg, TQWidget *parent, const char *name)
 
         revbox[i] = new TQLabel(mainWidget);
         revbox[i]->setFrameStyle(TQFrame::Panel | TQFrame::Sunken);
-        grid->addWidget(revbox[i], 0, 1, Qt::AlignVCenter);
+        grid->addWidget(revbox[i], 0, 1, TQt::AlignVCenter);
 
         TQLabel *selectlabel = new TQLabel(i18n("Select by tag:"), mainWidget);
         grid->addWidget(selectlabel, 0, 2);
@@ -166,7 +166,7 @@ LogDialog::LogDialog(KConfig& cfg, TQWidget *parent, const char *name)
 
         commentbox[i] = new TQTextEdit(mainWidget);
         commentbox[i]->setReadOnly(true);
-        commentbox[i]->setTextFormat(Qt::PlainText);
+        commentbox[i]->setTextFormat(TQt::PlainText);
         fm = commentbox[i]->fontMetrics();
         commentbox[i]->setMinimumHeight(2*fm.lineSpacing()+10);
         grid->addMultiCellWidget(commentbox[i], 2, 2, 1, 3);
@@ -199,7 +199,7 @@ LogDialog::LogDialog(KConfig& cfg, TQWidget *parent, const char *name)
     setButtonGuiItem(Apply, KGuiItem(i18n("Create Patch...")));
     setHelp("browsinglogs");
 
-    setWFlags(Qt::WDestructiveClose | getWFlags());
+    setWFlags(TQt::WDestructiveClose | getWFlags());
 
     TQSize size = configDialogSize(partConfig, "LogDialog");
     resize(size);
@@ -233,7 +233,7 @@ bool LogDialog::parseCvsLog(CvsService_stub* service, const TQString& fileName)
     cvsService = service;
     filename = fileName;
 
-    setCaption(i18n("CVS Log: %1").arg(filename));
+    setCaption(i18n("CVS Log: %1").tqarg(filename));
 
     DCOPRef job = cvsService->log(filename);
     if( !cvsService->ok() )
@@ -380,8 +380,8 @@ bool LogDialog::parseCvsLog(CvsService_stub* service, const TQString& fileName)
         }
     }
 
-    tagcombo[0]->insertItem(TQString::null);
-    tagcombo[1]->insertItem(TQString::null);
+    tagcombo[0]->insertItem(TQString());
+    tagcombo[1]->insertItem(TQString());
     TQPtrListIterator<LogDialogTagInfo> it(tags);
     for( ; it.current(); ++it )
     {
