@@ -39,7 +39,7 @@
 
 
 using Cervisia::Entry;
-using Cervisia::EntryStatus;
+using Cervisia::EntrytqStatus;
 
 
 // ------------------------------------------------------------------------------
@@ -103,7 +103,7 @@ UpdateDirItem::UpdateDirItem(UpdateView* parent,
  * Update the status of an item; if it doesn't exist yet, create new one
  */
 void UpdateDirItem::updateChildItem(const TQString& name,
-                                    EntryStatus status,
+                                    EntrytqStatus status,
                                     bool isdir)
 {
     if (UpdateItem* item = findItem(name))
@@ -111,7 +111,7 @@ void UpdateDirItem::updateChildItem(const TQString& name,
         if (isFileItem(item))
         {
             UpdateFileItem* fileItem = static_cast<UpdateFileItem*>(item);
-            fileItem->setStatus(status);
+            fileItem->settqStatus(status);
         }
         return;
     }
@@ -127,7 +127,7 @@ void UpdateDirItem::updateChildItem(const TQString& name,
     else
     {
         entry.m_type = Entry::File;
-        createFileItem(entry)->setStatus(status);
+        createFileItem(entry)->settqStatus(status);
     }
 }
 
@@ -150,7 +150,7 @@ void UpdateDirItem::updateEntriesItem(const Entry& entry,
                 entry.m_status == Cervisia::LocallyRemoved ||
                 entry.m_status == Cervisia::Conflict)
             {
-                fileItem->setStatus(entry.m_status);
+                fileItem->settqStatus(entry.m_status);
             }
             fileItem->setRevTag(entry.m_revision, entry.m_tag);
             fileItem->setDate(entry.m_dateTime);
@@ -175,10 +175,10 @@ void UpdateDirItem::scanDirectory()
 
     const CvsDir dir(path);
 
-    const QFileInfoList *files = dir.entryInfoList();
+    const TQFileInfoList *files = dir.entryInfoList();
     if (files)
     {
-        QFileInfoListIterator it(*files);
+        TQFileInfoListIterator it(*files);
         for (; it.current(); ++it)
         {
             Entry entry;
@@ -217,7 +217,7 @@ UpdateFileItem* UpdateDirItem::createFileItem(const Entry& entry)
 
 UpdateItem* UpdateDirItem::insertItem(UpdateItem* item)
 {
-    QPair<TMapItemsByName::iterator, bool> result
+    TQPair<TMapItemsByName::iterator, bool> result
         = m_itemsByName.insert(TMapItemsByName::value_type(item->entry().m_name, item));
     if (!result.second)
     {
@@ -250,10 +250,10 @@ UpdateItem* UpdateDirItem::findItem(const TQString& name) const
     return (it != m_itemsByName.end()) ? *it : 0;
 }
 
-// Qt-3.3.8 changed the parsing in TQDateTime::fromString() but introduced
+// TQt-3.3.8 changed the parsing in TQDateTime::fromString() but introduced
 // a bug which leads to the problem that days with 1 digit will incorrectly being
 // parsed as day 0 - which is invalid.
-// workaround with the implementation from Qt-3.3.6
+// workaround with the implementation from TQt-3.3.6
 TQDateTime parseDateTime(const TQString &s)
 {
         static const char * const qt_shortMonthNames[] = {
@@ -288,7 +288,7 @@ TQDateTime parseDateTime(const TQString &s)
 	TQDate date( year, month, day );
 	TQTime time;
 	int hour, minute, second;
-	int pivot = s.find( TQRegExp(TQString::fromLatin1("[0-9][0-9]:[0-9][0-9]:[0-9][0-9]")) );
+	int pivot = s.find( TQRegExp(TQString::tqfromLatin1("[0-9][0-9]:[0-9][0-9]:[0-9][0-9]")) );
 	if ( pivot != -1 ) {
 	    hour = s.mid( pivot, 2 ).toInt();
 	    minute = s.mid( pivot+3, 2 ).toInt();
@@ -355,7 +355,7 @@ void UpdateDirItem::syncWithEntries()
                 }
                 else
                 {
-                    // workaround Qt-3.3.8 bug with our own function (see function above)
+                    // workaround TQt-3.3.8 bug with our own function (see function above)
                     // const TQDateTime date(TQDateTime::fromString(timestamp)); // UTC Time
                     const TQDateTime date(parseDateTime(timestamp)); // UTC Time
                     TQDateTime fileDateUTC;
@@ -392,8 +392,8 @@ void UpdateDirItem::syncWithDirectory()
             // is file removed?
             if (!dir.exists(it.key()))
             {
-                fileItem->setStatus(Cervisia::Removed);
-                fileItem->setRevTag(TQString::null, TQString::null);
+                fileItem->settqStatus(Cervisia::Removed);
+                fileItem->setRevTag(TQString(), TQString());
             }
         }
     }
@@ -501,14 +501,14 @@ UpdateFileItem::UpdateFileItem(UpdateDirItem* parent, const Entry& entry)
 }
 
 
-void UpdateFileItem::setStatus(EntryStatus status)
+void UpdateFileItem::settqStatus(EntrytqStatus status)
 {
     if (status != m_entry.m_status)
     {
         m_entry.m_status = status;
         const bool visible(applyFilter(updateView()->filter()));
         if (visible)
-            repaint();
+            tqrepaint();
     }
     m_undefined = false;
 }
@@ -584,7 +584,7 @@ void UpdateFileItem::setRevTag(const TQString& rev, const TQString& tag)
     if (isVisible())
     {
         widthChanged();
-        repaint();
+        tqrepaint();
     }
 }
 
@@ -598,13 +598,13 @@ void UpdateFileItem::setDate(const TQDateTime& date)
 void UpdateFileItem::markUpdated(bool laststage,
                                  bool success)
 {
-    EntryStatus newstatus = m_entry.m_status;
+    EntrytqStatus newstatus = m_entry.m_status;
 
     if (laststage)
     {
         if (undefinedState() && m_entry.m_status != Cervisia::NotInCVS)
             newstatus = success? Cervisia::UpToDate : Cervisia::Unknown;
-        setStatus(newstatus);
+        settqStatus(newstatus);
     }
     else
         setUndefinedState(true);
@@ -668,7 +668,7 @@ int UpdateFileItem::compare(TQListViewItem* i,
     case MimeType:
         iResult = KMimeType::findByPath(entry().m_name)->comment().localeAwareCompare(KMimeType::findByPath(item->entry().m_name)->comment());
         break;
-    case Status:
+    case tqStatus:
         if ((iResult = ::compare(statusClass(), item->statusClass())) == 0)
             iResult = entry().m_name.localeAwareCompare(item->entry().m_name);
         break;
@@ -698,7 +698,7 @@ TQString UpdateFileItem::text(int column) const
     case MimeType:
 	result = KMimeType::findByPath(entry().m_name)->comment();
 	break;
-    case Status:
+    case tqStatus:
         result = toString(entry().m_status);
         break;
     case Revision:
