@@ -919,7 +919,7 @@ void KcmSambaConf::loadCharset(SambaShare* )
   _dictMngr->add("character set", _interface->characterSetEdit);
   _dictMngr->add("valid chars", _interface->validCharsEdit);
   
-  _dictMngr->add("unicode",_interface->unicodeChk);
+  _dictMngr->add("tqunicode",_interface->tqunicodeChk);
 }
 
 void KcmSambaConf::loadWinbind(SambaShare* )
@@ -1010,7 +1010,7 @@ void KcmSambaConf::loadCommands(SambaShare*)
 
 void KcmSambaConf::setComboIndexToValue(TQComboBox* box, const TQString & value, SambaShare* share) 
 {
-  int i = box->listBox()->index(box->listBox()->findItem(share->getValue(value,false,true),Qt::ExactMatch));
+  int i = box->listBox()->index(box->listBox()->findItem(share->getValue(value,false,true),TQt::ExactMatch));
   box->setCurrentItem(i);
 }
 
@@ -1102,7 +1102,7 @@ void KcmSambaConf::joinADomainBtnClicked() {
                             dlg->usernameEdit->text(),
                             dlg->passwordEdit->text()))
     {
-      KMessageBox::sorry(0,i18n("Joining the domain %1 failed.").arg(dlg->domainEdit->text()));
+      KMessageBox::sorry(0,i18n("Joining the domain %1 failed.").tqarg(dlg->domainEdit->text()));
     }
   }
   delete dlg;
@@ -1172,7 +1172,7 @@ void KcmSambaConf::addSambaUserBtnClicked()
     
     TQCString password;
     int passResult = KPasswordDialog::getNewPassword(password, 
-                        i18n("<qt>Please enter a password for the user <b>%1</b></qt>").arg(user.name));
+                        i18n("<qt>Please enter a password for the user <b>%1</b></qt>").tqarg(user.name));
     if (passResult != KPasswordDialog::Accepted) {
        list.remove(item);
        continue;
@@ -1180,7 +1180,7 @@ void KcmSambaConf::addSambaUserBtnClicked()
     
     if (!passwd.addUser(user,password))
     {
-      KMessageBox::sorry(0,i18n("<qt>Adding the user <b>%1</b> to the Samba user database failed.</qt>").arg(user.name));
+      KMessageBox::sorry(0,i18n("<qt>Adding the user <b>%1</b> to the Samba user database failed.</qt>").tqarg(user.name));
       break;
     }
 
@@ -1211,7 +1211,7 @@ void KcmSambaConf::removeSambaUserBtnClicked()
     SambaUser user( item->text(0), item->text(1).toInt() );
     if (!passwd.removeUser(user))
     {
-      KMessageBox::sorry(0,i18n("Removing the user %1 from the Samba user database failed.").arg(user.name));
+      KMessageBox::sorry(0,i18n("Removing the user %1 from the Samba user database failed.").tqarg(user.name));
       continue;
     }
 
@@ -1235,13 +1235,13 @@ void KcmSambaConf::sambaUserPasswordBtnClicked()
     
     TQCString password;
     int passResult = KPasswordDialog::getNewPassword(password,
-                        i18n("Please enter a password for the user %1").arg(user.name));
+                        i18n("Please enter a password for the user %1").tqarg(user.name));
     if (passResult != KPasswordDialog::Accepted)
        return;
     
     if (!passwd.changePassword(user,password))
     {
-      KMessageBox::sorry(0,i18n("Changing the password of the user %1 failed.").arg(user.name));
+      KMessageBox::sorry(0,i18n("Changing the password of the user %1 failed.").tqarg(user.name));
     } else {
       static_cast<QMultiCheckListItem*>(item)->setOn(COL_NOPASSWORD,false);
     }
@@ -1267,7 +1267,7 @@ void KcmSambaConf::save() {
   // Base settings
 
   _smbconf = _interface->configUrlRq->url();
-  KSimpleConfig config(TQString::fromLatin1(FILESHARECONF),false);
+  KSimpleConfig config(TQString::tqfromLatin1(FILESHARECONF),false);
   config.writeEntry("SMBCONF",_smbconf);
   config.sync();
 
