@@ -61,7 +61,7 @@ struct Row
 /**
  * A list of rows, each of which may have its own category options and other
  * associated data.  There is no relation between the order of rows in the vector and their
- * GUI layout.  Instead, each Row has a position member which indicates what GUI position it
+ * GUI tqlayout.  Instead, each Row has a position member which indicates what GUI position it
  * takes up.  The index into the vector is known as the row identifier (which is unique but
  * not necessarily constant).
  */
@@ -140,6 +140,7 @@ private:
 class FileRenamerWidget : public FileRenamerBase, public CategoryReaderInterface
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     FileRenamerWidget(TQWidget *parent);
@@ -185,7 +186,7 @@ private:
 
     /**
      * This function adds a "Insert Folder separator" checkbox to the end of
-     * the current layout.  The setting defaults to being unchecked.
+     * the current tqlayout.  The setting defaults to being unchecked.
      */
     void addFolderSeparatorCheckbox();
 
@@ -335,7 +336,7 @@ private:
     /**
      * This moves the widget \p l in the direction given by \p direction, taking
      * care to make sure that the checkboxes are not moved, and that they are
-     * enabled or disabled as appropriate for the new layout, and that the up and
+     * enabled or disabled as appropriate for the new tqlayout, and that the up and
      * down buttons are also adjusted as necessary.
      *
      * @param id the identifier of the row to move
@@ -426,14 +427,14 @@ private slots:
     virtual void slotRemoveRow(int id);
 
     /**
-     * This function moves \p category up in the layout.
+     * This function moves \p category up in the tqlayout.
      *
      * @param id the unique id of the widget to move up.
      */
     virtual void moveItemUp(int id);
 
     /**
-     * This function moves \p category down in the layout.
+     * This function moves \p category down in the tqlayout.
      *
      * @param id the unique id of the widget to move down.
      */
