@@ -46,7 +46,7 @@
 
 using namespace ActionCollection;
 
-enum PlayerManagerStatus { StatusStopped = -1, StatusPaused = 1, StatusPlaying = 2 };
+enum PlayerManagertqStatus { StatusStopped = -1, StatusPaused = 1, StatusPlaying = 2 };
 
 ////////////////////////////////////////////////////////////////////////////////
 // helper functions
@@ -194,7 +194,7 @@ TQStringList PlayerManager::trackProperties()
 TQString PlayerManager::trackProperty(const TQString &property) const
 {
     if(!playing() && !paused())
-        return TQString::null;
+        return TQString();
 
     return m_file.property(property);
 }
@@ -220,7 +220,7 @@ FileHandle PlayerManager::playingFile() const
 TQString PlayerManager::playingString() const
 {
     if(!playing())
-        return TQString::null;
+        return TQString();
 
     TQString str = m_file.tag()->artist() + " - " + m_file.tag()->title();
     if(m_file.tag()->artist().isEmpty())
