@@ -46,13 +46,14 @@ typedef TQValueList<PlaylistItem *> PlaylistItemList;
 class Playlist : public KListView, public PlaylistInterface
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
 
-    Playlist(PlaylistCollection *collection, const TQString &name = TQString::null,
+    Playlist(PlaylistCollection *collection, const TQString &name = TQString(),
 	     const TQString &iconName = "midi");
     Playlist(PlaylistCollection *collection, const PlaylistItemList &items,
-	     const TQString &name = TQString::null, const TQString &iconName = "midi");
+	     const TQString &name = TQString(), const TQString &iconName = "midi");
     Playlist(PlaylistCollection *collection, const TQFileInfo &playlistFile,
 	     const TQString &iconName = "midi");
 
@@ -192,7 +193,7 @@ public:
 
     /**
      * Returns the file name associated with this playlist (an m3u file) or
-     * TQString::null if no such file exists.
+     * TQString() if no such file exists.
      */
     TQString fileName() const { return m_fileName; }
 
@@ -711,7 +712,7 @@ private:
 
 bool processEvents();
 
-class FocusUpEvent : public QCustomEvent
+class FocusUpEvent : public TQCustomEvent
 {
 public:
     FocusUpEvent() : TQCustomEvent(id) {}
