@@ -91,7 +91,7 @@ PlaylistBox::PlaylistBox(TQWidget *parent, TQWidgetStack *playlistStack,
     // add the view modes stuff
 
     KSelectAction *viewModeAction =
-	new KSelectAction(i18n("View Modes"), "view_choose", KShortcut(), actions(), "viewModeMenu");
+	new KSelectAction(i18n("View Modes"), "view_choose", KShortcut(), ActionCollection::actions(), "viewModeMenu");
 
     m_viewModes.append(new ViewMode(this));
     m_viewModes.append(new CompactViewMode(this));
@@ -208,7 +208,7 @@ void PlaylistBox::duplicate()
 void PlaylistBox::paste()
 {
     Item *i = static_cast<Item *>(currentItem());
-    decode(kapp->clipboard()->data(), i);
+    decode(kapp->tqclipboard()->data(), i);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -289,7 +289,7 @@ void PlaylistBox::remove()
 
     if(!files.isEmpty()) {
 	int remove = KMessageBox::warningYesNoCancelList(
-	    this, i18n("Do you want to delete these files from the disk as well?"), files, TQString::null, KStdGuiItem::del(), i18n("Keep"));
+	    this, i18n("Do you want to delete these files from the disk as well?"), files, TQString(), KStdGuiItem::del(), i18n("Keep"));
 
 	if(remove == KMessageBox::Yes) {
 	    TQStringList couldNotDelete;
@@ -445,7 +445,7 @@ void PlaylistBox::contentsDropEvent(TQDropEvent *e)
     if(m_dropItem) {
 	Item *old = m_dropItem;
 	m_dropItem = 0;
-	old->repaint();
+	old->tqrepaint();
     }
 }
 
@@ -493,14 +493,14 @@ void PlaylistBox::contentsDragMoveEvent(TQDragMoveEvent *e)
 
 	    if(e->isAccepted()) {
 		m_dropItem = target;
-		target->repaint();
+		target->tqrepaint();
 		m_showTimer->start(1500, true);
 	    }
 	    else
 		m_dropItem = 0;
 
 	    if(old)
-		old->repaint();
+		old->tqrepaint();
 	}
     }
     else {
@@ -517,21 +517,21 @@ void PlaylistBox::contentsDragLeaveEvent(TQDragLeaveEvent *e)
     if(m_dropItem) {
 	Item *old = m_dropItem;
 	m_dropItem = 0;
-	old->repaint();
+	old->tqrepaint();
     }
     KListView::contentsDragLeaveEvent(e);
 }
 
 void PlaylistBox::contentsMousePressEvent(TQMouseEvent *e)
 {
-    if(e->button() == LeftButton)
+    if(e->button() == Qt::LeftButton)
 	m_doingMultiSelect = true;
     KListView::contentsMousePressEvent(e);
 }
 
 void PlaylistBox::contentsMouseReleaseEvent(TQMouseEvent *e)
 {
-    if(e->button() == LeftButton) {
+    if(e->button() == Qt::LeftButton) {
 	m_doingMultiSelect = false;
 	slotPlaylistChanged();
     }
@@ -722,10 +722,10 @@ int PlaylistBox::Item::compare(TQListViewItem *i, int col, bool) const
     return text(col).lower().localeAwareCompare(i->text(col).lower());
 }
 
-void PlaylistBox::Item::paintCell(TQPainter *painter, const TQColorGroup &colorGroup, int column, int width, int align)
+void PlaylistBox::Item::paintCell(TQPainter *painter, const TQColorGroup &tqcolorGroup, int column, int width, int align)
 {
     PlaylistBox *playlistBox = static_cast<PlaylistBox *>(listView());
-    playlistBox->viewMode()->paintCell(this, painter, colorGroup, column, width, align);
+    playlistBox->viewMode()->paintCell(this, painter, tqcolorGroup, column, width, align);
 }
 
 void PlaylistBox::Item::setText(int column, const TQString &text)
