@@ -21,7 +21,7 @@
     Boston, MA 02110-1301, USA.
 */
 
-// $Id: addresslineedit.cpp 1157647 2010-07-31 19:46:43Z tpearson $
+// $Id: addresslineedit.cpp 1246075 2011-08-10 06:08:18Z tpearson $
 
 #include "addresslineedit.h"
 
@@ -190,7 +190,7 @@ void AddressLineEdit::keyPressEvent(TQKeyEvent *e)
 
 void AddressLineEdit::mouseReleaseEvent( TQMouseEvent * e )
 {
-   if (m_useCompletion && (e->button() == MidButton))
+   if (m_useCompletion && (e->button() == Qt::MidButton))
    {
       m_smartPaste = true;
       KLineEdit::mouseReleaseEvent(e);
