@@ -129,7 +129,7 @@ void LdapConfigWidget::initWidget()
   if ( mFlags & W_PORT ) {
     label = new TQLabel( i18n( "Port:" ), this );
     mPort = new TQSpinBox( 0, 65535, 1, this, "kcfg_ldapport" );
-    mPort->setSizePolicy( TQSizePolicy( TQSizePolicy::Maximum, TQSizePolicy::Preferred ) );
+    mPort->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Maximum, TQSizePolicy::Preferred ) );
     mPort->setValue( 389 );
 
     mainLayout->addWidget( label, row, col );
@@ -140,7 +140,7 @@ void LdapConfigWidget::initWidget()
   if ( mFlags & W_VER ) {
     label = new TQLabel( i18n( "LDAP version:" ), this );
     mVer = new TQSpinBox( 2, 3, 1, this, "kcfg_ldapver" );
-    mVer->setSizePolicy( TQSizePolicy( TQSizePolicy::Maximum, TQSizePolicy::Preferred ) );
+    mVer->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Maximum, TQSizePolicy::Preferred ) );
     mVer->setValue( 3 );
     mainLayout->addWidget( label, row, col );
     mainLayout->addWidget( mVer, row, col+1 );
@@ -151,7 +151,7 @@ void LdapConfigWidget::initWidget()
   if ( mFlags & W_SIZELIMIT ) {
     label = new TQLabel( i18n( "Size limit:" ), this );
     mSizeLimit = new TQSpinBox( 0, 9999999, 1, this, "kcfg_ldapsizelimit" );
-    mSizeLimit->setSizePolicy( TQSizePolicy( TQSizePolicy::Maximum, TQSizePolicy::Preferred ) );
+    mSizeLimit->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Maximum, TQSizePolicy::Preferred ) );
     mSizeLimit->setValue( 0 );
     mSizeLimit->setSpecialValueText( i18n("Default") );
     mainLayout->addWidget( label, row, col );
@@ -162,7 +162,7 @@ void LdapConfigWidget::initWidget()
   if ( mFlags & W_TIMELIMIT ) {
     label = new TQLabel( i18n( "Time limit:" ), this );
     mTimeLimit = new TQSpinBox( 0, 9999999, 1, this, "kcfg_ldaptimelimit" );
-    mTimeLimit->setSizePolicy( TQSizePolicy( TQSizePolicy::Maximum, TQSizePolicy::Preferred ) );
+    mTimeLimit->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Maximum, TQSizePolicy::Preferred ) );
     mTimeLimit->setValue( 0 );
     mTimeLimit->setSuffix( i18n(" sec") );
     mTimeLimit->setSpecialValueText( i18n("Default") );
@@ -607,15 +607,15 @@ void LdapConfigWidget::setFlags( int flags )
 
   // First delete all the child widgets.
   // FIXME: I hope it's correct
-  const TQObjectList *ch = children();
-  TQObjectList ch2 = *ch;
+  const TQObjectList ch = childrenListObject();
+  TQObjectList ch2 = ch;
   TQObject *obj;
   TQWidget *widget;
 
   obj = ch2.first();
   while ( obj != 0 ) {
     widget = dynamic_cast<TQWidget*> (obj);
-    if ( widget && widget->parent() == this ) {
+    if ( widget && TQT_BASE_OBJECT(widget->parent()) == TQT_BASE_OBJECT(this) ) {
       mainLayout->remove( widget );
       delete ( widget );
     }
