@@ -17,8 +17,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #ifndef LOCATIONMAP_H
@@ -28,9 +28,10 @@
 #include <tqobject.h>
 #include <tqstring.h>
 
-class LocationMap : public QObject
+class LocationMap : public TQObject
 {
   Q_OBJECT
+  TQ_OBJECT
 
   public:
     static LocationMap *instance();
