@@ -21,9 +21,10 @@ namespace KAB {
 
 class Core;
 
-class DistributionListEntryView : public QWidget
+class DistributionListEntryView : public TQWidget
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     explicit DistributionListEntryView( KAB::Core* core, TQWidget* parent = 0 );
