@@ -17,8 +17,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #include <tqlayout.h>
@@ -54,7 +54,7 @@ class AddressBookWrapper : public KABC::AddressBook
     }
 };
 
-class ResourceItem : public QCheckListItem
+class ResourceItem : public TQCheckListItem
 {
   public:
     ResourceItem( KListView *parent, KABC::Resource *resource )
@@ -247,7 +247,7 @@ void ResourceSelection::add()
   KABC::Resource *resource = mManager->createResource( type );
   if ( !resource ) {
     KMessageBox::error( this, i18n("<qt>Unable to create an address book of type <b>%1</b>.</qt>")
-                              .arg( type ) );
+                              .tqarg( type ) );
     return;
   }
 
@@ -298,7 +298,7 @@ void ResourceSelection::remove()
 
   int result = KMessageBox::warningContinueCancel( this,
         i18n( "<qt>Do you really want to remove the address book <b>%1</b>?</qt>" )
-        .arg( item->resource()->resourceName() ), "",
+        .tqarg( item->resource()->resourceName() ), "",
         KGuiItem( i18n( "&Remove" ), "editdelete" ) );
   if ( result == KMessageBox::Cancel )
     return;
