@@ -17,8 +17,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #ifndef KDE2_XXPORT_H
@@ -29,6 +29,7 @@
 class KDE2XXPort : public KAB::XXPort
 {
   Q_OBJECT
+  TQ_OBJECT
 
   public:
     KDE2XXPort( KABC::AddressBook *ab, TQWidget *parent, const char *name = 0 );
