@@ -102,7 +102,7 @@ class PickAlarmFileRadio : public PickFileRadio
 	virtual TQString pickFile()    // called when browse button is pressed to select a file to display
 	{
 		return KAlarm::browseFile(i18n("Choose Text or Image File to Display"), mDefaultDir, fileEdit()->text(),
-		                          TQString::null, KFile::ExistingOnly, parentWidget(), "pickAlarmFile");
+		                          TQString(), KFile::ExistingOnly, parentWidget(), "pickAlarmFile");
 	}
     private:
 	TQString mDefaultDir;   // default directory for file browse button
@@ -118,7 +118,7 @@ class PickLogFileRadio : public PickFileRadio
 		: PickFileRadio(b, e, text, parent, name) { }
 	virtual TQString pickFile()    // called when browse button is pressed to select a log file
 	{
-		return KAlarm::browseFile(i18n("Choose Log File"), mDefaultDir, fileEdit()->text(), TQString::null,
+		return KAlarm::browseFile(i18n("Choose Log File"), mDefaultDir, fileEdit()->text(), TQString(),
 		                          KFile::LocalOnly, parentWidget(), "pickLogFile");
 	}
     private:
@@ -129,10 +129,10 @@ inline TQString recurText(const KAEvent& event)
 {
 	TQString r;
 	if (event.repeatCount())
-		r = TQString::fromLatin1("%1 / %2").arg(event.recurrenceText()).arg(event.repetitionText());
+		r = TQString::tqfromLatin1("%1 / %2").tqarg(event.recurrenceText()).tqarg(event.repetitionText());
 	else
 		r = event.recurrenceText();
-	return i18n("&Recurrence - [%1]").arg(r);
+	return i18n("&Recurrence - [%1]").tqarg(r);
 }
 
 // Collect these widget labels together to ensure consistent wording and
@@ -196,12 +196,12 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
 		TQHBox* box = new TQHBox(mainWidget);
 		box->setSpacing(spacingHint());
 		TQLabel* label = new TQLabel(i18n("Template name:"), box);
-		label->setFixedSize(label->sizeHint());
+		label->setFixedSize(label->tqsizeHint());
 		mTemplateName = new TQLineEdit(box);
 		mTemplateName->setReadOnly(mReadOnly);
 		label->setBuddy(mTemplateName);
 		TQWhatsThis::add(box, i18n("Enter the name of the alarm template"));
-		box->setFixedHeight(box->sizeHint().height());
+		box->setFixedHeight(box->tqsizeHint().height());
 	}
 	mTabs = new TQTabWidget(mainWidget);
 	mTabs->setMargin(marginHint());
@@ -217,7 +217,7 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
 	// Recurrence tab
 	TQVBox* recurTab = new TQVBox(mTabs);
 	mainPageBox->setSpacing(spacingHint());
-	mTabs->addTab(recurTab, TQString::null);
+	mTabs->addTab(recurTab, TQString());
 	mRecurPageIndex = 1;
 	mRecurrenceEdit = new RecurrenceEdit(readOnly, recurTab, "recurPage");
 	connect(mRecurrenceEdit, TQT_SIGNAL(shown()), TQT_SLOT(slotShowRecurrenceEdit()));
@@ -230,13 +230,13 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
 	mActionGroup = new ButtonGroup(i18n("Action"), mainPage, "actionGroup");
 	connect(mActionGroup, TQT_SIGNAL(buttonSet(int)), TQT_SLOT(slotAlarmTypeChanged(int)));
 	topLayout->addWidget(mActionGroup, 1);
-	TQBoxLayout* layout = new TQVBoxLayout(mActionGroup, marginHint(), spacingHint());
-	layout->addSpacing(fontMetrics().lineSpacing()/2);
-	TQGridLayout* grid = new TQGridLayout(layout, 1, 5);
+	TQBoxLayout* tqlayout = new TQVBoxLayout(mActionGroup, marginHint(), spacingHint());
+	tqlayout->addSpacing(fontMetrics().lineSpacing()/2);
+	TQGridLayout* grid = new TQGridLayout(tqlayout, 1, 5);
 
 	// Message radio button
 	mMessageRadio = new RadioButton(i18n("Te&xt"), mActionGroup, "messageButton");
-	mMessageRadio->setFixedSize(mMessageRadio->sizeHint());
+	mMessageRadio->setFixedSize(mMessageRadio->tqsizeHint());
 	TQWhatsThis::add(mMessageRadio,
 	      i18n("If checked, the alarm will display a text message."));
 	grid->addWidget(mMessageRadio, 1, 0);
@@ -244,7 +244,7 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
 
 	// File radio button
 	mFileRadio = new PickAlarmFileRadio(i18n("&File"), mActionGroup, "fileButton");
-	mFileRadio->setFixedSize(mFileRadio->sizeHint());
+	mFileRadio->setFixedSize(mFileRadio->tqsizeHint());
 	TQWhatsThis::add(mFileRadio,
 	      i18n("If checked, the alarm will display the contents of a text or image file."));
 	grid->addWidget(mFileRadio, 1, 2);
@@ -252,7 +252,7 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
 
 	// Command radio button
 	mCommandRadio = new RadioButton(i18n("Co&mmand"), mActionGroup, "cmdButton");
-	mCommandRadio->setFixedSize(mCommandRadio->sizeHint());
+	mCommandRadio->setFixedSize(mCommandRadio->tqsizeHint());
 	TQWhatsThis::add(mCommandRadio,
 	      i18n("If checked, the alarm will execute a shell command."));
 	grid->addWidget(mCommandRadio, 1, 4);
@@ -260,81 +260,81 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
 
 	// Email radio button
 	mEmailRadio = new RadioButton(i18n("&Email"), mActionGroup, "emailButton");
-	mEmailRadio->setFixedSize(mEmailRadio->sizeHint());
+	mEmailRadio->setFixedSize(mEmailRadio->tqsizeHint());
 	TQWhatsThis::add(mEmailRadio,
 	      i18n("If checked, the alarm will send an email."));
 	grid->addWidget(mEmailRadio, 1, 6);
 
 	initDisplayAlarms(mActionGroup);
-	layout->addWidget(mDisplayAlarmsFrame);
+	tqlayout->addWidget(mDisplayAlarmsFrame);
 	initCommand(mActionGroup);
-	layout->addWidget(mCommandFrame);
+	tqlayout->addWidget(mCommandFrame);
 	initEmail(mActionGroup);
-	layout->addWidget(mEmailFrame);
+	tqlayout->addWidget(mEmailFrame);
 
 	// Deferred date/time: visible only for a deferred recurring event.
 	mDeferGroup = new TQGroupBox(1, Qt::Vertical, i18n("Deferred Alarm"), mainPage, "deferGroup");
 	topLayout->addWidget(mDeferGroup);
 	TQLabel* label = new TQLabel(i18n("Deferred to:"), mDeferGroup);
-	label->setFixedSize(label->sizeHint());
+	label->setFixedSize(label->tqsizeHint());
 	mDeferTimeLabel = new TQLabel(mDeferGroup);
 
 	mDeferChangeButton = new TQPushButton(i18n("C&hange..."), mDeferGroup);
-	mDeferChangeButton->setFixedSize(mDeferChangeButton->sizeHint());
+	mDeferChangeButton->setFixedSize(mDeferChangeButton->tqsizeHint());
 	connect(mDeferChangeButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotEditDeferral()));
 	TQWhatsThis::add(mDeferChangeButton, i18n("Change the alarm's deferred time, or cancel the deferral"));
 	mDeferGroup->addSpace(0);
 
-	layout = new TQHBoxLayout(topLayout);
+	tqlayout = new TQHBoxLayout(topLayout);
 
 	// Date and time entry
 	if (mTemplate)
 	{
 		mTemplateTimeGroup = new ButtonGroup(i18n("Time"), mainPage, "templateGroup");
 		connect(mTemplateTimeGroup, TQT_SIGNAL(buttonSet(int)), TQT_SLOT(slotTemplateTimeType(int)));
-		layout->addWidget(mTemplateTimeGroup);
+		tqlayout->addWidget(mTemplateTimeGroup);
 		grid = new TQGridLayout(mTemplateTimeGroup, 2, 2, marginHint(), spacingHint());
 		grid->addRowSpacing(0, fontMetrics().lineSpacing()/2);
-		// Get alignment to use in TQGridLayout (AlignAuto doesn't work correctly there)
-		int alignment = TQApplication::reverseLayout() ? Qt::AlignRight : Qt::AlignLeft;
+		// Get tqalignment to use in TQGridLayout (AlignAuto doesn't work correctly there)
+		int tqalignment = TQApplication::reverseLayout() ? TQt::AlignRight : TQt::AlignLeft;
 
 		mTemplateDefaultTime = new RadioButton(i18n("&Default time"), mTemplateTimeGroup, "templateDefTimeButton");
-		mTemplateDefaultTime->setFixedSize(mTemplateDefaultTime->sizeHint());
+		mTemplateDefaultTime->setFixedSize(mTemplateDefaultTime->tqsizeHint());
 		mTemplateDefaultTime->setReadOnly(mReadOnly);
 		TQWhatsThis::add(mTemplateDefaultTime,
 		      i18n("Do not specify a start time for alarms based on this template. "
 		           "The normal default start time will be used."));
-		grid->addWidget(mTemplateDefaultTime, 0, 0, alignment);
+		grid->addWidget(mTemplateDefaultTime, 0, 0, tqalignment);
 
 		TQHBox* box = new TQHBox(mTemplateTimeGroup);
 		box->setSpacing(spacingHint());
 		mTemplateUseTime = new RadioButton(i18n("Time:"), box, "templateTimeButton");
-		mTemplateUseTime->setFixedSize(mTemplateUseTime->sizeHint());
+		mTemplateUseTime->setFixedSize(mTemplateUseTime->tqsizeHint());
 		mTemplateUseTime->setReadOnly(mReadOnly);
 		TQWhatsThis::add(mTemplateUseTime,
 		      i18n("Specify a start time for alarms based on this template."));
 		mTemplateTimeGroup->insert(mTemplateUseTime);
 		mTemplateTime = new TimeEdit(box, "templateTimeEdit");
-		mTemplateTime->setFixedSize(mTemplateTime->sizeHint());
+		mTemplateTime->setFixedSize(mTemplateTime->tqsizeHint());
 		mTemplateTime->setReadOnly(mReadOnly);
 		TQWhatsThis::add(mTemplateTime,
-		      TQString("%1\n\n%2").arg(i18n("Enter the start time for alarms based on this template."))
-		                         .arg(TimeSpinBox::shiftWhatsThis()));
+		      TQString("%1\n\n%2").tqarg(i18n("Enter the start time for alarms based on this template."))
+		                         .tqarg(TimeSpinBox::shiftWhatsThis()));
 		box->setStretchFactor(new TQWidget(box), 1);    // left adjust the controls
-		box->setFixedHeight(box->sizeHint().height());
-		grid->addWidget(box, 0, 1, alignment);
+		box->setFixedHeight(box->tqsizeHint().height());
+		grid->addWidget(box, 0, 1, tqalignment);
 
 		mTemplateAnyTime = new RadioButton(i18n("An&y time"), mTemplateTimeGroup, "templateAnyTimeButton");
-		mTemplateAnyTime->setFixedSize(mTemplateAnyTime->sizeHint());
+		mTemplateAnyTime->setFixedSize(mTemplateAnyTime->tqsizeHint());
 		mTemplateAnyTime->setReadOnly(mReadOnly);
 		TQWhatsThis::add(mTemplateAnyTime,
-		      i18n("Set the '%1' option for alarms based on this template.").arg(i18n("Any time")));
-		grid->addWidget(mTemplateAnyTime, 1, 0, alignment);
+		      i18n("Set the '%1' option for alarms based on this template.").tqarg(i18n("Any time")));
+		grid->addWidget(mTemplateAnyTime, 1, 0, tqalignment);
 
 		box = new TQHBox(mTemplateTimeGroup);
 		box->setSpacing(spacingHint());
 		mTemplateUseTimeAfter = new RadioButton(AlarmTimeWidget::i18n_w_TimeFromNow(), box, "templateFromNowButton");
-		mTemplateUseTimeAfter->setFixedSize(mTemplateUseTimeAfter->sizeHint());
+		mTemplateUseTimeAfter->setFixedSize(mTemplateUseTimeAfter->tqsizeHint());
 		mTemplateUseTimeAfter->setReadOnly(mReadOnly);
 		TQWhatsThis::add(mTemplateUseTimeAfter,
 		      i18n("Set alarms based on this template to start after the specified time "
@@ -342,15 +342,15 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
 		mTemplateTimeGroup->insert(mTemplateUseTimeAfter);
 		mTemplateTimeAfter = new TimeSpinBox(1, maxDelayTime, box);
 		mTemplateTimeAfter->setValue(1439);
-		mTemplateTimeAfter->setFixedSize(mTemplateTimeAfter->sizeHint());
+		mTemplateTimeAfter->setFixedSize(mTemplateTimeAfter->tqsizeHint());
 		mTemplateTimeAfter->setReadOnly(mReadOnly);
 		TQWhatsThis::add(mTemplateTimeAfter,
-		      TQString("%1\n\n%2").arg(AlarmTimeWidget::i18n_TimeAfterPeriod())
-		                         .arg(TimeSpinBox::shiftWhatsThis()));
-		box->setFixedHeight(box->sizeHint().height());
-		grid->addWidget(box, 1, 1, alignment);
+		      TQString("%1\n\n%2").tqarg(AlarmTimeWidget::i18n_TimeAfterPeriod())
+		                         .tqarg(TimeSpinBox::shiftWhatsThis()));
+		box->setFixedHeight(box->tqsizeHint().height());
+		grid->addWidget(box, 1, 1, tqalignment);
 
-		layout->addStretch();
+		tqlayout->addStretch();
 	}
 	else
 	{
@@ -363,30 +363,30 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
 	static const TQString reminderText = i18n("Enter how long in advance of the main alarm to display a reminder alarm.");
 	mReminder = new Reminder(i18n("Rem&inder:"),
 	                         i18n("Check to additionally display a reminder in advance of the main alarm time(s)."),
-	                         TQString("%1\n\n%2").arg(reminderText).arg(TimeSpinBox::shiftWhatsThis()),
+	                         TQString("%1\n\n%2").tqarg(reminderText).tqarg(TimeSpinBox::shiftWhatsThis()),
 	                         true, true, mainPage);
-	mReminder->setFixedSize(mReminder->sizeHint());
-	topLayout->addWidget(mReminder, 0, Qt::AlignAuto);
+	mReminder->setFixedSize(mReminder->tqsizeHint());
+	topLayout->addWidget(mReminder, 0, TQt::AlignAuto);
 
 	// Late cancel selector - default = allow late display
 	mLateCancel = new LateCancelSelector(true, mainPage);
-	topLayout->addWidget(mLateCancel, 0, Qt::AlignAuto);
+	topLayout->addWidget(mLateCancel, 0, TQt::AlignAuto);
 
 	// Acknowledgement confirmation required - default = no confirmation
-	layout = new TQHBoxLayout(topLayout, 0);
+	tqlayout = new TQHBoxLayout(topLayout, 0);
 	mConfirmAck = createConfirmAckCheckbox(mainPage);
-	mConfirmAck->setFixedSize(mConfirmAck->sizeHint());
-	layout->addWidget(mConfirmAck);
-	layout->addSpacing(2*spacingHint());
-	layout->addStretch();
+	mConfirmAck->setFixedSize(mConfirmAck->tqsizeHint());
+	tqlayout->addWidget(mConfirmAck);
+	tqlayout->addSpacing(2*spacingHint());
+	tqlayout->addStretch();
 
 	if (theApp()->korganizerEnabled())
 	{
 		// Show in KOrganizer checkbox
 		mShowInKorganizer = new CheckBox(i18n_ShowInKOrganizer(), mainPage);
-		mShowInKorganizer->setFixedSize(mShowInKorganizer->sizeHint());
+		mShowInKorganizer->setFixedSize(mShowInKorganizer->tqsizeHint());
 		TQWhatsThis::add(mShowInKorganizer, i18n("Check to copy the alarm into KOrganizer's calendar"));
-		layout->addWidget(mShowInKorganizer);
+		tqlayout->addWidget(mShowInKorganizer);
 	}
 
 	setButtonWhatsThis(Ok, i18n("Schedule the alarm at the specified time."));
@@ -436,40 +436,40 @@ void EditAlarmDlg::initDisplayAlarms(TQWidget* parent)
 	// File browse button
 	mFileBrowseButton = new TQPushButton(mFileBox);
 	mFileBrowseButton->setPixmap(SmallIcon("fileopen"));
-	mFileBrowseButton->setFixedSize(mFileBrowseButton->sizeHint());
+	mFileBrowseButton->setFixedSize(mFileBrowseButton->tqsizeHint());
 	TQToolTip::add(mFileBrowseButton, i18n("Choose a file"));
 	TQWhatsThis::add(mFileBrowseButton, i18n("Select a text or image file to display."));
 	mFileRadio->init(mFileBrowseButton, mFileMessageEdit);
 
 	// Font and colour choice button and sample text
 	mFontColourButton = new FontColourButton(mDisplayAlarmsFrame);
-	mFontColourButton->setMaximumHeight(mFontColourButton->sizeHint().height());
+	mFontColourButton->setMaximumHeight(mFontColourButton->tqsizeHint().height());
 	frameLayout->addWidget(mFontColourButton);
 
-	TQHBoxLayout* layout = new TQHBoxLayout(frameLayout, 0, 0);
+	TQHBoxLayout* tqlayout = new TQHBoxLayout(frameLayout, 0, 0);
 	mBgColourBox = new TQHBox(mDisplayAlarmsFrame);
 	mBgColourBox->setSpacing(spacingHint());
-	layout->addWidget(mBgColourBox);
-	layout->addStretch();
+	tqlayout->addWidget(mBgColourBox);
+	tqlayout->addStretch();
 	TQLabel* label = new TQLabel(i18n("&Background color:"), mBgColourBox);
 	mBgColourButton = new ColourCombo(mBgColourBox);
 	label->setBuddy(mBgColourButton);
 	TQWhatsThis::add(mBgColourBox, i18n("Select the alarm message background color"));
 
 	// Sound checkbox and file selector
-	layout = new TQHBoxLayout(frameLayout);
+	tqlayout = new TQHBoxLayout(frameLayout);
 	mSoundPicker = new SoundPicker(mDisplayAlarmsFrame);
-	mSoundPicker->setFixedSize(mSoundPicker->sizeHint());
-	layout->addWidget(mSoundPicker);
-	layout->addSpacing(2*spacingHint());
-	layout->addStretch();
+	mSoundPicker->setFixedSize(mSoundPicker->tqsizeHint());
+	tqlayout->addWidget(mSoundPicker);
+	tqlayout->addSpacing(2*spacingHint());
+	tqlayout->addStretch();
 
 	if (ShellProcess::authorised())    // don't display if shell commands not allowed (e.g. kiosk mode)
 	{
 		// Special actions button
 		mSpecialActionsButton = new SpecialActionsButton(i18n_SpecialActions(), mDisplayAlarmsFrame);
-		mSpecialActionsButton->setFixedSize(mSpecialActionsButton->sizeHint());
-		layout->addWidget(mSpecialActionsButton);
+		mSpecialActionsButton->setFixedSize(mSpecialActionsButton->tqsizeHint());
+		tqlayout->addWidget(mSpecialActionsButton);
 	}
 
 	// Top-adjust the controls
@@ -488,10 +488,10 @@ void EditAlarmDlg::initCommand(TQWidget* parent)
 	TQBoxLayout* frameLayout = new TQVBoxLayout(mCommandFrame, 0, spacingHint());
 
 	mCmdTypeScript = new CheckBox(i18n_p_EnterScript(), mCommandFrame);
-	mCmdTypeScript->setFixedSize(mCmdTypeScript->sizeHint());
+	mCmdTypeScript->setFixedSize(mCmdTypeScript->tqsizeHint());
 	connect(mCmdTypeScript, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotCmdScriptToggled(bool)));
 	TQWhatsThis::add(mCmdTypeScript, i18n("Check to enter the contents of a script instead of a shell command line"));
-	frameLayout->addWidget(mCmdTypeScript, 0, Qt::AlignAuto);
+	frameLayout->addWidget(mCmdTypeScript, 0, TQt::AlignAuto);
 
 	mCmdCommandEdit = new LineEdit(LineEdit::Url, mCommandFrame);
 	TQWhatsThis::add(mCmdCommandEdit, i18n("Enter a shell command to execute."));
@@ -505,20 +505,20 @@ void EditAlarmDlg::initCommand(TQWidget* parent)
 
 	mCmdOutputGroup = new ButtonGroup(i18n("Command Output"), mCommandFrame);
 	frameLayout->addWidget(mCmdOutputGroup);
-	TQBoxLayout* layout = new TQVBoxLayout(mCmdOutputGroup, marginHint(), spacingHint());
-	layout->addSpacing(fontMetrics().lineSpacing()/2);
+	TQBoxLayout* tqlayout = new TQVBoxLayout(mCmdOutputGroup, marginHint(), spacingHint());
+	tqlayout->addSpacing(fontMetrics().lineSpacing()/2);
 
 	// Execute in terminal window
 	RadioButton* button = new RadioButton(i18n_u_ExecInTermWindow(), mCmdOutputGroup, "execInTerm");
-	button->setFixedSize(button->sizeHint());
+	button->setFixedSize(button->tqsizeHint());
 	TQWhatsThis::add(button, i18n("Check to execute the command in a terminal window"));
 	mCmdOutputGroup->insert(button, EXEC_IN_TERMINAL);
-	layout->addWidget(button, 0, Qt::AlignAuto);
+	tqlayout->addWidget(button, 0, TQt::AlignAuto);
 
 	// Log file name edit box
 	TQHBox* box = new TQHBox(mCmdOutputGroup);
-	(new TQWidget(box))->setFixedWidth(button->style().subRect(TQStyle::SR_RadioButtonIndicator, button).width());   // indent the edit box
-//	(new TQWidget(box))->setFixedWidth(button->style().pixelMetric(TQStyle::PM_ExclusiveIndicatorWidth));   // indent the edit box
+	(new TQWidget(box))->setFixedWidth(button->tqstyle().subRect(TQStyle::SR_RadioButtonIndicator, button).width());   // indent the edit box
+//	(new TQWidget(box))->setFixedWidth(button->style().tqpixelMetric(TQStyle::PM_ExclusiveIndicatorWidth));   // indent the edit box
 	mCmdLogFileEdit = new LineEdit(LineEdit::Url, box);
 	mCmdLogFileEdit->setAcceptDrops(true);
 	TQWhatsThis::add(mCmdLogFileEdit, i18n("Enter the name or path of the log file."));
@@ -527,25 +527,25 @@ void EditAlarmDlg::initCommand(TQWidget* parent)
 	// The file browser dialogue is activated by the PickLogFileRadio class.
 	TQPushButton* browseButton = new TQPushButton(box);
 	browseButton->setPixmap(SmallIcon("fileopen"));
-	browseButton->setFixedSize(browseButton->sizeHint());
+	browseButton->setFixedSize(browseButton->tqsizeHint());
 	TQToolTip::add(browseButton, i18n("Choose a file"));
 	TQWhatsThis::add(browseButton, i18n("Select a log file."));
 
 	// Log output to file
 	button = new PickLogFileRadio(browseButton, mCmdLogFileEdit, i18n_g_LogToFile(), mCmdOutputGroup, "cmdLog");
-	button->setFixedSize(button->sizeHint());
+	button->setFixedSize(button->tqsizeHint());
 	TQWhatsThis::add(button,
 	      i18n("Check to log the command output to a local file. The output will be appended to any existing contents of the file."));
 	mCmdOutputGroup->insert(button, LOG_TO_FILE);
-	layout->addWidget(button, 0, Qt::AlignAuto);
-	layout->addWidget(box);
+	tqlayout->addWidget(button, 0, TQt::AlignAuto);
+	tqlayout->addWidget(box);
 
 	// Discard output
 	button = new RadioButton(i18n("Discard"), mCmdOutputGroup, "cmdDiscard");
-	button->setFixedSize(button->sizeHint());
+	button->setFixedSize(button->tqsizeHint());
 	TQWhatsThis::add(button, i18n("Check to discard command output."));
 	mCmdOutputGroup->insert(button, DISCARD_OUTPUT);
-	layout->addWidget(button, 0, Qt::AlignAuto);
+	tqlayout->addWidget(button, 0, TQt::AlignAuto);
 
 	// Top-adjust the controls
 	mCmdPadding = new TQHBox(mCommandFrame);
@@ -560,8 +560,8 @@ void EditAlarmDlg::initEmail(TQWidget* parent)
 {
 	mEmailFrame = new TQFrame(parent);
 	mEmailFrame->setFrameStyle(TQFrame::NoFrame);
-	TQBoxLayout* layout = new TQVBoxLayout(mEmailFrame, 0, spacingHint());
-	TQGridLayout* grid = new TQGridLayout(layout, 3, 3, spacingHint());
+	TQBoxLayout* tqlayout = new TQVBoxLayout(mEmailFrame, 0, spacingHint());
+	TQGridLayout* grid = new TQGridLayout(tqlayout, 3, 3, spacingHint());
 	grid->setColStretch(1, 1);
 
 	mEmailFromList = 0;
@@ -569,11 +569,11 @@ void EditAlarmDlg::initEmail(TQWidget* parent)
 	{
 		// Email sender identity
 		TQLabel* label = new TQLabel(i18n_EmailFrom(), mEmailFrame);
-		label->setFixedSize(label->sizeHint());
+		label->setFixedSize(label->tqsizeHint());
 		grid->addWidget(label, 0, 0);
 
 		mEmailFromList = new EmailIdCombo(KAMail::identityManager(), mEmailFrame);
-		mEmailFromList->setMinimumSize(mEmailFromList->sizeHint());
+		mEmailFromList->setMinimumSize(mEmailFromList->tqsizeHint());
 		label->setBuddy(mEmailFromList);
 		TQWhatsThis::add(mEmailFromList,
 		      i18n("Your email identity, used to identify you as the sender when sending email alarms."));
@@ -582,11 +582,11 @@ void EditAlarmDlg::initEmail(TQWidget* parent)
 
 	// Email recipients
 	TQLabel* label = new TQLabel(i18n_EmailTo(), mEmailFrame);
-	label->setFixedSize(label->sizeHint());
+	label->setFixedSize(label->tqsizeHint());
 	grid->addWidget(label, 1, 0);
 
 	mEmailToEdit = new LineEdit(LineEdit::Emails, mEmailFrame);
-	mEmailToEdit->setMinimumSize(mEmailToEdit->sizeHint());
+	mEmailToEdit->setMinimumSize(mEmailToEdit->tqsizeHint());
 	TQWhatsThis::add(mEmailToEdit,
 	      i18n("Enter the addresses of the email recipients. Separate multiple addresses by "
 	           "commas or semicolons."));
@@ -594,7 +594,7 @@ void EditAlarmDlg::initEmail(TQWidget* parent)
 
 	mEmailAddressButton = new TQPushButton(mEmailFrame);
 	mEmailAddressButton->setPixmap(SmallIcon("contents"));
-	mEmailAddressButton->setFixedSize(mEmailAddressButton->sizeHint());
+	mEmailAddressButton->setFixedSize(mEmailAddressButton->tqsizeHint());
 	connect(mEmailAddressButton, TQT_SIGNAL(clicked()), TQT_SLOT(openAddressBook()));
 	TQToolTip::add(mEmailAddressButton, i18n("Open address book"));
 	TQWhatsThis::add(mEmailAddressButton, i18n("Select email addresses from your address book."));
@@ -602,11 +602,11 @@ void EditAlarmDlg::initEmail(TQWidget* parent)
 
 	// Email subject
 	label = new TQLabel(i18n_j_EmailSubject(), mEmailFrame);
-	label->setFixedSize(label->sizeHint());
+	label->setFixedSize(label->tqsizeHint());
 	grid->addWidget(label, 2, 0);
 
 	mEmailSubjectEdit = new LineEdit(mEmailFrame);
-	mEmailSubjectEdit->setMinimumSize(mEmailSubjectEdit->sizeHint());
+	mEmailSubjectEdit->setMinimumSize(mEmailSubjectEdit->tqsizeHint());
 	label->setBuddy(mEmailSubjectEdit);
 	TQWhatsThis::add(mEmailSubjectEdit, i18n("Enter the email subject."));
 	grid->addMultiCellWidget(mEmailSubjectEdit, 2, 2, 1, 2);
@@ -614,19 +614,19 @@ void EditAlarmDlg::initEmail(TQWidget* parent)
 	// Email body
 	mEmailMessageEdit = new TextEdit(mEmailFrame);
 	TQWhatsThis::add(mEmailMessageEdit, i18n("Enter the email message."));
-	layout->addWidget(mEmailMessageEdit);
+	tqlayout->addWidget(mEmailMessageEdit);
 
 	// Email attachments
-	grid = new TQGridLayout(layout, 2, 3, spacingHint());
+	grid = new TQGridLayout(tqlayout, 2, 3, spacingHint());
 	label = new TQLabel(i18n("Attachment&s:"), mEmailFrame);
-	label->setFixedSize(label->sizeHint());
+	label->setFixedSize(label->tqsizeHint());
 	grid->addWidget(label, 0, 0);
 
 	mEmailAttachList = new TQComboBox(true, mEmailFrame);
-	mEmailAttachList->setMinimumSize(mEmailAttachList->sizeHint());
+	mEmailAttachList->setMinimumSize(mEmailAttachList->tqsizeHint());
 	mEmailAttachList->lineEdit()->setReadOnly(true);
 TQListBox* list = mEmailAttachList->listBox();
-TQRect rect = list->geometry();
+TQRect rect = list->tqgeometry();
 list->setGeometry(rect.left() - 50, rect.top(), rect.width(), rect.height());
 	label->setBuddy(mEmailAttachList);
 	TQWhatsThis::add(mEmailAttachList,
@@ -646,10 +646,10 @@ list->setGeometry(rect.left() - 50, rect.top(), rect.width(), rect.height());
 
 	// BCC email to sender
 	mEmailBcc = new CheckBox(i18n_s_CopyEmailToSelf(), mEmailFrame);
-	mEmailBcc->setFixedSize(mEmailBcc->sizeHint());
+	mEmailBcc->setFixedSize(mEmailBcc->tqsizeHint());
 	TQWhatsThis::add(mEmailBcc,
 	      i18n("If checked, the email will be blind copied to you."));
-	grid->addMultiCellWidget(mEmailBcc, 1, 1, 0, 1, Qt::AlignAuto);
+	grid->addMultiCellWidget(mEmailBcc, 1, 1, 0, 1, TQt::AlignAuto);
 }
 
 /******************************************************************************
@@ -708,11 +708,11 @@ void EditAlarmDlg::initialise(const KAEvent* event)
 			if (event->isTemplate())
 			{
 				// Initialising from an alarm template: use current date
-				TQDateTime now = TQDateTime::currentDateTime();
+				TQDateTime now = TQDateTime::tqcurrentDateTime();
 				int afterTime = event->templateAfterTime();
 				if (afterTime >= 0)
 				{
-					mTimeWidget->setDateTime(now.addSecs(afterTime * 60));
+					mTimeWidget->setDateTime(TQDateTime(now.addSecs(afterTime * 60)));
 					mTimeWidget->selectTimeFromNow();
 				}
 				else
@@ -728,7 +728,7 @@ void EditAlarmDlg::initialise(const KAEvent* event)
 			else
 			{
 				mExpiredRecurrence = recurs && event->mainExpired();
-				mTimeWidget->setDateTime(recurs || event->uidStatus() == KAEvent::EXPIRED ? event->startDateTime()
+				mTimeWidget->setDateTime(recurs || event->uidtqStatus() == KAEvent::EXPIRED ? event->startDateTime()
 				                         : event->mainExpired() ? event->deferDateTime() : event->mainDateTime());
 			}
 		}
@@ -750,7 +750,7 @@ void EditAlarmDlg::initialise(const KAEvent* event)
 		                        TimePeriod::HOURS_MINUTES);
 		mLateCancel->showAutoClose(action == KAEvent::MESSAGE || action == KAEvent::FILE);
 		mLateCancel->setAutoClose(event->autoClose());
-		mLateCancel->setFixedSize(mLateCancel->sizeHint());
+		mLateCancel->setFixedSize(mLateCancel->tqsizeHint());
 		if (mShowInKorganizer)
 			mShowInKorganizer->setChecked(event->copyToKOrganizer());
 		mConfirmAck->setChecked(event->confirmAck());
@@ -804,7 +804,7 @@ void EditAlarmDlg::initialise(const KAEvent* event)
 		mFontColourButton->setBgColour(Preferences::defaultBgColour());
 		mFontColourButton->setFgColour(Preferences::defaultFgColour());
 		mBgColourButton->setColour(Preferences::defaultBgColour());
-		TQDateTime defaultTime = TQDateTime::currentDateTime().addSecs(60);
+		TQDateTime defaultTime = TQDateTime::tqcurrentDateTime().addSecs(60);
 		if (mTemplate)
 		{
 			mTemplateTimeGroup->setButton(mTemplateTimeGroup->id(mTemplateDefaultTime));
@@ -817,7 +817,7 @@ void EditAlarmDlg::initialise(const KAEvent* event)
 		mLateCancel->setMinutes((Preferences::defaultLateCancel() ? 1 : 0), false, TimePeriod::HOURS_MINUTES);
 		mLateCancel->showAutoClose(true);
 		mLateCancel->setAutoClose(Preferences::defaultAutoClose());
-		mLateCancel->setFixedSize(mLateCancel->sizeHint());
+		mLateCancel->setFixedSize(mLateCancel->tqsizeHint());
 		if (mShowInKorganizer)
 			mShowInKorganizer->setChecked(Preferences::defaultCopyToKOrganizer());
 		mConfirmAck->setChecked(Preferences::defaultConfirmAck());
@@ -1212,7 +1212,7 @@ void EditAlarmDlg::setEvent(KAEvent& event, const TQString& text, bool trial)
 		if (mRecurrenceEdit->repeatType() != RecurrenceEdit::NO_RECUR)
 		{
 			mRecurrenceEdit->updateEvent(event, !mTemplate);
-			TQDateTime now = TQDateTime::currentDateTime();
+			TQDateTime now = TQDateTime::tqcurrentDateTime();
 			bool dateOnly = mAlarmDateTime.isDateOnly();
 			if (dateOnly  &&  mAlarmDateTime.date() < now.date()
 			||  !dateOnly  &&  mAlarmDateTime.rawDateTime() < now)
@@ -1232,7 +1232,7 @@ void EditAlarmDlg::setEvent(KAEvent& event, const TQString& text, bool trial)
 					DateTime remindTime = mAlarmDateTime.addMins(-reminder);
 					if (mDeferDateTime >= remindTime)
 					{
-						if (remindTime > TQDateTime::currentDateTime())
+						if (remindTime > TQDateTime::tqcurrentDateTime())
 							deferral = false;    // ignore deferral if it's after next reminder
 						else if (mDeferDateTime > remindTime)
 							deferReminder = true;    // it's the reminder which is being deferred
@@ -1298,7 +1298,7 @@ void EditAlarmDlg::showEvent(TQShowEvent* se)
 		if (KAlarm::readConfigWindowSize(EDIT_DIALOG_NAME, s))
 			s.setHeight(s.height() + (mDeferGroup->isHidden() ? 0 : mDeferGroupHeight));
 		else
-			s = minimumSize();
+			s = tqminimumSize();
 		resize(s);
 	}
 	KWin::setOnDesktop(winId(), mDesktop);    // ensure it displays on the desktop expected by the user
@@ -1381,7 +1381,7 @@ void EditAlarmDlg::slotOk()
 	{
 		if (timedRecurrence)
 		{
-			TQDateTime now = TQDateTime::currentDateTime();
+			TQDateTime now = TQDateTime::tqcurrentDateTime();
 			if (mAlarmDateTime.date() < now.date()
 			||  mAlarmDateTime.date() == now.date()
 			    && !mAlarmDateTime.isDateOnly() && mAlarmDateTime.time() < now.time())
@@ -1424,7 +1424,7 @@ void EditAlarmDlg::slotOk()
 				mTabs->setCurrentPage(mMainPageIndex);
 				mReminder->setFocusOnCount();
 				KMessageBox::sorry(this, i18n("Reminder period must be less than the recurrence interval, unless '%1' is checked."
-				                             ).arg(Reminder::i18n_first_recurrence_only()));
+				                             ).tqarg(Reminder::i18n_first_recurrence_only()));
 				return;
 			}
 		}
@@ -1479,15 +1479,15 @@ void EditAlarmDlg::slotTry()
 			if (mCommandRadio->isOn()  &&  mCmdOutputGroup->selectedId() != EXEC_IN_TERMINAL)
 			{
 				theApp()->commandMessage((ShellProcess*)proc, this);
-				KMessageBox::information(this, i18n("Command executed:\n%1").arg(text));
+				KMessageBox::information(this, i18n("Command executed:\n%1").tqarg(text));
 				theApp()->commandMessage((ShellProcess*)proc, 0);
 			}
 			else if (mEmailRadio->isOn())
 			{
 				TQString bcc;
 				if (mEmailBcc->isChecked())
-					bcc = i18n("\nBcc: %1").arg(Preferences::emailBccAddress());
-				KMessageBox::information(this, i18n("Email sent to:\n%1%2").arg(mEmailAddresses.join("\n")).arg(bcc));
+					bcc = i18n("\nBcc: %1").tqarg(Preferences::emailBccAddress());
+				KMessageBox::information(this, i18n("Email sent to:\n%1%2").tqarg(mEmailAddresses.join("\n")).tqarg(bcc));
 			}
 		}
 	}
@@ -1530,7 +1530,7 @@ void EditAlarmDlg::slotEditDeferral()
 			return;
 		limit = false;
 	}
-	TQDateTime now = TQDateTime::currentDateTime();
+	TQDateTime now = TQDateTime::tqcurrentDateTime();
 	if (limit)
 	{
 		if (repeatCount  &&  start < now)
@@ -1557,7 +1557,7 @@ void EditAlarmDlg::slotEditDeferral()
 		if (reminder)
 		{
 			DateTime remindTime = start.addMins(-reminder);
-			if (TQDateTime::currentDateTime() < remindTime)
+			if (TQDateTime::tqcurrentDateTime() < remindTime)
 				start = remindTime;
 		}
 		deferDlg.setLimit(start.addSecs(-60));
@@ -1565,7 +1565,7 @@ void EditAlarmDlg::slotEditDeferral()
 	if (deferDlg.exec() == TQDialog::Accepted)
 	{
 		mDeferDateTime = deferDlg.getDateTime();
-		mDeferTimeLabel->setText(mDeferDateTime.isValid() ? mDeferDateTime.formatLocale() : TQString::null);
+		mDeferTimeLabel->setText(mDeferDateTime.isValid() ? mDeferDateTime.formatLocale() : TQString());
 	}
 }
 
@@ -1604,7 +1604,7 @@ void EditAlarmDlg::slotShowRecurrenceEdit()
 	mRecurPageIndex = mTabs->currentPageIndex();
 	if (!mReadOnly  &&  !mTemplate)
 	{
-		TQDateTime now = TQDateTime::currentDateTime();
+		TQDateTime now = TQDateTime::tqcurrentDateTime();
 		mAlarmDateTime = mTimeWidget->getDateTime(0, false, false);
 		bool expired = (mAlarmDateTime.dateTime() < now);
 		if (mRecurSetDefaultEndDate)
@@ -1728,7 +1728,7 @@ bool EditAlarmDlg::checkEmailData()
 			if (!bad.isEmpty())
 			{
 				mEmailToEdit->setFocus();
-				KMessageBox::error(this, i18n("Invalid email address:\n%1").arg(bad));
+				KMessageBox::error(this, i18n("Invalid email address:\n%1").tqarg(bad));
 				return false;
 			}
 		}
@@ -1752,7 +1752,7 @@ bool EditAlarmDlg::checkEmailData()
 					break;      // empty
 				case -1:
 					mEmailAttachList->setFocus();
-					KMessageBox::error(this, i18n("Invalid email attachment:\n%1").arg(att));
+					KMessageBox::error(this, i18n("Invalid email attachment:\n%1").tqarg(att));
 					return false;
 			}
 		}
@@ -1826,7 +1826,7 @@ void EditAlarmDlg::slotAlarmTypeChanged(int)
 		focus = mEmailToEdit;
 	}
 	mLateCancel->showAutoClose(displayAlarm);
-	mLateCancel->setFixedSize(mLateCancel->sizeHint());
+	mLateCancel->setFixedSize(mLateCancel->tqsizeHint());
 	if (focus)
 		focus->setFocus();
 }
@@ -1895,8 +1895,8 @@ void EditAlarmDlg::openAddressBook()
  */
 void EditAlarmDlg::slotAddAttachment()
 {
-	TQString url = KAlarm::browseFile(i18n("Choose File to Attach"), mAttachDefaultDir, TQString::null,
-	                                 TQString::null, KFile::ExistingOnly, this, "pickAttachFile");
+	TQString url = KAlarm::browseFile(i18n("Choose File to Attach"), mAttachDefaultDir, TQString(),
+	                                 TQString(), KFile::ExistingOnly, this, "pickAttachFile");
 	if (!url.isEmpty())
 	{
 		mEmailAttachList->insertItem(url);
@@ -1948,7 +1948,7 @@ bool EditAlarmDlg::checkText(TQString& result, bool showErrorMessage) const
 		enum Err { NONE = 0, BLANK, NONEXISTENT, DIRECTORY, UNREADABLE, NOT_TEXT_IMAGE };
 		Err err = NONE;
 		KURL url;
-		int i = alarmtext.find(TQString::fromLatin1("/"));
+		int i = alarmtext.find(TQString::tqfromLatin1("/"));
 		if (i > 0  &&  alarmtext[i - 1] == ':')
 		{
 			url = alarmtext;
@@ -1973,7 +1973,7 @@ bool EditAlarmDlg::checkText(TQString& result, bool showErrorMessage) const
 			TQDir::setCurrent(TQDir::homeDirPath());
 			alarmtext = info.absFilePath();
 			url.setPath(alarmtext);
-			alarmtext = TQString::fromLatin1("file:") + alarmtext;
+			alarmtext = TQString::tqfromLatin1("file:") + alarmtext;
 			if (!err)
 			{
 				if      (info.isDir())        err = DIRECTORY;
@@ -2012,7 +2012,7 @@ bool EditAlarmDlg::checkText(TQString& result, bool showErrorMessage) const
 				default:
 					break;
 			}
-			if (KMessageBox::warningContinueCancel(const_cast<EditAlarmDlg*>(this), errmsg.arg(alarmtext))
+			if (KMessageBox::warningContinueCancel(const_cast<EditAlarmDlg*>(this), errmsg.tqarg(alarmtext))
 			    == KMessageBox::Cancel)
 				return false;
 		}
@@ -2030,7 +2030,7 @@ bool EditAlarmDlg::checkText(TQString& result, bool showErrorMessage) const
 TextEdit::TextEdit(TQWidget* parent, const char* name)
 	: KTextEdit(parent, name)
 {
-	TQSize tsize = sizeHint();
+	TQSize tsize = tqsizeHint();
 	tsize.setHeight(fontMetrics().lineSpacing()*13/4 + 2*frameWidth());
 	setMinimumSize(tsize);
 }
