@@ -54,8 +54,8 @@ static const int KALARM_AUTOSTART_TIMEOUT = 30;
 static const int SECS_PER_DAY = 3600 * 24;
 
 // KAlarm config file keys
-static const TQString START_OF_DAY(TQString::fromLatin1("StartOfDay"));
-static const TQString AUTOSTART_TRAY(TQString::fromLatin1("AutostartTray"));
+static const TQString START_OF_DAY(TQString::tqfromLatin1("StartOfDay"));
+static const TQString AUTOSTART_TRAY(TQString::tqfromLatin1("AutostartTray"));
 
 
 AlarmDaemon::AlarmDaemon(bool autostart, TQObject *parent, const char *name)
@@ -84,7 +84,7 @@ AlarmDaemon::AlarmDaemon(bool autostart, TQObject *parent, const char *name)
 		 * itself and instead will simply open a new window.
 		 */
 		KConfig kaconfig(locate("config", "kalarmrc"));
-		kaconfig.setGroup(TQString::fromLatin1("General"));
+		kaconfig.setGroup(TQString::tqfromLatin1("General"));
 		autostart = kaconfig.readBoolEntry(AUTOSTART_TRAY, false);
 		if (autostart)
 		{
@@ -119,8 +119,8 @@ void AlarmDaemon::autostartKAlarm()
 	}
 	kdDebug(5900) << "AlarmDaemon::autostartKAlarm(): starting KAlarm\n";
 	TQStringList args;
-	args << TQString::fromLatin1("--tray");
-	int ret = KApplication::kdeinitExec(TQString::fromLatin1("kalarm"), args);
+	args << TQString::tqfromLatin1("--tray");
+	int ret = KApplication::kdeinitExec(TQString::tqfromLatin1("kalarm"), args);
 	if (ret)
 		kdError(5900) << "AlarmDaemon::autostartKAlarm(): error=" << ret << endl;
 	else
@@ -138,7 +138,7 @@ void AlarmDaemon::startMonitoring()
 	// Set up the alarm timer
 	mAlarmTimer = new TQTimer(this);
 	connect(mAlarmTimer, TQT_SIGNAL(timeout()), TQT_SLOT(checkAlarmsSlot()));
-	setTimerStatus();
+	setTimertqStatus();
 
 	// Start monitoring calendar files.
 	// They are monitored until their client application registers, upon which
@@ -156,7 +156,7 @@ void AlarmDaemon::enableCal(const TQString& urlString, bool enable)
 	if (cal)
 	{
 		cal->setEnabled(enable);
-		notifyCalStatus(cal);    // notify KAlarm
+		notifyCaltqStatus(cal);    // notify KAlarm
 	}
 }
 
@@ -196,8 +196,8 @@ void AlarmDaemon::calendarLoaded(ADCalendar* cal, bool success)
 {
 	if (success)
 		kdDebug(5900) << "Calendar reloaded" << endl;
-	notifyCalStatus(cal);       // notify KAlarm
-	setTimerStatus();
+	notifyCaltqStatus(cal);       // notify KAlarm
+	setTimertqStatus();
 	checkAlarms(cal);
 }
 
@@ -262,8 +262,8 @@ void AlarmDaemon::registerApp(const TQCString& appName, const TQString& appTitle
 		ADConfigData::writeClient(appName, client);
 
 		ADConfigData::enableAutoStart(true);
-		setTimerStatus();
-		notifyCalStatus(client->calendar());
+		setTimertqStatus();
+		notifyCaltqStatus(client->calendar());
 		result = KAlarmd::SUCCESS;
 	}
 
@@ -365,7 +365,7 @@ void AlarmDaemon::checkAlarms(ADCalendar* cal)
 	if (!cal->loaded()  ||  !cal->enabled())
 		return;
 
-	TQDateTime now  = TQDateTime::currentDateTime();
+	TQDateTime now  = TQDateTime::tqcurrentDateTime();
 	kdDebug(5901) << "  To: " << now.toString() << endl;
 	TQValueList<KCal::Alarm*> alarms = cal->alarmsTo(now);
 	if (!alarms.count())
@@ -385,7 +385,7 @@ void AlarmDaemon::checkAlarms(ADCalendar* cal)
 		// The times for non-due alarms are set invalid in 'alarmtimes'.
 		bool recurs = event->doesRecur();
 		const TQStringList cats = event->categories();
-		bool floats = (cats.find(TQString::fromLatin1("DATE")) != cats.end());
+		bool floats = (cats.find(TQString::tqfromLatin1("DATE")) != cats.end());
 		TQDateTime nextDateTime = event->dtStart();
 		if (recurs)
 		{
@@ -478,7 +478,7 @@ bool AlarmDaemon::notifyEvent(ADCalendar* calendar, const TQString& eventID)
 		return false;
 	}
 	kdDebug(5900) << "AlarmDaemon::notifyEvent(" << appname << ", " << eventID << "): notification type=" << client->startClient() << endl;
-	TQString id = TQString::fromLatin1("ad:") + eventID;    // prefix to indicate that the notification if from the daemon
+	TQString id = TQString::tqfromLatin1("ad:") + eventID;    // prefix to indicate that the notification if from the daemon
 
 	// Check if the client application is running and ready to receive notification
 	bool registered = kapp->dcopClient()->isApplicationRegistered(static_cast<const char*>(appname));
@@ -531,7 +531,7 @@ bool AlarmDaemon::notifyEvent(ADCalendar* calendar, const TQString& eventID)
 /******************************************************************************
 * Starts or stops the alarm timer as necessary after a calendar is enabled/disabled.
 */
-void AlarmDaemon::setTimerStatus()
+void AlarmDaemon::setTimertqStatus()
 {
 #ifdef AUTOSTART_KALARM
 	if (!mAlarmTimer)
@@ -569,7 +569,7 @@ void AlarmDaemon::setTimerStatus()
 * Send a DCOP message to to the client which owns the specified calendar,
 * notifying it of a change in calendar status.
 */
-void AlarmDaemon::notifyCalStatus(const ADCalendar* cal)
+void AlarmDaemon::notifyCaltqStatus(const ADCalendar* cal)
 {
 	ClientInfo* client = ClientInfo::get(cal);
 	if (!client)
@@ -577,7 +577,7 @@ void AlarmDaemon::notifyCalStatus(const ADCalendar* cal)
 	TQCString appname = client->appName();
 	if (kapp->dcopClient()->isApplicationRegistered(static_cast<const char*>(appname)))
 	{
-		KAlarmd::CalendarStatus change = cal->available() ? (cal->enabled() ? KAlarmd::CALENDAR_ENABLED : KAlarmd::CALENDAR_DISABLED)
+		KAlarmd::CalendartqStatus change = cal->available() ? (cal->enabled() ? KAlarmd::CALENDAR_ENABLED : KAlarmd::CALENDAR_DISABLED)
 		                                                  : KAlarmd::CALENDAR_UNAVAILABLE;
 		kdDebug(5900) << "AlarmDaemon::notifyCalStatus() sending:" << appname << " -> " << change << endl;
 		AlarmGuiIface_stub stub(appname, client->dcopObject());
@@ -595,7 +595,7 @@ void AlarmDaemon::notifyCalStatus(const ADCalendar* cal)
 void AlarmDaemon::readKAlarmConfig()
 {
 	KConfig config(locate("config", "kalarmrc"));
-	config.setGroup(TQString::fromLatin1("General"));
+	config.setGroup(TQString::tqfromLatin1("General"));
 	TQDateTime defTime(TQDate(1900,1,1), TQTime());
 	mStartOfDay = config.readDateTimeEntry(START_OF_DAY, &defTime).time();
 	kdDebug(5900) << "AlarmDaemon::readKAlarmConfig()" << endl;
