@@ -115,14 +115,14 @@ bool KAMail::send(const KAEvent& event, TQStringList& errmsgs, bool allowNotify)
 		if (identity.isNull())
 		{
 			kdError(5950) << "KAMail::send(): identity" << event.emailFromId() << "not found" << endl;
-			errmsgs = errors(i18n("Invalid 'From' email address.\nKMail identity '%1' not found.").arg(event.emailFromId()));
+			errmsgs = errors(i18n("Invalid 'From' email address.\nKMail identity '%1' not found.").tqarg(event.emailFromId()));
 			return false;
 		}
 		from = identity.fullEmailAddr();
 		if (from.isEmpty())
 		{
 			kdError(5950) << "KAMail::send(): identity" << identity.identityName() << "uoid" << identity.uoid() << ": no email address" << endl;
-			errmsgs = errors(i18n("Invalid 'From' email address.\nEmail identity '%1' has no email address").arg(identity.identityName()));
+			errmsgs = errors(i18n("Invalid 'From' email address.\nEmail identity '%1' has no email address").tqarg(identity.identityName()));
 			return false;
 		}
 	}
@@ -144,7 +144,7 @@ bool KAMail::send(const KAEvent& event, TQStringList& errmsgs, bool allowNotify)
 		return false;
 	}
 	KAMailData data(event, from,
-	                (event.emailBcc() ? Preferences::emailBccAddress() : TQString::null),
+	                (event.emailBcc() ? Preferences::emailBccAddress() : TQString()),
 	                allowNotify);
 	kdDebug(5950) << "KAlarmApp::sendEmail(): To: " << event.emailAddresses(", ")
 	              << "\nSubject: " << event.emailSubject() << endl;
@@ -153,30 +153,30 @@ bool KAMail::send(const KAEvent& event, TQStringList& errmsgs, bool allowNotify)
 	{
 		// Use sendmail to send the message
 		TQString textComplete;
-		TQString command = KStandardDirs::findExe(TQString::fromLatin1("sendmail"),
-		                                         TQString::fromLatin1("/sbin:/usr/sbin:/usr/lib"));
+		TQString command = KStandardDirs::findExe(TQString::tqfromLatin1("sendmail"),
+		                                         TQString::tqfromLatin1("/sbin:/usr/sbin:/usr/lib"));
 		if (!command.isNull())
 		{
-			command += TQString::fromLatin1(" -f ");
+			command += TQString::tqfromLatin1(" -f ");
 			command += KPIM::getEmailAddress(from);
-			command += TQString::fromLatin1(" -oi -t ");
+			command += TQString::tqfromLatin1(" -oi -t ");
 			textComplete = initHeaders(data, false);
 		}
 		else
 		{
-			command = KStandardDirs::findExe(TQString::fromLatin1("mail"));
+			command = KStandardDirs::findExe(TQString::tqfromLatin1("mail"));
 			if (command.isNull())
 			{
-				errmsgs = errors(i18n("%1 not found").arg(TQString::fromLatin1("sendmail"))); // give up
+				errmsgs = errors(i18n("%1 not found").tqarg(TQString::tqfromLatin1("sendmail"))); // give up
 				return false;
 			}
 
-			command += TQString::fromLatin1(" -s ");
+			command += TQString::tqfromLatin1(" -s ");
 			command += KShellProcess::quote(event.emailSubject());
 
 			if (!data.bcc.isEmpty())
 			{
-				command += TQString::fromLatin1(" -b ");
+				command += TQString::tqfromLatin1(" -b ");
 				command += KShellProcess::quote(data.bcc);
 			}
 
@@ -281,7 +281,7 @@ TQString KAMail::sendKMail(const KAMailData& data)
 	}
 	if (data.allowNotify)
 		notifyQueued(data.event);
-	return TQString::null;
+	return TQString();
 }
 
 /******************************************************************************
@@ -321,9 +321,9 @@ TQString KAMail::addToKMailFolder(const KAMailData& data, const char* folder, bo
 		// Notify KMail of the message in the temporary file
 		TQByteArray  callData;
 		TQDataStream arg(callData, IO_WriteOnly);
-		arg << TQString::fromLatin1(folder) << tmpFile.name();
+		arg << TQString::tqfromLatin1(folder) << tmpFile.name();
 		if (callKMail(callData, "KMailIface", "dcopAddMessage(TQString,TQString)", "int"))
-			return TQString::null;
+			return TQString();
 		err = i18n("Error calling KMail");
 	}
 	kdError(5950) << "KAMail::addToKMailFolder(" << folder << "): " << err << endl;
@@ -385,16 +385,16 @@ TQString KAMail::initHeaders(const KAMailData& data, bool dateId)
 		char buff[64];
 		strftime(buff, sizeof(buff), "Date: %a, %d %b %Y %H:%M:%S %z", localtime(&timenow));
 		TQString from = data.from;
-		from.replace(TQRegExp("^.*<"), TQString::null).replace(TQRegExp(">.*$"), TQString::null);
-		message = TQString::fromLatin1(buff);
-		message += TQString::fromLatin1("\nMessage-Id: <%1.%2.%3>\n").arg(timenow).arg(tod.tv_usec).arg(from);
+		from.replace(TQRegExp("^.*<"), TQString()).replace(TQRegExp(">.*$"), TQString());
+		message = TQString::tqfromLatin1(buff);
+		message += TQString::tqfromLatin1("\nMessage-Id: <%1.%2.%3>\n").tqarg(timenow).tqarg(tod.tv_usec).tqarg(from);
 	}
-	message += TQString::fromLatin1("From: ") + data.from;
-	message += TQString::fromLatin1("\nTo: ") + data.event.emailAddresses(", ");
+	message += TQString::tqfromLatin1("From: ") + data.from;
+	message += TQString::tqfromLatin1("\nTo: ") + data.event.emailAddresses(", ");
 	if (!data.bcc.isEmpty())
-		message += TQString::fromLatin1("\nBcc: ") + data.bcc;
-	message += TQString::fromLatin1("\nSubject: ") + data.event.emailSubject();
-	message += TQString::fromLatin1("\nX-Mailer: %1/" KALARM_VERSION).arg(kapp->aboutData()->programName());
+		message += TQString::tqfromLatin1("\nBcc: ") + data.bcc;
+	message += TQString::tqfromLatin1("\nSubject: ") + data.event.emailSubject();
+	message += TQString::tqfromLatin1("\nX-Mailer: %1/" KALARM_VERSION).tqarg(kapp->aboutData()->programName());
 	return message;
 }
 
@@ -426,13 +426,13 @@ TQString KAMail::appendBodyAttachments(TQString& message, const KAEvent& event)
 		time(&timenow);
 		TQCString boundary;
 		boundary.sprintf("------------_%lu_-%lx=", 2*timenow, timenow);
-		message += TQString::fromLatin1("\nMIME-Version: 1.0");
-		message += TQString::fromLatin1("\nContent-Type: multipart/mixed;\n  boundary=\"%1\"\n").arg(boundary);
+		message += TQString::tqfromLatin1("\nMIME-Version: 1.0");
+		message += TQString::tqfromLatin1("\nContent-Type: multipart/mixed;\n  boundary=\"%1\"\n").tqarg(boundary.data());
 
 		if (!event.message().isEmpty())
 		{
 			// There is a message body
-			message += TQString::fromLatin1("\n--%1\nContent-Type: text/plain\nContent-Transfer-Encoding: 8bit\n\n").arg(boundary);
+			message += TQString::tqfromLatin1("\n--%1\nContent-Type: text/plain\nContent-Transfer-Encoding: 8bit\n\n").tqarg(boundary.data());
 			message += event.message();
 		}
 
@@ -446,12 +446,12 @@ TQString KAMail::appendBodyAttachments(TQString& message, const KAEvent& event)
 			KIO::UDSEntry uds;
 			if (!KIO::NetAccess::stat(url, uds, MainWindow::mainMainWindow())) {
 				kdError(5950) << "KAMail::appendBodyAttachments(): not found: " << attachment << endl;
-				return i18n("Attachment not found:\n%1").arg(attachment);
+				return i18n("Attachment not found:\n%1").tqarg(attachment);
 			}
 			KFileItem fi(uds, url);
 			if (fi.isDir()  ||  !fi.isReadable()) {
 				kdError(5950) << "KAMail::appendBodyAttachments(): not file/not readable: " << attachment << endl;
-				return attachError.arg(attachment);
+				return attachError.tqarg(attachment);
 			}
 
 			// Check if the attachment is a text file
@@ -463,25 +463,25 @@ TQString KAMail::appendBodyAttachments(TQString& message, const KAEvent& event)
 					text = (mimeType == textMimeTypes[i]);
 			}
 
-			message += TQString::fromLatin1("\n--%1").arg(boundary);
-			message += TQString::fromLatin1("\nContent-Type: %2; name=\"%3\"").arg(mimeType).arg(fi.text());
-			message += TQString::fromLatin1("\nContent-Transfer-Encoding: %1").arg(TQString::fromLatin1(text ? "8bit" : "BASE64"));
-			message += TQString::fromLatin1("\nContent-Disposition: attachment; filename=\"%4\"\n\n").arg(fi.text());
+			message += TQString::tqfromLatin1("\n--%1").tqarg(boundary.data());
+			message += TQString::tqfromLatin1("\nContent-Type: %2; name=\"%3\"").tqarg(mimeType).tqarg(fi.text());
+			message += TQString::tqfromLatin1("\nContent-Transfer-Encoding: %1").tqarg(TQString::tqfromLatin1(text ? "8bit" : "BASE64"));
+			message += TQString::tqfromLatin1("\nContent-Disposition: attachment; filename=\"%4\"\n\n").tqarg(fi.text());
 
 			// Read the file contents
 			TQString tmpFile;
 			if (!KIO::NetAccess::download(url, tmpFile, MainWindow::mainMainWindow())) {
 				kdError(5950) << "KAMail::appendBodyAttachments(): load failure: " << attachment << endl;
-				return attachError.arg(attachment);
+				return attachError.tqarg(attachment);
 			}
 			TQFile file(tmpFile);
 			if (!file.open(IO_ReadOnly) ) {
 				kdDebug(5950) << "KAMail::appendBodyAttachments() tmp load error: " << attachment << endl;
-				return attachError.arg(attachment);
+				return attachError.tqarg(attachment);
 			}
 			TQIODevice::Offset size = file.size();
 			char* contents = new char [size + 1];
-			Q_LONG bytes = file.readBlock(contents, size);
+			TQ_LONG bytes = file.readBlock(contents, size);
 			file.close();
 			contents[size] = 0;
 			bool atterror = false;
@@ -504,16 +504,16 @@ TQString KAMail::appendBodyAttachments(TQString& message, const KAEvent& event)
 					atterror = true;
 				}
 				else
-					message += TQString::fromLatin1(base64, base64Size);
+					message += TQString::tqfromLatin1(base64, base64Size);
 				delete[] base64;
 			}
 			delete[] contents;
 			if (atterror)
-				return attachError.arg(attachment);
+				return attachError.tqarg(attachment);
 		}
-		message += TQString::fromLatin1("\n--%1--\n.\n").arg(boundary);
+		message += TQString::tqfromLatin1("\n--%1--\n.\n").tqarg(boundary.data());
 	}
-	return TQString::null;
+	return TQString();
 }
 
 /******************************************************************************
@@ -523,7 +523,7 @@ TQString KAMail::appendBodyAttachments(TQString& message, const KAEvent& event)
 void KAMail::notifyQueued(const KAEvent& event)
 {
 	KMime::Types::Address addr;
-	TQString localhost = TQString::fromLatin1("localhost");
+	TQString localhost = TQString::tqfromLatin1("localhost");
 	TQString hostname  = getHostName();
 	const EmailAddressList& addresses = event.emailAddresses();
 	for (TQValueList<KCal::Person>::ConstIterator it = addresses.begin();  it != addresses.end();  ++it)
@@ -539,7 +539,7 @@ void KAMail::notifyQueued(const KAEvent& event)
 				TQString text = (Preferences::emailClient() == Preferences::KMAIL)
 				             ? i18n("An email has been queued to be sent by KMail")
 				             : i18n("An email has been queued to be sent");
-				KMessageBox::information(0, text, TQString::null, Preferences::EMAIL_QUEUED_NOTIFY);
+				KMessageBox::information(0, text, TQString(), Preferences::EMAIL_TQUEUED_NOTIFY);
 				return;
 			}
 		}
@@ -611,7 +611,7 @@ TQString KAMail::convertAddresses(const TQString& items, EmailAddressList& list)
 		if (!bad.isEmpty())
 			return bad;
 	}
-	return TQString::null;
+	return TQString();
 }
 
 #if 0
@@ -654,7 +654,7 @@ TQString KAMail::convertAddress(KMime::Types::Address addr, EmailAddressList& li
 		}
 		list += KCal::Person((*mb).displayName, addrPart);
 	}
-	return TQString::null;
+	return TQString();
 }
 
 /*
@@ -678,7 +678,7 @@ TQString KAMail::convertAddresses(const TQString& items, TQStringList& list)
 				return item;
 		}
 	}
-	return TQString::null;
+	return TQString();
 }*/
 
 /******************************************************************************
@@ -762,7 +762,7 @@ TQString KAMail::convertAttachments(const TQString& items, TQStringList& list)
 		}
 		next = i + 1;
 	}
-	return TQString::null;
+	return TQString();
 }
 
 #if 0
@@ -798,7 +798,7 @@ TQString KAMail::convertAttachments(const TQString& items, KURL::List& list)
 		}
 		next = i + 1;
 	}
-	return TQString::null;
+	return TQString();
 }
 #endif
 
@@ -922,10 +922,10 @@ char* KAMail::base64Encode(const char* in, TQIODevice::Offset size, TQIODevice::
 TQStringList KAMail::errors(const TQString& err, bool sendfail)
 {
 	TQString error1 = sendfail ? i18n("Failed to send email")
-	                          : i18n("Error copying sent email to KMail %1 folder").arg(i18n_sent_mail());
+	                          : i18n("Error copying sent email to KMail %1 folder").tqarg(i18n_sent_mail());
 	if (err.isEmpty())
 		return TQStringList(error1);
-	TQStringList errs(TQString::fromLatin1("%1:").arg(error1));
+	TQStringList errs(TQString::tqfromLatin1("%1:").tqarg(error1));
 	errs += err;
 	return errs;
 }
@@ -933,7 +933,7 @@ TQStringList KAMail::errors(const TQString& err, bool sendfail)
 /******************************************************************************
 *  Get the body of an email, given its serial number.
 */
-TQString KAMail::getMailBody(Q_UINT32 serialNumber)
+TQString KAMail::getMailBody(TQ_UINT32 serialNumber)
 {
 	// Get the body of the email from KMail
 	TQCString    replyType;
@@ -943,8 +943,8 @@ TQString KAMail::getMailBody(Q_UINT32 serialNumber)
 	arg << serialNumber;
 	arg << (int)0;
 	TQString body;
-	if (kapp->dcopClient()->call("kmail", "KMailIface", "getDecodedBodyPart(Q_UINT32,int)", data, replyType, replyData)
-	&&  replyType == "TQString")
+	if (kapp->dcopClient()->call("kmail", "KMailIface", "getDecodedBodyPart(TQ_UINT32,int)", data, replyType, replyData)
+	&&  replyType == TQSTRING_OBJECT_NAME_STRING)
 	{
 		TQDataStream reply_stream(replyData, IO_ReadOnly);
 		reply_stream >> body;
@@ -963,7 +963,7 @@ TQString getHostName()
 {
         char hname[256];
         if (gethostname(hname, sizeof(hname)))
-                return TQString::null;
+                return TQString();
         return TQString::fromLocal8Bit(hname);
 }
 }
@@ -1005,7 +1005,7 @@ bool parseUserName( const char* & scursor, const char * const send,
 
     default: // atom
       scursor--; // re-set scursor to point to ch again
-      tmp = TQString::null;
+      tmp = TQString();
       if ( parseAtom( scursor, send, result, false /* no 8bit */ ) ) {
         if (getpwnam(result.local8Bit()))
           return true;
@@ -1033,7 +1033,7 @@ bool parseAddress( const char* & scursor, const char * const send,
   const char * oldscursor = scursor;
   if ( parseMailbox( scursor, send, maybeMailbox, isCRLF ) ) {
     // yes, it is:
-    result.displayName = TQString::null;
+    result.displayName = TQString();
     result.mailboxList.append( maybeMailbox );
     return true;
   }
@@ -1044,10 +1044,10 @@ bool parseAddress( const char* & scursor, const char * const send,
   TQString maybeUserName;
   if ( parseUserName( scursor, send, maybeUserName, isCRLF ) ) {
     // yes, it is:
-    maybeMailbox.displayName = TQString::null;
+    maybeMailbox.displayName = TQString();
     maybeMailbox.addrSpec.localPart = maybeUserName;
-    maybeMailbox.addrSpec.domain = TQString::null;
-    result.displayName = TQString::null;
+    maybeMailbox.addrSpec.domain = TQString();
+    result.displayName = TQString();
     result.mailboxList.append( maybeMailbox );
     return true;
   }
