@@ -66,7 +66,7 @@ DetailedInfoDlg::DetailedInfoDlg( Element *el , TQWidget *parent, const char *na
 	createContent();
 
 	m_actionCollection = new KActionCollection(this);	
-	KStdAction::quit(this, TQT_SLOT(slotClose()), m_actionCollection);
+	KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(slotClose()), m_actionCollection);
 
 	setButtonTip( User2, i18n( "Goes to the previous element" ) );
 	setButtonTip( User1, i18n( "Goes to the next element" ) );
@@ -94,10 +94,10 @@ void DetailedInfoDlg::setElement(Element *element)
 KHTMLPart* DetailedInfoDlg::addHTMLTab( const TQString& title, const TQString& icontext, const TQString& iconname )
 {
 	TQFrame *frame = addPage(title, icontext, BarIcon(iconname));
-	TQVBoxLayout *layout = new TQVBoxLayout( frame );
-	layout->setMargin( 0 );
-	KHTMLPart *w = new KHTMLPart( frame, "html-part", frame );
-	layout->addWidget( w->view() );
+	TQVBoxLayout *tqlayout = new TQVBoxLayout( frame );
+	tqlayout->setMargin( 0 );
+	KHTMLPart *w = new KHTMLPart( frame, "html-part", TQT_TQOBJECT(frame) );
+	tqlayout->addWidget( w->view() );
 
 	return w;
 }
@@ -122,43 +122,43 @@ TQString DetailedInfoDlg::getHtml(DATATYPE type)
 	html.append( "<div><table summary=\"header\"><tr><td>" );
 	html.append( m_element->symbol() );
 	html.append( "<td><td>" );
-	html.append( i18n( "Block: %1" ).arg( m_element->block() ) );
+	html.append( i18n( "Block: %1" ).tqarg( m_element->block() ) );
 	html.append( "</td></tr></table></div>" );
 	html.append( "<table summary=\"characteristics\" class=\"characterstics\">");
 	switch ( type )
 	{
 		case CHEMICAL:
 			html.append( "<tr><td><img src=\"structure.png\" alt=\"icon\"/></td><td>" );
-			html.append( "<b>" + i18n( "Electronic configuration: %1" ).arg( m_element->parsedOrbits() ) + "</b>" );
+			html.append( "<b>" + i18n( "Electronic configuration: %1" ).tqarg( m_element->parsedOrbits() ) + "</b>" );
 			html.append( "</td></tr>" );
 			html.append( "<tr><td><img src=\"density.png\" alt=\"icon\"/></td><td>" );
-			html.append( "<b>" + i18n( "Density: %1" ).arg( m_element->adjustUnits( Element::DENSITY ) ) + "</b>" );
+			html.append( "<b>" + i18n( "Density: %1" ).tqarg( m_element->adjustUnits( Element::DENSITY ) ) + "</b>" );
 			html.append( "</td></tr>" );
 			html.append( "<tr><td><img src=\"radius.png\" alt=\"icon\"/></td><td><b>" );
-			html.append( "<b>" + i18n( "Covalent Radius: %1" ).arg( m_element->adjustRadius( Element::COVALENT ) ) + "</b>" );
+			html.append( "<b>" + i18n( "Covalent Radius: %1" ).tqarg( m_element->adjustRadius( Element::COVALENT ) ) + "</b>" );
 			html.append( "</td></tr>" );
 			if ( m_element->radius(Element::IONIC) > 0.0 )
 			{
 				html.append( "<tr><td><img src=\"radius.png\" alt=\"icon\"/></td><td>" );
-				html.append( i18n( "<b>Ionic Radius (Charge): %1</b> (%2)" ).arg( m_element->adjustRadius(Element::IONIC) ).arg( m_element->ioncharge() ) );
+				html.append( i18n( "<b>Ionic Radius (Charge): %1</b> (%2)" ).tqarg( m_element->adjustRadius(Element::IONIC) ).tqarg( m_element->ioncharge() ) );
 				html.append( "</td></tr>" );
 			}
 			if ( m_element->radius(Element::VDW) > 0.0 )
 			{
 				html.append( "<tr><td><img src=\"radius.png\" alt=\"icon\"/></td><td>" );
-				html.append( "<b>" + i18n( "van der Waals Radius: %1" ).arg( m_element->adjustRadius(Element::VDW) ) + "</b>" );
+				html.append( "<b>" + i18n( "van der Waals Radius: %1" ).tqarg( m_element->adjustRadius(Element::VDW) ) + "</b>" );
 				html.append( "</td></tr>" );
 			}
 		
 			if ( m_element->radius(Element::ATOMIC) > 0.0 )
 			{
 				html.append( "<tr><td><img src=\"radius.png\" alt=\"icon\"/></td><td><b>" );
-				html.append( "<b>" + i18n( "Atomic Radius: %1" ).arg( m_element->adjustRadius(Element::ATOMIC) ) + "</b>" );
+				html.append( "<b>" + i18n( "Atomic Radius: %1" ).tqarg( m_element->adjustRadius(Element::ATOMIC) ) + "</b>" );
 				html.append( "</td></tr>" );
 			}
 			
 			html.append( "<tr><td stype=\"text-align:center\"><img src=\"mass.png\" alt=\"icon\"/></td><td>" );
-			html.append( "<b>" + i18n( "Mass: %1" ).arg( m_element->adjustUnits( Element::MASS ) ) + "</b>" );
+			html.append( "<b>" + i18n( "Mass: %1" ).tqarg( m_element->adjustUnits( Element::MASS ) ) + "</b>" );
 			html.append( "</td></tr>" );
 			if ( !m_element->isotopes().isEmpty() )
 			{
@@ -171,22 +171,22 @@ TQString DetailedInfoDlg::getHtml(DATATYPE type)
 			html.append( "<tr><td><img src=\"discovery.png\" alt=\"icon\"/></td><td>" );
 			html.append( m_element->adjustUnits( Element::DATE ) );
 			if ( !m_element->scientist( ).isEmpty() )
-				html += "<br />" + i18n("It was discovered by %1").arg(m_element->scientist() );
+				html += "<br />" + i18n("It was discovered by %1").tqarg(m_element->scientist() );
 			html.append( "</td></tr>" );
 			
 			if ( m_element->abundance() > 0 ){
 			html.append( "<tr><td><img src=\"abundance.png\" alt=\"icon\"/></td><td>" );
-			html.append( i18n( "Abundance in crustal rocks: %1 ppm" ).arg( KGlobal::locale()->formatLong( m_element->abundance() ) ) );
+			html.append( i18n( "Abundance in crustal rocks: %1 ppm" ).tqarg( KGlobal::locale()->formatLong( m_element->abundance() ) ) );
 			html.append( "</td></tr>" );
 			}
 			
 			html.append( "<tr><td><img src=\"mass.png\" alt=\"icon\"/></td><td>" );
-			html.append( i18n( "Mean mass: %1 u" ).arg( KalziumUtils::localizedValue( m_element->meanmass(), 6 ) ) );
+			html.append( i18n( "Mean mass: %1 u" ).tqarg( KalziumUtils::localizedValue( m_element->meanmass(), 6 ) ) );
 			html.append( "</td></tr>" );
 			if ( !m_element->nameOrigin().isEmpty() )
 			{
 				html.append( "<tr><td><img src=\"book.png\" alt=\"icon\"/></td><td>" );
-				html.append( i18n( "Origin of the name: %1" ).arg( m_element->nameOrigin() ) );
+				html.append( i18n( "Origin of the name: %1" ).tqarg( m_element->nameOrigin() ) );
 				html.append( "</td></tr>" );
 			}
 			if ( m_element->artificial() || m_element->radioactive() )
@@ -203,16 +203,16 @@ TQString DetailedInfoDlg::getHtml(DATATYPE type)
 			break;
 		case ENERGY:
 			html.append( "<tr><td><img src=\"meltingpoint.png\" alt=\"icon\"/></td><td>" );
-			html.append( i18n( "Melting Point: %1" ).arg( m_element->adjustUnits( Element::MELTINGPOINT ) ) );
+			html.append( i18n( "Melting Point: %1" ).tqarg( m_element->adjustUnits( Element::MELTINGPOINT ) ) );
 			html.append( "</td></tr>" );
 			html.append( "<tr><td><img src=\"boilingpoint.png\" alt=\"icon\"/></td><td>" );
-			html.append( i18n( "Boiling Point: %1" ).arg( m_element->adjustUnits( Element::BOILINGPOINT ) ) );
+			html.append( i18n( "Boiling Point: %1" ).tqarg( m_element->adjustUnits( Element::BOILINGPOINT ) ) );
 			html.append( "</td></tr>" );
 			html.append( "<tr><td><img src=\"structure.png\" alt=\"icon\"/></td><td>" );
-			html.append( i18n( "Electronegativity: %1" ).arg( m_element->adjustUnits( Element::EN ) ) );
+			html.append( i18n( "Electronegativity: %1" ).tqarg( m_element->adjustUnits( Element::EN ) ) );
 			html.append( "</td></tr>" );
 			html.append( "<tr><td><img src=\"electronaffinity.png\" alt=\"icon\"/></td><td>" );
-			html.append( i18n( "Electron affinity: %1 " ).arg( m_element->adjustUnits(Element::EA) ) );
+			html.append( i18n( "Electron affinity: %1 " ).tqarg( m_element->adjustUnits(Element::EA) ) );
 			html.append( "</td></tr>" );
 						
 
@@ -221,7 +221,7 @@ TQString DetailedInfoDlg::getHtml(DATATYPE type)
 			{
 				html.append( "<tr><td><img src=\"ionisation.png\" alt=\"icon\"/></td><td>" );
 				html.append( i18n("the first variable is a number. The result is for example '1.' or '5.', the second is the value of the ionisation energy",
-				             "%1. Ionization energy: %2" ).arg( TQString::number( i+1 ), m_element->adjustUnits( Element::IE, ionlist[i] ) ) );
+				             "%1. Ionization energy: %2" ).tqarg( TQString::number( i+1 ), m_element->adjustUnits( Element::IE, ionlist[i] ) ) );
 			html.append( "</td></tr>" );
 			}
 			break;
@@ -264,13 +264,13 @@ TQString DetailedInfoDlg::isotopeTable()
 	{
 		html.append( "<tr><td align=\"right\">" );
 		if ( ( *it )->weight() > 0.0 )
-			html.append( i18n( "%1 u" ).arg( KalziumUtils::localizedValue( ( *it )->weight(), 6 ) ) );
-		//	html.append( i18n( "%1 u" ).arg( TQString::number( ( *it )->weight() ) ));
+			html.append( i18n( "%1 u" ).tqarg( KalziumUtils::localizedValue( ( *it )->weight(), 6 ) ) );
+		//	html.append( i18n( "%1 u" ).tqarg( TQString::number( ( *it )->weight() ) ));
 		html.append( "</td><td>" );
 		html.append( TQString::number( ( *it )->neutrons() ) );
 		html.append( "</td><td>" );
 		if ( ( *it )->percentage() > 0.0 )
-			html.append( i18n( "this can for example be '24%'", "%1%" ).arg( KalziumUtils::localizedValue( ( *it )->percentage(), 6 ) ) );
+			html.append( i18n( "this can for example be '24%'", "%1%" ).tqarg( KalziumUtils::localizedValue( ( *it )->percentage(), 6 ) ) );
 		html.append( "</td><td>" );
 		if ( ( *it )->halflife() > 0.0 ) {
 			html.append( ( *it )->halflifeAsString()  );
@@ -278,49 +278,49 @@ TQString DetailedInfoDlg::isotopeTable()
 		html.append( "</td><td>" );
 		if ( ( *it )->alphapercentage() > 0.0 ){
 			if ( ( *it )->alphadecay() > 0.0 )
-			html.append( i18n( "%1 MeV" ).arg( KalziumUtils::localizedValue( ( *it )->alphadecay(), 6 ) ) );
-			html.append( i18n( " %1" ).arg( TQChar( 945 ) ) );
+			html.append( i18n( "%1 MeV" ).tqarg( KalziumUtils::localizedValue( ( *it )->alphadecay(), 6 ) ) );
+			html.append( i18n( " %1" ).tqarg( TQChar( 945 ) ) );
 			if ( ( *it )->alphapercentage() < 100.0)
-				html.append( i18n( "(%1%)" ).arg( KalziumUtils::localizedValue( (*it )->alphapercentage(), 6 ) ) );
+				html.append( i18n( "(%1%)" ).tqarg( KalziumUtils::localizedValue( (*it )->alphapercentage(), 6 ) ) );
 			if ( ( *it )->betaminuspercentage() > 0.0 || ( *it )->betapluspercentage() > 0.0 || ( *it )->ecpercentage() > 0.0)
 			html.append( i18n( ", " ) );
 			}
 		if ( ( *it )->betaminuspercentage() > 0.0 ){
 			if ( ( *it )->betaminusdecay() > 0.0 )
-				html.append( i18n( "%1 MeV" ).arg( KalziumUtils::localizedValue( ( *it )->betaminusdecay(), 6 ) ) );
-			html.append( i18n( " %1<sup>-</sup>" ).arg( TQChar( 946 ) ) );
+				html.append( i18n( "%1 MeV" ).tqarg( KalziumUtils::localizedValue( ( *it )->betaminusdecay(), 6 ) ) );
+			html.append( i18n( " %1<sup>-</sup>" ).tqarg( TQChar( 946 ) ) );
 			if ( ( *it )->betaminuspercentage() < 100.0)
-				html.append( i18n( "(%1%)" ).arg( KalziumUtils::localizedValue( ( *it )->betaminuspercentage(), 6 ) ));
+				html.append( i18n( "(%1%)" ).tqarg( KalziumUtils::localizedValue( ( *it )->betaminuspercentage(), 6 ) ));
 			if ( ( *it )->betapluspercentage() > 0.0 || ( *it )->ecpercentage() > 0.0 )
 			html.append( i18n( ", " ) );
 			}
 		if ( ( *it )->betapluspercentage() > 0.0 ){
 			if ( ( *it )->betaplusdecay() > 0.0 )
-				html.append( i18n( "%1 MeV" ).arg( KalziumUtils::localizedValue( ( *it )->betaplusdecay(), 6 ) ) );
-			html.append( i18n( " %1<sup>+</sup>" ).arg(TQChar( 946 ) ) );
+				html.append( i18n( "%1 MeV" ).tqarg( KalziumUtils::localizedValue( ( *it )->betaplusdecay(), 6 ) ) );
+			html.append( i18n( " %1<sup>+</sup>" ).tqarg(TQChar( 946 ) ) );
 			if ( ( *it )->betapluspercentage() == ( *it )->ecpercentage() ) {
 				if ( ( *it )->ecdecay() > 0.0 ) {
-					html.append( i18n( "%1 MeV" ).arg( KalziumUtils::localizedValue( ( *it )->ecdecay(), 6 ) ) ); 
+					html.append( i18n( "%1 MeV" ).tqarg( KalziumUtils::localizedValue( ( *it )->ecdecay(), 6 ) ) ); 
 				}
 				html.append( i18n( "Acronym of Electron Capture"," EC" ) ); 
 			}
 			if ( ( *it )->betapluspercentage() < 100.0)	
-				html.append( i18n( "(%1%)" ).arg( KalziumUtils::localizedValue( ( *it )->betapluspercentage(), 6 ) ) ); 
+				html.append( i18n( "(%1%)" ).tqarg( KalziumUtils::localizedValue( ( *it )->betapluspercentage(), 6 ) ) ); 
 			html += " ";
 			}	
 		if ( ( *it )->ecpercentage() > 0.0 && ( *it )->ecpercentage()!=( *it )->betapluspercentage()){
 			if ( ( *it )->ecdecay() > 0.0 )
-				html.append( i18n( "%1 MeV" ).arg( KalziumUtils::localizedValue( ( *it )->ecdecay(), 6 ) ) );
+				html.append( i18n( "%1 MeV" ).tqarg( KalziumUtils::localizedValue( ( *it )->ecdecay(), 6 ) ) );
 			html.append( i18n( "Acronym of Electron Capture"," EC" ) );
 			if ( ( *it )->ecpercentage() < 100.0 )
-				html.append( i18n( "(%1%)" ).arg( KalziumUtils::localizedValue( ( *it )->ecpercentage(), 6 ) ) );
+				html.append( i18n( "(%1%)" ).tqarg( KalziumUtils::localizedValue( ( *it )->ecpercentage(), 6 ) ) );
 			}
 		html.append( "</td><td>" );
 		html.append( ( *it )->spin() );
 		html.append( "</td><td>" );
 		if ( !( *it )->magmoment().isEmpty() ) {
 			TQString v = KGlobal::locale()->formatNumber( ( *it )->magmoment(), false, 6 );
-			html.append( i18n( "%1 %2<sub>n</sub>" ).arg( v ).arg( TQChar( 956 ) ) );
+			html.append( i18n( "%1 %2<sub>n</sub>" ).tqarg( v ).tqarg( TQChar( 956 ) ) );
 		}	
 		html.append( "</td></tr>" );
 	
@@ -379,7 +379,7 @@ void DetailedInfoDlg::reloadContent()
 	const TQString element_symbol = m_element->symbol();
 
 	// updating caption
-	setCaption( i18n( "For example Carbon (6)" , "%1 (%2)" ).arg( element_name ).arg( m_elementNumber ) );
+	setCaption( i18n( "For example Carbon (6)" , "%1 (%2)" ).tqarg( element_name ).tqarg( m_elementNumber ) );
 
 	// updating overview tab
 	dTab->setElement( m_element );
@@ -389,21 +389,21 @@ void DetailedInfoDlg::reloadContent()
 	if ( TQFile::exists( picpath ) )
 	{
 		TQImage img( picpath, "JPEG" );
-		img = img.smoothScale ( 400, 400, TQImage::ScaleMin );
+		img = img.smoothScale ( 400, 400, TQ_ScaleMin );
 		TQPixmap pic;
 		pic.convertFromImage( img );
 		piclabel->setPixmap( pic );
 	}
 	else 
-		piclabel->setText( i18n( "No picture of %1 found." ).arg( element_name ) );
+		piclabel->setText( i18n( "No picture of %1 found." ).tqarg( element_name ) );
 
 	// updating atomic model tab
 	wOrbits->setElementNumber( m_elementNumber );
 	TQWhatsThis::add( wOrbits,
 	    i18n( "Here you can see the atomic hull of %1. %2 has the configuration %3." )
-	    .arg( m_element->elname() )
-	    .arg( m_element->elname() )
-	    .arg( m_element->parsedOrbits() ) );
+	    .tqarg( m_element->elname() )
+	    .tqarg( m_element->elname() )
+	    .tqarg( m_element->parsedOrbits() ) );
 
 	// updating html tabs
 	fillHTMLTab( m_htmlpages["chemical"], getHtml( CHEMICAL ) );
@@ -422,7 +422,7 @@ void DetailedInfoDlg::reloadContent()
 	}
 	else
 	{
-		m_spectrumLabel->setText( i18n( "No spectrum of %1 found." ).arg( element_name ) );
+		m_spectrumLabel->setText( i18n( "No spectrum of %1 found." ).tqarg( element_name ) );
 		m_spectrumStack->raiseWidget( m_spectrumLabel );
 	}
 }
