@@ -107,7 +107,7 @@ bool KEduVocDocument::open(const KURL& url, bool /*append*/)
     TQFile f(tmpfile);
     if (!f.open(IO_ReadOnly))
     {
-      KMessageBox::error(0, i18n("<qt>Cannot open file<br><b>%1</b></qt>").arg(url.path()));
+      KMessageBox::error(0, i18n("<qt>Cannot open file<br><b>%1</b></qt>").tqarg(url.path()));
       return false;
     }
 
@@ -163,7 +163,7 @@ bool KEduVocDocument::open(const KURL& url, bool /*append*/)
         // TODO new readers provide an explicite error message
         // the two messages should be merged
         TQString format = i18n("Could not load \"%1\"\nDo you want to try again?");
-        TQString msg = format.arg(url.path());
+        TQString msg = format.tqarg(url.path());
         int result = KMessageBox::warningContinueCancel(0, msg,
                                                         kapp->makeStdCaption(i18n("I/O Failure")),
                                                         i18n("&Retry"));
@@ -211,7 +211,7 @@ bool KEduVocDocument::saveAs(TQObject * /*parent*/, const KURL & url, FileType f
 
     if (!f.open(IO_WriteOnly))
     {
-      KMessageBox::error(0, i18n("<qt>Cannot write to file<br><b>%1</b></qt>").arg(tmp.path()));
+      KMessageBox::error(0, i18n("<qt>Cannot write to file<br><b>%1</b></qt>").tqarg(tmp.path()));
       return false;
     }
 
@@ -253,7 +253,7 @@ bool KEduVocDocument::saveAs(TQObject * /*parent*/, const KURL & url, FileType f
       // TODO new writers provide an explicite error message
       // the two messages should be merged
       TQString format = i18n("Could not save \"%1\"\nDo you want to try again?");
-      TQString msg = format.arg(tmp.path());
+      TQString msg = format.tqarg(tmp.path());
       int result = KMessageBox::warningContinueCancel(0, msg,
                                                       kapp->makeStdCaption(i18n("I/O Failure")),
                                                       i18n("&Retry"));
@@ -972,7 +972,7 @@ KEduVocDocument::FileType KEduVocDocument::detectFT(const TQString &filename)
 
    TQDataStream is( &f );
 
-   Q_INT8 c1, c2, c3, c4, c5;
+   TQ_INT8 c1, c2, c3, c4, c5;
    is >> c1
       >> c2
       >> c3
@@ -989,7 +989,7 @@ KEduVocDocument::FileType KEduVocDocument::detectFT(const TQString &filename)
    line.insert (0, c1);
    f.close();
 
-   bool stat = is.device()->status();
+   bool stat = is.tqdevice()->status();
    if (stat != IO_Ok)
      return kvd_none;
    if (c1 == '<' && c2 == '?' && c3 == 'x' && c4 == 'm' && c5 == 'l')
