@@ -22,9 +22,10 @@ class LeitnerSystem;
 @author Martin Pfeiffer
 */
 
-class LeitnerSystemView : public QScrollView
+class LeitnerSystemView : public TQScrollView
 {
 	Q_OBJECT
+  TQ_OBJECT
 		
 public:
     LeitnerSystemView(TQWidget* parent = 0, const char* name = 0, WFlags f = 0);
