@@ -25,8 +25,8 @@ ${APP_NAME}Preferences::${APP_NAME}Preferences()
 ${APP_NAME}PrefPageOne::${APP_NAME}PrefPageOne(TQWidget *parent)
     : TQFrame(parent)
 {
-    TQHBoxLayout *layout = new TQHBoxLayout(this);
-    layout->setAutoAdd(true);
+    TQHBoxLayout *tqlayout = new TQHBoxLayout(this);
+    tqlayout->setAutoAdd(true);
 
     new TQLabel("Add something here", this);
 }
@@ -34,8 +34,8 @@ ${APP_NAME}PrefPageOne::${APP_NAME}PrefPageOne(TQWidget *parent)
 ${APP_NAME}PrefPageTwo::${APP_NAME}PrefPageTwo(TQWidget *parent)
     : TQFrame(parent)
 {
-    TQHBoxLayout *layout = new TQHBoxLayout(this);
-    layout->setAutoAdd(true);
+    TQHBoxLayout *tqlayout = new TQHBoxLayout(this);
+    tqlayout->setAutoAdd(true);
 
     new TQLabel("Add something here", this);
 }
