@@ -25,7 +25,7 @@ karmPart::karmPart( TQWidget *parentWidget, const char *widgetName,
                                   TQObject *parent, const char *name )
     : DCOPObject ( "KarmDCOPIface" ), KParts::ReadWritePart(parent, name), 
     _accel     ( new KAccel( parentWidget ) ),
-    _watcher   ( new KAccelMenuWatch( _accel, parentWidget ) )
+    _watcher   ( new KAccelMenuWatch( _accel, TQT_TQOBJECT(parentWidget) ) )
 {
     // we need an instance
     setInstance( karmPartFactory::instance() );
@@ -117,109 +117,109 @@ void karmPart::makeMenus()
   (void) KStdAction::print( this, TQT_SLOT( print() ), actionCollection());
   actionKeyBindings = KStdAction::keyBindings( this, TQT_SLOT( keyBindings() ),
       actionCollection() );
-  actionPreferences = KStdAction::preferences(_preferences,
+  actionPreferences = KStdAction::preferences(TQT_TQOBJECT(_preferences),
       TQT_SLOT(showDialog()),
       actionCollection() );
   (void) KStdAction::save( this, TQT_SLOT( save() ), actionCollection() );
   KAction* actionStartNewSession = new KAction( i18n("Start &New Session"),
       0,
-      this,
+      TQT_TQOBJECT(this),
       TQT_SLOT( startNewSession() ),
       actionCollection(),
       "start_new_session");
   KAction* actionResetAll = new KAction( i18n("&Reset All Times"),
       0,
-      this,
+      TQT_TQOBJECT(this),
       TQT_SLOT( resetAllTimes() ),
       actionCollection(),
       "reset_all_times");
   actionStart = new KAction( i18n("&Start"),
-      TQString::fromLatin1("1rightarrow"), Key_S,
-      _taskView,
+      TQString::tqfromLatin1("1rightarrow"), Key_S,
+      TQT_TQOBJECT(_taskView),
       TQT_SLOT( startCurrentTimer() ), actionCollection(),
       "start");
   actionStop = new KAction( i18n("S&top"),
-      TQString::fromLatin1("stop"), 0,
-      _taskView,
+      TQString::tqfromLatin1("stop"), 0,
+      TQT_TQOBJECT(_taskView),
       TQT_SLOT( stopCurrentTimer() ), actionCollection(),
       "stop");
   actionStopAll = new KAction( i18n("Stop &All Timers"),
       Key_Escape,
-      _taskView,
+      TQT_TQOBJECT(_taskView),
       TQT_SLOT( stopAllTimers() ), actionCollection(),
       "stopAll");
   actionStopAll->setEnabled(false);
 
   actionNew = new KAction( i18n("&New..."),
-      TQString::fromLatin1("filenew"), CTRL+Key_N,
-      _taskView,
+      TQString::tqfromLatin1("filenew"), CTRL+Key_N,
+      TQT_TQOBJECT(_taskView),
       TQT_SLOT( newTask() ), actionCollection(),
       "new_task");
   actionNewSub = new KAction( i18n("New &Subtask..."),
-      TQString::fromLatin1("kmultiple"), CTRL+ALT+Key_N,
-      _taskView,
+      TQString::tqfromLatin1("kmultiple"), CTRL+ALT+Key_N,
+      TQT_TQOBJECT(_taskView),
       TQT_SLOT( newSubTask() ), actionCollection(),
       "new_sub_task");
   actionDelete = new KAction( i18n("&Delete"),
-      TQString::fromLatin1("editdelete"), Key_Delete,
-      _taskView,
+      TQString::tqfromLatin1("editdelete"), Key_Delete,
+      TQT_TQOBJECT(_taskView),
       TQT_SLOT( deleteTask() ), actionCollection(),
       "delete_task");
   actionEdit = new KAction( i18n("&Edit..."),
-      TQString::fromLatin1("edit"), CTRL + Key_E,
-      _taskView,
+      TQString::tqfromLatin1("edit"), CTRL + Key_E,
+      TQT_TQOBJECT(_taskView),
       TQT_SLOT( editTask() ), actionCollection(),
       "edit_task");
 //  actionAddComment = new KAction( i18n("&Add Comment..."),
-//      TQString::fromLatin1("document"),
+//      TQString::tqfromLatin1("document"),
 //      CTRL+ALT+Key_E,
-//      _taskView,
+//      TQT_TQOBJECT(_taskView),
 //      TQT_SLOT( addCommentToTask() ),
 //      actionCollection(),
 //      "add_comment_to_task");
   actionMarkAsComplete = new KAction( i18n("&Mark as Complete"),
-      TQString::fromLatin1("document"),
+      TQString::tqfromLatin1("document"),
       CTRL+Key_M,
-      _taskView,
+      TQT_TQOBJECT(_taskView),
       TQT_SLOT( markTaskAsComplete() ),
       actionCollection(),
       "mark_as_complete");
   actionMarkAsIncomplete = new KAction( i18n("&Mark as Incomplete"),
-      TQString::fromLatin1("document"),
+      TQString::tqfromLatin1("document"),
       CTRL+Key_M,
-      _taskView,
+      TQT_TQOBJECT(_taskView),
       TQT_SLOT( markTaskAsIncomplete() ),
       actionCollection(),
       "mark_as_incomplete");
   actionClipTotals = new KAction( i18n("&Copy Totals to Clipboard"),
-      TQString::fromLatin1("klipper"),
+      TQString::tqfromLatin1("klipper"),
       CTRL+Key_C,
-      _taskView,
+      TQT_TQOBJECT(_taskView),
       TQT_SLOT( clipTotals() ),
       actionCollection(),
       "clip_totals");
   actionClipHistory = new KAction( i18n("Copy &History to Clipboard"),
-      TQString::fromLatin1("klipper"),
+      TQString::tqfromLatin1("klipper"),
       CTRL+ALT+Key_C,
-      _taskView,
+      TQT_TQOBJECT(_taskView),
       TQT_SLOT( clipHistory() ),
       actionCollection(),
       "clip_history");
 
   new KAction( i18n("Import &Legacy Flat File..."), 0,
-      _taskView, TQT_SLOT(loadFromFlatFile()), actionCollection(),
+      TQT_TQOBJECT(_taskView), TQT_SLOT(loadFromFlatFile()), actionCollection(),
       "import_flatfile");
   new KAction( i18n("&Export to CSV File..."), 0,
-      _taskView, TQT_SLOT(exportcsvFile()), actionCollection(),
+      TQT_TQOBJECT(_taskView), TQT_SLOT(exportcsvFile()), actionCollection(),
       "export_csvfile");
   new KAction( i18n("Export &History to CSV File..."), 0,
-      this, TQT_SLOT(exportcsvHistory()), actionCollection(),
+      TQT_TQOBJECT(this), TQT_SLOT(exportcsvHistory()), actionCollection(),
       "export_csvhistory");
   new KAction( i18n("Import Tasks From &Planner..."), 0,
-      _taskView, TQT_SLOT(importPlanner()), actionCollection(),
+      TQT_TQOBJECT(_taskView), TQT_SLOT(importPlanner()), actionCollection(),
       "import_planner");  
   new KAction( i18n("Configure KArm..."), 0,
-      _preferences, TQT_SLOT(showDialog()), actionCollection(),
+      TQT_TQOBJECT(_preferences), TQT_SLOT(showDialog()), actionCollection(),
       "configure_karm");  
 
 /*
@@ -333,7 +333,7 @@ bool karmPart::saveFile()
     if (isReadWrite() == false)
         return false;
 
-    // m_file is always local, so we use QFile
+    // m_file is always local, so we use TQFile
     TQFile file(m_file);
     if (file.open(IO_WriteOnly) == false)
         return false;
@@ -509,11 +509,11 @@ TQString karmPart::setPerCentComplete( const TQString& taskName, int perCent )
     if ((_taskView->item_at_index(i)->name()==taskName))
     {
       index=i;
-      if (err==TQString::null) err="task name is abigious";
-      if (err=="no such task") err=TQString::null;
+      if (err==TQString()) err="task name is abigious";
+      if (err=="no such task") err=TQString();
     }
   }
-  if (err==TQString::null) 
+  if (err==TQString()) 
   {
     _taskView->item_at_index(index)->setPercentComplete( perCent, _taskView->storage() );
   }
@@ -576,7 +576,7 @@ int karmPart::bookTime
 TQString karmPart::getError( int mkb ) const
 {
   if ( mkb <= KARM_MAX_ERROR_NO ) return m_error[ mkb ];
-  else return i18n( "Invalid error number: %1" ).arg( mkb );
+  else return i18n( "Invalid error number: %1" ).tqarg( mkb );
 }
 
 int karmPart::totalMinutesForTaskId( const TQString& taskId )
