@@ -11,9 +11,10 @@
 #include <tqptrlist.h>
 
 
-class KALedMeter : public QFrame
+class KALedMeter : public TQFrame
 {
-    Q_OBJECT       
+    Q_OBJECT
+    TQ_OBJECT
 public:
     KALedMeter( TQWidget *parent );
 
