@@ -303,7 +303,7 @@ void KateFileTemplates::refreshMenu( PluginView *v )
   m_acRecentTemplates->plug( m );
   m->insertSeparator();
 
-  TQDict<TQPopupMenu> submenus; // ### QMAP
+  TQDict<TQPopupMenu> submenus; // ### TQMAP
   for ( uint i = 0; i < m_templates.count(); i++ )
   {
     if ( ! submenus[ m_templates.at( i )->group ] )
@@ -348,7 +348,7 @@ void KateFileTemplates::slotAny()
   // get a URL and pass that to slotOpenTemplate
   TQString fn = KFileDialog::getOpenFileName(
                           "katefiletemplate",
-                          TQString::null,
+                          TQString(),
                           application()->activeMainWindow()->viewManager()->activeView(),
                           i18n("Open as Template") );
   if ( ! fn.isEmpty() )
@@ -381,7 +381,7 @@ void KateFileTemplates::slotOpenTemplate( const KURL &url )
     if ( ! file.open( IO_ReadOnly ) )
     {
       KMessageBox::sorry( application()->activeMainWindow()->viewManager()->activeView(),
-                          i18n("<qt>Error opening the file<br><strong>%1</strong><br>for reading. The document will not be created.</qt>").arg(filename),
+                          i18n("<qt>Error opening the file<br><strong>%1</strong><br>for reading. The document will not be created.</qt>").tqarg(filename),
                           i18n("Template Plugin"), 0 );
       KIO::NetAccess::removeTempFile( tmpfile );
       return;
@@ -479,7 +479,7 @@ void KateFileTemplates::slotOpenTemplate( const KURL &url )
         count++;
 
     if ( docname.contains( "%1" ) )
-      docname = docname.arg( count );
+      docname = docname.tqarg( count );
 
     doc->setDocName( docname );
 
@@ -687,7 +687,7 @@ KateTemplateWizard::KateTemplateWizard( TQWidget *parent, KateFileTemplates *kft
   rb = new TQRadioButton( i18n("Use an existing file:"), page );
   bgOrigin->insert( rb, 2 );
   glo->addMultiCellWidget( rb, 3, 3, 1, 2 );
-  int marg = rb->style().subRect( TQStyle::SR_RadioButtonIndicator, rb ).width();
+  int marg = rb->tqstyle().subRect( TQStyle::SR_RadioButtonIndicator, rb ).width();
   glo->addItem( new TQSpacerItem( marg, 1, TQSizePolicy::Fixed ), 4, 1 );
   urOrigin = new KURLRequester( page );
   glo->addWidget( urOrigin, 4, 2 );
@@ -795,12 +795,12 @@ KateTemplateWizard::KateTemplateWizard( TQWidget *parent, KateFileTemplates *kft
       "edit the data in the KDE email information."), page ) );
 
   cbRRealname = new TQCheckBox( i18n("Replace full name '%1' with the "
-    "'%{fullname}' macro").arg( sFullname ), page );
+    "'%{fullname}' macro").tqarg( sFullname ), page );
   cbRRealname->setEnabled( ! sFullname.isEmpty() );
   lo->addWidget( cbRRealname );
 
   cbREmail = new TQCheckBox( i18n("Replace email address '%1' with the "
-      "'%email' macro").arg( sEmail ), page);
+      "'%email' macro").tqarg( sEmail ), page);
   cbREmail->setEnabled( ! sEmail.isEmpty() );
   lo->addWidget( cbREmail );
 
@@ -922,7 +922,7 @@ void KateTemplateWizard::accept()
       if ( KMessageBox::warningContinueCancel( this, i18n(
           "<p>The file <br><strong>'%1'</strong><br> already exists; if you "
           "do not want to overwrite it, change the template file name to "
-          "something else.").arg( templateUrl.prettyURL() ),
+          "something else.").tqarg( templateUrl.prettyURL() ),
       i18n("File Exists"), i18n("Overwrite") )
            == KMessageBox::Cancel )
         return;
@@ -976,7 +976,7 @@ void KateTemplateWizard::accept()
       {
         KMessageBox::sorry( this, i18n(
             "<qt>Error opening the file<br><strong>%1</strong><br>for reading. "
-            "The document will not be created</qt>").arg(u.prettyURL()),
+            "The document will not be created</qt>").tqarg(u.prettyURL()),
             i18n("Template Plugin"), 0 );
 
         KIO::NetAccess::removeTempFile( tmpfile );
@@ -1055,7 +1055,7 @@ void KateTemplateWizard::accept()
   {
     KMessageBox::sorry( this, i18n(
         "Unable to save the template to '%1'.\n\nThe template will be opened, "
-        "so you can save it from the editor.").arg( templateUrl.prettyURL() ),
+        "so you can save it from the editor.").tqarg( templateUrl.prettyURL() ),
         i18n("Save Failed") );
 
     kft->application()->activeMainWindow()->viewManager()->openURL( KURL() );
@@ -1146,7 +1146,7 @@ void KateTemplateManager::reload()
 {
   lvTemplates->clear();
 
-  TQDict<KListViewItem> groupitems; // FIXME QMAP
+  TQDict<KListViewItem> groupitems; // FIXME TQMAP
   for ( uint i = 0; i < kft->templates().count(); i++ )
   {
     if ( ! groupitems[ kft->templates().at( i )->group ] )
@@ -1233,7 +1233,7 @@ void KateTemplateManager::slotUpload()
   if ( item )
   {
     KFTNewStuff *ns = new KFTNewStuff( "katefiletemplates/template", this );
-    ns->upload( item->templateinfo->filename, TQString::null );
+    ns->upload( item->templateinfo->filename, TQString() );
   }
 }
 
