@@ -184,7 +184,7 @@ bool KatePrinter::print (KateDocument *doc)
          // This retrieves all tags, ued or not, but
          // none of theese operations should be expensive,
          // and searcing each tag in the format strings is avoided.
-         TQDateTime dt = TQDateTime::currentDateTime();
+         TQDateTime dt = TQDateTime::tqcurrentDateTime();
          TQMap<TQString,TQString> tags;
 
          KUser u (KUser::UseRealUserID);
@@ -192,9 +192,9 @@ bool KatePrinter::print (KateDocument *doc)
 
          tags["d"] = KGlobal::locale()->formatDateTime(dt, true, false);
          tags["D"] =  KGlobal::locale()->formatDateTime(dt, false, false);
-         tags["h"] =  KGlobal::locale()->formatTime(dt.time(), false);
-         tags["y"] =  KGlobal::locale()->formatDate(dt.date(), true);
-         tags["Y"] =  KGlobal::locale()->formatDate(dt.date(), false);
+         tags["h"] =  KGlobal::locale()->formatTime(TQT_TQTIME_OBJECT(dt.time()), false);
+         tags["y"] =  KGlobal::locale()->formatDate(TQT_TQDATE_OBJECT(dt.date()), true);
+         tags["Y"] =  KGlobal::locale()->formatDate(TQT_TQDATE_OBJECT(dt.date()), false);
          tags["f"] =  doc->url().fileName();
          tags["U"] =  doc->url().prettyURL();
          if ( selectionOnly )
@@ -505,7 +505,7 @@ bool KatePrinter::print (KateDocument *doc)
              // use color of dsNormal for the title string and the hline
              KateAttributeList _dsList;
              KateHlManager::self()->getDefaults ( renderer.config()->schema(), _dsList );
-             paint.setPen( _dsList.at(0)->textColor() );
+             paint.setPen( _dsList.tqat(0)->textColor() );
              int _marg = 0; // this could be available globally!??
              if ( useBox )
              {
