@@ -80,7 +80,7 @@
     This widget is designed to work with the KateStyleListView class exclusively.
     Added by anders, jan 23 2002.
 */
-class KateStyleListItem : public QListViewItem
+class KateStyleListItem : public TQListViewItem
 {
   public:
     KateStyleListItem( TQListViewItem *parent=0, const TQString & stylename=0,
@@ -141,7 +141,7 @@ class KateStyleListItem : public QListViewItem
     to use our own palette (that is set on the viewport rather than on the listview
     itself).
 */
-class KateStyleListCaption : public QListViewItem
+class KateStyleListCaption : public TQListViewItem
 {
   public:
     KateStyleListCaption( TQListView *parent, const TQString & name );
@@ -281,19 +281,19 @@ KateSchemaConfigColorTab::KateSchemaConfigColorTab( TQWidget *parent, const char
   b = new TQHBox (gbTextArea);
   b->setSpacing(KDialog::spacingHint());
   label = new TQLabel( i18n("Normal text:"), b);
-  label->setAlignment( AlignLeft|AlignVCenter);
+  label->tqsetAlignment( AlignLeft|AlignVCenter);
   m_back = new KColorButton(b);
 
   b = new TQHBox (gbTextArea);
   b->setSpacing(KDialog::spacingHint());
   label = new TQLabel( i18n("Selected text:"), b);
-  label->setAlignment( AlignLeft|AlignVCenter);
+  label->tqsetAlignment( AlignLeft|AlignVCenter);
   m_selected = new KColorButton(b);
 
   b = new TQHBox (gbTextArea);
   b->setSpacing(KDialog::spacingHint());
   label = new TQLabel( i18n("Current line:"), b);
-  label->setAlignment( AlignLeft|AlignVCenter);
+  label->tqsetAlignment( AlignLeft|AlignVCenter);
   m_current = new KColorButton(b);
 
   // Markers from kdelibs/interfaces/ktextinterface/markinterface.h
@@ -319,31 +319,31 @@ KateSchemaConfigColorTab::KateSchemaConfigColorTab( TQWidget *parent, const char
   b = new TQHBox (gbBorder);
   b->setSpacing(KDialog::spacingHint());
   label = new TQLabel( i18n("Left border background:"), b);
-  label->setAlignment( AlignLeft|AlignVCenter);
+  label->tqsetAlignment( AlignLeft|AlignVCenter);
   m_iconborder = new KColorButton(b);
 
   b = new TQHBox (gbBorder);
   b->setSpacing(KDialog::spacingHint());
   label = new TQLabel( i18n("Line numbers:"), b);
-  label->setAlignment( AlignLeft|AlignVCenter);
+  label->tqsetAlignment( AlignLeft|AlignVCenter);
   m_linenumber = new KColorButton(b);
 
   b = new TQHBox (gbBorder);
   b->setSpacing(KDialog::spacingHint());
   label = new TQLabel( i18n("Bracket highlight:"), b);
-  label->setAlignment( AlignLeft|AlignVCenter);
+  label->tqsetAlignment( AlignLeft|AlignVCenter);
   m_bracket = new KColorButton(b);
 
   b = new TQHBox (gbBorder);
   b->setSpacing(KDialog::spacingHint());
   label = new TQLabel( i18n("Word wrap markers:"), b);
-  label->setAlignment( AlignLeft|AlignVCenter);
+  label->tqsetAlignment( AlignLeft|AlignVCenter);
   m_wwmarker = new KColorButton(b);
 
   b = new TQHBox (gbBorder);
   b->setSpacing(KDialog::spacingHint());
   label = new TQLabel( i18n("Tab markers:"), b);
-  label->setAlignment( AlignLeft|AlignVCenter);
+  label->tqsetAlignment( AlignLeft|AlignVCenter);
   m_tmarker = new KColorButton(b);
 
   blay->addWidget(gbBorder);
@@ -643,14 +643,14 @@ void KateSchemaConfigFontColorTab::schemaChanged (uint schema)
   p.setColor( TQColorGroup::Highlight,
     KateFactory::self()->schemaManager()->schema(schema)->
       readColorEntry( "Color Selection", &_c ) );
-  _c = l->at(0)->textColor(); // not quite as much of an assumption ;)
+  _c = l->tqat(0)->textColor(); // not quite as much of an assumption ;)
   p.setColor( TQColorGroup::Text, _c );
   m_defaultStyles->viewport()->setPalette( p );
 
   // insert the default styles backwards to get them in the right order
   for ( int i = KateHlManager::self()->defaultStyles() - 1; i >= 0; i-- )
   {
-    new KateStyleListItem( m_defaultStyles, KateHlManager::self()->defaultStyleName(i, true), l->at( i ) );
+    new KateStyleListItem( m_defaultStyles, KateHlManager::self()->defaultStyleName(i, true), l->tqat( i ) );
   }
 }
 
@@ -770,7 +770,7 @@ void KateSchemaConfigHighlightTab::schemaChanged (uint schema)
   p.setColor( TQColorGroup::Highlight,
     KateFactory::self()->schemaManager()->schema(m_schema)->
       readColorEntry( "Color Selection", &_c ) );
-  _c = l->at(0)->textColor(); // not quite as much of an assumption ;)
+  _c = l->tqat(0)->textColor(); // not quite as much of an assumption ;)
   p.setColor( TQColorGroup::Text, _c );
   m_styles->viewport()->setPalette( p );
 
@@ -795,9 +795,9 @@ void KateSchemaConfigHighlightTab::schemaChanged (uint schema)
         parent->setOpen(true);
         prefixes.insert( prefix, parent );
       }
-      new KateStyleListItem( parent, name, l->at(itemData->defStyleNum), itemData );
+      new KateStyleListItem( parent, name, l->tqat(itemData->defStyleNum), itemData );
     } else {
-      new KateStyleListItem( m_styles, itemData->name, l->at(itemData->defStyleNum), itemData );
+      new KateStyleListItem( m_styles, itemData->name, l->tqat(itemData->defStyleNum), itemData );
     }
   }
 }
@@ -1088,9 +1088,9 @@ void KateStyleListView::showPopupMenu( KateStyleListItem *i, const TQPoint &glob
   TQPixmap scl(16,16);
   scl.fill( i->style()->selectedTextColor() );
   TQPixmap bgcl(16,16);
-  bgcl.fill( i->style()->itemSet(KateAttribute::BGColor) ? i->style()->bgColor() : viewport()->colorGroup().base() );
+  bgcl.fill( i->style()->itemSet(KateAttribute::BGColor) ? i->style()->bgColor() : viewport()->tqcolorGroup().base() );
   TQPixmap sbgcl(16,16);
-  sbgcl.fill( i->style()->itemSet(KateAttribute::SelectedBGColor) ? i->style()->selectedBGColor() : viewport()->colorGroup().base() );
+  sbgcl.fill( i->style()->itemSet(KateAttribute::SelectedBGColor) ? i->style()->selectedBGColor() : viewport()->tqcolorGroup().base() );
 
   if ( showtitle )
     m.insertTitle( i->contextName(), KateStyleListItem::ContextName );
@@ -1156,7 +1156,7 @@ void KateStyleListView::slotMousePressed(int btn, TQListViewItem* i, const TQPoi
   if ( dynamic_cast<KateStyleListItem*>(i) ) {
      if ( btn == Qt::LeftButton && c > 0 ) {
       // map pos to item/column and call KateStyleListItem::activate(col, pos)
-      ((KateStyleListItem*)i)->activate( c, viewport()->mapFromGlobal( pos ) - TQPoint( 0, itemRect(i).top() ) );
+      ((KateStyleListItem*)i)->activate( c, viewport()->mapFromGlobal( pos ) - TQPoint( 0, tqitemRect(i).top() ) );
     }
   }
 }
@@ -1357,7 +1357,7 @@ void KateStyleListItem::toggleDefStyle()
     delete is;
     is = new KateAttribute( *ds );
     updateStyle();
-    repaint();
+    tqrepaint();
   }
 }
 
@@ -1441,7 +1441,7 @@ void KateStyleListItem::setColor( int column )
     break;
   }
 
-  repaint();
+  tqrepaint();
 }
 
 void KateStyleListItem::unsetColor( int c )
@@ -1465,7 +1465,7 @@ void KateStyleListItem::paintCell( TQPainter *p, const TQColorGroup& /*cg*/, int
   Q_ASSERT( lv ); //###
 
   // use a private color group and set the text/highlighted text colors
-  TQColorGroup mcg = lv->viewport()->colorGroup();
+  TQColorGroup mcg = lv->viewport()->tqcolorGroup();
 
   if ( col ) // col 0 is drawn by the superclass method
     p->fillRect( 0, 0, width, height(), TQBrush( mcg.base() ) );
@@ -1602,7 +1602,7 @@ void KateStyleListCaption::paintCell( TQPainter *p, const TQColorGroup& /*cg*/,
   Q_ASSERT( lv ); //###
 
   // use the same colorgroup as the other items in the viewport
-  TQColorGroup mcg = lv->viewport()->colorGroup();
+  TQColorGroup mcg = lv->viewport()->tqcolorGroup();
 
   TQListViewItem::paintCell( p, mcg, col, width, align );
 }
