@@ -33,7 +33,7 @@ ConfigBox::ConfigBox ( TQWidget *parent, const char *name)
   glay->addWidget(disp, 1, 2);
   disp->display(1);
 
-  speed = new TQSlider(1, 10, 1, 1, TQSlider::Horizontal, page);
+  speed = new TQSlider(1, 10, 1, 1, Qt::Horizontal, page);
   glay->addMultiCellWidget(speed, 2, 2, 2, 3);
 
   connect(speed, TQT_SIGNAL(valueChanged(int)), disp, TQT_SLOT(display(int)));
