@@ -21,11 +21,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -115,7 +115,7 @@ void CatalogManager::init()
     _foundFilesList.clear();
     _toBeSearched.clear();
     _timerFind = new TQTimer( this );
-    connect(_timerFind, TQT_SIGNAL( timeout() ), this, TQT_SLOT(findNextFile()) );
+    connect(_timerFind, TQT_SIGNAL( timeout() ), TQT_TQOBJECT(this), TQT_SLOT(findNextFile()) );
     _searchStopped = false;
 
    _prefDialog=0;
@@ -126,26 +126,26 @@ void CatalogManager::init()
    
    if ( _project == NULL )
    {
-	KMessageBox::error( this, i18n("Cannot open project file\n%1").arg(_configFile)
+	KMessageBox::error( this, i18n("Cannot open project file\n%1").tqarg(_configFile)
 	    , i18n("Project File Error"));
 
 	_project = KBabel::ProjectManager::open(KBabel::ProjectManager::defaultProjectName());
    }
    
    connect( _project, TQT_SIGNAL (signalCatManSettingsChanged())
-	, this, TQT_SLOT (updateSettings()));
+	, TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
 
    TQWidget *view = new TQWidget(this);
-   TQVBoxLayout* layout= new TQVBoxLayout(view);
-   layout->setMargin(0);
-   layout->setSpacing(KDialog::spacingHint());
+   TQVBoxLayout* tqlayout= new TQVBoxLayout(view);
+   tqlayout->setMargin(0);
+   tqlayout->setSpacing(KDialog::spacingHint());
 
    _catalogManager=new CatalogManagerView(_project, view,"catalog manager");
-   layout->addWidget(_catalogManager);
-   layout->setStretchFactor(_catalogManager,1);
+   tqlayout->addWidget(_catalogManager);
+   tqlayout->setStretchFactor(_catalogManager,1);
 
    connect(this,TQT_SIGNAL(settingsChanged(KBabel::CatManSettings))
-            ,_catalogManager,TQT_SLOT(setSettings(KBabel::CatManSettings)));
+            ,TQT_TQOBJECT(_catalogManager),TQT_SLOT(setSettings(KBabel::CatManSettings)));
    connect(_catalogManager,TQT_SIGNAL(openFile(TQString,TQString))
            ,this,TQT_SLOT(openFile(TQString,TQString)));
    connect(_catalogManager,TQT_SIGNAL(openFileInNewWindow(TQString,TQString))
@@ -157,12 +157,12 @@ void CatalogManager::init()
    connect(_catalogManager,TQT_SIGNAL(gotoFileEntry(TQString,TQString,int))
            ,this,TQT_SLOT(openFile(TQString,TQString,int)));
    connect(_catalogManager, TQT_SIGNAL(selectedChanged(uint)),
-           this, TQT_SLOT(selectedChanged(uint)));
+           TQT_TQOBJECT(this), TQT_SLOT(selectedChanged(uint)));
 
    KWin::setIcons(winId(),BarIcon("catalogmanager",32)
            ,SmallIcon("catalogmanager"));
 
-   TQHBoxLayout* hBoxL = new TQHBoxLayout(layout);
+   TQHBoxLayout* hBoxL = new TQHBoxLayout(tqlayout);
    _progressLabel = new TQLabel(view);
    hBoxL->addWidget(_progressLabel);
    _progressBar=new KProgress(view);
@@ -173,19 +173,19 @@ void CatalogManager::init()
    _progressBar->hide();
 
    connect(_catalogManager,TQT_SIGNAL(prepareProgressBar(TQString,int))
-           , this, TQT_SLOT(prepareProgressBar(TQString,int)));
+           , TQT_TQOBJECT(this), TQT_SLOT(prepareProgressBar(TQString,int)));
    connect(_catalogManager,TQT_SIGNAL(clearProgressBar())
-           , this, TQT_SLOT(clearProgressBar()));
+           , TQT_TQOBJECT(this), TQT_SLOT(clearProgressBar()));
    connect(_catalogManager,TQT_SIGNAL(progress(int))
            , _progressBar, TQT_SLOT(setProgress(int)));
 //   connect(_catalogManager, TQT_SIGNAL(signalBuildTree(bool))
-//	   , this, TQT_SLOT(enableMenuForFiles(bool)));
+//	   , TQT_TQOBJECT(this), TQT_SLOT(enableMenuForFiles(bool)));
    connect(_catalogManager, TQT_SIGNAL(signalBuildTree(bool))
-	   , this, TQT_SLOT(enableActions(bool)));
+	   , TQT_TQOBJECT(this), TQT_SLOT(enableActions(bool)));
    connect(this, TQT_SIGNAL(searchStopped())
-	   , _catalogManager, TQT_SLOT(stopSearch()));
+	   , TQT_TQOBJECT(_catalogManager), TQT_SLOT(stopSearch()));
    connect(_catalogManager, TQT_SIGNAL(prepareFindProgressBar(int))
-	   , this, TQT_SLOT(prepareStatusProgressBar(int)));
+	   , TQT_TQOBJECT(this), TQT_SLOT(prepareStatusProgressBar(int)));
 
    setCentralWidget(view);
    resize( 600,300);
@@ -219,60 +219,60 @@ void CatalogManager::setupActions()
     KAction *action;
 
     // the file menu
-    action = new KAction( i18n("&Open"), CTRL+Key_O, _catalogManager,
+    action = new KAction( i18n("&Open"), CTRL+Key_O, TQT_TQOBJECT(_catalogManager),
                           TQT_SLOT(slotOpenFile()),actionCollection(), "open");
     action->setEnabled(false);
-    action = new KAction(i18n("&Open Template"),Key_Space,_catalogManager,
+    action = new KAction(i18n("&Open Template"),Key_Space,TQT_TQOBJECT(_catalogManager),
                          TQT_SLOT(slotOpenTemplate()),actionCollection(), "open_template");
     action->setEnabled(false);
-    action = new KAction(i18n("Open in &New Window"),CTRL+SHIFT+Key_O,_catalogManager,
+    action = new KAction(i18n("Open in &New Window"),CTRL+SHIFT+Key_O,TQT_TQOBJECT(_catalogManager),
                          TQT_SLOT(slotOpenFileInNewWindow()),actionCollection(), "open_new_window");
     action->setEnabled(false);
 
-    action = KStdAction::quit(kapp, TQT_SLOT (closeAllWindows()), actionCollection());
+    action = KStdAction::quit(TQT_TQOBJECT(kapp), TQT_SLOT (closeAllWindows()), actionCollection());
 
     actionMap["open_template"] = NEEDS_POT;
 
     // the edit menu
-    action = new KAction( i18n("Fi&nd in Files..."), CTRL+Key_F, this,
+    action = new KAction( i18n("Fi&nd in Files..."), CTRL+Key_F, TQT_TQOBJECT(this),
                           TQT_SLOT(find()), actionCollection(), "find_in_files");
     action->setEnabled(false);
-    action = new KAction( i18n("Re&place in Files..."), CTRL+Key_R, this,
+    action = new KAction( i18n("Re&place in Files..."), CTRL+Key_R, TQT_TQOBJECT(this),
                           TQT_SLOT(replace()), actionCollection(), "replace_in_files");
     action->setEnabled(false);
-    action = new KAction( i18n("&Stop Searching"), "stop", Key_Escape, this,
+    action = new KAction( i18n("&Stop Searching"), "stop", Key_Escape, TQT_TQOBJECT(this),
                           TQT_SLOT(stopSearching()), actionCollection(), "stop_search");
     action->setEnabled(false);
-    action = new KAction( i18n("&Reload"), "reload", KStdAccel::reload(), _catalogManager,
+    action = new KAction( i18n("&Reload"), "reload", KStdAccel::reload(), TQT_TQOBJECT(_catalogManager),
                           TQT_SLOT(updateCurrent()), actionCollection(), "reload");
     action->setEnabled(false);
 
     // the marking menu
-    action = new KAction( i18n("&Toggle Marking"), CTRL+Key_M, _catalogManager,
+    action = new KAction( i18n("&Toggle Marking"), CTRL+Key_M, TQT_TQOBJECT(_catalogManager),
                           TQT_SLOT(toggleMark()), actionCollection(), "toggle_marking");
     action->setEnabled(false);
-    action = new KAction( i18n("Remove Marking"), 0, _catalogManager,
+    action = new KAction( i18n("Remove Marking"), 0, TQT_TQOBJECT(_catalogManager),
                           TQT_SLOT(slotClearMarksInDir()), actionCollection(), "remove_marking");
     action->setEnabled(false);
-    action = new KAction( i18n("Toggle All Markings"), 0, _catalogManager,
+    action = new KAction( i18n("Toggle All Markings"), 0, TQT_TQOBJECT(_catalogManager),
                           TQT_SLOT(toggleAllMarks()), actionCollection(), "toggle_all_marking");
     action->setEnabled(false);
-    action = new KAction( i18n("Remove All Markings"), 0, _catalogManager,
+    action = new KAction( i18n("Remove All Markings"), 0, TQT_TQOBJECT(_catalogManager),
                           TQT_SLOT(clearAllMarks()), actionCollection(), "remove_all_marking");
     action->setEnabled(false);
-    action = new KAction( i18n("Mark Modified Files"), 0, _catalogManager,
+    action = new KAction( i18n("Mark Modified Files"), 0, TQT_TQOBJECT(_catalogManager),
                           TQT_SLOT(markModifiedFiles()), actionCollection(), "mark_modified_files");
     // fixme to enabling this when loading is done using updateFinished() signal
     action->setEnabled(true);
-    action = new KAction( i18n("&Load Markings..."), 0, _catalogManager,
+    action = new KAction( i18n("&Load Markings..."), 0, TQT_TQOBJECT(_catalogManager),
                           TQT_SLOT(loadMarks()), actionCollection(), "load_marking");
     action->setEnabled(false);
-    action = new KAction( i18n("&Save Markings..."), 0, _catalogManager,
+    action = new KAction( i18n("&Save Markings..."), 0, TQT_TQOBJECT(_catalogManager),
                           TQT_SLOT(saveMarks()), actionCollection(), "save_marking");
     action->setEnabled(false);
-    (void)new KAction(i18n("&Mark Files..."), 0, _catalogManager,
+    (void)new KAction(i18n("&Mark Files..."), 0, TQT_TQOBJECT(_catalogManager),
                       TQT_SLOT(slotMarkPattern()), actionCollection(), "mark_pattern");
-    (void)new KAction(i18n("&Unmark Files..."), 0, _catalogManager,
+    (void)new KAction(i18n("&Unmark Files..."), 0, TQT_TQOBJECT(_catalogManager),
                       TQT_SLOT(slotUnmarkPattern()), actionCollection(), "unmark_pattern");
 
     actionMap["remove_marking"]     = NEEDS_MARK;
@@ -282,102 +282,102 @@ void CatalogManager::setupActions()
 
     // go menu
     action = new KAction(i18n("Nex&t Untranslated"), "nextuntranslated", ALT+Key_Next,
-                         _catalogManager, TQT_SLOT(gotoNextUntranslated()),actionCollection(), "go_next_untrans");
+                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoNextUntranslated()),actionCollection(), "go_next_untrans");
     action->setEnabled(false);
     action = new KAction(i18n("Prev&ious Untranslated"), "prevuntranslated", ALT+Key_Prior,
-                         _catalogManager, TQT_SLOT(gotoPreviousUntranslated()),actionCollection(), "go_prev_untrans");
+                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoPreviousUntranslated()),actionCollection(), "go_prev_untrans");
     action->setEnabled(false);
     action = new KAction(i18n("Ne&xt Fuzzy"), "nextfuzzy", CTRL+Key_Next,
-                         _catalogManager, TQT_SLOT(gotoNextFuzzy()),actionCollection(), "go_next_fuzzy");
+                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoNextFuzzy()),actionCollection(), "go_next_fuzzy");
     action->setEnabled(false);
     action = new KAction(i18n("Pre&vious Fuzzy"), "prevfuzzy", CTRL+Key_Prior,
-                         _catalogManager, TQT_SLOT(gotoPreviousFuzzy()),actionCollection(), "go_prev_fuzzy");
+                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoPreviousFuzzy()),actionCollection(), "go_prev_fuzzy");
     action->setEnabled(false);
     action = new KAction(i18n("N&ext Fuzzy or Untranslated"), "nextfuzzyuntrans", CTRL+SHIFT+Key_Next,
-                         _catalogManager, TQT_SLOT(gotoNextFuzzyOrUntranslated()),actionCollection(), "go_next_fuzzyUntr");
+                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoNextFuzzyOrUntranslated()),actionCollection(), "go_next_fuzzyUntr");
     action->setEnabled(false);
     action = new KAction(i18n("P&revious Fuzzy or Untranslated"), "prevfuzzyuntrans", CTRL+SHIFT+Key_Prior,
-                         _catalogManager, TQT_SLOT(gotoPreviousFuzzyOrUntranslated()),actionCollection(), "go_prev_fuzzyUntr");
+                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoPreviousFuzzyOrUntranslated()),actionCollection(), "go_prev_fuzzyUntr");
     action->setEnabled(false);
 
     action = new KAction(i18n("Next Err&or"), "nexterror", ALT+SHIFT+Key_Next,
-                         _catalogManager, TQT_SLOT(gotoNextError()),actionCollection(), "go_next_error");
+                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoNextError()),actionCollection(), "go_next_error");
     action->setEnabled(false);
     action = new KAction(i18n("Previo&us Error"), "preverror", ALT+SHIFT+Key_Prior,
-                         _catalogManager, TQT_SLOT(gotoPreviousError()),actionCollection(), "go_prev_error");
+                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoPreviousError()),actionCollection(), "go_prev_error");
     action->setEnabled(false);
     action = new KAction(i18n("Next Te&mplate Only"), "nexttemplate", CTRL+Key_Down,
-                         _catalogManager, TQT_SLOT(gotoNextTemplate()),actionCollection(), "go_next_template");
+                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoNextTemplate()),actionCollection(), "go_next_template");
     action->setEnabled(false);
     action = new KAction(i18n("Previous Temp&late Only"), "prevtemplate", CTRL+Key_Up,
-                         _catalogManager, TQT_SLOT(gotoPreviousTemplate()),actionCollection(), "go_prev_template");
+                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoPreviousTemplate()),actionCollection(), "go_prev_template");
     action->setEnabled(false);
     action = new KAction(i18n("Next Tran&slation Exists"), "nextpo", ALT+Key_Down,
-                         _catalogManager, TQT_SLOT(gotoNextPo()),actionCollection(), "go_next_po");
+                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoNextPo()),actionCollection(), "go_next_po");
     action->setEnabled(false);
     action = new KAction(i18n("Previous Transl&ation Exists"), "prevpo", ALT+Key_Up,
-                         _catalogManager, TQT_SLOT(gotoPreviousPo()),actionCollection(), "go_prev_po");
+                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoPreviousPo()),actionCollection(), "go_prev_po");
     action->setEnabled(false);
 
     action = new KAction(i18n("Previous Marke&d"), "prevmarked", SHIFT+Key_Up,
-                         _catalogManager, TQT_SLOT(gotoPreviousMarked()),actionCollection(), "go_prev_marked");
+                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoPreviousMarked()),actionCollection(), "go_prev_marked");
     action->setEnabled(false);
     action = new KAction(i18n("Next &Marked"), "nextmarked", SHIFT+Key_Down,
-                         _catalogManager, TQT_SLOT(gotoNextMarked()),actionCollection(), "go_next_marked");
+                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(gotoNextMarked()),actionCollection(), "go_next_marked");
     action->setEnabled(false);
 
     // project menu
     // the project menu
    action = new KAction(i18n("&New..."), "filenew"
-           , this, TQT_SLOT(projectNew()),actionCollection()
+           , TQT_TQOBJECT(this), TQT_SLOT(projectNew()),actionCollection()
            ,"project_new");
 
    action = new KAction(i18n("&Open..."), "fileopen"
-           , this, TQT_SLOT(projectOpen()),actionCollection()
+           , TQT_TQOBJECT(this), TQT_SLOT(projectOpen()),actionCollection()
            ,"project_open");
 
    action = new KAction(i18n("C&lose"), "fileclose"
-           , this, TQT_SLOT(projectClose()),actionCollection()
+           , TQT_TQOBJECT(this), TQT_SLOT(projectClose()),actionCollection()
            ,"project_close");
 
    action->setEnabled (_project->filename() != KBabel::ProjectManager::defaultProjectName() );
 
    action = new KAction(i18n("&Configure..."), "configure"
-           , this, TQT_SLOT(projectConfigure()),actionCollection()
+           , TQT_TQOBJECT(this), TQT_SLOT(projectConfigure()),actionCollection()
            ,"project_settings");
 
     // tools menu
     action = new KAction( i18n("&Statistics"), "statistics",  CTRL+Key_S,
-                          _catalogManager, TQT_SLOT(statistics()), actionCollection(), "statistics");
+                          TQT_TQOBJECT(_catalogManager), TQT_SLOT(statistics()), actionCollection(), "statistics");
     action->setEnabled(false);
     action = new KAction( i18n("S&tatistics in Marked"), "statistics",  CTRL+ALT+Key_S,
-                          _catalogManager, TQT_SLOT(markedStatistics()), actionCollection(), "statistics_marked");
+                          TQT_TQOBJECT(_catalogManager), TQT_SLOT(markedStatistics()), actionCollection(), "statistics_marked");
     action->setEnabled(false);
     action = new KAction( i18n("Check S&yntax"), "syntax", CTRL+Key_Y,
-                          _catalogManager, TQT_SLOT(checkSyntax()), actionCollection(), "syntax");
+                          TQT_TQOBJECT(_catalogManager), TQT_SLOT(checkSyntax()), actionCollection(), "syntax");
     action->setEnabled(false);
     action = new KAction( i18n("S&pell Check"), "spellcheck",  CTRL+Key_I,
-                          this, TQT_SLOT(spellcheck()), actionCollection(), "spellcheck");
+                          TQT_TQOBJECT(this), TQT_SLOT(spellcheck()), actionCollection(), "spellcheck");
     action->setEnabled(false);
     action = new KAction( i18n("Spell Check in &Marked"), "spellcheck", CTRL+ALT+Key_I,
-                          this, TQT_SLOT(markedSpellcheck()), actionCollection(), "spellcheck_marked");
+                          TQT_TQOBJECT(this), TQT_SLOT(markedSpellcheck()), actionCollection(), "spellcheck_marked");
     action->setEnabled(false);
     action = new KAction( i18n("&Rough Translation"),  CTRL+Key_T,
-                          _catalogManager, TQT_SLOT(roughTranslation()), actionCollection(), "rough_translation");
+                          TQT_TQOBJECT(_catalogManager), TQT_SLOT(roughTranslation()), actionCollection(), "rough_translation");
     action->setEnabled(false);
     action = new KAction( i18n("Rough Translation in M&arked"), CTRL+ALT+Key_T,
-                          _catalogManager, TQT_SLOT(markedRoughTranslation()), actionCollection(), "rough_translation_marked");
+                          TQT_TQOBJECT(_catalogManager), TQT_SLOT(markedRoughTranslation()), actionCollection(), "rough_translation_marked");
     action->setEnabled(false);
     action = new KAction( i18n("Mai&l"), "mail_send", CTRL+Key_A,
-                          _catalogManager, TQT_SLOT(mailFiles()), actionCollection(), "mail_file");
+                          TQT_TQOBJECT(_catalogManager), TQT_SLOT(mailFiles()), actionCollection(), "mail_file");
     action->setEnabled(false);
     action = new KAction( i18n("Mail Mar&ked"), "mail_send", CTRL+ALT+Key_A,
-                          _catalogManager, TQT_SLOT(mailMarkedFiles()), actionCollection(),	"mail_file_marked");
+                          TQT_TQOBJECT(_catalogManager), TQT_SLOT(mailMarkedFiles()), actionCollection(),	"mail_file_marked");
     action->setEnabled(false);
 
     action = new KAction( i18n("&Pack"), "tar", CTRL+Key_B,
-                         _catalogManager, TQT_SLOT(packageFiles()), actionCollection(), "package_file");
-    action = new KAction( i18n("Pack &Marked"), "tar", CTRL+ALT+Key_B, _catalogManager, TQT_SLOT(packageMarkedFiles()), actionCollection(), "package_file_marked");
+                         TQT_TQOBJECT(_catalogManager), TQT_SLOT(packageFiles()), actionCollection(), "package_file");
+    action = new KAction( i18n("Pack &Marked"), "tar", CTRL+ALT+Key_B, TQT_TQOBJECT(_catalogManager), TQT_SLOT(packageMarkedFiles()), actionCollection(), "package_file_marked");
     action->setEnabled(false);
 
     actionMap["statistics_marked"]        = NEEDS_DIR | NEEDS_MARK;
@@ -393,7 +393,7 @@ void CatalogManager::setupActions()
     TQValueList<KDataToolInfo> tools = ToolAction::validationTools();
 
     TQPtrList<KAction> actions = ToolAction::dataToolActionList(
-	tools, _catalogManager, TQT_SLOT(validateUsingTool( const KDataToolInfo &, const TQString& ))
+	tools, TQT_TQOBJECT(_catalogManager), TQT_SLOT(validateUsingTool( const KDataToolInfo &, const TQString& ))
 	,"validate", false, actionCollection() );
 
     KActionMenu* m_menu = new KActionMenu(i18n("&Validation"), actionCollection(),
@@ -407,7 +407,7 @@ void CatalogManager::setupActions()
     }
 
     actions = ToolAction::dataToolActionList(
-	tools, _catalogManager, TQT_SLOT(validateMarkedUsingTool( const KDataToolInfo &, const TQString& ))
+	tools, TQT_TQOBJECT(_catalogManager), TQT_SLOT(validateMarkedUsingTool( const KDataToolInfo &, const TQString& ))
 	,"validate", false, actionCollection(), "marked_" );
     m_menu = new KActionMenu(i18n("V&alidation Marked"), actionCollection(),
           "dynamic_validation_marked");
@@ -422,19 +422,19 @@ void CatalogManager::setupActions()
 
     // CVS submenu
     // Actions for PO files
-    (void)new KAction( i18n( "Update" ), "down", 0, _catalogManager,
+    (void)new KAction( i18n( "Update" ), "down", 0, TQT_TQOBJECT(_catalogManager),
       TQT_SLOT( cvsUpdate( ) ), actionCollection( ), "cvs_update" );
-    (void)new KAction( i18n( "Update Marked" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Update Marked" ), 0, TQT_TQOBJECT(_catalogManager),
       TQT_SLOT( cvsUpdateMarked( ) ), actionCollection( ), "cvs_update_marked" );
-    (void)new KAction( i18n( "Commit" ), "up", 0, _catalogManager,
+    (void)new KAction( i18n( "Commit" ), "up", 0, TQT_TQOBJECT(_catalogManager),
       TQT_SLOT( cvsCommit( ) ), actionCollection( ), "cvs_commit" );
-    (void)new KAction( i18n( "Commit Marked" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Commit Marked" ), 0, TQT_TQOBJECT(_catalogManager),
       TQT_SLOT( cvsCommitMarked( ) ), actionCollection( ), "cvs_commit_marked" );
-    (void)new KAction( i18n( "Status" ), 0, _catalogManager,
-      TQT_SLOT( cvsStatus( ) ), actionCollection( ), "cvs_status" );
-    (void)new KAction( i18n( "Status for Marked" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Status" ), 0, TQT_TQOBJECT(_catalogManager),
+      TQT_SLOT( cvstqStatus( ) ), actionCollection( ), "cvs_status" );
+    (void)new KAction( i18n( "Status for Marked" ), 0, TQT_TQOBJECT(_catalogManager),
       TQT_SLOT( cvsStatusMarked( ) ), actionCollection( ), "cvs_status_marked" );
-    (void)new KAction( i18n( "Show Diff" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Show Diff" ), 0, TQT_TQOBJECT(_catalogManager),
       TQT_SLOT( cvsDiff( ) ), actionCollection( ), "cvs_diff" );
 
     // CVS
@@ -448,27 +448,27 @@ void CatalogManager::setupActions()
 
     // SVN submenu
     // Actions for PO files
-    (void)new KAction( i18n( "Update" ), "down", 0, _catalogManager,
+    (void)new KAction( i18n( "Update" ), "down", 0, TQT_TQOBJECT(_catalogManager),
     TQT_SLOT( svnUpdate( ) ), actionCollection( ), "svn_update" );
-    (void)new KAction( i18n( "Update Marked" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Update Marked" ), 0, TQT_TQOBJECT(_catalogManager),
     TQT_SLOT( svnUpdateMarked( ) ), actionCollection( ), "svn_update_marked" );
-    (void)new KAction( i18n( "Commit" ), "up", 0, _catalogManager,
+    (void)new KAction( i18n( "Commit" ), "up", 0, TQT_TQOBJECT(_catalogManager),
     TQT_SLOT( svnCommit( ) ), actionCollection( ), "svn_commit" );
-    (void)new KAction( i18n( "Commit Marked" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Commit Marked" ), 0, TQT_TQOBJECT(_catalogManager),
     TQT_SLOT( svnCommitMarked( ) ), actionCollection( ), "svn_commit_marked" );
-    (void)new KAction( i18n( "Status (Local)" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Status (Local)" ), 0, TQT_TQOBJECT(_catalogManager),
     TQT_SLOT( svnStatusLocal() ), actionCollection( ), "svn_status_local" );
-    (void)new KAction( i18n( "Status (Local) for Marked" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Status (Local) for Marked" ), 0, TQT_TQOBJECT(_catalogManager),
     TQT_SLOT( svnStatusLocalMarked() ), actionCollection( ), "svn_status_local_marked" );
-    (void)new KAction( i18n( "Status (Remote)" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Status (Remote)" ), 0, TQT_TQOBJECT(_catalogManager),
     TQT_SLOT( svnStatusRemote() ), actionCollection( ), "svn_status_remote" );
-    (void)new KAction( i18n( "Status (Remote) for Marked" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Status (Remote) for Marked" ), 0, TQT_TQOBJECT(_catalogManager),
     TQT_SLOT( svnStatusRemoteMarked() ), actionCollection( ), "svn_status_remote_marked" );
-    (void)new KAction( i18n( "Show Diff" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Show Diff" ), 0, TQT_TQOBJECT(_catalogManager),
     TQT_SLOT( svnDiff( ) ), actionCollection( ), "svn_diff" );
-    (void)new KAction( i18n( "Show Information" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Show Information" ), 0, TQT_TQOBJECT(_catalogManager),
     TQT_SLOT( svnInfo() ), actionCollection( ), "svn_info" );
-    (void)new KAction( i18n( "Show Information for Marked" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Show Information for Marked" ), 0, TQT_TQOBJECT(_catalogManager),
     TQT_SLOT( svnInfoMarked() ), actionCollection( ), "svn_info_marked" );
 
     // SVN
@@ -485,13 +485,13 @@ void CatalogManager::setupActions()
     actionMap["svn_info_marked"]   = NEEDS_PO | NEEDS_PO_SVN | NEEDS_MARK;
 
     // CVS Actions for POT files
-    (void)new KAction( i18n( "Update Templates" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Update Templates" ), 0, TQT_TQOBJECT(_catalogManager),
       TQT_SLOT( cvsUpdateTemplate( ) ), actionCollection( ), "cvs_update_template" );
-    (void)new KAction( i18n( "Update Marked Templates" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Update Marked Templates" ), 0, TQT_TQOBJECT(_catalogManager),
       TQT_SLOT( cvsUpdateMarkedTemplate( ) ), actionCollection( ), "cvs_update_marked_template" );
-    (void)new KAction( i18n( "Commit Templates" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Commit Templates" ), 0, TQT_TQOBJECT(_catalogManager),
       TQT_SLOT( cvsCommitTemplate( ) ), actionCollection( ), "cvs_commit_template" );
-    (void)new KAction( i18n( "Commit Marked Templates" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Commit Marked Templates" ), 0, TQT_TQOBJECT(_catalogManager),
       TQT_SLOT( cvsCommitMarkedTemplate( ) ), actionCollection( ), "cvs_commit_marked_template" );
 
     actionMap["cvs_update_template"]        = NEEDS_POT | NEEDS_POT_CVS;
@@ -500,13 +500,13 @@ void CatalogManager::setupActions()
     actionMap["cvs_commit_marked_template"] = NEEDS_POT | NEEDS_POT_CVS | NEEDS_MARK;
 
     // SVN Actions for POT files
-    (void)new KAction( i18n( "Update Templates" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Update Templates" ), 0, TQT_TQOBJECT(_catalogManager),
     TQT_SLOT( svnUpdateTemplate( ) ), actionCollection( ), "svn_update_template" );
-    (void)new KAction( i18n( "Update Marked Templates" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Update Marked Templates" ), 0, TQT_TQOBJECT(_catalogManager),
     TQT_SLOT( svnUpdateMarkedTemplate( ) ), actionCollection( ), "svn_update_marked_template" );
-    (void)new KAction( i18n( "Commit Templates" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Commit Templates" ), 0, TQT_TQOBJECT(_catalogManager),
     TQT_SLOT( svnCommitTemplate( ) ), actionCollection( ), "svn_commit_template" );
-    (void)new KAction( i18n( "Commit Marked Templates" ), 0, _catalogManager,
+    (void)new KAction( i18n( "Commit Marked Templates" ), 0, TQT_TQOBJECT(_catalogManager),
     TQT_SLOT( svnCommitMarkedTemplate( ) ), actionCollection( ), "svn_commit_marked_template" );
 
     actionMap["svn_update_template"]        = NEEDS_POT | NEEDS_POT_SVN;
@@ -530,7 +530,7 @@ void CatalogManager::setupActions()
                                actionCollection(), "file_commands");
     _catalogManager->setFileCommandsMenu( actionMenu->popupMenu());
 
-    action = new KAction(i18n("&Delete"),Key_Delete,_catalogManager,TQT_SLOT(slotDeleteFile()),actionCollection(), "delete");
+    action = new KAction(i18n("&Delete"),Key_Delete,TQT_TQOBJECT(_catalogManager),TQT_SLOT(slotDeleteFile()),actionCollection(), "delete");
     action->setEnabled(false);
 
 #if KDE_IS_VERSION( 3, 2, 90 )
@@ -552,7 +552,7 @@ void CatalogManager::setupStatusBar()
     _statusProgressBar->hide();
 
     statusBar()->addWidget(progressBox,1);
-    statusBar()->setMinimumHeight(_statusProgressBar->sizeHint().height());
+    statusBar()->setMinimumHeight(_statusProgressBar->tqsizeHint().height());
 
     TQWhatsThis::add(statusBar(),
 	i18n("<qt><p><b>Statusbar</b></p>\n"
@@ -912,7 +912,7 @@ void CatalogManager::clearStatusProgressBar()
 
 void CatalogManager::setNumberOfFound(int toBeSent, int total)
 {
-    _foundLabel->setText(i18n("Found: %1/%2").arg(toBeSent).arg(total));
+    _foundLabel->setText(i18n("Found: %1/%2").tqarg(toBeSent).tqarg(total));
 }
 
 void CatalogManager::decreaseNumberOfFound()
@@ -1189,10 +1189,10 @@ void CatalogManager::projectNew()
     if( p )
     {
 	disconnect( _project, TQT_SIGNAL (signalCatManSettingsChanged())
-	    , this, TQT_SLOT (updateSettings()));
+	    , TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
         _project = p;
 	connect( _project, TQT_SIGNAL (signalCatManSettingsChanged())
-	    , this, TQT_SLOT (updateSettings()));
+	    , TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
 
 	_configFile = _project->filename();
         restoreSettings();
@@ -1209,7 +1209,7 @@ void CatalogManager::projectOpen()
     {
         oldproject = TQString();
     }
-    const TQString file = KFileDialog::getOpenFileName(oldproject, TQString::null, this);
+    const TQString file = KFileDialog::getOpenFileName(oldproject, TQString(), this);
     if (file.isEmpty())
     {
         return;
@@ -1218,10 +1218,10 @@ void CatalogManager::projectOpen()
     if( p )
     {
 	disconnect( _project, TQT_SIGNAL (signalCatManSettingsChanged())
-	    , this, TQT_SLOT (updateSettings()));
+	    , TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
         _project = p;
 	connect( _project, TQT_SIGNAL (signalCatManSettingsChanged())
-	    , this, TQT_SLOT (updateSettings()));
+	    , TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
 
 	_configFile = p->filename();
         restoreSettings();
@@ -1232,17 +1232,17 @@ void CatalogManager::projectOpen()
     }
     else
     {
-	KMessageBox::error (this, i18n("Cannot open project file %1").arg(file));
+	KMessageBox::error (this, i18n("Cannot open project file %1").tqarg(file));
     }
 }
 
 void CatalogManager::projectClose()
 {
     disconnect( _project, TQT_SIGNAL (signalCatManSettingsChanged())
-	    , this, TQT_SLOT (updateSettings()));
+	    , TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
     _project = KBabel::ProjectManager::open(KBabel::ProjectManager::defaultProjectName());
     connect( _project, TQT_SIGNAL (signalCatManSettingsChanged())
-	    , this, TQT_SLOT (updateSettings()));
+	    , TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
     _configFile = _project->filename();
     restoreSettings();
     updateSettings();
@@ -1263,7 +1263,7 @@ void CatalogManager::projectConfigure()
     KBabel::ProjectDialog* _projectDialog = new ProjectDialog(_project);
 
     connect (_projectDialog, TQT_SIGNAL (settingsChanged())
-	, this, TQT_SLOT (updateSettings()));
+	, TQT_TQOBJECT(this), TQT_SLOT (updateSettings()));
 
     // settings are updated via signals
     _projectDialog->exec();
