@@ -23,11 +23,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -143,7 +143,7 @@ CatalogManagerView::CatalogManagerView(KBabel::Project::Ptr project, TQWidget* p
    setColumnAlignment(2,AlignCenter);
    addColumn(COLTEXT(COL_TOTAL));
    setColumnAlignment(3,AlignCenter);
-   addColumn(TQString::null); // CVS/SVN column, header is set later
+   addColumn(TQString()); // CVS/SVN column, header is set later
    addColumn(COLTEXT(COL_REVISION));
    addColumn(COLTEXT(COL_TRANSLATOR));
 
@@ -445,7 +445,7 @@ void CatalogManagerView::loadMarks()
 #endif
     {
 	KMessageBox::error(this,i18n(
-	    "Error while trying to open file:\n %1").arg(url.prettyURL()));
+	    "Error while trying to open file:\n %1").tqarg(url.prettyURL()));
 	return;
     }
 
@@ -471,7 +471,7 @@ void CatalogManagerView::loadMarks()
 	{
     	    KMessageBox::error(this
 		,i18n("Error while trying to read file:\n %1\n"
-		"Maybe it is not a valid file with list of markings.").arg(url.prettyURL()));
+		"Maybe it is not a valid file with list of markings.").tqarg(url.prettyURL()));
 	    f.close();
 	    return;
 	}
@@ -480,7 +480,7 @@ void CatalogManagerView::loadMarks()
     else
     {
 	KMessageBox::error(this,i18n(
-	    "Error while trying to open file:\n %1").arg(url.prettyURL()));
+	    "Error while trying to open file:\n %1").tqarg(url.prettyURL()));
     }
 
     KIO::NetAccess::removeTempFile( filename );
@@ -516,8 +516,8 @@ void CatalogManagerView::saveMarks()
     // ### FIXME: why is the file dialog not doing this?
     if ( KIO::NetAccess::exists( url2, false, this ) )
     {
-        if(KMessageBox::warningContinueCancel(this,TQString("<qt>%1</qt>").arg(i18n("The file %1 already exists. "
-	            "Do you want to overwrite it?").arg(url2.prettyURL())),i18n("Warning"),i18n("&Overwrite"))==KMessageBox::Cancel)
+        if(KMessageBox::warningContinueCancel(this,TQString("<qt>%1</qt>").tqarg(i18n("The file %1 already exists. "
+	            "Do you want to overwrite it?").tqarg(url2.prettyURL())),i18n("Warning"),i18n("&Overwrite"))==KMessageBox::Cancel)
 	{
 	    return;
 	}
@@ -568,7 +568,7 @@ void CatalogManagerView::saveMarks()
     {
         // ### KDE4 FIXME: strip the final \n of the message
         KMessageBox::error( this,
-            i18n( "An error occurred while trying to write to file:\n%1\n" ).arg( url.prettyURL()) );
+            i18n( "An error occurred while trying to write to file:\n%1\n" ).tqarg( url.prettyURL()) );
     }
     else if ( !localFile )
     {
@@ -577,7 +577,7 @@ void CatalogManagerView::saveMarks()
         {
             // ### KDE4 FIXME: strip the final \n of the message
             KMessageBox::error(this,
-                i18n("An error occurred while trying to upload the file:\n%1\n").arg(url.prettyURL()));
+                i18n("An error occurred while trying to upload the file:\n%1\n").tqarg(url.prettyURL()));
         }
     }
 
@@ -713,7 +713,7 @@ void CatalogManagerView::markedStatistics()
    showStatistics( i, markedDoList );
 }
 
-void CatalogManagerView::showStatistics( CatManListItem  *i, TQStringList &childrenList )
+void CatalogManagerView::showStatistics( CatManListItem  *i, TQStringList &tqchildrenList )
 {
    KLocale *locale = KGlobal::locale();
 
@@ -727,7 +727,7 @@ void CatalogManagerView::showStatistics( CatManListItem  *i, TQStringList &child
       int totalUntranslated=0;
 
       TQStringList::const_iterator it;
-      for( it = childrenList.constBegin(); it != childrenList.constEnd(); ++it )
+      for( it = tqchildrenList.constBegin(); it != tqchildrenList.constEnd(); ++it )
       {
          CatManListItem* item = _fileList[(*it)];
 
@@ -768,29 +768,29 @@ void CatalogManagerView::showStatistics( CatManListItem  *i, TQStringList &child
       if(name.isEmpty())
           msg = i18n("Statistics for all:\n");
       else
-          msg = i18n("Statistics for %1:\n").arg(name);
+          msg = i18n("Statistics for %1:\n").tqarg(name);
 
-      msg+=i18n("Number of packages: %1\n").arg(locale->formatNumber(totalPackages, 0));
+      msg+=i18n("Number of packages: %1\n").tqarg(locale->formatNumber(totalPackages, 0));
 
       percent=100.0-((double)needworkPo*100.0)/totalPackages;
-      msg+=i18n("Complete translated: %1 % (%2)\n").arg(locale->formatNumber(percent,2)).arg(locale->formatNumber(totalPackages-needworkPo, 0));
+      msg+=i18n("Complete translated: %1 % (%2)\n").tqarg(locale->formatNumber(percent,2)).tqarg(locale->formatNumber(totalPackages-needworkPo, 0));
 
       percent=100.0-((double)totalPo*100.0)/totalPackages;
-      msg+=i18n("Only template available: %1 % (%2)\n").arg(locale->formatNumber(percent,2)).arg(locale->formatNumber(totalPackages-totalPo,0));
+      msg+=i18n("Only template available: %1 % (%2)\n").tqarg(locale->formatNumber(percent,2)).tqarg(locale->formatNumber(totalPackages-totalPo,0));
       percent=((double)totalNoPot*100.0)/totalPackages;
-      msg+=i18n("Only PO file available: %1 % (%2)\n").arg(locale->formatNumber(percent,02)).arg(locale->formatNumber(totalNoPot, 0));
+      msg+=i18n("Only PO file available: %1 % (%2)\n").tqarg(locale->formatNumber(percent,02)).tqarg(locale->formatNumber(totalNoPot, 0));
 
-      msg+=i18n("Number of messages: %1\n").arg(locale->formatNumber(totalMsgid, 0));
+      msg+=i18n("Number of messages: %1\n").tqarg(locale->formatNumber(totalMsgid, 0));
 
       long int totalTranslated = totalMsgid - totalFuzzy - totalUntranslated;
       percent=((double)totalTranslated*100.0)/totalMsgid;
-      msg+=i18n("Translated: %1 % (%2)\n").arg(locale->formatNumber(percent,2)).arg(locale->formatNumber(totalTranslated, 0));
+      msg+=i18n("Translated: %1 % (%2)\n").tqarg(locale->formatNumber(percent,2)).tqarg(locale->formatNumber(totalTranslated, 0));
 
       percent=((double)totalFuzzy*100.0)/totalMsgid;
-      msg+=i18n("Fuzzy: %1 % (%2)\n").arg(locale->formatNumber(percent,2)).arg(locale->formatNumber(totalFuzzy, 0));
+      msg+=i18n("Fuzzy: %1 % (%2)\n").tqarg(locale->formatNumber(percent,2)).tqarg(locale->formatNumber(totalFuzzy, 0));
 
       percent=((double)totalUntranslated*100.0)/totalMsgid;
-      msg+=i18n("Untranslated: %1 % (%2)\n").arg(locale->formatNumber(percent,2)).arg(locale->formatNumber(totalUntranslated, 0));
+      msg+=i18n("Untranslated: %1 % (%2)\n").tqarg(locale->formatNumber(percent,2)).tqarg(locale->formatNumber(totalUntranslated, 0));
 
    KMessageBox::information(this,msg,i18n("Statistics"));
 }
@@ -807,7 +807,7 @@ void CatalogManagerView::checkSyntax()
       if(!item->hasPo())
          return;
 
-      Msgfmt::Status status;
+      Msgfmt::tqStatus status;
       TQString output;
       Msgfmt msgfmt;
 
@@ -850,7 +850,7 @@ void CatalogManagerView::checkSyntax()
    }
    else
    {
-      Msgfmt::Status status;
+      Msgfmt::tqStatus status;
       TQString output;
       Msgfmt msgfmt;
 
@@ -866,7 +866,7 @@ void CatalogManagerView::checkSyntax()
             if(!name.isEmpty())
             {
                msg=i18n("All files in folder %1 are syntactically correct.\n"
-"Output of \"msgfmt --statistics\":\n").arg(name)+output;
+"Output of \"msgfmt --statistics\":\n").tqarg(name)+output;
             }
             else
             {
@@ -882,7 +882,7 @@ void CatalogManagerView::checkSyntax()
             if(!name.isEmpty())
             {
                msg=i18n("At least one file in folder %1 has syntax errors.\n"
-"Output of \"msgfmt --statistics\":\n").arg(name)+output;
+"Output of \"msgfmt --statistics\":\n").tqarg(name)+output;
             }
             else
             {
@@ -898,7 +898,7 @@ void CatalogManagerView::checkSyntax()
             if(!name.isEmpty())
             {
                msg=i18n("At least one file in folder %1 has header syntax errors.\n"
-"Output of \"msgfmt --statistics\":\n").arg(name)+output;
+"Output of \"msgfmt --statistics\":\n").tqarg(name)+output;
             }
             else
             {
@@ -914,7 +914,7 @@ void CatalogManagerView::checkSyntax()
             if(!name.isEmpty())
             {
               msg=i18n("An error occurred while processing \"msgfmt --statistics *.po\" "
-"in folder %1").arg(name);
+"in folder %1").tqarg(name);
             }
             else
             {
@@ -985,10 +985,10 @@ void CatalogManagerView::mailFiles()
   CatManListItem* item = (CatManListItem*)currentItem();
   if(item->isDir()) {
     TQStringList filesToSend;
-    TQStringList childrenList = item->allChildrenList(true);
+    TQStringList tqchildrenList = item->allChildrenList(true);
 
     TQStringList::const_iterator it;
-    for (it = childrenList.constBegin(); it != childrenList.constEnd(); ++it) {
+    for (it = tqchildrenList.constBegin(); it != tqchildrenList.constEnd(); ++it) {
       CatManListItem* i = _fileList[(*it)];
       if (i->hasPo()) {
 	filesToSend << i->poFile();
@@ -1023,23 +1023,23 @@ void CatalogManagerView::packageFiles( )
     CatManListItem* item = (CatManListItem*)currentItem();
     if(item->isDir()) {
         TQStringList filesToPackage;
-        TQStringList childrenList = item->allChildrenList(true);
+        TQStringList tqchildrenList = item->allChildrenList(true);
 
         TQStringList::const_iterator it;
-        for (it = childrenList.constBegin(); it != childrenList.constEnd(); ++it) {
+        for (it = tqchildrenList.constBegin(); it != tqchildrenList.constEnd(); ++it) {
           CatManListItem* i = _fileList[(*it)];
           if (i->hasPo()) {
 	    filesToPackage << i->poFile();
           }
         }
-	TQString packageFileName = KFileDialog::getSaveFileName(TQString::null,"*.tar.bz2\n*.tar.gz",this);
-	mailer->buildArchive( filesToPackage, packageFileName, TQString::null, false );
+	TQString packageFileName = KFileDialog::getSaveFileName(TQString(),"*.tar.bz2\n*.tar.gz",this);
+	mailer->buildArchive( filesToPackage, packageFileName, TQString(), false );
     }
     else {
         if (item->hasPo()) {
           TQStringList fileToPackage(item->poFile());
-	  TQString packageFileName = KFileDialog::getSaveFileName(TQString::null,"*.tar.bz2\n*.tar.gz",this);
-	  mailer->buildArchive( fileToPackage, packageFileName, TQString::null, false );
+	  TQString packageFileName = KFileDialog::getSaveFileName(TQString(),"*.tar.bz2\n*.tar.gz",this);
+	  mailer->buildArchive( fileToPackage, packageFileName, TQString(), false );
         }
     }
 }
@@ -1057,8 +1057,8 @@ void CatalogManagerView::packageMarkedFiles( )
       }
     }
 
-    TQString packageFileName = KFileDialog::getSaveFileName(TQString::null,"*.tar.bz2\n*.tar.gz",this);
-    mailer->buildArchive( filesToPackage, packageFileName, TQString::null, false );
+    TQString packageFileName = KFileDialog::getSaveFileName(TQString(),"*.tar.bz2\n*.tar.gz",this);
+    mailer->buildArchive( filesToPackage, packageFileName, TQString(), false );
 }
 
 // CVS
@@ -1082,14 +1082,14 @@ void CatalogManagerView::cvsCommitMarked( )
   doCVSCommand( CVS::Commit, true );
 }
 
-void CatalogManagerView::cvsStatus( )
+void CatalogManagerView::cvstqStatus( )
 {
-  doCVSCommand( CVS::Status );
+  doCVSCommand( CVS::tqStatus );
 }
 
 void CatalogManagerView::cvsStatusMarked( )
 {
-  doCVSCommand( CVS::Status, true );
+  doCVSCommand( CVS::tqStatus, true );
 }
 
 void CatalogManagerView::cvsUpdateTemplate( )
@@ -1137,7 +1137,7 @@ void CatalogManagerView::doCVSCommand( CVS::Command cmd, bool marked, bool templ
     TQString cvsItem;
     CatManListItem * item = (CatManListItem*)currentItem( );
     if ( ( cmd == CVS::Commit || cmd == CVS::Diff ) && item->isDir( ) ) {
-      // all children including directories
+      // all tqchildren including directories
       TQStringList cvsItems = item->allChildrenFileList (true, false, true);
       if ( !cvsItems.isEmpty( ) )
         cvshandler->execCVSCommand( this, cmd, cvsItems, templates, config );
@@ -1249,7 +1249,7 @@ void CatalogManagerView::doSVNCommand( SVN::Command cmd, bool marked, bool templ
         TQString svnItem;
         CatManListItem * item = (CatManListItem*)currentItem( );
         if ( ( cmd == SVN::Commit || cmd == SVN::Diff ) && item->isDir( ) ) {
-      // all children including directories
+      // all tqchildren including directories
             TQStringList svnItems = item->allChildrenFileList (true, false, true);
             if ( !svnItems.isEmpty( ) )
                 svnhandler->execSVNCommand( this, cmd, svnItems, templates, config );
@@ -1283,14 +1283,14 @@ TQString CatalogManagerView::find( FindOptions &options, TQStringList &rest )
    const TQString search = options.findStr.lower().simplifyWhiteSpace();
    TQStringList searchWords = TQStringList::split(' ', search);
 
-   TQStringList childrenList;
-   if( i->isFile() ) childrenList.append(i->name());
-   else childrenList =i->allChildrenList(true);
+   TQStringList tqchildrenList;
+   if( i->isFile() ) tqchildrenList.append(i->name());
+   else tqchildrenList =i->allChildrenList(true);
 
-   emit prepareFindProgressBar(childrenList.size());
+   emit prepareFindProgressBar(tqchildrenList.size());
 
    TQStringList::const_iterator it;
-   for( it = childrenList.constBegin(); it != childrenList.constEnd(); ++it )
+   for( it = tqchildrenList.constBegin(); it != tqchildrenList.constEnd(); ++it )
    {
 	 CatManListItem* item = _fileList[(*it)];
 
@@ -1341,11 +1341,11 @@ TQString CatalogManagerView::find( FindOptions &options, TQStringList &rest )
 		const TQString foundItemFile = itemFile;
 
 		it++;
-		while( it != childrenList.constEnd() )
+		while( it != tqchildrenList.constEnd() )
 		{
         	    CatManListItem *item = _fileList[(*it)];
 
-		    itemFile = TQString::null;
+		    itemFile = TQString();
 		    if( options.inTemplates )
 		    {
 			if( item->hasPot() ) itemFile=item->potFile();
@@ -1353,7 +1353,7 @@ TQString CatalogManagerView::find( FindOptions &options, TQStringList &rest )
 			if( item->hasPo() )itemFile=item->poFile();
 		    }
 		    if( options.inMarkedFiles && !item->marked() )
-			itemFile=TQString::null;
+			itemFile=TQString();
 
 		    if( !itemFile.isNull())
 		    {
@@ -1380,10 +1380,10 @@ TQString CatalogManagerView::find( FindOptions &options, TQStringList &rest )
 	    _stopSearch = false;
 	    rest.clear();
 	    if( _updateNesting == 0 && !_stop ) emit updateFinished();
-	    return TQString::null;
+	    return TQString();
 	}
    }
-   return TQString::null;
+   return TQString();
 }
 
 bool CatalogManagerView::hasMatchingWords( TQStringList &itemWords, TQStringList &searchWords)
@@ -1499,12 +1499,12 @@ void CatalogManagerView::slotDeleteFile()
 
    if(item && item->isFile() && item->hasPo() && !item->hasPot())
    {
-      const TQString msg=i18n("Do you really want to delete the file %1?").arg(item->poFile());
+      const TQString msg=i18n("Do you really want to delete the file %1?").tqarg(item->poFile());
       if(KMessageBox::warningContinueCancel(this,msg,i18n("Warning"),KGuiItem( i18n("Delete"), "editdelete"))== KMessageBox::Continue)
       {
          if(!TQFile::remove(item->poFile()))
          {
-             KMessageBox::sorry(this,i18n("Was not able to delete the file %1!").arg(item->poFile()));
+             KMessageBox::sorry(this,i18n("Was not able to delete the file %1!").tqarg(item->poFile()));
          }
       }
    }
@@ -1765,7 +1765,7 @@ void CatalogManagerView::buildTree()
    {
       KMessageBox::error(this,i18n("You have not specified a valid folder "
 "for the base folder of the PO files:\n%1\n"
-"Please check your settings in the project settings dialog.").arg(_settings.poBaseDir));
+"Please check your settings in the project settings dialog.").tqarg(_settings.poBaseDir));
 
       _active=false;
       _updateNesting--;
@@ -1782,7 +1782,7 @@ void CatalogManagerView::buildTree()
    {
       KMessageBox::error(this,i18n("You have not specified a valid folder "
 "for the base folder of the PO template files:\n%1\n"
-"Please check your settings in the project settings dialog.").arg(_settings.potBaseDir));
+"Please check your settings in the project settings dialog.").tqarg(_settings.potBaseDir));
    }
 
    cvshandler->setPOTBaseDir( _settings.potBaseDir );
@@ -2507,7 +2507,7 @@ void CatalogManagerView::showEvent(TQShowEvent*)
 
 void CatalogManagerView::contentsMousePressEvent(TQMouseEvent* event)
 {
-   if(event->button() == LeftButton)
+   if(event->button() == Qt::LeftButton)
       _pressPos=event->pos();
 
    TQListView::contentsMousePressEvent( event );
@@ -2515,11 +2515,11 @@ void CatalogManagerView::contentsMousePressEvent(TQMouseEvent* event)
 
 void CatalogManagerView::contentsMouseMoveEvent(TQMouseEvent* event)
 {
-   if(event->state() & LeftButton)
+   if(event->state() & Qt::LeftButton)
    {
       const int delay = KGlobalSettings::dndEventDelay();
-      if(QABS( event->pos().x() - _pressPos.x() ) >= delay ||
-         QABS( event->pos().y() - _pressPos.y() ) >= delay)
+      if(TQABS( event->pos().x() - _pressPos.x() ) >= delay ||
+         TQABS( event->pos().y() - _pressPos.y() ) >= delay)
       {
          CatManListItem* item = (CatManListItem*)itemAt(contentsToViewport(_pressPos));
          if(item && item->isFile())
@@ -3008,7 +3008,7 @@ void CatalogManagerView::validate_internal( const TQStringList& files, const KDa
 	    true, i18n("Validation Options"), KDialogBase::Ok|KDialogBase::Cancel);
 	_validateOptions = new ValidationOptions(_validateOptionsDlg);
 	_validateOptionsDlg->setMainWidget( _validateOptions );
-	_validateOptions->resize( _validateOptions->sizeHint() );
+	_validateOptions->resize( _validateOptions->tqsizeHint() );
 
 	// setup stored values
 	_validateOptions->markAsFuzzy->setChecked( _markAsFuzzy );
