@@ -22,11 +22,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -183,7 +183,7 @@ void CatManListItem::setOpen(bool open)
 
 TQStringList CatManListItem::allChildrenList(bool onlyFiles) const
 {
-   TQStringList childrenList;
+   TQStringList tqchildrenList;
 
    CatManListItem * myChild = (CatManListItem*)firstChild();
    while( myChild )
@@ -192,26 +192,26 @@ TQStringList CatManListItem::allChildrenList(bool onlyFiles) const
 
       if(myChild->isFile())
       {
-         childrenList.append(name);
+         tqchildrenList.append(name);
       }
       else if(myChild->isDir())
       {
          if(!onlyFiles)
-            childrenList.append(name);
+            tqchildrenList.append(name);
 
-         childrenList+=myChild->allChildrenList(onlyFiles);
+         tqchildrenList+=myChild->allChildrenList(onlyFiles);
       }
 
       myChild = (CatManListItem*)myChild->nextSibling();
    }
 
-   return childrenList;
+   return tqchildrenList;
 }
 
 
 TQStringList CatManListItem::allChildrenFileList(bool onlyFiles, bool emptyDirs, bool onlyModified) const
 {
-   TQStringList childrenList;
+   TQStringList tqchildrenList;
 
    CatManListItem * myChild = (CatManListItem*)firstChild();
    while( myChild )
@@ -219,22 +219,22 @@ TQStringList CatManListItem::allChildrenFileList(bool onlyFiles, bool emptyDirs,
       if(myChild->isFile() && myChild->hasPo() &&
        !(!myChild->isModified() && onlyModified))
       {
-         childrenList.append(myChild->poFile());
+         tqchildrenList.append(myChild->poFile());
       }
       else if(myChild->isDir())
       {
          if(!onlyFiles && (emptyDirs || myChild->_primary.exists() ))
 	 {
-            childrenList.append(myChild->poFile());
+            tqchildrenList.append(myChild->poFile());
 	 }
 
-         childrenList+=myChild->allChildrenFileList(onlyFiles,false,onlyModified);
+         tqchildrenList+=myChild->allChildrenFileList(onlyFiles,false,onlyModified);
       }
 
       myChild = (CatManListItem*)myChild->nextSibling();
    }
 
-   return childrenList;
+   return tqchildrenList;
 }
 
 
@@ -417,7 +417,7 @@ void CatManListItem::update(bool showPoInfo,bool includeChildren
 
              if(showPoInfo)
              {
-                _lastUpdated=TQDateTime::currentDateTime();
+                _lastUpdated=TQDateTime::tqcurrentDateTime();
 
 			    bool neededWork=needsWork();
 				bool needWork=false;
@@ -435,17 +435,17 @@ void CatManListItem::update(bool showPoInfo,bool includeChildren
                     const CVSHandler* cvsHandler = _view->cvsHandler();
                     const SVNHandler* svnHandler = _view->svnHandler();
                     
-                    const CVSHandler::FileStatus cvsFileStatus = cvsHandler->fstatus( poFile() );
-                    const SVNHandler::FileStatus svnFileStatus = svnHandler->fstatus( poFile() );
+                    const CVSHandler::FiletqStatus cvsFiletqStatus = cvsHandler->fstatus( poFile() );
+                    const SVNHandler::FiletqStatus svnFiletqStatus = svnHandler->fstatus( poFile() );
 
-                    _isModified = cvsHandler->isConsideredModified( cvsFileStatus )
-                        || svnHandler->isConsideredModified( svnFileStatus );
+                    _isModified = cvsHandler->isConsideredModified( cvsFiletqStatus )
+                        || svnHandler->isConsideredModified( svnFiletqStatus );
 
                     TQString versionControl;
-                    if ( cvsFileStatus != CVSHandler::NO_REPOSITORY )
-                        versionControl = cvsHandler->fileStatus( cvsFileStatus );
-                    else if  ( svnFileStatus != SVNHandler::NO_REPOSITORY )
-                        versionControl = svnHandler->fileStatus( svnFileStatus );
+                    if ( cvsFiletqStatus != CVSHandler::NO_REPOSITORY )
+                        versionControl = cvsHandler->filetqStatus( cvsFiletqStatus );
+                    else if  ( svnFiletqStatus != SVNHandler::NO_REPOSITORY )
+                        versionControl = svnHandler->filetqStatus( svnFiletqStatus );
                     else
                         versionControl = i18n("No version control");
 
@@ -532,15 +532,15 @@ void CatManListItem::update(bool showPoInfo,bool includeChildren
 
              if(showPoInfo)
              {
-                _lastUpdated=TQDateTime::currentDateTime();
+                _lastUpdated=TQDateTime::tqcurrentDateTime();
 
 		// clean previous state information
-		setText(COL_FUZZY,TQString::null);
-                setText(COL_UNTRANS,TQString::null);
-                setText(COL_TOTAL,TQString::null);
-		setText(COL_CVS_OR_SVN, TQString::null);
-                setText(COL_REVISION, TQString::null);
-                setText(COL_TRANSLATOR, TQString::null);
+		setText(COL_FUZZY,TQString());
+                setText(COL_UNTRANS,TQString());
+                setText(COL_TOTAL,TQString());
+		setText(COL_CVS_OR_SVN, TQString());
+                setText(COL_REVISION, TQString());
+                setText(COL_TRANSLATOR, TQString());
 
 		setPixmap(COL_NAME,ICON_UPDATING);
 
@@ -617,7 +617,7 @@ void CatManListItem::updateAfterSave( PoInfo &poInfo )
         TQString name=_primary.fileName();
         setText(COL_NAME,name.left(name.length()-3));
 
-        _lastUpdated=TQDateTime::currentDateTime();
+        _lastUpdated=TQDateTime::tqcurrentDateTime();
 
 	bool neededWork=needsWork();
 	bool needWork=false;
@@ -625,14 +625,14 @@ void CatManListItem::updateAfterSave( PoInfo &poInfo )
         TQPixmap icon;
 	_hasErrors=false;
 
-        const CVSHandler::FileStatus cvsFileStatus = _view->cvsHandler()->fstatus(poFile());
-        const SVNHandler::FileStatus svnFileStatus = _view->svnHandler()->fstatus(poFile());
+        const CVSHandler::FiletqStatus cvsFiletqStatus = _view->cvsHandler()->fstatus(poFile());
+        const SVNHandler::FiletqStatus svnFiletqStatus = _view->svnHandler()->fstatus(poFile());
 
         TQString versionControl;
-        if ( cvsFileStatus != CVSHandler::NO_REPOSITORY )
-            versionControl = _view->cvsHandler()->fileStatus( cvsFileStatus );
-        else if  ( svnFileStatus != SVNHandler::NO_REPOSITORY )
-            versionControl = _view->svnHandler()->fileStatus( svnFileStatus );
+        if ( cvsFiletqStatus != CVSHandler::NO_REPOSITORY )
+            versionControl = _view->cvsHandler()->filetqStatus( cvsFiletqStatus );
+        else if  ( svnFiletqStatus != SVNHandler::NO_REPOSITORY )
+            versionControl = _view->svnHandler()->filetqStatus( svnFiletqStatus );
         else
             versionControl = i18n("No version control");
  
@@ -799,7 +799,7 @@ TQString CatManListItem::package(bool rootSlash) const
 
 TQString CatManListItem::packageDir( ) const
 {
-  return ( _type == Dir ? _package : TQString::null );
+  return ( _type == Dir ? _package : TQString() );
 }
 
 TQString CatManListItem::name() const
@@ -825,12 +825,12 @@ TQPixmap CatManListItem::paintExclamation(TQPixmap* pixmap)
    int width=pixmap->width();
    int height=pixmap->height();
 
-   int diameter=QMIN(width,height);
+   int diameter=TQMIN(width,height);
 
    TQBitmap mask=pixmap->createHeuristicMask();
 
    TQPainter mp(&mask);
-   mp.setPen(TQPen(Qt::color1,1));
+   mp.setPen(TQPen(TQt::color1,1));
    mp.drawEllipse(width-diameter,height-diameter,diameter,diameter);
 
    TQPixmap result(width,height);
