@@ -20,11 +20,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -36,7 +36,7 @@
 #include <unistd.h>
 #include <sys/stat.h>
 #include <time.h>
-// Qt include files
+// TQt include files
 #include <tqdir.h>
 #include <tqfile.h>
 #include <tqfileinfo.h>
@@ -83,7 +83,7 @@ void SVNHandler::setPOTBaseDir( const TQString& dir )
   emit signalIsPOTRepository( _isPOTRepository );
 }
 
-TQString SVNHandler::fileStatus( const FileStatus status ) const
+TQString SVNHandler::filetqStatus( const FiletqStatus status ) const
 {
   switch ( status ) {
     case NO_REPOSITORY:
@@ -115,7 +115,7 @@ TQString SVNHandler::fileStatus( const FileStatus status ) const
   }
 }
 
-SVNHandler::FileStatus SVNHandler::fstatus( const TQString& filename ) const
+SVNHandler::FiletqStatus SVNHandler::fstatus( const TQString& filename ) const
 {
   // no valid repository
   if ( !_isPORepository )
@@ -145,7 +145,7 @@ SVNHandler::FileStatus SVNHandler::fstatus( const TQString& filename ) const
   int errorLine, errorCol;
   TQDomNodeList nodelist;
   TQDomNode node;
-  TQDomElement entry, wcStatus;
+  TQDomElement entry, wctqStatus;
 
   // Parse the output.
   if ( !doc.setContent( out.getOutput(), &errorMsg, &errorLine, &errorCol ) ) {
@@ -177,22 +177,22 @@ SVNHandler::FileStatus SVNHandler::fstatus( const TQString& filename ) const
   if ( node.isNull() )
     return ERROR_IN_WC;
 
-  wcStatus = node.toElement();
+  wctqStatus = node.toElement();
 
-  if ( wcStatus.attributeNode("item").value() == "normal" )
+  if ( wctqStatus.attributeNode("item").value() == "normal" )
     return UP_TO_DATE;
-  if ( wcStatus.attributeNode("item").value() == "modified" )
+  if ( wctqStatus.attributeNode("item").value() == "modified" )
     return LOCALLY_MODIFIED;
-  if ( wcStatus.attributeNode("item").value() == "conflicted" )
+  if ( wctqStatus.attributeNode("item").value() == "conflicted" )
     return CONFLICT;
-  if ( wcStatus.attributeNode("item").value() == "unversioned" )
+  if ( wctqStatus.attributeNode("item").value() == "unversioned" )
     return NOT_IN_SVN;
   // TODO Ignored entry should have separate return value probably.
-  if ( wcStatus.attributeNode("item").value() == "ignored" )
+  if ( wctqStatus.attributeNode("item").value() == "ignored" )
     return NOT_IN_SVN;
-  if ( wcStatus.attributeNode("item").value() == "added" )
+  if ( wctqStatus.attributeNode("item").value() == "added" )
     return LOCALLY_ADDED;
-  if ( wcStatus.attributeNode("item").value() == "deleted" )
+  if ( wctqStatus.attributeNode("item").value() == "deleted" )
     return LOCALLY_REMOVED;
   // TODO What to do with "missing", "incomplete", "replaced", "merged",
   // "obstructed", "external"? Can these appear at all in our case?
@@ -269,7 +269,7 @@ no_status_xml:
 
 }
 
-TQString SVNHandler::svnStatus( const TQString& filename ) const
+TQString SVNHandler::svntqStatus( const TQString& filename ) const
 {
   return map[filename];
 }
@@ -491,7 +491,7 @@ void SVNHandler::processDiff( TQString output )
     KMessageBox::error( 0, error );
 }
 
-bool SVNHandler::isConsideredModified( const FileStatus status ) const
+bool SVNHandler::isConsideredModified( const FiletqStatus status ) const
 {
   /*
    * A file is modified if it is either:
