@@ -21,11 +21,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -93,7 +93,7 @@ Catalog::~Catalog()
 TQString Catalog::msgctxt(uint index) const
 {
     if (  d->_entries.isEmpty() )
-        return TQString::null;
+        return TQString();
    uint max=d->_entries.count()-1;
    if(index > max)
       index=max;
@@ -103,7 +103,7 @@ TQString Catalog::msgctxt(uint index) const
 TQStringList Catalog::msgid(uint index, const bool noNewlines) const
 {
    if (  d->_entries.isEmpty() )
-        return TQString::null;
+        return TQString();
     uint max=d->_entries.count()-1;
    if(index > max)
       index=max;
@@ -114,7 +114,7 @@ TQStringList Catalog::msgid(uint index, const bool noNewlines) const
 TQStringList Catalog::msgstr(uint index, const bool noNewlines) const
 {
     if (  d->_entries.isEmpty() )
-        return TQString::null;
+        return TQString();
 
    uint max=d->_entries.count()-1;
    if(index > max)
@@ -126,7 +126,7 @@ TQStringList Catalog::msgstr(uint index, const bool noNewlines) const
 TQString Catalog::comment(uint index) const
 {
     if (  d->_entries.isEmpty() )
-        return TQString::null;
+        return TQString();
    uint max=d->_entries.count()-1;
    if(index > max)
       index=max;
@@ -497,7 +497,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
    }
 
    temp="X-Generator: KBabel %1\\n";
-   temp=temp.arg(VERSION);
+   temp=temp.tqarg(VERSION);
    found=false;
 
    for( it = headerList.begin(); it != headerList.end(); ++it )
@@ -533,7 +533,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
 
 
    temp="Plural-Forms: %1\\n";
-   temp=temp.arg(identityOptions.gnuPluralFormHeader);
+   temp=temp.tqarg(identityOptions.gnuPluralFormHeader);
    found=false;
 
    // update plural form header
@@ -578,12 +578,12 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
     		if( saveOptions.FSFCopyright == ProjectSettingsBase::Remove) 
 		    (*it).remove(" YEAR Free Software Foundation, Inc");
 		else 
-		    (*it).replace("YEAR", TQDate::currentDate().toString("yyyy"));
+		    (*it).replace("YEAR", TQDate::tqcurrentDate().toString("yyyy"));
 	    } else
 	    if( saveOptions.FSFCopyright == ProjectSettingsBase::Update )
 	    {
 		    //update years
-		    TQString cy = TQDate::currentDate().toString("yyyy");
+		    TQString cy = TQDate::tqcurrentDate().toString("yyyy");
 		    if( !(*it).contains( TQRegExp(cy)) ) // is the year already included?
 		    {
 			int index = (*it).findRev( TQRegExp("[\\d]+[\\d\\-, ]*") );
@@ -674,7 +674,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
         {
             temp+=(" <"+identityOptions.authorEmail+">");
         }
-        temp+=", "+TQDate::currentDate().toString("yyyy")+".";
+        temp+=", "+TQDate::tqcurrentDate().toString("yyyy")+".";
 
         // ### TODO: it would be nice if the entry could start with "COPYRIGHT" and have the "(C)" symbol (both not mandatory)
         TQRegExp regexpAuthorYear( "^#.*(<.+@.+>)?,\\s*([\\d]+[\\d\\-, ]*|YEAR)" );
@@ -721,7 +721,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
             found = false;
             bool foundAuthor = false;
     
-            const TQString cy = TQDate::currentDate().toString("yyyy");
+            const TQString cy = TQDate::tqcurrentDate().toString("yyyy");
 
             ait = foundAuthors.end();
             for( it = foundAuthors.begin() ; it!=foundAuthors.end(); ++it )
@@ -816,7 +816,7 @@ void Catalog::setFuzzy(uint index, bool on)
 
 }
 
-void Catalog::removeFuzzyStatus(uint index)
+void Catalog::removeFuzzytqStatus(uint index)
 {
     setFuzzy(index,false);
 }
@@ -888,10 +888,10 @@ TQString Catalog::encoding() const
     return encodingStr;
 }
 
-ConversionStatus Catalog::openURL(const KURL& url, const TQString& package)
+ConversiontqStatus Catalog::openURL(const KURL& url, const TQString& package)
 {
    TQString target;
-   ConversionStatus error = OK;
+   ConversiontqStatus error = OK;
 
    if(KIO::NetAccess::download(url, target, NULL))
    {
@@ -971,8 +971,8 @@ ConversionStatus Catalog::openURL(const KURL& url, const TQString& package)
 
             if( package.isEmpty() )
 	    {
-		d->_packageName=TQString::null;
-		d->_packageDir=TQString::null;
+		d->_packageName=TQString();
+		d->_packageDir=TQString();
 	    }
 	    else setPackage(package);
 
@@ -992,10 +992,10 @@ ConversionStatus Catalog::openURL(const KURL& url, const TQString& package)
    }
 }
 
-ConversionStatus Catalog::openURL(const KURL& openUrl, const KURL& saveURL, const TQString& package)
+ConversiontqStatus Catalog::openURL(const KURL& openUrl, const KURL& saveURL, const TQString& package)
 {
    TQString target;
-   ConversionStatus error = OK;
+   ConversiontqStatus error = OK;
 
    if(KIO::NetAccess::download(openUrl, target, NULL))
    {
@@ -1069,8 +1069,8 @@ ConversionStatus Catalog::openURL(const KURL& openUrl, const KURL& saveURL, cons
            d->_url = saveURL;
            if( package.isEmpty() )
 	   {
-		d->_packageName=TQString::null;
-		d->_packageDir=TQString::null;
+		d->_packageName=TQString();
+		d->_packageDir=TQString();
 	   }
 	   else setPackage(package);
 
@@ -1093,7 +1093,7 @@ ConversionStatus Catalog::openURL(const KURL& openUrl, const KURL& saveURL, cons
    }
 }
 
-Msgfmt::Status Catalog::checkSyntax(TQString& output, bool clearErrors)
+Msgfmt::tqStatus Catalog::checkSyntax(TQString& output, bool clearErrors)
 {
    if( !d->_mimeTypes.contains( "application/x-gettext" ) )
 	return Msgfmt::Unsupported;
@@ -1112,7 +1112,7 @@ Msgfmt::Status Catalog::checkSyntax(TQString& output, bool clearErrors)
    }
 
    Msgfmt msgfmt;
-   Msgfmt::Status result = msgfmt.checkSyntax( filename , output, pluralFormType() != KDESpecific );
+   Msgfmt::tqStatus result = msgfmt.checkSyntax( filename , output, pluralFormType() != KDESpecific );
 
    if( clearErrors) clearErrorList();
 
@@ -1185,7 +1185,7 @@ void Catalog::removeFromErrorList(uint index)
 	}
 }
 
-TQStringList Catalog::itemStatus(uint index, bool recheck, TQPtrList<KDataTool> whatToCheck)
+TQStringList Catalog::itemtqStatus(uint index, bool recheck, TQPtrList<KDataTool> whatToCheck)
 {
     if (  d->_entries.isEmpty() )
         return TQStringList();
@@ -1207,7 +1207,7 @@ TQStringList Catalog::itemStatus(uint index, bool recheck, TQPtrList<KDataTool>
 	return item.errors();
 }
 
-TQStringList Catalog::itemStatus(uint index)
+TQStringList Catalog::itemtqStatus(uint index)
 {
        if (  d->_entries.isEmpty() )
         return TQStringList();
@@ -1800,7 +1800,7 @@ int Catalog::findPrevInList(const TQValueList<uint>& list,uint index) const
 
 TQString Catalog::dateTime() const
 {
-    const TQDateTime dt = TQDateTime::currentDateTime();
+    const TQDateTime dt = TQDateTime::tqcurrentDateTime();
     TQString dateTimeString;
     
     const SaveSettings options = d->_project->saveSettings();
@@ -1936,7 +1936,7 @@ TQString Catalog::dateTime() const
 }
 
 
-ConversionStatus Catalog::saveFile()
+ConversiontqStatus Catalog::saveFile()
 {
    if(d->_url.isEmpty())
    {
@@ -1947,11 +1947,11 @@ ConversionStatus Catalog::saveFile()
    return saveFileAs(d->_url,true);
 }
 
-ConversionStatus Catalog::saveFileAs(const KURL &url, bool overwrite)
+ConversiontqStatus Catalog::saveFileAs(const KURL &url, bool overwrite)
 {
    if( d->_active ) return BUSY;
 
-   ConversionStatus status=OK;
+   ConversiontqStatus status=OK;
 
    bool newName=false;
    KURL targetURL=d->_url;
@@ -2036,14 +2036,14 @@ TQString Catalog::saveTempFile()
    TQString filename = kapp->tempSaveName("/temp/kbabel_temp.po");
    if( writeFile(filename) != OK )
    {
-      filename = TQString::null;
+      filename = TQString();
    }
 
    return filename;
 }
 
 
-ConversionStatus Catalog::writeFile(TQString localFile , bool overwrite)
+ConversiontqStatus Catalog::writeFile(TQString localFile , bool overwrite)
 {
    TQFileInfo info(localFile);
 
@@ -2066,7 +2066,7 @@ ConversionStatus Catalog::writeFile(TQString localFile , bool overwrite)
       }
    }
 
-    ConversionStatus error = OK;
+    ConversiontqStatus error = OK;
     CatalogExportPlugin* filter=0;
 
     // gimme plugin for this MIME type
@@ -2549,7 +2549,7 @@ bool Catalog::findNext(const FindOptions* findOpts, DocPosition& docPos, int& le
         int contextInfoPos = -1;
 		TQString targetStr;
 
-		kapp->processEvents(10);
+		kapp->tqprocessEvents(10);
 
 		if( d->_stop || endReached)
 		{
@@ -2798,7 +2798,7 @@ bool Catalog::findPrev(const FindOptions* findOpts, DocPosition& docPos, int& le
         int contextInfoPos = -1;
 		TQString targetStr;
 
-		kapp->processEvents(10);
+		kapp->tqprocessEvents(10);
 
 		if( d->_stop || beginReached)
 		{
@@ -3134,7 +3134,7 @@ Catalog::DiffResult Catalog::diff(uint entry, TQString *result)
 
         int counter=0;
         int oldPercent=0;
-        int max = QMAX( d->msgidDiffList.count()-1, 1);
+        int max = TQMAX( d->msgidDiffList.count()-1, 1);
 
         TQStringList::ConstIterator it;
         for(it = d->msgidDiffList.begin();
@@ -3155,7 +3155,7 @@ Catalog::DiffResult Catalog::diff(uint entry, TQString *result)
                 bestId = (*it);
             }
 
-            kapp->processEvents(10);
+            kapp->tqprocessEvents(10);
 
 	    if( d->_stop )
 	    {
@@ -3220,7 +3220,7 @@ void Catalog::setDiffList( const TQValueList<DiffEntry>& list)
     d->msgstr2MsgidDiffList.clear();
     d->diffCache.clear();
 
-    uint max = QMAX(list.count()-1,1);
+    uint max = TQMAX(list.count()-1,1);
     int oldPercent=0;
     uint counter=0;
     TQValueList<DiffEntry>::ConstIterator it;
@@ -3232,7 +3232,7 @@ void Catalog::setDiffList( const TQValueList<DiffEntry>& list)
         {
             oldPercent = percent;
             emit signalProgress(percent);
-            kapp->processEvents(10);
+            kapp->tqprocessEvents(10);
         }
 
         TQString id = (*it).msgid;
