@@ -22,11 +22,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -107,9 +107,10 @@ struct DiffEntry
 * @short Class, that represents a translation catalog(po-file)
 * @author Matthias Kiefer <matthias.kiefer@gmx.de>
 */
-class KDE_EXPORT Catalog : public QObject
+class KDE_EXPORT Catalog : public TQObject
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
    enum DiffResult{DiffOk, DiffNotFound, DiffNeedList};
@@ -225,7 +226,7 @@ public:
     * @return the list of errors found for a given item index
     * @param index index of the item to check
     */
-   TQStringList itemStatus(uint index);
+   TQStringList itemtqStatus(uint index);
 
    /**
     * @return the list of errors found for a given item index
@@ -233,7 +234,7 @@ public:
     * @param recheck flag, if the item status should be checked now
     * @param whatToCheck what checks to do (a list of tools to be used
     */
-   TQStringList itemStatus(uint index, bool recheck, TQPtrList<KDataTool> whatToCheck);
+   TQStringList itemtqStatus(uint index, bool recheck, TQPtrList<KDataTool> whatToCheck);
 
    /**
    * replaces msgstr in catalog item at index index with msgstr
@@ -252,7 +253,7 @@ public:
    bool setHeader(CatalogItem header);
 
    /** removes string ", fuzzy" from comment */
-   void removeFuzzyStatus(uint index);
+   void removeFuzzytqStatus(uint index);
 
    /** sets or unsets fuzzy status of entry index */
    void setFuzzy(uint index, bool on);
@@ -296,19 +297,19 @@ public:
    * opens file url by using KDE's network downlad and calls
    * openFile with a local filename
    */
-   ConversionStatus openURL(const KURL& url, const TQString& package=TQString::null);
+   ConversiontqStatus openURL(const KURL& url, const TQString& package=TQString());
 
    /**
    * opens file openURL by using KDE's network downlad and calls
    * openFile with a local filename
    * sets current URL to saveURL
    */
-   ConversionStatus openURL(const KURL& openURL, const KURL& saveURL, const TQString& package=TQString::null);
+   ConversiontqStatus openURL(const KURL& openURL, const KURL& saveURL, const TQString& package=TQString());
 
    /** save the file under the old filename */
-   ConversionStatus saveFile();
+   ConversiontqStatus saveFile();
    /** saves the file under a new filename */
-   ConversionStatus saveFileAs(const KURL& url,bool overwrite=false);
+   ConversiontqStatus saveFileAs(const KURL& url,bool overwrite=false);
 
    /**
    * saves the current catalog in a temporary file and
@@ -341,7 +342,7 @@ public:
     * @param clearError should the errors be cleared before running msgfmt
     * @return the file codec used for the current catalog
     */
-   Msgfmt::Status checkSyntax(TQString& output, bool clearErrors=true);
+   Msgfmt::tqStatus checkSyntax(TQString& output, bool clearErrors=true);
 
    /**
     * checks using an external tool. The tool must provide the "validate" command
@@ -478,12 +479,12 @@ public:
    TagSettings tagSettings() const;
 
    /**
-   * reads the header from QTextstream and puts it in header
+   * reads the header from TQTextstream and puts it in header
    * I made it static to be able to use this function for
    * the search in po-files. This way, I can easily find the first
    * catalog entry in the textstream
    */
-//   static ConversionStatus readHeader(TQTextStream& stream,CatalogItem& header);
+//   static ConversiontqStatus readHeader(TQTextStream& stream,CatalogItem& header);
 
 
    void registerView(CatalogView* view);
@@ -611,7 +612,7 @@ private:
    void processCommand(EditCommand* cmd, CatalogView* view2exclude=0, bool undo=false);
 
    /** do the actual file write using plugin */
-   ConversionStatus writeFile(TQString localfile, bool overwrite=false);
+   ConversiontqStatus writeFile(TQString localfile, bool overwrite=false);
 
    /**
    * generates  lists that contain indexes of all fuzzy and untranslated entries
