@@ -22,11 +22,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -57,15 +57,15 @@ FindDialog::FindDialog(bool forReplace, TQWidget* parent)
 		, _regExpEditDialog(0), _replaceDlg(forReplace)
 {
 	TQWidget* page = new TQWidget(this);
-	TQVBoxLayout *layout = new TQVBoxLayout(page, 0, spacingHint());
+	TQVBoxLayout *tqlayout = new TQVBoxLayout(page, 0, spacingHint());
 
 	TQLabel *label = new TQLabel(i18n("&Find:"),page);
-	layout->addWidget(label);
+	tqlayout->addWidget(label);
 
 	_findCombo = new KComboBox(true, page, "findCombo");
 	_findCombo->setMaxCount(10);
 	_findCombo->setInsertionPolicy(KComboBox::AtTop);
-	layout->addWidget(_findCombo);
+	tqlayout->addWidget(_findCombo);
 	label->setBuddy(_findCombo);
 
 	TQString msg=i18n("<qt><p><b>Find text</b></p>"
@@ -82,11 +82,11 @@ FindDialog::FindDialog(bool forReplace, TQWidget* parent)
                 setButtonOK(i18n("&Replace"));
 
 		_replaceLabel = new TQLabel(i18n("&Replace with:"),page);
-		layout->addWidget(_replaceLabel);
+		tqlayout->addWidget(_replaceLabel);
 		_replaceCombo = new KComboBox(true, page, "replaceCombo");
 		_replaceCombo->setMaxCount(10);
 		_replaceCombo->setInsertionPolicy(KComboBox::AtTop);
-		layout->addWidget(_replaceCombo);
+		tqlayout->addWidget(_replaceCombo);
 		_replaceLabel->setBuddy(_replaceCombo);
 
 	    	msg=i18n("<qt><p><b>Replace text</b></p>"
@@ -107,7 +107,7 @@ FindDialog::FindDialog(bool forReplace, TQWidget* parent)
 
 	_buttonGrp = new TQButtonGroup(3, Qt::Horizontal, i18n("Where to Search"), page);
 	connect(_buttonGrp,TQT_SIGNAL(clicked(int)), this, TQT_SLOT(inButtonsClicked(int)));
-	layout->addWidget(_buttonGrp);
+	tqlayout->addWidget(_buttonGrp);
 
 	_inMsgid = new TQCheckBox(i18n("&Msgid"),_buttonGrp);
 	_inMsgstr = new TQCheckBox(i18n("M&sgstr"),_buttonGrp);
@@ -119,7 +119,7 @@ FindDialog::FindDialog(bool forReplace, TQWidget* parent)
 
 
 	TQGroupBox* box = new TQGroupBox(2, Qt::Horizontal, i18n("Options"), page);
-	layout->addWidget(box);
+	tqlayout->addWidget(box);
 
 	_caseSensitive = new TQCheckBox(i18n("C&ase sensitive"),box);
 	_wholeWords = new TQCheckBox(i18n("O&nly whole words"),box);
@@ -520,7 +520,7 @@ void FindDialog::inButtonsClicked(int id)
 void FindDialog::regExpButtonClicked()
 {
     if ( _regExpEditDialog == 0 )
-         _regExpEditDialog = KParts::ComponentFactory::createInstanceFromQuery<TQDialog>( "KRegExpEditor/KRegExpEditor", TQString::null, this );
+         _regExpEditDialog = KParts::ComponentFactory::createInstanceFromQuery<TQDialog>( "KRegExpEditor/KRegExpEditor", TQString(), TQT_TQOBJECT(this) );
 
     KRegExpEditorInterface *iface = dynamic_cast<KRegExpEditorInterface *>( _regExpEditDialog );
     if( iface )
@@ -536,10 +536,10 @@ ReplaceDialog::ReplaceDialog(TQWidget* parent)
                    , true,false,i18n("&Replace"),i18n("&Goto Next"),i18n("R&eplace All"))
 {
 	TQWidget* page = plainPage();
-	TQVBoxLayout *layout = new TQVBoxLayout(page, 0, spacingHint());
+	TQVBoxLayout *tqlayout = new TQVBoxLayout(page, 0, spacingHint());
 
 	TQLabel *label = new TQLabel(i18n("Replace this string?"),page);
-	layout->addWidget(label);
+	tqlayout->addWidget(label);
 
 	connect(this,TQT_SIGNAL(user1Clicked()),this,TQT_SIGNAL(replace()));
 	connect(this,TQT_SIGNAL(user2Clicked()),this,TQT_SIGNAL(next()));
