@@ -22,11 +22,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -79,25 +79,25 @@ using namespace KBabel;
 static TQSize sizeHintForWidget(const TQWidget* widget)
 {
   //
-  // The size is computed by adding the sizeHint().height() of all
-  // widget children and taking the width of the widest child and adding
-  // layout()->margin() and layout()->spacing()
+  // The size is computed by adding the tqsizeHint().height() of all
+  // widget tqchildren and taking the width of the widest child and adding
+  // tqlayout()->margin() and tqlayout()->spacing()
   //
 
   TQSize size;
 
   int numChild = 0;
-  TQObjectList *l = (TQObjectList*)(widget->children());
+  TQObjectList l = widget->childrenListObject();
 
-  for( uint i=0; i < l->count(); i++ )
+  for( uint i=0; i < l.count(); i++ )
   {
-    TQObject *o = l->at(i);
+    TQObject *o = l.at(i);
     if( o->isWidgetType() )
     {
       numChild += 1;
       TQWidget *w=((TQWidget*)o);
 
-      TQSize s = w->sizeHint();
+      TQSize s = w->tqsizeHint();
       if( s.isEmpty() == true )
       {
           s = TQSize( 50, 100 ); // Default size
@@ -109,8 +109,8 @@ static TQSize sizeHintForWidget(const TQWidget* widget)
 
   if( numChild > 0 )
   {
-    size.setHeight( size.height() + widget->layout()->spacing()*(numChild-1) );
-    size += TQSize( widget->layout()->margin()*2, widget->layout()->margin()*2 + 1 );
+    size.setHeight( size.height() + widget->tqlayout()->spacing()*(numChild-1) );
+    size += TQSize( widget->tqlayout()->margin()*2, widget->tqlayout()->margin()*2 + 1 );
   }
   else
   {
@@ -127,12 +127,12 @@ SavePreferences::SavePreferences(TQWidget *parent)
     :  KTabCtl(parent)
 {
     TQWidget* page = new TQWidget(this);
-    TQVBoxLayout* layout=new TQVBoxLayout(page);
-    layout->setSpacing(KDialog::spacingHint());
-    layout->setMargin(KDialog::marginHint());
+    TQVBoxLayout* tqlayout=new TQVBoxLayout(page);
+    tqlayout->setSpacing(KDialog::spacingHint());
+    tqlayout->setMargin(KDialog::marginHint());
 
     TQGroupBox* box=new TQGroupBox(1,Qt::Horizontal,page);
-    layout->addWidget(box);
+    tqlayout->addWidget(box);
 
     box->setMargin(KDialog::marginHint());
     _updateButton = new TQCheckBox(i18n("&Update header when saving"),box, "kcfg_AutoUpdate");
@@ -141,7 +141,7 @@ SavePreferences::SavePreferences(TQWidget *parent)
     _saveObsoleteButton = new TQCheckBox(i18n("Save &obsolete entries"),box, "kcfg_SaveObsolete");
     
     TQGroupBox* descBox=new TQGroupBox(1,Qt::Horizontal,i18n("De&scription"),page);
-    layout->addWidget(descBox);
+    tqlayout->addWidget(descBox);
     
     descBox->setMargin(KDialog::marginHint());
     _descriptionEdit = new TQLineEdit(descBox, "kcfg_DescriptionString");
@@ -149,7 +149,7 @@ SavePreferences::SavePreferences(TQWidget *parent)
     TQGroupBox* encodingBox = new TQGroupBox(1,Qt::Horizontal,i18n("Encoding")
                                   ,page);
     encodingBox->setMargin(KDialog::marginHint());
-    layout->addWidget(encodingBox);
+    tqlayout->addWidget(encodingBox);
     TQHBox *b = new TQHBox(encodingBox);
 
     TQLabel* tempLabel=new TQLabel(i18n("Default:"),b);
@@ -177,23 +177,23 @@ SavePreferences::SavePreferences(TQWidget *parent)
 
     _autoSaveBox = new TQGroupBox( 1, Qt::Horizontal, i18n( "Automatic Saving" ), page );
     _autoSaveBox->setMargin( KDialog::marginHint( ) );
-    layout->addWidget( _autoSaveBox );
+    tqlayout->addWidget( _autoSaveBox );
     _autoSaveDelay = new KIntNumInput( _autoSaveBox, "kcfg_AutoSaveDelay" );
     _autoSaveDelay->setRange( 0, 60 );
     _autoSaveDelay->setSuffix( i18n( "Short for minutes", " min" ) );
     _autoSaveDelay->setSpecialValueText( i18n( "No autosave" ) );
 
-    layout->addStretch(1);
+    tqlayout->addStretch(1);
     page->setMinimumSize(sizeHintForWidget(page));
     addTab(page, i18n("&General"));
     
     page = new TQWidget(this);
-    layout=new TQVBoxLayout(page);
-    layout->setSpacing(KDialog::spacingHint());
-    layout->setMargin(KDialog::marginHint());
+    tqlayout=new TQVBoxLayout(page);
+    tqlayout->setSpacing(KDialog::spacingHint());
+    tqlayout->setMargin(KDialog::marginHint());
 
     TQGroupBox* gridBox = new TQGroupBox(2,Qt::Horizontal,i18n("Fields to Update"),page);
-    layout->addWidget(gridBox);
+    tqlayout->addWidget(gridBox);
     gridBox->setMargin(KDialog::marginHint());
 
     _revisionButton = new TQCheckBox(i18n("Re&vision-Date"),gridBox, "kcfg_UpdateRevisionDate");
@@ -204,10 +204,10 @@ SavePreferences::SavePreferences(TQWidget *parent)
     _projectButton = new TQCheckBox(i18n("Pro&ject"),gridBox, "kcfg_UpdateProject");
 
     TQButtonGroup* dateBox = new TQButtonGroup(2,Qt::Horizontal,i18n("Format of Revision-Date"),page, "kcfg_DateFormat");
-    layout->addWidget(dateBox);
+    tqlayout->addWidget(dateBox);
     box->setMargin(KDialog::marginHint());
 
-    // we remove/insert default date button to correctly map Qt::DateFormat to our Ids
+    // we remove/insert default date button to correctly map TQt::DateFormat to our Ids
     _defaultDateButton = new TQRadioButton( i18n("De&fault date format"),dateBox );
     dateBox->remove (_defaultDateButton);
     _localDateButton = new TQRadioButton( i18n("Local date fo&rmat"),dateBox );
@@ -225,7 +225,7 @@ SavePreferences::SavePreferences(TQWidget *parent)
     TQGroupBox* projectBox = new TQGroupBox(1,Qt::Horizontal,i18n("Project String")
                                   ,page);
     projectBox->setMargin(KDialog::marginHint());
-    layout->addWidget(projectBox);
+    tqlayout->addWidget(projectBox);
     b = new TQHBox(projectBox);
 
     tempLabel=new TQLabel(i18n("Project-Id:"),b);
@@ -234,31 +234,31 @@ SavePreferences::SavePreferences(TQWidget *parent)
     b->setSpacing(KDialog::spacingHint());
     tempLabel->setBuddy(_projectEdit);
     
-    layout->addStretch(1);
+    tqlayout->addStretch(1);
     page->setMinimumSize(sizeHintForWidget(page));
     addTab(page, i18n("&Header"));
     
     page = new TQWidget(this);
-    layout=new TQVBoxLayout(page);
-    layout->setSpacing(KDialog::spacingHint());
-    layout->setMargin(KDialog::marginHint());
+    tqlayout=new TQVBoxLayout(page);
+    tqlayout->setSpacing(KDialog::spacingHint());
+    tqlayout->setMargin(KDialog::marginHint());
 
     TQGroupBox* translatorCopyrightBox = new TQGroupBox(1,Qt::Horizontal, page);
     translatorCopyrightBox->setMargin(KDialog::marginHint());
     _translatorCopyrightButton = 
 	new TQCheckBox(i18n("Update &translator copyright")
 	    ,translatorCopyrightBox, "kcfg_UpdateTranslatorCopyright");
-    layout->addWidget(translatorCopyrightBox);
+    tqlayout->addWidget(translatorCopyrightBox);
 
     TQGroupBox* fsfBox=new TQButtonGroup(1,Qt::Horizontal,i18n("Free Software Foundation Copyright"),page, "kcfg_FSFCopyright");
-    layout->addWidget(fsfBox);
+    tqlayout->addWidget(fsfBox);
 
     fsfBox->setMargin(KDialog::marginHint());
     _removeFSFButton = new TQRadioButton(i18n("&Remove copyright if empty"),fsfBox);
     _updateFSFButton = new TQRadioButton(i18n("&Update copyright"),fsfBox);
     _nochangeFSFButton = new TQRadioButton(i18n("Do &not change"),fsfBox);
 
-    layout->addStretch(1);
+    tqlayout->addStretch(1);
     page->setMinimumSize(sizeHintForWidget(page));
     addTab(page, i18n("Cop&yright"));
 
@@ -289,7 +289,7 @@ SavePreferences::SavePreferences(TQWidget *parent)
 "<ul><li><b>%1</b>: this is the encoding that fits the character "
 "set of your system language.</li>"
 "<li><b>%2</b>: uses Unicode (UTF-8) encoding.</li>"
-"</ul></qt>").arg(defaultName).arg(utf8Name) );
+"</ul></qt>").tqarg(defaultName).tqarg(utf8Name) );
 
 
     TQWhatsThis::add(_oldEncodingButton
@@ -323,7 +323,7 @@ SavePreferences::SavePreferences(TQWidget *parent)
 "in the online help.</p>"
 "</qt>") );
 
-    setMinimumSize(sizeHint());
+    setMinimumSize(tqsizeHint());
 }
 
 
@@ -402,18 +402,18 @@ IdentityPreferences::IdentityPreferences(TQWidget* parent, const TQString& proje
          : TQWidget(parent)
 {
     TQWidget* page = this;
-    TQVBoxLayout* layout=new TQVBoxLayout(page);
-    layout->setSpacing(KDialog::spacingHint());
-    layout->setMargin(KDialog::marginHint());
+    TQVBoxLayout* tqlayout=new TQVBoxLayout(page);
+    tqlayout->setSpacing(KDialog::spacingHint());
+    tqlayout->setMargin(KDialog::marginHint());
 
     if( !project.isEmpty() )
     {
 	// show the project name in the widget at the top
-	layout->addWidget(new TQLabel(i18n("<font size=\"+1\">Project: %1</font>").arg(project),page));
+	tqlayout->addWidget(new TQLabel(i18n("<font size=\"+1\">Project: %1</font>").tqarg(project),page));
     }
 
     TQGroupBox* group = new TQGroupBox(2,Qt::Horizontal,page);
-    layout->addWidget(group);
+    tqlayout->addWidget(group);
     group->setMargin(KDialog::marginHint());
     
     TQLabel* tempLabel=new TQLabel(i18n("&Name:"),group);
@@ -443,12 +443,12 @@ IdentityPreferences::IdentityPreferences(TQWidget* parent, const TQString& proje
 
     tempLabel=new TQLabel(i18n("&Language mailing list:"),group);
     _listEdit = new TQLineEdit(group, "kcfg_Mailinglist");
-    _listEdit->setMinimumSize(100,_listEdit->sizeHint().height());
+    _listEdit->setMinimumSize(100,_listEdit->tqsizeHint().height());
     tempLabel->setBuddy(_listEdit);
  
     tempLabel=new TQLabel(i18n("&Timezone:"), group);
     _timezoneEdit = new TQLineEdit(group, "kcfg_Timezone");
-    _timezoneEdit->setMinimumSize(100,_timezoneEdit->sizeHint().height());
+    _timezoneEdit->setMinimumSize(100,_timezoneEdit->tqsizeHint().height());
     tempLabel->setBuddy(_timezoneEdit);
 
 
@@ -462,7 +462,7 @@ IdentityPreferences::IdentityPreferences(TQWidget* parent, const TQString& proje
 
 
     group = new TQGroupBox(1,Qt::Horizontal,page);
-    layout->addWidget(group);
+    tqlayout->addWidget(group);
     group->setMargin(KDialog::marginHint());
 
     hbox = new TQHBox(group);
@@ -534,11 +534,11 @@ IdentityPreferences::IdentityPreferences(TQWidget* parent, const TQString& proje
 	    "GNU gettext tools for currently set language; just press the <b>Lookup</b> "
 	    "button.</p></qt>"));
 
-    layout->addStretch(1);
+    tqlayout->addStretch(1);
 
     page->setMinimumSize(sizeHintForWidget(page));
 
-    setMinimumSize(sizeHint());
+    setMinimumSize(tqsizeHint());
 
     _mailEdit->installEventFilter(this);
     _listEdit->installEventFilter(this);
@@ -571,12 +571,12 @@ bool IdentityPreferences::eventFilter(TQObject *o, TQEvent *e)
                 TQString mail=url.path();
 
                 bool handled=false;
-                if(o == _mailEdit)
+                if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(_mailEdit))
                 {
                     handled=true;
                     _mailEdit->setText(mail);
                 }
-                else if(o == _listEdit)
+                else if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(_listEdit))
                 {
                     handled=true;
                     _listEdit->setText(mail);
@@ -619,12 +619,12 @@ void IdentityPreferences::testPluralForm()
                 "of singular/plural forms automatically for the "
                 "language code \"%1\".\n"
                 "Do you have kdelibs.po installed for this language?\n"
-                "Please set the correct number manually.").arg(lang);
+                "Please set the correct number manually.").tqarg(lang);
     }
     else
     {
         msg = i18n("The number of singular/plural forms found for "
-                "the language code \"%1\" is %2.").arg(lang).arg(number);
+                "the language code \"%1\" is %2.").tqarg(lang).tqarg(number);
     }
 
     if(!msg.isEmpty())
@@ -663,13 +663,13 @@ MiscPreferences::MiscPreferences(TQWidget *parent)
 {
     TQWidget* page = this;
 
-    TQVBoxLayout* layout=new TQVBoxLayout(page);
-    layout->setSpacing(KDialog::spacingHint());
-    layout->setMargin(KDialog::marginHint());
+    TQVBoxLayout* tqlayout=new TQVBoxLayout(page);
+    tqlayout->setSpacing(KDialog::spacingHint());
+    tqlayout->setMargin(KDialog::marginHint());
 
     TQGroupBox* box=new TQGroupBox(1,Qt::Horizontal,page);
     box->setMargin(KDialog::marginHint());
-    layout->addWidget(box);
+    tqlayout->addWidget(box);
 
     TQHBox *hbox = new TQHBox(box);
     hbox->setSpacing(KDialog::spacingHint());
@@ -681,7 +681,7 @@ MiscPreferences::MiscPreferences(TQWidget *parent)
     hbox->setStretchFactor(accelMarkerEdit,1);
     TQString msg=i18n("<qt><p><b>Marker for keyboard accelerator</b></p>"
         "<p>Define here, what character marks the following "
-        "character as keyboard accelerator. For example in Qt it is "
+        "character as keyboard accelerator. For example in TQt it is "
         "'&amp;' and in Gtk it is '_'.</p></qt>");
     TQWhatsThis::add(label,msg);
     TQWhatsThis::add(accelMarkerEdit,msg);
@@ -715,7 +715,7 @@ MiscPreferences::MiscPreferences(TQWidget *parent)
     vbgroup->setTitle(i18n("Compression Method for Mail Attachments"));
     vbgroup->setRadioButtonExclusive(true);
     vbgroup->setMargin(KDialog::marginHint());
-    layout->addWidget(vbgroup);
+    tqlayout->addWidget(vbgroup);
 
     bzipButton = new TQRadioButton(i18n("tar/&bzip2"), vbgroup, "kcfg_BZipCompression");
     gzipButton = new TQRadioButton(i18n("tar/&gzip"), vbgroup);
@@ -723,7 +723,7 @@ MiscPreferences::MiscPreferences(TQWidget *parent)
     compressSingle = new TQCheckBox(i18n("&Use compression when sending "
 					"a single file"), vbgroup, "kcfg_CompressSingleFile");
 
-    layout->addStretch(1);
+    tqlayout->addStretch(1);
     page->setMinimumSize(sizeHintForWidget(page));
 }
 
@@ -778,7 +778,7 @@ void MiscPreferences::regExpButtonClicked()
 {
     if ( _regExpEditDialog==0 )
       _regExpEditDialog = KParts::ComponentFactory::createInstanceFromQuery<TQDialog>
-	("KRegExpEditor/KRegExpEditor", TQString::null, this );
+	("KRegExpEditor/KRegExpEditor", TQString(), TQT_TQOBJECT(this) );
 
     KRegExpEditorInterface *iface = dynamic_cast<KRegExpEditorInterface *>( _regExpEditDialog );
     if( iface )
@@ -794,30 +794,30 @@ SpellPreferences::SpellPreferences(TQWidget* parent)
          : TQWidget(parent)
 {
     TQWidget* page = this;
-    TQVBoxLayout* layout=new TQVBoxLayout(page);
-    layout->setSpacing(KDialog::spacingHint());
-    layout->setMargin(KDialog::marginHint());
+    TQVBoxLayout* tqlayout=new TQVBoxLayout(page);
+    tqlayout->setSpacing(KDialog::spacingHint());
+    tqlayout->setMargin(KDialog::marginHint());
 
 
     onFlyBtn = new TQCheckBox(i18n("On the &fly spellchecking"),page, "kcfg_OnFlySpellCheck");
-    layout->addWidget(onFlyBtn);
+    tqlayout->addWidget(onFlyBtn);
 
     TQWhatsThis::add(onFlyBtn, i18n("<qt><p><b>On the fly spellchecking</b></p>"
         "<p>Activate this to let KBabel spell check the text "
 	"as you type. Mispelled words will be colored by the error color.</p></qt>"));
 	
     spellConfig = new KSpellConfig(page,"spellConfigWidget",0,false);
-    layout->addWidget(spellConfig);
+    tqlayout->addWidget(spellConfig);
     remIgnoredBtn = new TQCheckBox(i18n("&Remember ignored words"),page, "kcfg_RememberIgnored");
-    layout->addWidget(remIgnoredBtn);
+    tqlayout->addWidget(remIgnoredBtn);
     
     connect( spellConfig, TQT_SIGNAL( configChanged() )
 	, this, TQT_SIGNAL ( settingsChanged() ) );
 
     TQLabel *tempLabel = new TQLabel(i18n("F&ile to store ignored words:"),page);
-    layout->addWidget(tempLabel);
+    tqlayout->addWidget(tempLabel);
     ignoreURLEdit = new KURLRequester(page, "kcfg_IgnoreURL");
-    layout->addWidget(ignoreURLEdit);
+    tqlayout->addWidget(ignoreURLEdit);
     tempLabel->setBuddy(ignoreURLEdit);
 
     connect(remIgnoredBtn,TQT_SIGNAL(toggled(bool)),ignoreURLEdit
@@ -833,11 +833,11 @@ SpellPreferences::SpellPreferences(TQWidget* parent)
     TQWhatsThis::add(tempLabel,msg);
     TQWhatsThis::add(ignoreURLEdit,msg);
 
-    layout->addStretch(1);
+    tqlayout->addStretch(1);
 
     page->setMinimumSize(sizeHintForWidget(page));
 
-    setMinimumSize(sizeHint());
+    setMinimumSize(tqsizeHint());
 }
 
 
@@ -879,13 +879,13 @@ CatmanPreferences::CatmanPreferences(TQWidget* parent)
 {
     TQWidget* page = this;
 
-    TQVBoxLayout* layout=new TQVBoxLayout(page);
-    layout->setSpacing(KDialog::spacingHint());
-    layout->setMargin(KDialog::marginHint());
+    TQVBoxLayout* tqlayout=new TQVBoxLayout(page);
+    tqlayout->setSpacing(KDialog::spacingHint());
+    tqlayout->setMargin(KDialog::marginHint());
 
     TQGroupBox* box=new TQGroupBox(1,Qt::Horizontal,page);
     box->setMargin(KDialog::marginHint());
-    layout->addWidget(box);
+    tqlayout->addWidget(box);
 
     TQLabel* label=new TQLabel(i18n("&Base folder of PO files:"),box);
     TQHBox* hbox = new TQHBox(box);
@@ -896,7 +896,7 @@ CatmanPreferences::CatmanPreferences(TQWidget* parent)
 												
     _poDirEdit = new KURLRequester(hbox, "kcfg_PoBaseDir");
     _poDirEdit->setMode( mode );
-    _poDirEdit->setMinimumSize(250,_poDirEdit->sizeHint().height());
+    _poDirEdit->setMinimumSize(250,_poDirEdit->tqsizeHint().height());
     label->setBuddy(_poDirEdit);
 
 
@@ -906,7 +906,7 @@ CatmanPreferences::CatmanPreferences(TQWidget* parent)
 
     _potDirEdit = new KURLRequester(hbox, "kcfg_PotBaseDir");
     _potDirEdit->setMode( mode );
-    _potDirEdit->setMinimumSize(250,_potDirEdit->sizeHint().height());
+    _potDirEdit->setMinimumSize(250,_potDirEdit->tqsizeHint().height());
     label->setBuddy(_potDirEdit);
 
 
@@ -919,7 +919,7 @@ CatmanPreferences::CatmanPreferences(TQWidget* parent)
 
     box=new TQGroupBox(1,Qt::Horizontal,page);
     box->setMargin(KDialog::marginHint());
-    layout->addWidget(box);
+    tqlayout->addWidget(box);
 
     _openWindowButton = new TQCheckBox(i18n("O&pen files in new window"),box, "kcfg_OpenWindow");
 
@@ -956,11 +956,11 @@ CatmanPreferences::CatmanPreferences(TQWidget* parent)
         "so invalid PO files could be shown as good ones, "
         "even if Gettext tools would reject such files.</p></qt>") );
 
-    layout->addStretch(1);
+    tqlayout->addStretch(1);
 
     page->setMinimumSize(sizeHintForWidget(page));
 
-    setMinimumSize(sizeHint());
+    setMinimumSize(tqsizeHint());
 }
 
 
@@ -981,13 +981,13 @@ DirCommandsPreferences::DirCommandsPreferences(TQWidget* parent)
 {
     TQWidget* page = this;
 
-    TQVBoxLayout* layout=new TQVBoxLayout(page);
-    layout->setSpacing(KDialog::spacingHint());
-    layout->setMargin(KDialog::marginHint());
+    TQVBoxLayout* tqlayout=new TQVBoxLayout(page);
+    tqlayout->setSpacing(KDialog::spacingHint());
+    tqlayout->setMargin(KDialog::marginHint());
 
     TQGroupBox* box = new TQGroupBox( 1 , Qt::Horizontal , i18n("Commands for Folders") , page );
     box->setMargin( KDialog::marginHint() );
-    layout->addWidget( box );
+    tqlayout->addWidget( box );
 
     _dirCmdEdit = new CmdEdit( box );
     new TQLabel( i18n("Replaceables:\n@PACKAGE@, @PODIR@, @POTDIR@\n"
@@ -1010,10 +1010,10 @@ DirCommandsPreferences::DirCommandsPreferences(TQWidget* parent)
 
 
 
-    layout->addStretch(1);
+    tqlayout->addStretch(1);
     page->setMinimumSize(sizeHintForWidget(page));
 
-    setMinimumSize(sizeHint());
+    setMinimumSize(tqsizeHint());
 }
 
 
@@ -1044,13 +1044,13 @@ FileCommandsPreferences::FileCommandsPreferences(TQWidget* parent)
 {
     TQWidget* page = this;
 
-    TQVBoxLayout* layout=new TQVBoxLayout(page);
-    layout->setSpacing(KDialog::spacingHint());
-    layout->setMargin(KDialog::marginHint());
+    TQVBoxLayout* tqlayout=new TQVBoxLayout(page);
+    tqlayout->setSpacing(KDialog::spacingHint());
+    tqlayout->setMargin(KDialog::marginHint());
 
     TQGroupBox* box=new TQGroupBox( 1 , Qt::Horizontal , i18n("Commands for Files") , page );
     box->setMargin( KDialog::marginHint() );
-    layout->addWidget( box );
+    tqlayout->addWidget( box );
 
     _fileCmdEdit = new CmdEdit( box );
     new TQLabel( i18n("Replaceables:\n"
@@ -1074,10 +1074,10 @@ FileCommandsPreferences::FileCommandsPreferences(TQWidget* parent)
 
 
 
-    layout->addStretch(1);
+    tqlayout->addStretch(1);
     page->setMinimumSize(sizeHintForWidget(page));
 
-    setMinimumSize(sizeHint());
+    setMinimumSize(tqsizeHint());
 }
 
 
@@ -1107,13 +1107,13 @@ ViewPreferences::ViewPreferences(TQWidget* parent)
 {
     TQWidget* page = this;
 
-    TQVBoxLayout* layout=new TQVBoxLayout(page);
-    layout->setSpacing(KDialog::spacingHint());
-    layout->setMargin(KDialog::marginHint());
+    TQVBoxLayout* tqlayout=new TQVBoxLayout(page);
+    tqlayout->setSpacing(KDialog::spacingHint());
+    tqlayout->setMargin(KDialog::marginHint());
 
     TQGroupBox* box=new TQGroupBox(2, Qt::Horizontal,i18n("Shown Columns"),page);
     box->setMargin(KDialog::marginHint());
-    layout->addWidget(box);
+    tqlayout->addWidget(box);
 
     _flagColumnCheckbox = new TQCheckBox( i18n("Fla&g"), box, "kcfg_ShowFlagColumn" );
     _fuzzyColumnCheckbox = new TQCheckBox( i18n("&Fuzzy"), box, "kcfg_ShowFuzzyColumn" );
@@ -1126,11 +1126,11 @@ ViewPreferences::ViewPreferences(TQWidget* parent)
     TQWhatsThis::add(box,i18n("<qt><p><b>Shown columns</b></p>\n"
      "<p></p></qt>"));
      
-    layout->addStretch(1);
+    tqlayout->addStretch(1);
 
     page->setMinimumSize(sizeHintForWidget(page));
 
-    setMinimumSize(sizeHint());
+    setMinimumSize(tqsizeHint());
 }
 
 
@@ -1148,9 +1148,9 @@ void ViewPreferences::defaults(const CatManSettings& _settings)
 SourceContextPreferences::SourceContextPreferences(TQWidget* parent): TQWidget(parent)
 {
     TQWidget* page = this;
-    TQVBoxLayout* layout=new TQVBoxLayout(page);
-    layout->setSpacing(KDialog::spacingHint());
-    layout->setMargin(KDialog::marginHint());
+    TQVBoxLayout* tqlayout=new TQVBoxLayout(page);
+    tqlayout->setSpacing(KDialog::spacingHint());
+    tqlayout->setMargin(KDialog::marginHint());
     
     TQHBox* box = new TQHBox(page);
     box->setSpacing(KDialog::spacingHint());
@@ -1159,21 +1159,21 @@ SourceContextPreferences::SourceContextPreferences(TQWidget* parent): TQWidget(p
     const KFile::Mode mode = static_cast<KFile::Mode>( KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly );
     _coderootEdit = new KURLRequester ( box, "kcfg_CodeRoot" );
     _coderootEdit->setMode( mode );
-    _coderootEdit->setMinimumSize( 250, _coderootEdit->sizeHint().height() );
+    _coderootEdit->setMinimumSize( 250, _coderootEdit->tqsizeHint().height() );
     tempLabel->setBuddy( _coderootEdit );
-    layout->addWidget(box);
+    tqlayout->addWidget(box);
 												
     // FIXME: use KConfigXT    
     _pathsEditor = new KListEditor(page);
     _pathsEditor->setTitle(i18n("Path Patterns"));
-    layout->addWidget(_pathsEditor);
+    tqlayout->addWidget(_pathsEditor);
     
     connect ( _pathsEditor, TQT_SIGNAL (itemsChanged ())
 	, this, TQT_SIGNAL (itemsChanged ()));
     
     _pathsEditor->installEventFilter(this);
 				    
-    setMinimumSize(sizeHint());
+    setMinimumSize(tqsizeHint());
 }
 
 SourceContextPreferences::~SourceContextPreferences()
