@@ -22,11 +22,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -77,7 +77,7 @@ RoughTransDlg::RoughTransDlg(KBabelDictBox *dict, Catalog *cat
         ,partTransCounter(0)
         ,totalTried(0)
 {
-    setButtonBoxOrientation(Vertical);
+    setButtonBoxOrientation(Qt::Vertical);
     setButtonText(User1,i18n("&Start"));
     setButtonText(User2,i18n("S&top"));
     setButtonText(User3,i18n("C&ancel"));
@@ -187,9 +187,9 @@ RoughTransDlg::RoughTransDlg(KBabelDictBox *dict, Catalog *cat
     progressbar = new KProgress(mw,"progressbar");
     progressbar->setTextEnabled(true);
     progressbar->setFormat("%v/%m (%p%)");
-    TQHBoxLayout* pblayout= new TQHBoxLayout(mainLayout);
-    pblayout->add(label);
-    pblayout->add(progressbar);
+    TQHBoxLayout* pbtqlayout= new TQHBoxLayout(mainLayout);
+    pbtqlayout->add(label);
+    pbtqlayout->add(progressbar);
 
     transButton->setChecked(config->readBoolEntry("Translated",false));
     untransButton->setChecked(config->readBoolEntry("Untranslated",true));
@@ -278,7 +278,7 @@ void RoughTransDlg::translate()
     for(int i = 0; i < total; i++)
     {
         progressbar->setProgress(i+1);
-        kapp->processEvents(100);
+        kapp->tqprocessEvents(100);
 
         if(stop || cancel) break;
 
@@ -478,7 +478,7 @@ void RoughTransDlg::translate()
                             if(!word.contains(digitReg))
                                 wordList.append(word);
 
-                            word=TQString::null;
+                            word=TQString();
                         }
                     }
                     else if(!word.isEmpty())
@@ -486,7 +486,7 @@ void RoughTransDlg::translate()
                         if(!word.contains(digitReg))
                             wordList.append(word);
 
-                        word=TQString::null;
+                        word=TQString();
                     }
                         
                 }
@@ -503,7 +503,7 @@ void RoughTransDlg::translate()
                             if(!word.isEmpty() && !word.contains(digitReg))
                                 wordList.append(word);
 
-                            word=TQString::null;
+                            word=TQString();
                             
                             wordList.append("\\n\n");
                             index+=2;
@@ -513,7 +513,7 @@ void RoughTransDlg::translate()
                             if(!word.contains(digitReg))
                                 wordList.append(word);
 
-                            word=TQString::null;
+                            word=TQString();
                         }
                     }
                     else if(!word.isEmpty())
@@ -521,7 +521,7 @@ void RoughTransDlg::translate()
                         if(!word.contains(digitReg))
                             wordList.append(word);
 
-                        word=TQString::null;
+                        word=TQString();
                     }
                 }
                 else if(!word.isEmpty())
@@ -530,7 +530,7 @@ void RoughTransDlg::translate()
                         wordList.append(word);
 		    }
 
-                    word=TQString::null;
+                    word=TQString();
                 }
             }
 	    
@@ -571,7 +571,7 @@ void RoughTransDlg::translate()
                 }
 
                 if(wordCounter==0)
-                    translation=TQString::null;
+                    translation=TQString();
 
                 ++dit;
             }
@@ -673,13 +673,13 @@ void RoughTransDlg::showStatistics()
             "Exact translations: %2 (%3%)\n"
             "Approximate translations: %4 (%5%)\n"
             "Nothing found: %6 (%7%)")
-            .arg( locale->formatNumber(totalTried,0) )
-            .arg( locale->formatNumber(exactTransCounter,0) )
-            .arg( locale->formatNumber( ((double)(10000*exactTransCounter/QMAX(totalTried,1)))/100) )
-            .arg( locale->formatNumber(partTransCounter,0) )
-            .arg( locale->formatNumber(((double)(10000*partTransCounter/QMAX(totalTried,1)))/100) )
-            .arg( locale->formatNumber(nothing,0) )
-            .arg( locale->formatNumber(((double)(10000*nothing/QMAX(totalTried,1)))/100) );
+            .tqarg( locale->formatNumber(totalTried,0) )
+            .tqarg( locale->formatNumber(exactTransCounter,0) )
+            .tqarg( locale->formatNumber( ((double)(10000*exactTransCounter/TQMAX(totalTried,1)))/100) )
+            .tqarg( locale->formatNumber(partTransCounter,0) )
+            .tqarg( locale->formatNumber(((double)(10000*partTransCounter/TQMAX(totalTried,1)))/100) )
+            .tqarg( locale->formatNumber(nothing,0) )
+            .tqarg( locale->formatNumber(((double)(10000*nothing/TQMAX(totalTried,1)))/100) );
 
     KMessageBox::information(this, statMsg
             , i18n("Rough Translation Statistics"));
@@ -748,7 +748,7 @@ void RoughTransDlg::fuzzyButtonToggled(bool on)
           "check the results carefully. Deactivate this option only if "
           "you know what you are doing.</p></qt>");
 
-        KMessageBox::information(this, msg, TQString::null,"MarkFuzzyWarningInRoughTransDlg");
+        KMessageBox::information(this, msg, TQString(),"MarkFuzzyWarningInRoughTransDlg");
     }
 }
 
