@@ -23,11 +23,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -57,7 +57,7 @@ GettextImportPlugin::GettextImportPlugin(TQObject* parent, const char* name, con
 {
 }
 
-ConversionStatus GettextImportPlugin::load(const TQString& filename, const TQString&)
+ConversiontqStatus GettextImportPlugin::load(const TQString& filename, const TQString&)
 {
    kdDebug( KBABEL ) << k_funcinfo << endl;
    
@@ -106,7 +106,7 @@ ConversionStatus GettextImportPlugin::load(const TQString& filename, const TQStr
       //recoveredErrorInHeader = true;
    }
    
-   TQIODevice *dev = stream.device();
+   TQIODevice *dev = stream.tqdevice();
    int fileSize = dev->size();
 
    // if somethings goes wrong with the parsing, we don't have deleted the old contents
@@ -117,7 +117,7 @@ ConversionStatus GettextImportPlugin::load(const TQString& filename, const TQStr
    kdDebug(KBABEL) << "start parsing..." << endl;
 
    // first read header
-   const ConversionStatus status = readHeader(stream);
+   const ConversiontqStatus status = readHeader(stream);
 
 
    if ( status == RECOVERED_PARSE_ERROR )
@@ -173,13 +173,13 @@ ConversionStatus GettextImportPlugin::load(const TQString& filename, const TQStr
 
    while( !stream.eof() )
    {
-      kapp->processEvents(10);
+      kapp->tqprocessEvents(10);
       if( isStopped() )
       {
          return STOPPED;
       }
 
-      const ConversionStatus success=readEntry(stream);
+      const ConversiontqStatus success=readEntry(stream);
 
       if(success==OK)
       {
@@ -297,12 +297,12 @@ TQTextCodec* GettextImportPlugin::codecForArray(TQByteArray& array, bool* hadCod
    }
 
    TQTextStream stream( array, IO_ReadOnly );
-   // ### TODO Qt4: see if it can be done with TQByteArray alone, in an encoding-neutral way.
+   // ### TODO TQt4: see if it can be done with TQByteArray alone, in an encoding-neutral way.
    // Set ISO-8859-1 as it is a relatively neutral encoding when reading (compared to UTF-8  or a random locale encoing)
    stream.setEncoding( TQTextStream::Latin1 );
 
    // first read header
-   ConversionStatus status = readHeader(stream);
+   ConversiontqStatus status = readHeader(stream);
    if(status!=OK && status != RECOVERED_PARSE_ERROR)
    {
        kdDebug(KBABEL) << "wasn't able to read header" << endl;
@@ -360,18 +360,18 @@ TQTextCodec* GettextImportPlugin::codecForArray(TQByteArray& array, bool* hadCod
    return codec;
 }
 
-ConversionStatus GettextImportPlugin::readHeader(TQTextStream& stream)
+ConversiontqStatus GettextImportPlugin::readHeader(TQTextStream& stream)
 {
    CatalogItem temp;
-   int filePos=stream.device()->at();
-   ConversionStatus status=readEntry(stream);
+   int filePos=stream.tqdevice()->at();
+   ConversiontqStatus status=readEntry(stream);
 
    if(status==OK || status==RECOVERED_PARSE_ERROR)
    {
       // test if this is the header
       if(!_msgid.first().isEmpty())
       {
-         stream.device()->at(filePos);
+         stream.tqdevice()->at(filePos);
       }
 
       return status;
@@ -380,7 +380,7 @@ ConversionStatus GettextImportPlugin::readHeader(TQTextStream& stream)
    return PARSE_ERROR;
 }
 
-ConversionStatus GettextImportPlugin::readEntry(TQTextStream& stream)
+ConversiontqStatus GettextImportPlugin::readEntry(TQTextStream& stream)
 {
    //kdDebug( KBABEL ) << k_funcinfo << " START" << endl;
    enum {Begin,Comment,Msgctxt,Msgid,Msgstr} part=Begin;
@@ -402,13 +402,13 @@ ConversionStatus GettextImportPlugin::readEntry(TQTextStream& stream)
    
    while( !stream.eof() )
    {
-       const int pos=stream.device()->at();
+       const int pos=stream.tqdevice()->at();
 
        line=stream.readLine();
 
        //kdDebug() << "Parsing line: " << line << endl;
 
-       // ### Qt4: no need of a such a check
+       // ### TQt4: no need of a such a check
        if(line.isNull()) // file end
           break;
        else if ( line.startsWith( "<<<<<<<" ) || line.startsWith( "=======" ) || line.startsWith( ">>>>>>>" ) )
@@ -761,7 +761,7 @@ ConversionStatus GettextImportPlugin::readEntry(TQTextStream& stream)
             else if((line.find(TQRegExp("^\\s*msgid")) != -1) || (line.find(TQRegExp("^\\s*#")) != -1))
             {
                // We have read successfully one entry, so end loop.
-               stream.device()->at(pos);// reset position in stream to beginning of this line
+               stream.tqdevice()->at(pos);// reset position in stream to beginning of this line
                break;
             }
             else if(line.startsWith("msgstr"))
