@@ -22,11 +22,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -115,9 +115,9 @@ class MyKProgress: public KProgress
 public:
     MyKProgress( TQWidget *parent, const char *name ) : KProgress( parent, name )
     {
-        setSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Preferred );
+        tqsetSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Preferred );
     }
-    TQSize sizeHint() const { return TQSize( 1, 1);}
+    TQSize tqsizeHint() const { return TQSize( 1, 1);}
 };
 
 KBabelMW::KBabelMW(TQString projectFile)
@@ -129,7 +129,7 @@ KBabelMW::KBabelMW(TQString projectFile)
     
     if ( _project == NULL ) // FIXME should not happen anymore
     {
-	KMessageBox::error( this, i18n("Cannot open project file\n%1").arg(projectFile)
+	KMessageBox::error( this, i18n("Cannot open project file\n%1").tqarg(projectFile)
             , i18n("Project File Error"));
 	_project = ProjectManager::open(KBabel::ProjectManager::defaultProjectName());
     }
@@ -147,7 +147,7 @@ KBabelMW::KBabelMW(KBCatalog* catalog, TQString projectFile)
 
     if ( _project == NULL )
     {
-	KMessageBox::error( this, i18n("Cannot open project file\n%1").arg(projectFile)
+	KMessageBox::error( this, i18n("Cannot open project file\n%1").tqarg(projectFile)
             , i18n("Project File Error"));
 	_project = ProjectManager::open(KBabel::ProjectManager::defaultProjectName());
     }
@@ -217,18 +217,18 @@ void KBabelMW::init(KBCatalog* catalog)
     connect(catalog,TQT_SIGNAL(signalTotalNumberChanged(uint)),this
             ,TQT_SLOT(setNumberOfTotal(uint)));
     connect(catalog,TQT_SIGNAL(signalProgress(int)),_progressBar,TQT_SLOT(setProgress(int)));
-    connect(catalog,TQT_SIGNAL(signalClearProgressBar()),this,TQT_SLOT(clearProgressBar()));
+    connect(catalog,TQT_SIGNAL(signalClearProgressBar()),TQT_TQOBJECT(this),TQT_SLOT(clearProgressBar()));
     connect(catalog,TQT_SIGNAL(signalResetProgressBar(TQString,int))
-           ,this,TQT_SLOT(prepareProgressBar(TQString,int)));
-    connect(catalog,TQT_SIGNAL(signalFileOpened(bool)),this,TQT_SLOT(enableDefaults(bool)));
+           ,TQT_TQOBJECT(this),TQT_SLOT(prepareProgressBar(TQString,int)));
+    connect(catalog,TQT_SIGNAL(signalFileOpened(bool)),TQT_TQOBJECT(this),TQT_SLOT(enableDefaults(bool)));
     connect(catalog,TQT_SIGNAL(signalFileOpened(bool)),m_view,TQT_SLOT(newFileOpened(bool)));
-    connect(catalog,TQT_SIGNAL(signalModified(bool)),this,TQT_SLOT(showModified(bool)));
+    connect(catalog,TQT_SIGNAL(signalModified(bool)),TQT_TQOBJECT(this),TQT_SLOT(showModified(bool)));
 
     // allow the view to change the statusbar and caption
     connect(m_view, TQT_SIGNAL(signalChangeStatusbar(const TQString&)),
-            this,   TQT_SLOT(changeStatusbar(const TQString&)));
+            TQT_TQOBJECT(this),   TQT_SLOT(changeStatusbar(const TQString&)));
     connect(m_view, TQT_SIGNAL(signalChangeCaption(const TQString&)),
-            this,   TQT_SLOT(changeCaption(const TQString&)));
+            TQT_TQOBJECT(this),   TQT_SLOT(changeCaption(const TQString&)));
     connect(m_view,TQT_SIGNAL(signalFirstDisplayed(bool, bool)),this
            ,TQT_SLOT(firstEntryDisplayed(bool, bool)));
     connect(m_view,TQT_SIGNAL(signalLastDisplayed(bool, bool)),this
@@ -263,15 +263,15 @@ void KBabelMW::init(KBCatalog* catalog)
                   ,TQT_SLOT(setLedColor(const TQColor&)));
 
 
-    connect(m_view,TQT_SIGNAL(signalSearchActive(bool)),this,TQT_SLOT(enableStop(bool)));
+    connect(m_view,TQT_SIGNAL(signalSearchActive(bool)),TQT_TQOBJECT(this),TQT_SLOT(enableStop(bool)));
 
     connect(m_view,TQT_SIGNAL(signalProgress(int)),_progressBar,TQT_SLOT(setProgress(int)));
-    connect(m_view,TQT_SIGNAL(signalClearProgressBar()),this,TQT_SLOT(clearProgressBar()));
+    connect(m_view,TQT_SIGNAL(signalClearProgressBar()),TQT_TQOBJECT(this),TQT_SLOT(clearProgressBar()));
     connect(m_view,TQT_SIGNAL(signalResetProgressBar(TQString,int))
-           ,this,TQT_SLOT(prepareProgressBar(TQString,int)));
+           ,TQT_TQOBJECT(this),TQT_SLOT(prepareProgressBar(TQString,int)));
 
     connect(m_view,TQT_SIGNAL(signalDictionariesChanged())
-           , this, TQT_SLOT(buildDictMenus()));
+           , TQT_TQOBJECT(this), TQT_SLOT(buildDictMenus()));
     connect(m_view,TQT_SIGNAL(signalCursorPosChanged(int,int)), this
             , TQT_SLOT(updateCursorPosition(int,int)));
 
@@ -301,7 +301,7 @@ void KBabelMW::init(KBCatalog* catalog)
               bmHandler, TQT_SLOT(slotClearBookmarks()));
     }
     connect(bmHandler, TQT_SIGNAL(signalBookmarkSelected(int)),
-            this, TQT_SLOT(slotOpenBookmark(int)));
+            TQT_TQOBJECT(this), TQT_SLOT(slotOpenBookmark(int)));
     connect(m_view, TQT_SIGNAL(signalNewFileOpened(KURL)),
             bmHandler, TQT_SLOT(slotClearBookmarks()));
 
@@ -333,9 +333,9 @@ void KBabelMW::init(KBCatalog* catalog)
                    "The minimum requirement is to fill out the Identity page.\n"
                    "Also check the encoding on the Save page, which is currently "
                    "set to %1. You may want to change this setting "
-                   "according to the settings of your language team.").arg(encodingStr));
+                   "according to the settings of your language team.").tqarg(encodingStr));
 
-      TQTimer::singleShot(1,this,TQT_SLOT(projectConfigure()));
+      TQTimer::singleShot(1,TQT_TQOBJECT(this),TQT_SLOT(projectConfigure()));
     }
 
     _config->writeEntry("Version",VERSION);
@@ -404,68 +404,68 @@ void KBabelMW::setupActions()
    KAction* action;
 
    // the file menu
-   action = KStdAction::open(this, TQT_SLOT(fileOpen()), actionCollection());
+   action = KStdAction::open(TQT_TQOBJECT(this), TQT_SLOT(fileOpen()), actionCollection());
 
-   a_recent = KStdAction::openRecent(this, TQT_SLOT(openRecent(const KURL&)), actionCollection());
+   a_recent = KStdAction::openRecent(TQT_TQOBJECT(this), TQT_SLOT(openRecent(const KURL&)), actionCollection());
    a_recent->setMaxItems(MAX_RECENT);
    
-   action = KStdAction::revert(m_view,TQT_SLOT(revertToSaved()),actionCollection());
-   action=KStdAction::save(this, TQT_SLOT(fileSave()), actionCollection());
-   action = KStdAction::saveAs(this, TQT_SLOT(fileSaveAs()), actionCollection());
-   action = new KAction(i18n("Save Sp&ecial..."), 0, this, TQT_SLOT(fileSaveSpecial()),
+   action = KStdAction::revert(TQT_TQOBJECT(m_view),TQT_SLOT(revertToSaved()),actionCollection());
+   action=KStdAction::save(TQT_TQOBJECT(this), TQT_SLOT(fileSave()), actionCollection());
+   action = KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(fileSaveAs()), actionCollection());
+   action = new KAction(i18n("Save Sp&ecial..."), 0, TQT_TQOBJECT(this), TQT_SLOT(fileSaveSpecial()),
          actionCollection(), "save_special" );
-   action = new KAction(i18n("Set &Package..."), 0, m_view, TQT_SLOT(setFilePackage()),
+   action = new KAction(i18n("Set &Package..."), 0, TQT_TQOBJECT(m_view), TQT_SLOT(setFilePackage()),
          actionCollection(), "set_package" );
 
-   action = KStdAction::mail(this, TQT_SLOT(fileMail()), actionCollection());
+   action = KStdAction::mail(TQT_TQOBJECT(this), TQT_SLOT(fileMail()), actionCollection());
 
-   action = new KAction(i18n("&New View"), 0, this, TQT_SLOT(fileNewView()),
+   action = new KAction(i18n("&New View"), 0, TQT_TQOBJECT(this), TQT_SLOT(fileNewView()),
          actionCollection(), "file_new_view");
 
-   action = new KAction(i18n("New &Window"), 0, this, TQT_SLOT(fileNewWindow()),
+   action = new KAction(i18n("New &Window"), 0, TQT_TQOBJECT(this), TQT_SLOT(fileNewWindow()),
          actionCollection(), "file_new_window");
    action->setShortcut( KStdAccel::openNew() );
 
-   action = KStdAction::quit(this, TQT_SLOT(quit()), actionCollection());
+   action = KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(quit()), actionCollection());
 
 
 
    // the edit menu
-   action = KStdAction::undo(m_view, TQT_SLOT(undo()), actionCollection());
-   action = KStdAction::redo(m_view, TQT_SLOT(redo()), actionCollection());
-   action = KStdAction::cut(m_view, TQT_SIGNAL(signalCut()), actionCollection());
-   action = KStdAction::copy(m_view, TQT_SIGNAL(signalCopy()), actionCollection());
-   action = KStdAction::paste(m_view, TQT_SIGNAL(signalPaste()), actionCollection());
-   action = KStdAction::selectAll(m_view, TQT_SIGNAL(signalSelectAll()), actionCollection());
-   action = KStdAction::find(m_view, TQT_SLOT(find()), actionCollection());
-   action = KStdAction::findNext(m_view, TQT_SLOT(findNext()), actionCollection());
-   action = KStdAction::findPrev(m_view, TQT_SLOT(findPrev()), actionCollection());
-   action = KStdAction::replace(m_view, TQT_SLOT(replace()), actionCollection());
+   action = KStdAction::undo(TQT_TQOBJECT(m_view), TQT_SLOT(undo()), actionCollection());
+   action = KStdAction::redo(TQT_TQOBJECT(m_view), TQT_SLOT(redo()), actionCollection());
+   action = KStdAction::cut(TQT_TQOBJECT(m_view), TQT_SIGNAL(signalCut()), actionCollection());
+   action = KStdAction::copy(TQT_TQOBJECT(m_view), TQT_SIGNAL(signalCopy()), actionCollection());
+   action = KStdAction::paste(TQT_TQOBJECT(m_view), TQT_SIGNAL(signalPaste()), actionCollection());
+   action = KStdAction::selectAll(TQT_TQOBJECT(m_view), TQT_SIGNAL(signalSelectAll()), actionCollection());
+   action = KStdAction::find(TQT_TQOBJECT(m_view), TQT_SLOT(find()), actionCollection());
+   action = KStdAction::findNext(TQT_TQOBJECT(m_view), TQT_SLOT(findNext()), actionCollection());
+   action = KStdAction::findPrev(TQT_TQOBJECT(m_view), TQT_SLOT(findPrev()), actionCollection());
+   action = KStdAction::replace(TQT_TQOBJECT(m_view), TQT_SLOT(replace()), actionCollection());
 
-   action = KStdAction::clear( m_view, TQT_SLOT(clear()), actionCollection(), "clear" );
+   action = KStdAction::clear( TQT_TQOBJECT(m_view), TQT_SLOT(clear()), actionCollection(), "clear" );
 
-   action = new KAction(i18n("Cop&y Msgid to Msgstr"), "msgid2msgstr", CTRL+Key_Space, m_view
+   action = new KAction(i18n("Cop&y Msgid to Msgstr"), "msgid2msgstr", CTRL+Key_Space, TQT_TQOBJECT(m_view)
                  ,TQT_SLOT(msgid2msgstr()), actionCollection(), "msgid2msgstr");
    action = new KAction(i18n("Copy Searc&h Result to Msgstr"), "search2msgstr",
-                        CTRL+ALT+Key_Space, m_view, TQT_SLOT(search2msgstr()),
+                        CTRL+ALT+Key_Space, TQT_TQOBJECT(m_view), TQT_SLOT(search2msgstr()),
                         actionCollection(), "search2msgstr");
-   action = new KAction(i18n("Copy Msgstr to Other &Plurals"), Key_F11, m_view
+   action = new KAction(i18n("Copy Msgstr to Other &Plurals"), Key_F11, TQT_TQOBJECT(m_view)
                    ,TQT_SLOT(plural2msgstr()), actionCollection(), "plural2msgstr");
-   action = new KAction(i18n("Copy Selected Character to Msgstr"), Key_F10, m_charselectorview
+   action = new KAction(i18n("Copy Selected Character to Msgstr"), Key_F10, TQT_TQOBJECT(m_charselectorview)
                    ,TQT_SLOT(emitChar()), actionCollection(), "char2msgstr");
 
-   a_unsetFuzzy = new KAction(i18n("To&ggle Fuzzy Status"), "togglefuzzy", CTRL+Key_U, m_view
-                 , TQT_SLOT(removeFuzzyStatus()), actionCollection(), "edit_toggle_fuzzy");
-   action = new KAction(i18n("&Edit Header..."), 0, m_view, TQT_SLOT(editHeader()),
+   a_unsetFuzzy = new KAction(i18n("To&ggle Fuzzy Status"), "togglefuzzy", CTRL+Key_U, TQT_TQOBJECT(m_view)
+                 , TQT_SLOT(removeFuzzytqStatus()), actionCollection(), "edit_toggle_fuzzy");
+   action = new KAction(i18n("&Edit Header..."), 0, TQT_TQOBJECT(m_view), TQT_SLOT(editHeader()),
          actionCollection(), "edit_edit_header");
 
    action = new KAction(i18n("&Insert Next Tag"), "insert_tag", CTRL+ALT+Key_N
-           , m_view, TQT_SLOT(insertNextTag())
+           , TQT_TQOBJECT(m_view), TQT_SLOT(insertNextTag())
            , actionCollection(),"insert_next_tag");
    connect(m_view,TQT_SIGNAL(signalNextTagAvailable(bool)),action
            ,TQT_SLOT(setEnabled(bool)));
    action = new KAction(i18n("Insert Next Tag From Msgid P&osition"), "insert_tag", CTRL+Key_M
-           , m_view, TQT_SLOT(insertNextTagMsgid())
+           , TQT_TQOBJECT(m_view), TQT_SLOT(insertNextTagMsgid())
            , actionCollection(),"insert_next_tag_msgid");
    connect(m_view,TQT_SIGNAL(signalNextTagAvailable(bool)),action
            ,TQT_SLOT(setEnabled(bool)));
@@ -477,22 +477,22 @@ void KBabelMW::setupActions()
    connect(actionMenu,TQT_SIGNAL(activated()),m_view,TQT_SLOT(insertNextTag()));
 
    action = new KAction(i18n("Show Tags Menu"),CTRL+Key_Less
-           , m_view, TQT_SLOT(showTagsMenu()), actionCollection(),"show_tags_menu");
+           , TQT_TQOBJECT(m_view), TQT_SLOT(showTagsMenu()), actionCollection(),"show_tags_menu");
    action->setEnabled(false);
 
    connect(m_view,TQT_SIGNAL(signalTagsAvailable(bool)),action
            ,TQT_SLOT(setEnabled(bool)));
 
    action = new KAction(i18n("Move to Next Tag"), 0, CTRL+ALT+Key_M
-           , m_view, TQT_SLOT(skipToNextTag())
+           , TQT_TQOBJECT(m_view), TQT_SLOT(skipToNextTag())
            , actionCollection(),"move_to_next_tag");
 
    action = new KAction(i18n("Move to Previous Tag"), 0, CTRL+ALT+Key_B
-           , m_view, TQT_SLOT(skipToPreviousTag())
+           , TQT_TQOBJECT(m_view), TQT_SLOT(skipToPreviousTag())
            , actionCollection(),"move_to_prev_tag");
 
    action = new KAction(i18n("Insert Next Argument"), "insert_arg", CTRL+ALT+Key_G
-           , m_view, TQT_SLOT(insertNextArg())
+           , TQT_TQOBJECT(m_view), TQT_SLOT(insertNextArg())
            , actionCollection(),"insert_next_arg");
    connect(m_view,TQT_SIGNAL(signalNextArgAvailable(bool)),action
            ,TQT_SLOT(setEnabled(bool)));
@@ -504,7 +504,7 @@ void KBabelMW::setupActions()
    connect(actionMenu,TQT_SIGNAL(activated()),m_view,TQT_SLOT(insertNextArg()));
 
    action = new KAction(i18n("Show Arguments Menu"),CTRL+Key_Percent
-           , m_view, TQT_SLOT(showArgsMenu()), actionCollection(),"show_args_menu");
+           , TQT_TQOBJECT(m_view), TQT_SLOT(showArgsMenu()), actionCollection(),"show_args_menu");
    action->setEnabled(false);
 
    connect(m_view,TQT_SIGNAL(signalArgsAvailable(bool)),action
@@ -512,181 +512,181 @@ void KBabelMW::setupActions()
 
     // next, the go-menu
     action = new KAction(i18n("&Previous"), "previous",
-                 KStdAccel::shortcut(KStdAccel::Prior), m_view , TQT_SLOT(gotoPrev()),
+                 KStdAccel::shortcut(KStdAccel::Prior), TQT_TQOBJECT(m_view) , TQT_SLOT(gotoPrev()),
                  actionCollection(),"go_prev_entry");
    action = new KAction(i18n("&Next"), "next",
-                 KStdAccel::shortcut(KStdAccel::Next), m_view , TQT_SLOT(gotoNext()),
+                 KStdAccel::shortcut(KStdAccel::Next), TQT_TQOBJECT(m_view) , TQT_SLOT(gotoNext()),
                  actionCollection(),"go_next_entry");
-   action = KStdAction::goTo(m_view, TQT_SLOT(gotoEntry()), actionCollection());
+   action = KStdAction::goTo(TQT_TQOBJECT(m_view), TQT_SLOT(gotoEntry()), actionCollection());
    action->setShortcut( KStdAccel::gotoLine());
-   action = KStdAction::firstPage(m_view, TQT_SLOT(gotoFirst()),actionCollection());
+   action = KStdAction::firstPage(TQT_TQOBJECT(m_view), TQT_SLOT(gotoFirst()),actionCollection());
    action->setText(i18n("&First Entry"));
    action->setShortcut(CTRL+ALT+Key_Home);
-   action = KStdAction::lastPage(m_view, TQT_SLOT(gotoLast()),actionCollection());
+   action = KStdAction::lastPage(TQT_TQOBJECT(m_view), TQT_SLOT(gotoLast()),actionCollection());
    action->setText(i18n("&Last Entry"));
    action->setShortcut(CTRL+ALT+Key_End);
    a_prevFoU = new KAction(i18n("P&revious Fuzzy or Untranslated"),"prevfuzzyuntrans",
-         CTRL+SHIFT+Key_Prior, m_view,
+         CTRL+SHIFT+Key_Prior, TQT_TQOBJECT(m_view),
          TQT_SLOT(gotoPrevFuzzyOrUntrans()),actionCollection(), "go_prev_fuzzyUntr");
    a_nextFoU = new KAction(i18n("N&ext Fuzzy or Untranslated"),"nextfuzzyuntrans",
-         CTRL+SHIFT+Key_Next, m_view,
+         CTRL+SHIFT+Key_Next, TQT_TQOBJECT(m_view),
          TQT_SLOT(gotoNextFuzzyOrUntrans()),actionCollection(), "go_next_fuzzyUntr");
    a_prevFuzzy = new KAction(i18n("Pre&vious Fuzzy"),"prevfuzzy",
-         CTRL+Key_Prior, m_view,
+         CTRL+Key_Prior, TQT_TQOBJECT(m_view),
          TQT_SLOT(gotoPrevFuzzy()),actionCollection(), "go_prev_fuzzy");
    a_nextFuzzy = new KAction(i18n("Ne&xt Fuzzy"), "nextfuzzy",
-         CTRL+Key_Next, m_view,
+         CTRL+Key_Next, TQT_TQOBJECT(m_view),
          TQT_SLOT(gotoNextFuzzy()),actionCollection(), "go_next_fuzzy");
    a_prevUntrans = new KAction(i18n("Prev&ious Untranslated"), "prevuntranslated",
-         ALT+Key_Prior, m_view,
+         ALT+Key_Prior, TQT_TQOBJECT(m_view),
          TQT_SLOT(gotoPrevUntranslated()),actionCollection(), "go_prev_untrans");
    a_nextUntrans = new KAction(i18n("Nex&t Untranslated"), "nextuntranslated",
-         ALT+Key_Next, m_view,
+         ALT+Key_Next, TQT_TQOBJECT(m_view),
          TQT_SLOT(gotoNextUntranslated()),actionCollection(), "go_next_untrans");
    action = new KAction(i18n("Previo&us Error"), "preverror",
-          SHIFT+Key_Prior, m_view,
+          SHIFT+Key_Prior, TQT_TQOBJECT(m_view),
          TQT_SLOT(gotoPrevError()),actionCollection(), "go_prev_error");
    action = new KAction(i18n("Next Err&or"), "nexterror",
-         SHIFT+Key_Next, m_view,
+         SHIFT+Key_Next, TQT_TQOBJECT(m_view),
          TQT_SLOT(gotoNextError()),actionCollection(), "go_next_error");
-   action = new KAction(i18n("&Back in History"), "back", ALT+Key_Left, m_view,
+   action = new KAction(i18n("&Back in History"), "back", ALT+Key_Left, TQT_TQOBJECT(m_view),
          TQT_SLOT(backHistory()),actionCollection(), "go_back_history");
-   action = new KAction(i18n("For&ward in History"), "forward", ALT+Key_Right, m_view,
+   action = new KAction(i18n("For&ward in History"), "forward", ALT+Key_Right, TQT_TQOBJECT(m_view),
          TQT_SLOT(forwardHistory()),actionCollection(), "go_forward_history");
 
     // the search menu
    actionMenu=new KActionMenu(i18n("&Find Text"),
          "transsearch",actionCollection(),"dict_search_all");
    connect(actionMenu,TQT_SIGNAL(activated()),m_view,TQT_SLOT(startSearch()));
-   dictMenu = new DictionaryMenu(actionMenu->popupMenu(),actionCollection(),this);
-   connect(dictMenu,TQT_SIGNAL(activated(const TQString)), m_view
+   dictMenu = new DictionaryMenu(actionMenu->popupMenu(),actionCollection(),TQT_TQOBJECT(this));
+   connect(dictMenu,TQT_SIGNAL(activated(const TQString)), TQT_TQOBJECT(m_view)
            , TQT_SLOT(startSearch(const TQString)));
 
    actionMenu=new KActionMenu(i18n("F&ind Selected Text"),
          "transsearch",actionCollection(),"dict_search_selected");
    connect(actionMenu,TQT_SIGNAL(activated()),m_view,TQT_SLOT(startSelectionSearch()));
-   selectionDictMenu = new DictionaryMenu(actionMenu->popupMenu(),actionCollection(),this);
-   connect(selectionDictMenu,TQT_SIGNAL(activated(const TQString)), m_view
+   selectionDictMenu = new DictionaryMenu(actionMenu->popupMenu(),actionCollection(),TQT_TQOBJECT(this));
+   connect(selectionDictMenu,TQT_SIGNAL(activated(const TQString)), TQT_TQOBJECT(m_view)
            , TQT_SLOT(startSelectionSearch(const TQString)));
 
    actionMenu=new KActionMenu(i18n("&Edit Dictionary"),
          "transsearch",actionCollection(),"dict_edit");
-   editDictMenu = new DictionaryMenu(actionMenu->popupMenu(),actionCollection(),this);
-   connect(editDictMenu,TQT_SIGNAL(activated(const TQString)), m_view
+   editDictMenu = new DictionaryMenu(actionMenu->popupMenu(),actionCollection(),TQT_TQOBJECT(this));
+   connect(editDictMenu,TQT_SIGNAL(activated(const TQString)), TQT_TQOBJECT(m_view)
            , TQT_SLOT(editDictionary(const TQString)));
 
 
    actionMenu=new KActionMenu(i18n("Con&figure Dictionary"),
          "transsearch",actionCollection(),"dict_configure");
-   configDictMenu = new DictionaryMenu(actionMenu->popupMenu(),actionCollection(),this);
-   connect(configDictMenu,TQT_SIGNAL(activated(const TQString)), m_view
+   configDictMenu = new DictionaryMenu(actionMenu->popupMenu(),actionCollection(),TQT_TQOBJECT(this));
+   connect(configDictMenu,TQT_SIGNAL(activated(const TQString)), TQT_TQOBJECT(m_view)
            , TQT_SLOT(configureDictionary(const TQString)));
 
    actionMenu=new KActionMenu(i18n("About Dictionary"), "transsearch",
          actionCollection(), "dict_about");
-   aboutDictMenu = new DictionaryMenu(actionMenu->popupMenu(),actionCollection(),this);
-   connect(aboutDictMenu,TQT_SIGNAL(activated(const TQString)), m_view
+   aboutDictMenu = new DictionaryMenu(actionMenu->popupMenu(),actionCollection(),TQT_TQOBJECT(this));
+   connect(aboutDictMenu,TQT_SIGNAL(activated(const TQString)), TQT_TQOBJECT(m_view)
            , TQT_SLOT(aboutDictionary(const TQString)));
 
    buildDictMenus();
 
     // the project menu
    action = new KAction(i18n("&New..."), "filenew"
-           , this, TQT_SLOT(projectNew()),actionCollection()
+           , TQT_TQOBJECT(this), TQT_SLOT(projectNew()),actionCollection()
            ,"project_new");
 
    action = new KAction(i18n("&Open..."), "fileopen"
-           , this, TQT_SLOT(projectOpen()),actionCollection()
+           , TQT_TQOBJECT(this), TQT_SLOT(projectOpen()),actionCollection()
            ,"project_open");
 
    action = new KAction(i18n("C&lose"), "fileclose"
-           , this, TQT_SLOT(projectClose()),actionCollection()
+           , TQT_TQOBJECT(this), TQT_SLOT(projectClose()),actionCollection()
            ,"project_close");
    action->setEnabled (_project->filename() != KBabel::ProjectManager::defaultProjectName() );
 
    action = new KAction(i18n("&Configure..."), "configure"
-           , this, TQT_SLOT(projectConfigure()),actionCollection()
+           , TQT_TQOBJECT(this), TQT_SLOT(projectConfigure()),actionCollection()
            ,"project_settings");
 
-   a_recentprojects = new KRecentFilesAction(i18n("Open &Recent"), 0, this, TQT_SLOT(projectOpenRecent(const KURL&)), actionCollection(), "recent_projects");
+   a_recentprojects = new KRecentFilesAction(i18n("Open &Recent"), 0, TQT_TQOBJECT(this), TQT_SLOT(projectOpenRecent(const KURL&)), actionCollection(), "recent_projects");
 
     // the tools menu
    action = new KAction(i18n("&Spell Check..."), "spellcheck", CTRL+Key_I
-           , m_view, TQT_SLOT(spellcheckCommon()),actionCollection()
+           , TQT_TQOBJECT(m_view), TQT_SLOT(spellcheckCommon()),actionCollection()
            ,"spellcheck_common");
    action = new KAction(i18n("&Check All..."), "spellcheck_all", 0
-           , m_view, TQT_SLOT(spellcheckAll()),actionCollection()
+           , TQT_TQOBJECT(m_view), TQT_SLOT(spellcheckAll()),actionCollection()
            ,"spellcheck_all");
    action = new KAction(i18n("C&heck From Cursor Position..."), "spellcheck_from_cursor", 0
-           , m_view, TQT_SLOT(spellcheckFromCursor()),actionCollection()
+           , TQT_TQOBJECT(m_view), TQT_SLOT(spellcheckFromCursor()),actionCollection()
            ,"spellcheck_from_cursor");
    action = new KAction(i18n("Ch&eck Current..."), "spellcheck_actual", 0
-           , m_view, TQT_SLOT(spellcheckCurrent()),actionCollection()
+           , TQT_TQOBJECT(m_view), TQT_SLOT(spellcheckCurrent()),actionCollection()
            ,"spellcheck_current");
    action = new KAction(i18n("Check Fro&m Current to End of File..."), 0
-           , m_view, TQT_SLOT(spellcheckFromCurrent()),actionCollection()
+           , TQT_TQOBJECT(m_view), TQT_SLOT(spellcheckFromCurrent()),actionCollection()
            ,"spellcheck_from_current");
    action = new KAction(i18n("Chec&k Selected Text..."), "spellcheck_selected", 0
-           , m_view, TQT_SLOT(spellcheckMarked()),actionCollection()
+           , TQT_TQOBJECT(m_view), TQT_SLOT(spellcheckMarked()),actionCollection()
            ,"spellcheck_marked");
 
    KToggleAction *toggleAction;
 
    toggleAction = new KToggleAction(i18n("&Diffmode"), "autodiff", 0
            ,actionCollection(), "diff_toggleDiff");
-   connect(toggleAction,TQT_SIGNAL(toggled(bool)), m_view, TQT_SLOT(toggleAutoDiff(bool)));
+   connect(toggleAction,TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(m_view), TQT_SLOT(toggleAutoDiff(bool)));
    connect(m_view,TQT_SIGNAL(signalDiffEnabled(bool)), toggleAction
                , TQT_SLOT(setChecked(bool)));
    toggleAction->setChecked(m_view->autoDiffEnabled());
 
    action = new KAction(i18n("&Show Diff"), "diff", Key_F5
-           , m_view, TQT_SLOT(diff()),actionCollection()
+           , TQT_TQOBJECT(m_view), TQT_SLOT(diff()),actionCollection()
            ,"diff_diff");
    action = new KAction(i18n("S&how Original Text"), "contents", Key_F6
-           , m_view, TQT_SLOT(diffShowOrig()),actionCollection()
+           , TQT_TQOBJECT(m_view), TQT_SLOT(diffShowOrig()),actionCollection()
            ,"diff_showOrig");
 
    action = new KAction(i18n("&Open File for Diff"), "fileopen" ,0
-           , m_view, TQT_SLOT(openDiffFile()),actionCollection()
+           , TQT_TQOBJECT(m_view), TQT_SLOT(openDiffFile()),actionCollection()
            ,"diff_openFile");
 
    action = new KAction(i18n("&Rough Translation..."), 0
-           , m_view, TQT_SLOT(roughTranslation()),actionCollection()
+           , TQT_TQOBJECT(m_view), TQT_SLOT(roughTranslation()),actionCollection()
            ,"rough_translation");
 
-   action = new KAction(i18n("&Catalog Manager..."),"catalogmanager", 0 , this,
+   action = new KAction(i18n("&Catalog Manager..."),"catalogmanager", 0 , TQT_TQOBJECT(this),
          TQT_SLOT(openCatalogManager()),actionCollection(), "open_catalog_manager");
 
-   new KAction( i18n("Toggle Edit Mode"), 0, Key_Insert,this,TQT_SLOT(toggleEditMode()), actionCollection(), "toggle_insert_mode");
+   new KAction( i18n("Toggle Edit Mode"), 0, Key_Insert,TQT_TQOBJECT(this),TQT_SLOT(toggleEditMode()), actionCollection(), "toggle_insert_mode");
    
-   new KAction( i18n("&Word Count"), 0, m_view, TQT_SLOT(wordCount()), actionCollection(), "word_count");   
+   new KAction( i18n("&Word Count"), 0, TQT_TQOBJECT(m_view), TQT_SLOT(wordCount()), actionCollection(), "word_count");   
 
     // next, the settings menu
     createStandardStatusBarAction();
 
-    KStdAction::configureToolbars(this,TQT_SLOT(optionsEditToolbars()),actionCollection());
+    KStdAction::configureToolbars(TQT_TQOBJECT(this),TQT_SLOT(optionsEditToolbars()),actionCollection());
 
     KStdAction::keyBindings(guiFactory(),TQT_SLOT(configureShortcuts()),actionCollection());
-    KStdAction::preferences(this,TQT_SLOT(optionsPreferences()),actionCollection());
+    KStdAction::preferences(TQT_TQOBJECT(this),TQT_SLOT(optionsPreferences()),actionCollection());
 
     setStandardToolBarMenuEnabled ( true );
 
-   action = new KAction(i18n("&Stop Searching"), "stop",Key_Escape, m_view,
+   action = new KAction(i18n("&Stop Searching"), "stop",Key_Escape, TQT_TQOBJECT(m_view),
          TQT_SLOT(stopSearch()),actionCollection(), "stop_search");
    action->setEnabled(false);
 
-   new KAction(i18n("&Gettext Info"), 0, this,
+   new KAction(i18n("&Gettext Info"), 0, TQT_TQOBJECT(this),
            TQT_SLOT(gettextHelp()), actionCollection(), "help_gettext");
 
 
    // the bookmarks menu
 
-   action = KStdAction::addBookmark(this, TQT_SLOT(slotAddBookmark()),
+   action = KStdAction::addBookmark(TQT_TQOBJECT(this), TQT_SLOT(slotAddBookmark()),
       actionCollection(), "add_bookmark");
    action->setEnabled(false);
    // this action is now connected to dummySlot(), and later reconnected
    // to bmHandler after that object actually is created
-   new KAction(i18n("Clear Bookmarks"), 0, this, TQT_SLOT(dummySlot()),
+   new KAction(i18n("Clear Bookmarks"), 0, TQT_TQOBJECT(this), TQT_SLOT(dummySlot()),
       actionCollection(), "clear_bookmarks");
 
    setupDynamicActions();
@@ -724,7 +724,7 @@ void KBabelMW::setupStatusBar()
        _errorLed->setFixedSize(15,12);
        new TQLabel(i18n("faulty")+" ",statusBox);
 
-       statusBox->setFixedWidth(statusBox->sizeHint().width());
+       statusBox->setFixedWidth(statusBox->tqsizeHint().width());
        statusBar()->addWidget(statusBox);
     }
 
@@ -732,7 +732,7 @@ void KBabelMW::setupStatusBar()
 
     statusBar()->insertItem(i18n("RW"),ID_STATUS_READONLY);
 
-    statusBar()->insertItem(i18n("Line: %1 Col: %2").arg(1).arg(1)
+    statusBar()->insertItem(i18n("Line: %1 Col: %2").tqarg(1).tqarg(1)
             ,ID_STATUS_CURSOR);
 
     TQHBox* progressBox = new TQHBox(statusBar(),"progressBox");
@@ -743,7 +743,7 @@ void KBabelMW::setupStatusBar()
     progressBox->setStretchFactor(_progressBar,1);
 
     statusBar()->addWidget(progressBox,1);
-    statusBar()->setMinimumHeight(progressBox->sizeHint().height());
+    statusBar()->setMinimumHeight(progressBox->tqsizeHint().height());
 
     TQWhatsThis::add(statusBar(),
        i18n("<qt><p><b>Statusbar</b></p>\n\
@@ -759,19 +759,19 @@ void KBabelMW::setupDynamicActions()
    TQValueList<KDataToolInfo> tools = ToolAction::validationTools();
 
    TQPtrList<KAction> actions = ToolAction::dataToolActionList(
-      tools, m_view, TQT_SLOT(validateUsingTool( const KDataToolInfo &, const TQString & )),
+      tools, TQT_TQOBJECT(m_view), TQT_SLOT(validateUsingTool( const KDataToolInfo &, const TQString & )),
       "validate", false, actionCollection() );
 
    KActionMenu* m_menu = new KActionMenu(i18n("&Validation"), actionCollection(), "dynamic_validation_tools");
 
-   KAction* ac = new KAction(i18n("Perform &All Checks"), CTRL+Key_E , m_view,
+   KAction* ac = new KAction(i18n("Perform &All Checks"), CTRL+Key_E , TQT_TQOBJECT(m_view),
          TQT_SLOT(checkAll()),actionCollection(), "check_all");
    ac->setEnabled(false);
    m_menu->insert(ac);
 
    m_menu->insert( new KActionSeparator() );
 
-   ac = new KAction(i18n("C&heck Syntax"), CTRL+Key_T , m_view,
+   ac = new KAction(i18n("C&heck Syntax"), CTRL+Key_T , TQT_TQOBJECT(m_view),
          TQT_SLOT(checkSyntax()),actionCollection(), "check_syntax");
    ac->setEnabled(false);
    m_menu->insert(ac);
@@ -801,7 +801,7 @@ void KBabelMW::setupDynamicActions()
 
    // create corresponding actions
    actions = ToolAction::dataToolActionList(
-      modifyTools, m_view, TQT_SLOT(modifyUsingTool( const KDataToolInfo &, const TQString & )),
+      modifyTools, TQT_TQOBJECT(m_view), TQT_SLOT(modifyUsingTool( const KDataToolInfo &, const TQString & )),
       "validate", true, actionCollection() );
 
    // skip validation actions
@@ -833,7 +833,7 @@ void KBabelMW::setupDynamicActions()
 
    // create corresponding actions
    actions = ToolAction::dataToolActionList(
-      modifyTools, m_view, TQT_SLOT(modifyUsingTool( const KDataToolInfo &, const TQString & )),
+      modifyTools, TQT_TQOBJECT(m_view), TQT_SLOT(modifyUsingTool( const KDataToolInfo &, const TQString & )),
       "validate", true, actionCollection() );
 
    // skip validation actions
@@ -844,7 +844,7 @@ void KBabelMW::setupDynamicActions()
 
    // create corresponding actions
    actions = ToolAction::dataToolActionList(
-      modifyTools, m_view, TQT_SLOT(modifyCatalogUsingTool( const KDataToolInfo &, const TQString & )),
+      modifyTools, TQT_TQOBJECT(m_view), TQT_SLOT(modifyCatalogUsingTool( const KDataToolInfo &, const TQString & )),
       "validate", true, actionCollection() );
 
    // insert tools
@@ -923,7 +923,7 @@ bool KBabelMW::queryClose()
 {
    if(m_view->isSearching())
    {
-       connect(m_view,TQT_SIGNAL(signalSearchActive(bool)),this,TQT_SLOT(quit()));
+       connect(m_view,TQT_SIGNAL(signalSearchActive(bool)),TQT_TQOBJECT(this),TQT_SLOT(quit()));
        m_view->stopSearch();
        return false;
    }
@@ -932,7 +932,7 @@ bool KBabelMW::queryClose()
    {
        // stop the activity and try again
        m_view->catalog()->stop();
-       TQTimer::singleShot(0, this, TQT_SLOT( close() ));
+       TQTimer::singleShot(0, TQT_TQOBJECT(this), TQT_SLOT( close() ));
        return false;
    }
 
@@ -996,10 +996,10 @@ void KBabelMW::wheelEvent(TQWheelEvent *e)
 
 void KBabelMW::openRecent(const KURL& url)
 {
-   KBabelView *view = KBabelView::viewForURL(url,TQString::null);
+   KBabelView *view = KBabelView::viewForURL(url,TQString());
    if(view)
    {
-       KWin::activateWindow(view->topLevelWidget()->winId());
+       KWin::activateWindow(view->tqtopLevelWidget()->winId());
        return;
    }
 
@@ -1008,7 +1008,7 @@ void KBabelMW::openRecent(const KURL& url)
 
 void KBabelMW::open(const KURL& url)
 {
-   open(url,TQString::null,false);
+   open(url,TQString(),false);
 }
 
 void KBabelMW::open(const KURL& url, const TQString package, bool newWindow)
@@ -1019,7 +1019,7 @@ void KBabelMW::open(const KURL& url, const TQString package, bool newWindow)
    if(view)
    {
         kdDebug(KBABEL) << "there is a such view" << endl;
-       KWin::activateWindow(view->topLevelWidget()->winId());
+       KWin::activateWindow(view->tqtopLevelWidget()->winId());
        return;
    }
 
@@ -1067,7 +1067,7 @@ void KBabelMW::addToRecentFiles(KURL url)
 void KBabelMW::fileSave()
 {
     // do it asynchronously due to kdelibs bug
-    TQTimer::singleShot( 0, this, TQT_SLOT( fileSave_internal() ));
+    TQTimer::singleShot( 0, TQT_TQOBJECT(this), TQT_SLOT( fileSave_internal() ));
 }
 
 void KBabelMW::fileSave_internal()
@@ -1181,7 +1181,7 @@ void KBabelMW::optionsEditToolbars()
 {
    saveMainWindowSettings( KGlobal::config(), "View" );
    KEditToolbar dlg(actionCollection());
-   connect(&dlg, TQT_SIGNAL(newToolbarConfig()), this, TQT_SLOT(newToolbarConfig()));
+   connect(&dlg, TQT_SIGNAL(newToolbarConfig()), TQT_TQOBJECT(this), TQT_SLOT(newToolbarConfig()));
    dlg.exec();
 }
 
@@ -1361,23 +1361,23 @@ void KBabelMW::faultyDisplayed(bool flag)
 
 void KBabelMW::displayedEntryChanged(const KBabel::DocPosition& pos)
 {
-   statusBar()->changeItem(i18n("Current: %1").arg(pos.item+1),ID_STATUS_CURRENT);
+   statusBar()->changeItem(i18n("Current: %1").tqarg(pos.item+1),ID_STATUS_CURRENT);
   _currentIndex = pos.item;
 }
 
 void KBabelMW::setNumberOfTotal(uint number)
 {
-   statusBar()->changeItem(i18n("Total: %1").arg(number),ID_STATUS_TOTAL);
+   statusBar()->changeItem(i18n("Total: %1").tqarg(number),ID_STATUS_TOTAL);
 }
 
 void KBabelMW::setNumberOfFuzzies(uint number)
 {
-   statusBar()->changeItem(i18n("Fuzzy: %1").arg(number),ID_STATUS_FUZZY);
+   statusBar()->changeItem(i18n("Fuzzy: %1").tqarg(number),ID_STATUS_FUZZY);
 }
 
 void KBabelMW::setNumberOfUntranslated(uint number)
 {
-   statusBar()->changeItem(i18n("Untranslated: %1").arg(number),ID_STATUS_UNTRANS);
+   statusBar()->changeItem(i18n("Untranslated: %1").tqarg(number),ID_STATUS_UNTRANS);
 }
 
 void KBabelMW::hasFuzzyAfterwards(bool flag)
@@ -1566,7 +1566,7 @@ void KBabelMW::gettextHelp()
     if(!error.isEmpty())
     {
         KMessageBox::sorry(this,i18n("An error occurred while "
-                "trying to open the gettext info page:\n%1").arg(error));
+                "trying to open the gettext info page:\n%1").tqarg(error));
     }
 }
 
@@ -1602,7 +1602,7 @@ void KBabelMW::buildDictMenus()
 
 void KBabelMW::updateCursorPosition(int line, int col)
 {
-    statusBar()->changeItem(i18n("Line: %1 Col: %2").arg(line+1).arg(col+1)
+    statusBar()->changeItem(i18n("Line: %1 Col: %2").tqarg(line+1).tqarg(col+1)
             ,ID_STATUS_CURSOR);
 }
 
@@ -1621,7 +1621,7 @@ KBabelMW *KBabelMW::winForURL(const KURL& url, TQString project)
         }
 
         if(p)
-            kb = static_cast<KBabelMW*>(p);
+            kb = static_cast<KBabelMW*>(TQT_TQWIDGET(p));
     }
 
     return kb;
@@ -1641,7 +1641,7 @@ KBabelMW *KBabelMW::emptyWin(TQString project)
         }
 
         if(p)
-            kb = static_cast<KBabelMW*>(p);
+            kb = static_cast<KBabelMW*>(TQT_TQWIDGET(p));
     }
 
     return kb;
@@ -1651,7 +1651,7 @@ void KBabelMW::spellcheckMoreFiles(TQStringList filelist)
 {
     if( filelist.isEmpty() ) return;
     _toSpellcheck = filelist;
-    connect( m_view, TQT_SIGNAL( signalSpellcheckDone(int) ), this, TQT_SLOT( spellcheckDone(int)));
+    connect( m_view, TQT_SIGNAL( signalSpellcheckDone(int) ), TQT_TQOBJECT(this), TQT_SLOT( spellcheckDone(int)));
     spellcheckDone( KS_IGNORE ); // use something else than KS_STOP
 }
 
@@ -1659,7 +1659,7 @@ void KBabelMW::spellcheckDone( int result)
 {
     if( _toSpellcheck.isEmpty() || result == KS_STOP)
     {
-        disconnect( m_view, TQT_SIGNAL( signalSpellcheckDone(int)), this, TQT_SLOT(spellcheckDone( int)));
+        disconnect( m_view, TQT_SIGNAL( signalSpellcheckDone(int)), TQT_TQOBJECT(this), TQT_SLOT(spellcheckDone( int)));
         KMessageBox::information( this, i18n("MessageBox text", "Spellchecking of multiple files is finished."),
             i18n("MessageBox caption", "Spellcheck Done"));
     }
@@ -1668,9 +1668,9 @@ void KBabelMW::spellcheckDone( int result)
         TQString file = _toSpellcheck.first();
         _toSpellcheck.pop_front();
         if( m_view->isModified() ) fileSave();
-        open(KURL( file ), TQString::null, false);
+        open(KURL( file ), TQString(), false);
         kdDebug(KBABEL) << "Starting another spellcheck" << endl;
-        TQTimer::singleShot( 1, m_view, TQT_SLOT(spellcheckAllMulti()));
+        TQTimer::singleShot( 1, TQT_TQOBJECT(m_view), TQT_SLOT(spellcheckAllMulti()));
     }
 }
 
@@ -1710,7 +1710,7 @@ void KBabelMW::projectOpen()
     {
         oldproject = TQString();
     }
-    const TQString file = KFileDialog::getOpenFileName(oldproject, TQString::null, this);
+    const TQString file = KFileDialog::getOpenFileName(oldproject, TQString(), this);
     if (file.isEmpty())
     {
         return;
@@ -1751,7 +1751,7 @@ void KBabelMW::projectOpen(const TQString& file)
     }
     else 
     {
-	KMessageBox::error( this, i18n("Cannot open project file\n%1").arg(file)
+	KMessageBox::error( this, i18n("Cannot open project file\n%1").tqarg(file)
             , i18n("Project File Error"));
 	_project = ProjectManager::open(KBabel::ProjectManager::defaultProjectName());
 	m_view->useProject(_project);
@@ -1793,7 +1793,7 @@ void KBabelMW::projectConfigure()
     {
         _projectDialog = new ProjectDialog(_project);
 	connect (_projectDialog, TQT_SIGNAL (settingsChanged())
-	    , m_view, TQT_SLOT (updateProjectSettings()));
+	    , TQT_TQOBJECT(m_view), TQT_SLOT (updateProjectSettings()));
     }
 
     int prefHeight=_projectDialog->height();
