@@ -22,11 +22,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -93,6 +93,7 @@ class TagListView;
 class KBabelView : public TQWidget, public KBabel::CatalogView
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     /**
     * Default constructor
@@ -202,7 +203,7 @@ public slots:
 
     /** opens a filedialog and asks for an url */
     void open();
-    void open(const KURL& url, const TQString & package=TQString::null, bool checkModified=true, bool newView=false);
+    void open(const KURL& url, const TQString & package=TQString(), bool checkModified=true, bool newView=false);
     void setFilePackage();
     void revertToSaved();
 
@@ -267,7 +268,7 @@ public slots:
     void skipToTagFromTool(int index);
     void wordCount();
 
-    void removeFuzzyStatus();
+    void removeFuzzytqStatus();
     /** opens the header editor for the po-file */
     void editHeader();
 
@@ -450,7 +451,7 @@ protected slots:
 
 private slots:
    void msgstrPluralFormChanged (uint index);
-   void autoRemoveFuzzyStatus();
+   void autoRemoveFuzzytqStatus();
 
    /** connected to the catalog. it is called when a new file is opened*/
    void newFileOpened(bool readOnly);
