@@ -22,11 +22,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -537,7 +537,7 @@ void KBabelView::diffInternal(bool autoDf)
     	            KMessageBox::sorry(this
         	        ,i18n("An error occurred while trying to get the list "
                         "of messages for this file from the database:\n"
-                        "%1").arg(error));
+                        "%1").tqarg(error));
 
             	    _diffing=false;
                     _diffEnabled=false;
@@ -709,7 +709,7 @@ bool KBabelView::openDiffFile(bool autoDiff)
     connect(&cat,TQT_SIGNAL(signalProgress(int)),this,TQT_SIGNAL(signalProgress(int)));
     emit signalResetProgressBar(i18n("loading file for diff"),100);
 
-    ConversionStatus stat = cat.openURL(url);
+    ConversiontqStatus stat = cat.openURL(url);
 
     emit signalClearProgressBar();
 
@@ -722,40 +722,40 @@ bool KBabelView::openDiffFile(bool autoDiff)
             {
                 KMessageBox::sorry(this
                     ,i18n("Error while trying to read file:\n %1\n"
-                   "Maybe it is not a valid PO file.").arg(url.prettyURL()));
+                   "Maybe it is not a valid PO file.").tqarg(url.prettyURL()));
                 break;
             }
             case NO_PERMISSIONS:
             {
                 KMessageBox::sorry(this,i18n(
                 "You do not have permissions to read file:\n %1")
-                        .arg(url.prettyURL()));
+                        .tqarg(url.prettyURL()));
                 break;
             }
             case NO_FILE:
             {
                  KMessageBox::sorry(this,i18n(
                  "You have not specified a valid file:\n %1")
-                         .arg(url.prettyURL()));
+                         .tqarg(url.prettyURL()));
                 break;
             }
 	    case NO_PLUGIN:
 	    {
 	         KMessageBox::error(this,i18n(
-	              "KBabel cannot find a corresponding plugin for the MIME type of the file:\n %1").arg(url.prettyURL()));
+	              "KBabel cannot find a corresponding plugin for the MIME type of the file:\n %1").tqarg(url.prettyURL()));
 	         break;
 	    }
 	    case UNSUPPORTED_TYPE:
 	    {
 	          KMessageBox::error(this,i18n(
-	               "The import plugin cannot handle this type of the file:\n %1").arg(url.prettyURL()));
+	               "The import plugin cannot handle this type of the file:\n %1").tqarg(url.prettyURL()));
                   break;
 	    }
             default:
             {
                  KMessageBox::sorry(this,i18n(
                   "Error while trying to open file:\n %1")
-                         .arg(url.prettyURL()));
+                         .tqarg(url.prettyURL()));
                  break;
             }
 
@@ -802,8 +802,8 @@ void KBabelView::showTryLaterMessageBox()
 	         "However, the string might be found "
 		 "in the files being searched at the moment.\n"
 		 "Please try later."), contents);
-    label2->setAlignment( Qt::AlignAuto | Qt::AlignVCenter | Qt::ExpandTabs | Qt::WordBreak );
-    label2->setMinimumSize(label2->sizeHint());
+    label2->tqsetAlignment( TQt::AlignAuto | TQt::AlignVCenter | TQt::ExpandTabs | TQt::WordBreak );
+    label2->setMinimumSize(label2->tqsizeHint());
     lay->add( label2 );
     lay->addStretch(1);
 
@@ -822,7 +822,7 @@ void KBabelView::showTryLaterMessageBox()
 void KBabelView::setFilePackage()
 {
     bool result=false;
-    TQString p = KInputDialog::getText(TQString::null, i18n("Enter new package for the current file:"),_catalog->package(),&result,this);
+    TQString p = KInputDialog::getText(TQString(), i18n("Enter new package for the current file:"),_catalog->package(),&result,this);
     if( result )
     {
 	_catalog->setPackage(p);
@@ -1020,6 +1020,6 @@ void KBabelView::wordCount()
     KMessageBox::information( this
 	, i18n("Total words: %1\n\n"
 "Words in untranslated messages: %2\n\n"
-"Words in fuzzy messages: %3").arg(total).arg(untranslated).arg(fuzzy)
+"Words in fuzzy messages: %3").tqarg(total).tqarg(untranslated).tqarg(fuzzy)
 	, i18n("Word Count") );
 }
