@@ -21,11 +21,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -187,7 +187,7 @@ int KBabelApp::newInstance()
             widget->show();
             for (int i=0; i < args->count(); i++)
             {
-               widget->open( args->url(i) , TQString::null, i != 0 );
+               widget->open( args->url(i) , TQString(), i != 0 );
             }
 
 	    kdDebug () << "Resuming DCOP" << endl;
@@ -242,7 +242,7 @@ void KBabelInterface::openURL(TQCString url, TQCString package, WId window, int
     KBabelMW *kb = KBabelMW::winForURL(u,project);
     if(kb)
     {
-        KWin::activateWindow(kb->topLevelWidget()->winId());
+        KWin::activateWindow(kb->tqtopLevelWidget()->winId());
     }
     else
     {
@@ -255,7 +255,7 @@ void KBabelInterface::openURL(TQCString url, TQCString package, WId window, int
 	    if( mw->inherits("KBabelMW") && mw->winId() == window)
     	    {
         	kb = static_cast<KBabelMW*>(mw);
-        	KWin::activateWindow(kb->topLevelWidget()->winId());
+        	KWin::activateWindow(kb->tqtopLevelWidget()->winId());
         	kb->open(u, TQString::fromUtf8(package),newWindow);
 
 		kdDebug () << "Resuming DCOP" << endl;
@@ -272,7 +272,7 @@ void KBabelInterface::openURL(TQCString url, TQCString package, WId window, int
 	{
 	    // here, we don't care about "open in new window", because
 	    // it's empty
-    	    KWin::setActiveWindow(kb->topLevelWidget()->winId());
+    	    KWin::setActiveWindow(kb->tqtopLevelWidget()->winId());
 	    kb->projectOpen(projectFile);
     	    kb->open(u,TQString::fromUtf8(package),false);
 
@@ -289,7 +289,7 @@ void KBabelInterface::openURL(TQCString url, TQCString package, WId window, int
 	    if( mw->inherits("KBabelMW") && static_cast<KBabelMW*>(mw)->project()==project)
     	    {
         	kb = static_cast<KBabelMW*>(mw);
-        	KWin::activateWindow(kb->topLevelWidget()->winId());
+        	KWin::activateWindow(kb->tqtopLevelWidget()->winId());
         	kb->open(u, TQString::fromUtf8(package),newWindow);
 
 		kdDebug () << "Resuming DCOP" << endl;
@@ -305,7 +305,7 @@ void KBabelInterface::openURL(TQCString url, TQCString package, WId window, int
 	    kb = new KBabelMW(project);
     	    kb->show();
 	} else kb = static_cast<KBabelMW*>(mw);
-        KWin::activateWindow(kb->topLevelWidget()->winId());
+        KWin::activateWindow(kb->tqtopLevelWidget()->winId());
         kb->open(u,TQString::fromUtf8(package),newWindow);
     }
     
@@ -331,7 +331,7 @@ void KBabelInterface::openTemplate(TQCString openFilename, TQCString saveFilenam
     KBabelMW *kb = KBabelMW::winForURL(u, project);
     if(kb)
     {
-        KWin::activateWindow(kb->topLevelWidget()->winId());
+        KWin::activateWindow(kb->tqtopLevelWidget()->winId());
     }
     else
     {
@@ -342,7 +342,7 @@ void KBabelInterface::openTemplate(TQCString openFilename, TQCString saveFilenam
         if(mw && mw->inherits("KBabelMW") && static_cast<KBabelMW*>(mw)->project()==project)
         {
             kb = static_cast<KBabelMW*>(mw);
-            KWin::activateWindow(kb->topLevelWidget()->winId());
+            KWin::activateWindow(kb->tqtopLevelWidget()->winId());
 	    kb->projectOpen(projectFile);
             kb->openTemplate(t,u,TQString::fromUtf8(package),newWindow);
         }
@@ -350,7 +350,7 @@ void KBabelInterface::openTemplate(TQCString openFilename, TQCString saveFilenam
         {
             kb = new KBabelMW(project);
             kb->show();
-            KWin::activateWindow(kb->topLevelWidget()->winId());
+            KWin::activateWindow(kb->tqtopLevelWidget()->winId());
             kb->openTemplate(t,u,TQString::fromUtf8(package));
         }
     }
@@ -505,7 +505,7 @@ KBabelMW* KBabelInterface::findInstance( const KURL& url, const TQString& projec
 
 	if(kb)
 	{
-    	    KWin::activateWindow(kb->topLevelWidget()->winId());
+    	    KWin::activateWindow(kb->tqtopLevelWidget()->winId());
 	}
     }
 
@@ -555,7 +555,7 @@ int main(int argc, char **argv)
     about.addAuthor("Andrea Rizzi",I18N_NOOP("Wrote the dictionary plugin "
 		"for searching in a database and some other code.")
             ,"rizzi@kde.org");
-    about.addAuthor("Stanislav Visnovsky",I18N_NOOP("Current maintainer, porting to KDE3/Qt3.")
+    about.addAuthor("Stanislav Visnovsky",I18N_NOOP("Current maintainer, porting to KDE3/TQt3.")
 	,"visnovsky@kde.org");
     about.addAuthor("Marco Wegner",I18N_NOOP("Bug fixes, KFilePlugin for PO files, CVS support, mailing files")
          ,"dubbleu@web.de");
@@ -578,7 +578,7 @@ int main(int argc, char **argv)
 	about.addCredit("SuSE GmbH"
 					,I18N_NOOP("Sponsored development of KBabel for a while.")
 					,"suse@suse.de","http://www.suse.de");
-    about.addCredit("Trolltech", I18N_NOOP("KBabel contains code from Qt"), 0, "http://www.trolltech.com");
+    about.addCredit("Trolltech", I18N_NOOP("KBabel contains code from TQt"), 0, "http://www.trolltech.com");
 
     about.addCredit("Eva Brucherseifer", I18N_NOOP("String distance algorithm implementation"), "eva@kde.org");
 
