@@ -25,11 +25,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -49,7 +49,7 @@
 #include <tqclipboard.h>
 #include <tqapplication.h>
 #include <tqdragobject.h>
-//#include <private/qrichtext_p.h>
+//#include <private/tqrichtext_p.h>
 #include <tqpopupmenu.h>
 
 #include <kdebug.h>
@@ -120,7 +120,7 @@ void MyMultiLineEdit::processCommand(EditCommand* cmd, bool undo)
 
   TQPalette _visibleHighlight( palette() );
   TQPalette _invisibleHighlight( palette() );
-  TQColorGroup newcg( colorGroup() );
+  TQColorGroup newcg( tqcolorGroup() );
   newcg.setColor( TQColorGroup::HighlightedText, newcg.text() );
   newcg.setColor( TQColorGroup::Highlight, newcg.base() );
   if( hasFocus() ) _invisibleHighlight.setActive( newcg );
@@ -293,10 +293,10 @@ void MyMultiLineEdit::setText(const TQString& s)
     _lastParagraph=0;
     _lastParagraphOffset=0;
     // workaround, since insert does not interpret markup
-    setTextFormat( Qt::PlainText );
+    setTextFormat( TQt::PlainText );
     _firstChangedLine=_lastChangedLine=0;
     KTextEdit::setText(s);
-    setTextFormat( Qt::AutoText );
+    setTextFormat( TQt::AutoText );
     // now the number of lines is known, let's do highlight
     _lastChangedLine=paragraphs();
     emit textChanged();
@@ -308,7 +308,7 @@ void MyMultiLineEdit::insertAt( const TQString & s, int line, int col, bool mark
    // it will invoke insert, don't need to send InsTextCmd
    KTextEdit::insertAt(s,line,col);
    
-   // code from QMultiLineEdit
+   // code from TQMultiLineEdit
    if( mark )  
 	setSelection( line, col, line, col + s.length(), 0 );
    // end of copied code
@@ -362,7 +362,7 @@ void MyMultiLineEdit::insert( const TQString & text, bool indent, bool checkNewL
    
    TQPalette _visibleHighlight( palette() );
    TQPalette _invisibleHighlight( palette() );
-   TQColorGroup newcg( colorGroup() );
+   TQColorGroup newcg( tqcolorGroup() );
    newcg.setColor( TQColorGroup::HighlightedText, newcg.text() );
    newcg.setColor( TQColorGroup::Highlight, newcg.base() );
    if( hasFocus() ) _invisibleHighlight.setActive( newcg );
@@ -546,8 +546,8 @@ void MyMultiLineEdit::offset2Pos(int offset, int &paragraph, int &index) const
 
 int MyMultiLineEdit::pos2Offset(uint paragraph, uint index)
 {
-    paragraph = QMAX( QMIN( (int)paragraph, paragraphs() - 1), 0 ); // Sanity check
-    index  = QMAX( QMIN( (int)index,  paragraphLength( paragraph )), 0 ); // Sanity check
+    paragraph = TQMAX( TQMIN( (int)paragraph, paragraphs() - 1), 0 ); // Sanity check
+    index  = TQMAX( TQMIN( (int)index,  paragraphLength( paragraph )), 0 ); // Sanity check
 
     {
         uint lastI;
@@ -569,7 +569,7 @@ int MyMultiLineEdit::pos2Offset(uint paragraph, uint index)
 	_lastParagraphOffset=tmp;
 	_lastParagraph=paragraph;
 
-	tmp += QMIN( lastI, index );
+	tmp += TQMIN( lastI, index );
 
 	return tmp;
     }
@@ -598,21 +598,21 @@ MsgMultiLineEdit::MsgMultiLineEdit(int ID, KSpell* spell, TQWidget* parent,const
                 _cleverEditing(false),
                 _highlightBg(false),
                 _spacePoints(false),
-                _bgColor(colorGroup().base().dark(110)),
+                _bgColor(tqcolorGroup().base().dark(110)),
 		_textColor(KGlobalSettings::textColor()),
-		_errorColor(Qt::red),
+		_errorColor(TQt::red),
 		_currentColor(KGlobalSettings::textColor()),
 		_whitespace(0),
                 _hlSyntax(true),
-                _quoteColor(Qt::darkGreen),
-                _unquoteColor(Qt::red),
-                _cformatColor(Qt::blue),
-                _accelColor(Qt::darkMagenta),
+                _quoteColor(TQt::darkGreen),
+                _unquoteColor(TQt::red),
+                _cformatColor(TQt::blue),
+                _accelColor(TQt::darkMagenta),
                 _showDiff(false),
                 _diffUnderlineAdd(true),
                 _diffStrikeOutDel(true),
-                _diffAddColor(Qt::darkGreen),
-                _diffDelColor(Qt::darkRed),
+                _diffAddColor(TQt::darkGreen),
+                _diffDelColor(TQt::darkRed),
 		_currentUnicodeNumber(0),
 		highlighter(0),
 		_tagStartPara(0), _tagStartIndex(0), _tagEndPara(0), _tagEndIndex(0)
@@ -882,10 +882,10 @@ void MsgMultiLineEdit::setFont(const TQFont& font)
    // we don't need to calculate a special offset for non-breaking space, since
    // they are very similar in size
    TQFontMetrics fm(font);
-   _wsOffsetX = QMAX(fm.width(' ')/2-2,1);
-   _wsOffsetY = QMAX(fm.height()/2-1,0);
+   _wsOffsetX = TQMAX(fm.width(' ')/2-2,1);
+   _wsOffsetY = TQMAX(fm.height()/2-1,0);
    
-   repaint();
+   tqrepaint();
 }
 
 void MsgMultiLineEdit::setDiffDisplayMode(bool addUnderline, bool delStrikeOut)
@@ -910,7 +910,7 @@ void MsgMultiLineEdit::setDiffColors(const TQColor& addColor
 void MsgMultiLineEdit::setTextColor(const TQColor &color )
 {
   TQPalette p( palette() );
-  TQColorGroup newcg( colorGroup() );
+  TQColorGroup newcg( tqcolorGroup() );
   newcg.setColor( TQColorGroup::Text, color );
   if( hasFocus() ) p.setActive( newcg );
   else p.setInactive( newcg );
@@ -992,11 +992,11 @@ void MsgMultiLineEdit::paintSpacePoints()
             int i = s.find( " " );
             while( (i >= 0) && (i < (int)s.length()-1) ) // -1 because text will end by EOLN
             {
-                TQPixmap* pm = ( s.at(i).unicode() == 0x00A0U ) ? wsnb : ws;
+                TQPixmap* pm = ( s.tqat(i).tqunicode() == 0x00A0U ) ? wsnb : ws;
                 TQRect r = mapToView( curpara, i );
                 r.moveBy( r.width()/2, (r.height() - fm.descent())/2 );
                 r.moveBy( -pm->rect().width()/2, -pm->rect().height()/2-1 );
-                bitBlt(viewport(), r.topLeft(), pm, pm->rect(), Qt::CopyROP);
+                bitBlt(viewport(), r.topLeft(), pm, pm->rect(), TQt::CopyROP);
                 i = s.find( " ", i+1 );
             }
             ++curpara;
@@ -1015,7 +1015,7 @@ void MsgMultiLineEdit::paintSpacePoints()
 
             painter.drawText( TQPoint( 0, mapToView( curpara, 0 ).top()) +
                     TQPoint(0, qs.height() + 4), "\""); // 4 = hardcoded margin in QT
-            painter.drawText( mapToView( curpara, QMAX( 0,
+            painter.drawText( mapToView( curpara, TQMAX( 0,
                 ((int)text( curpara ).length())-1)).topRight() +
                 TQPoint(0, qs.height() + 4), "\"");  // 4 = hardcoded margin in QT
         }
@@ -1025,7 +1025,7 @@ void MsgMultiLineEdit::paintSpacePoints()
     {
         if( paragraphs() == (int)diffPos.size() ) // sanity check
         {
-            painter.setRasterOp( Qt::AndROP );
+            painter.setRasterOp( TQt::AndROP );
             for( int curpara = paranum; curpara < paragraphs() ; curpara++ )
             {
                 r = paragraphRect(curpara);
@@ -1141,10 +1141,10 @@ void MsgMultiLineEdit::paintSpacePoints()
     }
 }
 
-void MsgMultiLineEdit::repaint()
+void MsgMultiLineEdit::tqrepaint()
 {
     highlight();
-    MyMultiLineEdit::repaint();
+    MyMultiLineEdit::tqrepaint();
 }
 
 void MsgMultiLineEdit::forceUpdate()
@@ -1152,7 +1152,7 @@ void MsgMultiLineEdit::forceUpdate()
     _firstChangedLine=0;
     _lastChangedLine=paragraphs()-1;
     highlighter->highlight();
-    MyMultiLineEdit::repaint();
+    MyMultiLineEdit::tqrepaint();
 }
 
 void MsgMultiLineEdit::ensureCursorVisible()
@@ -1167,7 +1167,7 @@ void MsgMultiLineEdit::highlight()
     
     TQColor bg;
     if( _highlightBg ) bg = _bgColor;
-    else bg = colorGroup().base(); 
+    else bg = tqcolorGroup().base(); 
 
     for( int i = 0 ; i < paragraphs() ; i++ )
 	    setParagraphBackgroundColor( i, bg );
@@ -1188,7 +1188,7 @@ void MsgMultiLineEdit::highlight()
 	TQRegExp markup("(\\\\)|(\")|(\\\\[abfnrtv'\"\?\\\\])|(\\\\\\d+)|(\\\\x[\\dabcdef]+)"
 	    "|(%[\\ddioxXucsfeEgGphln]+)|(&[^\\s])|(&[\\w-]+;)");
 
-	for( i = QMAX(_firstChangedLine,0) ; i < QMIN(_lastChangedLine+1,(uint)paragraphs()) ; i++ ) {
+	for( i = TQMAX(_firstChangedLine,0) ; i < TQMIN(_lastChangedLine+1,(uint)paragraphs()) ; i++ ) {
 	
 	TQString line=text(i);
 
@@ -1252,7 +1252,7 @@ void MsgMultiLineEdit::highlight()
 	{
 	    TQColor c;
 	    TQFont f;
-	    VerticalAlignment v;
+	   Qt::VerticalAlignment v;
 	    getFormat(_firstChangedLine-1, paragraphLength(_firstChangedLine-1)-1, &f, &c, &v);
 	    TQString l = text(_firstChangedLine-1);
 	    if( c==_tagColor  && !l.endsWith(">") ) // hope _tagColor will be different than other colors
