@@ -22,11 +22,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -74,7 +74,7 @@
 
 using namespace KBabel;
 
-class ResultListItem : public QListViewItem
+class ResultListItem : public TQListViewItem
 {
 public:
     ResultListItem(TQListView *parent, const SearchResult& result,bool richText);
@@ -251,12 +251,12 @@ KBabelDictBox::KBabelDictBox( TQWidget* parent,  const char* name, WFlags fl )
    
    hbox = new TQHBoxLayout;
    hbox->addStretch(1);
-   listButton = new TQToolButton(Qt::UpArrow,this);
+   listButton = new TQToolButton(TQt::UpArrow,this);
    listButton->setFixedSize(20,15);
    listButton->setAutoRepeat(false);
    connect(listButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(showListOnly()));
    hbox->addWidget(listButton);
-   detailButton = new TQToolButton(Qt::DownArrow,this);
+   detailButton = new TQToolButton(TQt::DownArrow,this);
    detailButton->setFixedSize(20,15);
    detailButton->setAutoRepeat(false);
    connect(detailButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(showDetailsOnly()));
@@ -324,10 +324,10 @@ KBabelDictBox::KBabelDictBox( TQWidget* parent,  const char* name, WFlags fl )
    mainLayout->addLayout(hbox);
    
    totalResultsLabel->setNum(100000);
-   totalResultsLabel->setFixedSize(totalResultsLabel->sizeHint());
+   totalResultsLabel->setFixedSize(totalResultsLabel->tqsizeHint());
    totalResultsLabel->setNum(0);
    currentLabel->setNum(100000);
-   currentLabel->setFixedSize(currentLabel->sizeHint());
+   currentLabel->setFixedSize(currentLabel->tqsizeHint());
    currentLabel->setNum(0);
 
    setRMBMenu(new TQPopupMenu(this));
@@ -388,7 +388,7 @@ KBabelDictBox::KBabelDictBox( TQWidget* parent,  const char* name, WFlags fl )
    
          if(factory)
          {
-            SearchEngine *e = (SearchEngine *)factory->create(this
+            SearchEngine *e = (SearchEngine *)factory->create(TQT_TQOBJECT(this)
                   , "searchengine", "SearchEngine");
             if(!e)
             {
@@ -419,7 +419,7 @@ KBabelDictBox::KBabelDictBox( TQWidget* parent,  const char* name, WFlags fl )
    
       if(factory)
       {
-            SearchEngine *e = (SearchEngine *)factory->create(this
+            SearchEngine *e = (SearchEngine *)factory->create(TQT_TQOBJECT(this)
                   , "searchengine", "SearchEngine");
             if(!e)
             {
@@ -447,7 +447,7 @@ KBabelDictBox::KBabelDictBox( TQWidget* parent,  const char* name, WFlags fl )
    
       if(factory)
       {
-            SearchEngine *e = (SearchEngine *)factory->create(this
+            SearchEngine *e = (SearchEngine *)factory->create(TQT_TQOBJECT(this)
                   , "searchengine", "SearchEngine");
             if(!e)
             {
@@ -759,7 +759,7 @@ TQString KBabelDictBox::translate(const TQString text)
    if(!engine)
    {
       kdDebug(KBABELDICT) << "no module available" << endl;
-      return TQString::null;
+      return TQString();
    }
    else 
    {
@@ -779,7 +779,7 @@ TQString KBabelDictBox::fuzzyTranslation(const TQString text, int &score)
    if(!engine)
    {
       kdDebug(KBABELDICT) << "no module available" << endl;
-      return TQString::null;
+      return TQString();
    }
    else 
    {
@@ -799,7 +799,7 @@ TQString KBabelDictBox::searchTranslation(const TQString text, int &score)
    if(!engine)
    {
       kdDebug(KBABELDICT) << "no module available" << endl;
-      return TQString::null;
+      return TQString();
    }
    else 
    {
@@ -1007,7 +1007,7 @@ void KBabelDictBox::showResult(TQListViewItem *item)
                 if(!info->filePath.isEmpty())
                 {
                     rmbPopup->changeItem(editFileIndex
-                        ,i18n("Edit File %1").arg(info->location));
+                        ,i18n("Edit File %1").tqarg(info->location));
                     rmbPopup->setItemEnabled(editFileIndex,true);
                 }
                 else
@@ -1182,7 +1182,7 @@ void KBabelDictBox::nextInfo()
             if(!info->filePath.isEmpty())
             {
                 rmbPopup->changeItem(editFileIndex
-                        ,i18n("Edit File %1").arg(info->location));
+                        ,i18n("Edit File %1").tqarg(info->location));
                 rmbPopup->setItemEnabled(editFileIndex,true);
             }
             else
@@ -1255,7 +1255,7 @@ void KBabelDictBox::about()
          if(aboutData->bugAddress() != "submit@bugs.kde.org")
          {
             text += "\n" + i18n("Send bugs to %1")
-                  .arg(aboutData->bugAddress()) +"\n";
+                  .tqarg(aboutData->bugAddress()) +"\n";
          }
 
          TQLabel *label = new TQLabel(text,0);
@@ -1410,7 +1410,7 @@ void KBabelDictBox::copy()
    }
    else
    {
-      QClipboard *cb = KApplication::clipboard();
+      TQClipboard *cb = KApplication::tqclipboard();
       cb->setText(translation());
    }
 }
@@ -1502,7 +1502,7 @@ void KBabelDictBox::configure(const TQString& id, bool modal)
    {
       if(e->id() == id)
       {
-         TQString caption = i18n("Configure Dictionary %1").arg(e->name());
+         TQString caption = i18n("Configure Dictionary %1").tqarg(e->name());
          KDialogBase *dialog = new KDialogBase(this,"prefDialog"
                    , modal, caption
                    , KDialogBase::Ok|KDialogBase::Apply|KDialogBase::Cancel|
@@ -1534,7 +1534,7 @@ void KBabelDictBox::configure(const TQString& id, bool modal)
 
 void KBabelDictBox::destroyConfigDialog()
 {
-    const TQObject *obj = sender();
+    const TQObject *obj = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()));
     if(obj && obj->inherits("KDialogBase"))
     {
        KDialogBase *dialog = (KDialogBase*)obj;
@@ -1609,14 +1609,14 @@ bool KBabelDictBox::eventFilter(TQObject *o, TQEvent *e)
 {
     if(e->type() == TQEvent::Wheel)
     {
-        TQWheelEvent *we = static_cast<TQWheelEvent*>(e);
+        TQWheelEvent *we = TQT_TQWHEELEVENT(e);
         if(we)
         {
             wheelEvent(we);
             return true;
         }
     }
-    else if(e->type() == TQEvent::Resize && o == resultListView)
+    else if(e->type() == TQEvent::Resize && TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(resultListView))
     {
         if(resultListView->height() < 2)
         {
@@ -1696,7 +1696,7 @@ void KBabelDictBox::editFile()
                  {
                      KMessageBox::sorry(this
                              ,i18n("There was an error starting KBabel:\n%1")
-                                    .arg(error));
+                                    .tqarg(error));
                      return;
                  }
              }
