@@ -18,11 +18,11 @@
  *                                                                         *
  *   In addition, as a special exception, the copyright holders give       *
  *   permission to link the code of this program with any edition of       *
- *   the Qt library by Trolltech AS, Norway (or with modified versions     *
- *   of Qt that use the same license as Qt), and distribute linked         *
+ *   the TQt library by Trolltech AS, Norway (or with modified versions     *
+ *   of TQt that use the same license as TQt), and distribute linked         *
  *   combinations including the two.  You must obey the GNU General        *
  *   Public License in all respects for all of the code used other than    *
- *   Qt. If you modify this file, you may extend this exception to         *
+ *   TQt. If you modify this file, you may extend this exception to         *
  *   your version of the file, but you are not obligated to do so.  If     *
  *   you do not wish to do so, delete this exception statement from        *
  *   your version.                                                         *
@@ -124,7 +124,7 @@ KDBSearchEngine::loadDatabase (TQString database, bool noask = false)
 					     i18n
 					     ("Database folder does not exist:\n%1\n"
 					      "Do you want to create it now?").
-					     arg (database), TQString::null, i18n("Create Folder"), i18n("Do Not Create")) ==
+					     arg (database), TQString(), i18n("Create Folder"), i18n("Do Not Create")) ==
 	      KMessageBox::Yes)
 	    {
 		asked = true;
@@ -255,7 +255,7 @@ KDBSearchEngine::loadDatabase (TQString database, bool noask = false)
 		if (asked
 		    || KMessageBox::questionYesNo (0,
 						   i18n
-						   ("Database files not found.\nDo you want to create them now?"), TQString::null, i18n("Create"), i18n("Do Not Create"))
+						   ("Database files not found.\nDo you want to create them now?"), TQString(), i18n("Create"), i18n("Do Not Create"))
 		    == KMessageBox::Yes)
 		  {
 		      //fprintf(stderr,"SI\n");
@@ -474,7 +474,7 @@ KDBSearchEngine::messagesForFilter (const SearchFilter * filter,
 	  if (count % step == 0)
 	    {
 		emit progress (100 * count / totalRecord);
-		kapp->processEvents (100);
+		kapp->tqprocessEvents (100);
 	    }
 	  if (stopNow)
 	    {
@@ -559,7 +559,7 @@ KDBSearchEngine::repeat ()
     bool ok = false;
 
     min =
-	QInputDialog::getInteger (i18n ("Minimum Repetition"),
+	TQInputDialog::getInteger (i18n ("Minimum Repetition"),
 				  i18n
 				  ("Insert the minimum number of repetitions for a string:"),
 				  2, 1, 999999, 1, &ok);
@@ -582,7 +582,7 @@ KDBSearchEngine::repeat ()
 	  if (count % step == 0)
 	    {
 		emit progress (100 * count / totalRecord);
-		kapp->processEvents (100);
+		kapp->tqprocessEvents (100);
 	    }
 	  if (stopNow)
 	    {
@@ -755,7 +755,7 @@ KDBSearchEngine::startSearchNow (int searchmode)
 	step = 100;
 
     emit progress (0);
-    kapp->processEvents (100);
+    kapp->tqprocessEvents (100);
     if (stopNow)
     {
 	stopNow = false;
@@ -773,9 +773,9 @@ KDBSearchEngine::startSearchNow (int searchmode)
 //   Emit progress, process event and check stop now
 	  if (count % step == 0)
 	    {
-		emit progress (100 * count / /*QMAX( */
+		emit progress (100 * count / /*TQMAX( */
 			       totalprogress /*,1) */ );
-		kapp->processEvents (100);
+		kapp->tqprocessEvents (100);
 
 		if (stopNow)
 		{
@@ -1406,19 +1406,19 @@ KDBSearchEngine::about () const
 
 }
 
-QString
+TQString
 KDBSearchEngine::name () const
 {
     return i18n ("Translation Database");
 }
 
-QString
+TQString
 KDBSearchEngine::id () const
 {
     return TQString ("KDBSearchEngine");
 }
 
-QString
+TQString
 KDBSearchEngine::lastError ()
 {
     return lasterror;
@@ -1552,11 +1552,11 @@ KDBSearchEngine::setLastError (const TQString & er)
     lasterror = er;
 }
 
-QString
+TQString
 KDBSearchEngine::translate (const TQString & text, const uint pluralForm)
 {
     if (!openDb ())
-	return TQString::null;
+	return TQString();
 /*
 
 if(!dbOpened)
@@ -1566,7 +1566,7 @@ if(!dbOpened)
         {
          //emit anerror
 	 hasError(i18n("Database not opened"));
-         return TQString::null;
+         return TQString();
        }
      }
 */
@@ -1574,7 +1574,7 @@ if(!dbOpened)
     DataBaseItem dbit = dm->getItem (text);
 
     if (dbit.isNull ())
-	return TQString::null;
+	return TQString();
     if (dbit.numTra == 1)
 	return dbit.translations[0].translation;
 
@@ -1715,7 +1715,7 @@ TQValueList < KeyAndScore > KDBSearchEngine::searchWords (TQString phrase,
 				  {
 				      emit
 				      progress (100 * count / totalprogress);
-				      kapp->processEvents (100);
+				      kapp->tqprocessEvents (100);
 				  }
 				  if (stopNow)
 				  {
@@ -1744,9 +1744,9 @@ TQValueList < KeyAndScore > KDBSearchEngine::searchWords (TQString phrase,
 
 		      int
 			  in = 0, len = 0;
-		      QString
+		      TQString
 			  keyst = dm->getKey (min);
-		      QRegExp
+		      TQRegExp
 		      reg ("[a-zA-Z0-9_%" /*+remchar */  + regaddchar + "]+");
 		      while ((in = reg.search (keyst, in + len)) != -1)
 			{
@@ -1798,7 +1798,7 @@ TQValueList < KeyAndScore > KDBSearchEngine::searchWords (TQString phrase,
 
     for (int j = 0; j < nres; j++)
       {
-	  QString
+	  TQString
 	      strkey = dm->getKey (resloc[j]);
 	  int
 	      stdscore = KDBSearchEngine::score (phrase, strkey);
@@ -1811,7 +1811,7 @@ TQValueList < KeyAndScore > KDBSearchEngine::searchWords (TQString phrase,
 		    in = 0, len = 0, nword = 0;
 		int
 		    remove = retnot ? common : 0;
-		QRegExp
+		TQRegExp
 		reg ("[a-zA-Z0-9_%" /*+remchar */  + regaddchar + "]+");
 		while ((in = reg.search (strkey, in + len)) != -1)
 		  {
