@@ -19,11 +19,11 @@
  *                                                                         *
  *   In addition, as a special exception, the copyright holders give       *
  *   permission to link the code of this program with any edition of       *
- *   the Qt library by Trolltech AS, Norway (or with modified versions     *
- *   of Qt that use the same license as Qt), and distribute linked         *
+ *   the TQt library by Trolltech AS, Norway (or with modified versions     *
+ *   of TQt that use the same license as TQt), and distribute linked         *
  *   combinations including the two.  You must obey the GNU General        *
  *   Public License in all respects for all of the code used other than    *
- *   Qt. If you modify this file, you may extend this exception to         *
+ *   TQt. If you modify this file, you may extend this exception to         *
  *   your version of the file, but you are not obligated to do so.  If     *
  *   you do not wish to do so, delete this exception statement from        *
  *   your version.                                                         *
@@ -703,7 +703,7 @@ DataBaseManager::cursorGet (uint32 flags)
     else
       {
 	  kdDebug (KBABEL_SEARCH) << TQString ("...cursor getting...%1").
-	      arg (ret) << endl;
+	      tqarg (ret) << endl;
 
 	  return DataBaseItem ();
       }
@@ -740,7 +740,7 @@ int
 DataBaseManager::count ()
 {
     DB_BTREE_STAT *dstat = 0;
-#if DB_VERSION_MAJOR == 4 && DB_VERSION_MINOR >= 3
+#if (DB_VERSION_MAJOR == 4 && DB_VERSION_MINOR >= 3) || (DB_VERSION_MAJOR >= 5)
     db->stat (db, NULL, &dstat, DB_FAST_STAT);
 #else
     db->stat (db, &dstat, DB_FAST_STAT);
@@ -782,7 +782,7 @@ DataBaseManager::createDataBase (TQString directory,
 
     rename (filename.local8Bit (), filename.local8Bit () + ",old");
 
-//kdDebug(0) << TQString("Creating %1").arg(filename) << endl;
+//kdDebug(0) << TQString("Creating %1").tqarg(filename) << endl;
 
     iAmOk = true;
 
@@ -861,7 +861,7 @@ DataBaseManager::createDataBase (TQString directory,
 	loadInfo ();
     else
 	kdDebug (KBABEL_SEARCH) << TQString ("I am NOT  ok : %1").
-	    arg (ret) << endl;
+	    tqarg (ret) << endl;
 
 //THIS IS WRONG, rewrite the error handling. 
     return iAmOk;
@@ -889,7 +889,7 @@ DataBaseManager::getCatalogInfo (int n)
 	  return InfoItem ();
       }
 
-// kdDebug(0) << TQString("Trad %1").arg(ret) << endl;
+// kdDebug(0) << TQString("Trad %1").tqarg(ret) << endl;
 
     InfoItem it ((char *) data.data, language);
 //free(data.data);  // Read docu for this!!!!
@@ -979,7 +979,7 @@ DataBaseManager::loadInfo ()
     int nrec;
     DB_BTREE_STAT *stat;
 // memset(&stat,0,sizeof(DB_BTREE_STAT));
-#if DB_VERSION_MAJOR == 4 && DB_VERSION_MINOR >= 3
+#if (DB_VERSION_MAJOR == 4 && DB_VERSION_MINOR >= 3) || (DB_VERSION_MAJOR >= 5)
     if (infoDb->stat (infoDb, NULL, &stat, DB_FAST_STAT))
 	fprintf (stderr, "Cannot stat\n");
 #else
@@ -1000,7 +1000,7 @@ DataBaseManager::loadInfo ()
 
 TQValueList < TQString > DataBaseManager::wordsIn (TQString string)
 {
-    QString
+    TQString
 	a;
     TQValueList < TQString > words;
     int
@@ -1015,7 +1015,7 @@ TQValueList < TQString > DataBaseManager::wordsIn (TQString string)
     int
 	c = 0;
     //words.setAutoDelete(true);  //Not sure... check if it is en.
-    QString
+    TQString
 	m;
     for (i = 0; i < l; i++)
 	if (a[i].isLetterOrNumber ())
@@ -1324,7 +1324,7 @@ DataBaseManager::appendKey (TQString _key)
     else
 	ret = *(uint32 *) key.data;
 
-//kdDebug(0) << TQString("Append result %1,err = %1").arg(ret).arg(err) << endl;
+//kdDebug(0) << TQString("Append result %1,err = %1").tqarg(ret).tqarg(err) << endl;
 
 
     free (data.data);
@@ -1333,7 +1333,7 @@ DataBaseManager::appendKey (TQString _key)
 
 }
 
-QString
+TQString
 DataBaseManager::getKey (uint32 n)
 {
 
@@ -1349,11 +1349,11 @@ DataBaseManager::getKey (uint32 n)
 //Check for errors
     int ret = indexDb->get (indexDb, 0, &key, &data, 0);	//DB_SET_RECNO);
     if (ret)
-	return TQString::null;
+	return TQString();
 
     return TQString::fromUtf8 ((char *) data.data);
 
-// kdDebug(0) << TQString("Trad %1").arg(ret) << endl;
+// kdDebug(0) << TQString("Trad %1").tqarg(ret) << endl;
 
 }
 
