@@ -8,12 +8,13 @@ class KAboutData;
 class DbSe2Factory : public KLibFactory
 {
 	Q_OBJECT
+  TQ_OBJECT
 public:
 	DbSe2Factory( TQObject *parent=0, const char *name=0);
 	~DbSe2Factory();
 
 	virtual TQObject *createObject( TQObject *parent=0, const char *name=0,
-	                               const char *classname="TQObject",
+	                               const char *classname=TQOBJECT_OBJECT_NAME_STRING,
 	                               const TQStringList &args = TQStringList());
 
 	static KInstance *instance();
