@@ -22,11 +22,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -369,7 +369,7 @@ bool PoCompendium::searchWords(const TQString& searchStr, uint pluralForm, TQPtr
                     emit progress( (50*checkCounter+1)/catalogInfo.total);
                 }
             
-                kapp->processEvents(100);
+                kapp->tqprocessEvents(100);
 
                 TQString origStr = data->catalog()->msgid(*it).first();
                 origStr = CompendiumData::simplify(origStr);
@@ -537,7 +537,7 @@ bool PoCompendium::searchNGram(const TQString& searchStr, uint pluralForm, TQPtr
             continue;
         }
        
-        kapp->processEvents(100);
+        kapp->tqprocessEvents(100);
 
         TQString origStr = data->catalog()->msgid(i).first();
         origStr = CompendiumData::simplify(origStr);
@@ -938,7 +938,7 @@ TQString PoCompendium::translate(const TQString& text, uint pluralForm)
     
     if(error || !data || data->active())
     {
-        return TQString::null;
+        return TQString();
     }
    
 
@@ -950,7 +950,7 @@ TQString PoCompendium::translate(const TQString& text, uint pluralForm)
         return data->catalog()->msgstr(*index).first();
     }
    
-    return TQString::null;
+    return TQString();
 }
 
 TQString PoCompendium::fuzzyTranslation(const TQString& text, int &score, const uint pluralForm)
@@ -965,7 +965,7 @@ TQString PoCompendium::fuzzyTranslation(const TQString& text, int &score, const
     
   if(error || !data || data->active())
     {
-      return TQString::null;
+      return TQString();
     }
     
   // try to find fuzzy string
@@ -1029,7 +1029,7 @@ TQString PoCompendium::fuzzyTranslation(const TQString& text, int &score, const
     return data->catalog()->msgstr(best_matching).first();
   }
  
-  return TQString::null;
+  return TQString();
 }
 
 
@@ -1041,7 +1041,7 @@ TQString PoCompendium::searchTranslation(const TQString& text, int &sc, const ui
     }
  
     if(isSearching())
-        return TQString::null;
+        return TQString();
 
     clearResults();
     stop = false;
@@ -1058,13 +1058,13 @@ TQString PoCompendium::searchTranslation(const TQString& text, int &sc, const ui
     if(error || !data)
     {
         active = false;
-        return TQString::null;
+        return TQString();
     }
 
     if(data->active())
     {
         active = false;
-        return TQString::null;
+        return TQString();
     }
    
     emit started();
@@ -1145,7 +1145,7 @@ TQString PoCompendium::searchTranslation(const TQString& text, int &sc, const ui
     
     sc = 0;
     
-    return TQString::null;
+    return TQString();
 }
 
 
@@ -1204,7 +1204,7 @@ void PoCompendium::registerData()
 
 void PoCompendium::removeData()
 {
-    const TQObject *s=sender();
+    const TQObject *s=TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()));
     if(s && s->inherits("CompendiumData"))
     {
         const CompendiumData *d=static_cast<const CompendiumData*>(s);
