@@ -22,11 +22,11 @@
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
+  the TQt library by Trolltech AS, Norway (or with modified versions
+  of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
-  Qt. If you modify this file, you may extend this exception to
+  TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
@@ -240,8 +240,8 @@ bool TmxCompendium::startSearch(const TQString& text, uint pluralForm, const Sea
 
         TranslationInfo *info = new TranslationInfo;
         info->location = directory(realURL,0);
-        info->translator = TQString::null;
-        info->description = TQString::null;
+        info->translator = TQString();
+        info->description = TQString();
         result->descriptions.append(info);
 
         results.append(result);
@@ -294,8 +294,8 @@ bool TmxCompendium::startSearch(const TQString& text, uint pluralForm, const Sea
 
                 TranslationInfo *info = new TranslationInfo;
                 info->location = directory(realURL,0);
-                info->translator = TQString::null;
-                info->description = TQString::null;
+                info->translator = TQString();
+                info->description = TQString();
                 result->descriptions.append(info);
  
                 addResult(result);
@@ -337,7 +337,7 @@ bool TmxCompendium::startSearch(const TQString& text, uint pluralForm, const Sea
                     emit progress( (100*(checkCounter+1))/data->numberOfEntries());
                 }
             
-                kapp->processEvents(100);
+                kapp->tqprocessEvents(100);
 
                 TQString origStr = data->msgid(*it);
                 origStr = TmxCompendiumData::simplify(origStr);
@@ -436,8 +436,8 @@ bool TmxCompendium::startSearch(const TQString& text, uint pluralForm, const Sea
 
                     TranslationInfo *info = new TranslationInfo;
                     info->location = directory(realURL,0);
-                    info->translator = TQString::null;
-                    info->description = TQString::null;
+                    info->translator = TQString();
+                    info->description = TQString();
                     result->descriptions.append(info);
  
                     addResult(result);
@@ -484,7 +484,7 @@ bool TmxCompendium::startSearch(const TQString& text, uint pluralForm, const Sea
                  continue;
             }
        
-            kapp->processEvents(100);
+            kapp->tqprocessEvents(100);
 
             if(i >= data->numberOfEntries())
             {
@@ -577,8 +577,8 @@ bool TmxCompendium::startSearch(const TQString& text, uint pluralForm, const Sea
 
                  TranslationInfo *info = new TranslationInfo;
                  info->location = directory(realURL,0);
-                 info->translator = TQString::null;
-                 info->description = TQString::null;
+                 info->translator = TQString();
+                 info->description = TQString();
                  result->descriptions.append(info);
     
                  addResult(result);
@@ -818,7 +818,7 @@ TQString TmxCompendium::translate(const TQString& text, uint pluralForm)
     
     if(error || !data || data->active())
     {
-        return TQString::null;
+        return TQString();
     }
    
 
@@ -829,7 +829,7 @@ TQString TmxCompendium::translate(const TQString& text, uint pluralForm)
         return data->msgstr(*index);
     }
    
-    return TQString::null;
+    return TQString();
 }
 
 TQString TmxCompendium::fuzzyTranslation(const TQString& text, int &score, uint pluralForm)
@@ -844,7 +844,7 @@ TQString TmxCompendium::fuzzyTranslation(const TQString& text, int &score, uint
     
   if(error || !data || data->active())
     {
-      return TQString::null;
+      return TQString();
     }
     
   // try to find fuzzy string
@@ -907,7 +907,7 @@ TQString TmxCompendium::fuzzyTranslation(const TQString& text, int &score, uint
     return data->msgstr(best_matching);
   }
  
-  return TQString::null;
+  return TQString();
 }
 
 
@@ -965,7 +965,7 @@ void TmxCompendium::registerData()
 
 void TmxCompendium::removeData()
 {
-    const TQObject *s=sender();
+    const TQObject *s=TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()));
     if(s && s->inherits("TmxCompendiumData"))
     {
         const TmxCompendiumData *d=static_cast<const TmxCompendiumData*>(s);
