@@ -17,7 +17,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbggame.cpp 1157643 2010-07-31 19:42:31Z tpearson $
+  $Id: kbggame.cpp 1246260 2011-08-10 22:19:39Z tpearson $
 
 */
 
@@ -39,7 +39,7 @@ KBgGame::KBgGame(int cookie, TQObject *parent)
 
 bool KBgGame::playerInput(TQDataStream &msg,KPlayer *player)
 {
-    Q_INT32 move;
+    TQ_INT32 move;
     msg >>  move;
     cerr << "  Player " << player->id() << " moved to " << move << endl;
     return true;
