@@ -64,9 +64,9 @@
 /*
  * Just some internal constants and classes
  */
-const int US   = KBgStatus::US;
-const int THEM = KBgStatus::THEM;
-const int BOTH = KBgStatus::BOTH;
+const int US   = KBgtqStatus::US;
+const int THEM = KBgtqStatus::THEM;
+const int BOTH = KBgtqStatus::BOTH;
 
 const int HOME_US_LEFT     = 101;
 const int HOME_US_RIGHT    = 102;
@@ -95,9 +95,10 @@ class KBgBoardQDice;
  *
  * This class handles all game operations of the client.
  */
-class KBgBoard : public QWidget
+class KBgBoard : public TQWidget
 {
 	Q_OBJECT
+  TQ_OBJECT
 
 	friend class KBgBoardCell;
 	friend class KBgBoardHome;
@@ -180,7 +181,7 @@ class KBgBoard : public QWidget
 	 * This function has to be reimplemented to provide a minimum size for
 	 * the playing area.
 	 */
-	TQSize minimumSizeHint() const;
+	TQSize tqminimumSizeHint() const;
 public slots:
 
 	/**
@@ -210,10 +211,10 @@ public slots:
 
 	/**
 	 * This is the most important public member. It takes
-	 * a board status - s. the KBgBoardStatus class -
+	 * a board status - s. the KBgBoardtqStatus class -
 	 * and sets the board accordingly.
 	 */
-	void setState(const KBgStatus &);
+	void setState(const KBgtqStatus &);
 
 	/**
 	 * Set the context menu
@@ -223,7 +224,7 @@ public slots:
 	/**
 	 * Get the current state of the board.
 	 */
-	KBgStatus *getState(KBgStatus *st) const;
+	KBgtqStatus *getState(KBgtqStatus *st) const;
 
 	/**
 	 * Sets the edit mode of the board. In that mode the board can be
@@ -291,7 +292,7 @@ public slots:
 	/* ************************************************** */
 
 protected:
-  virtual TQSize sizeHint() const;
+  virtual TQSize tqsizeHint() const;
 
 	TQColor baseColors[2];
 	TQFont boardFont;
@@ -458,9 +459,10 @@ protected:
  * on a backgammon board. It has a bunch of virtual functions that
  * are overloaded in the derived classes.
  */
-class KBgBoardCell : public QLabel
+class KBgBoardCell : public TQLabel
 {
       	Q_OBJECT
+  TQ_OBJECT
 
  public:
 
@@ -533,7 +535,7 @@ protected:
 	virtual void drawContents(TQPainter *);
 
 	/**
-	 * Status numbers that store the current board status.
+	 * tqStatus numbers that store the current board status.
 	 */
 	int mouseButton;
 	int direction;
@@ -550,7 +552,7 @@ protected:
 	int cellID;
 
 	/**
-	 * Indicates whether this cell needs to repaint itself after
+	 * Indicates whether this cell needs to tqrepaint itself after
 	 * the board has been processed.
 	 */
 	bool stateChanged;
@@ -615,6 +617,7 @@ protected:
 class KBgBoardHome : public KBgBoardCell
 {
       	Q_OBJECT
+  TQ_OBJECT
 
  public:
 	/**
@@ -677,6 +680,7 @@ class KBgBoardHome : public KBgBoardCell
 class KBgBoardBar : public KBgBoardCell
 {
        	Q_OBJECT
+  TQ_OBJECT
 
  public:
 	/**
@@ -724,6 +728,7 @@ class KBgBoardBar : public KBgBoardCell
 class KBgBoardField : public KBgBoardCell
 {
 	Q_OBJECT
+  TQ_OBJECT
 
  public:
 	/**
@@ -816,9 +821,10 @@ class KBgBoardMove
  *
  * A very simple dialog with two SpinBoxes and two buttons.
  */
-class KBgBoardQDice : public QDialog
+class KBgBoardQDice : public TQDialog
 {
 	Q_OBJECT
+  TQ_OBJECT
 
 public:
 
@@ -831,7 +837,7 @@ public:
 protected:
 
 	/**
-	 * Spin boxes and buttons are children
+	 * Spin boxes and buttons are tqchildren
 	 */
 	TQSpinBox     *sb[2];
 	TQPushButton  *ok;
@@ -849,9 +855,10 @@ public slots:
 /**
  * Simple dialog that allows to query the user for the cube value.
  */
-class KBgBoardQCube : public QDialog
+class KBgBoardQCube : public TQDialog
 {
 	Q_OBJECT
+  TQ_OBJECT
 
 public:
 
@@ -864,7 +871,7 @@ public:
 protected:
 
 	/**
-	 * Spin boxes and buttons are children
+	 * Spin boxes and buttons are tqchildren
 	 */
 	TQComboBox    *cb[2];
 	TQPushButton  *ok;
@@ -897,6 +904,7 @@ protected slots:
 class KBgBoardSetup : public KBgBoard
 {
 	Q_OBJECT
+  TQ_OBJECT
 
 public:
 
