@@ -12,7 +12,7 @@ struct BugImpl : public KShared
 public:
     BugImpl( const TQString &_title, const Person &_submitter, TQString _number,
         uint _age, Bug::Severity _severity, Person _developerTODO,
-        Bug::Status _status, const Bug::BugMergeList& _mergedWith  )
+        Bug::tqStatus _status, const Bug::BugMergeList& _mergedWith  )
     : age( _age ), title( _title ), submitter( _submitter ), number( _number ),
         severity( _severity ), developerTODO( _developerTODO ),
         status( _status ), mergedWith( _mergedWith )
@@ -25,7 +25,7 @@ public:
     TQString number;
     Bug::Severity severity;
     Person developerTODO;
-    Bug::Status status;
+    Bug::tqStatus status;
 
     Bug::BugMergeList mergedWith;
 };
