@@ -52,14 +52,14 @@ CentralWidget::CentralWidget( const TQCString &initialPackage,
                               const char * name )
   : TQWidget( parent, name )
 {
-    // Master layout
+    // Master tqlayout
     ( new TQVBoxLayout( this, 0,
                        KDialog::spacingHint() ) )->setAutoAdd( true );
 
-    // Create TQSplitter children
-    m_vertSplitter = new TQSplitter( TQSplitter::Vertical, this );
+    // Create TQSplitter tqchildren
+    m_vertSplitter = new TQSplitter( Qt::Vertical, this );
     m_listPane     = new CWBugListContainer( m_vertSplitter );
-    m_horSplitter  = new TQSplitter( TQSplitter::Horizontal,m_vertSplitter );
+    m_horSplitter  = new TQSplitter( Qt::Horizontal,m_vertSplitter );
 // The search pane isn't used. Should we remove the code?
     m_searchPane   = new CWSearchWidget( m_horSplitter );
     m_bugPane      = new CWBugDetailsContainer( m_horSplitter );
@@ -67,7 +67,7 @@ CentralWidget::CentralWidget( const TQCString &initialPackage,
     m_searchPane->hide();
 //    m_listPane->hide();
 
-    m_searchPane->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum,
+    m_searchPane->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum,
                                                     TQSizePolicy::Minimum ) );
     m_horSplitter->setResizeMode( m_searchPane, TQSplitter::FollowSizeHint );
 
@@ -188,7 +188,7 @@ void CentralWidget::writeConfig()
 
 void CentralWidget::slotRetrieveBugList( const TQString &package )
 {
-    slotRetrieveBugList( package, TQString::null );
+    slotRetrieveBugList( package, TQString() );
 }
 
 void CentralWidget::slotRetrieveBugList( const TQString &p, const TQString &component )
@@ -356,10 +356,10 @@ void CentralWidget::slotExtractAttachments()
 
             int res = KMessageBox::questionYesNoList( this,
                                                       i18n("Found the following attachments. Save?"),
-                                                      fileList, TQString::null, KStdGuiItem::save(), KStdGuiItem::dontSave() );
+                                                      fileList, TQString(), KStdGuiItem::save(), KStdGuiItem::dontSave() );
             if ( res == KMessageBox::No )
                 return;
-            TQString dir = KFileDialog::getExistingDirectory( TQString::null, this, i18n("Select Folder Where to Save Attachments") );
+            TQString dir = KFileDialog::getExistingDirectory( TQString(), this, i18n("Select Folder Where to Save Attachments") );
             if ( !dir.isEmpty() )
             {
                 if ( !dir.endsWith( "/" ) )
