@@ -144,68 +144,68 @@ KBBMainWindow::~KBBMainWindow()
 void KBBMainWindow::initActions()
 {
     // Prepare and create XML GUI
-    fileQuit          = KStdAction::quit( this,
+    fileQuit          = KStdAction::quit( TQT_TQOBJECT(this),
                         TQT_SLOT( close() ), actionCollection() );
     fileQuit->setToolTip( i18n( "Quit KBugBuster" ) );
 
-    new KAction( i18n("See &Pending Changes"), "contents", 0, this, TQT_SLOT( slotListChanges() ),
+    new KAction( i18n("See &Pending Changes"), "contents", 0, TQT_TQOBJECT(this), TQT_SLOT( slotListChanges() ),
                  actionCollection(), "file_seechanges" );
-    new KAction( i18n("&Submit Changes"), "mail_send", 0, this, TQT_SLOT( slotSubmit() ),
+    new KAction( i18n("&Submit Changes"), "mail_send", 0, TQT_TQOBJECT(this), TQT_SLOT( slotSubmit() ),
                  actionCollection(), "file_submit" );
 
-    reloadpacklist = new KAction( i18n("Reload &Product List"), "reload", CTRL+Qt::Key_F5, m_mainWidget, TQT_SLOT( slotReloadPackageList() ),
+    reloadpacklist = new KAction( i18n("Reload &Product List"), "reload", CTRL+TQt::Key_F5, TQT_TQOBJECT(m_mainWidget), TQT_SLOT( slotReloadPackageList() ),
                  actionCollection(), "reload_packagelist" );
-    reloadpack= new KAction( i18n("Reload Bug &List (for current product)"), "reload", Qt::Key_F5, m_mainWidget, TQT_SLOT( slotReloadPackage() ),
+    reloadpack= new KAction( i18n("Reload Bug &List (for current product)"), "reload", TQt::Key_F5, TQT_TQOBJECT(m_mainWidget), TQT_SLOT( slotReloadPackage() ),
                  actionCollection(), "reload_package" );
-    reloadbug = new KAction( i18n("Reload Bug &Details (for current bug)"), "reload", SHIFT+Qt::Key_F5, m_mainWidget, TQT_SLOT( slotReloadBug() ),
+    reloadbug = new KAction( i18n("Reload Bug &Details (for current bug)"), "reload", SHIFT+TQt::Key_F5, TQT_TQOBJECT(m_mainWidget), TQT_SLOT( slotReloadBug() ),
                  actionCollection(), "reload_bug" );
-    loadMyBugs = new KAction( i18n( "Load &My Bugs List" ), 0, m_mainWidget, TQT_SLOT( slotLoadMyBugs() ),
+    loadMyBugs = new KAction( i18n( "Load &My Bugs List" ), 0, TQT_TQOBJECT(m_mainWidget), TQT_SLOT( slotLoadMyBugs() ),
                  actionCollection(), "load_my_bugs" );
-    reloadall = new KAction( i18n("Load All Bug Details (for current product)"), Qt::Key_F6, m_mainWidget, TQT_SLOT( slotRetrieveAllBugDetails() ), actionCollection(), "load_allbugs" );
-    new KAction( i18n("Extract &Attachments"), "filesave", Qt::Key_F4, m_mainWidget, TQT_SLOT( slotExtractAttachments() ),
+    reloadall = new KAction( i18n("Load All Bug Details (for current product)"), TQt::Key_F6, TQT_TQOBJECT(m_mainWidget), TQT_SLOT( slotRetrieveAllBugDetails() ), actionCollection(), "load_allbugs" );
+    new KAction( i18n("Extract &Attachments"), "filesave", TQt::Key_F4, TQT_TQOBJECT(m_mainWidget), TQT_SLOT( slotExtractAttachments() ),
                  actionCollection(), "extract_attachments" );
 
-    new KAction( i18n("Clear Cache"), 0, this, TQT_SLOT( clearCache() ),
+    new KAction( i18n("Clear Cache"), 0, TQT_TQOBJECT(this), TQT_SLOT( clearCache() ),
                  actionCollection(), "clear_cache" );
 
-    new KAction( i18n("&Search by Product..."), "goto", CTRL+Qt::Key_P, this,
+    new KAction( i18n("&Search by Product..."), "goto", CTRL+TQt::Key_P, TQT_TQOBJECT(this),
                  TQT_SLOT( searchPackage() ), actionCollection(), "search_package" );
-    new KAction( i18n("Search by Bug &Number..."), "filefind", CTRL+Qt::Key_N, this,
+    new KAction( i18n("Search by Bug &Number..."), "filefind", CTRL+TQt::Key_N, TQT_TQOBJECT(this),
                  TQT_SLOT( searchBugNumber() ), actionCollection(), "search_bugnumber" );
     // For now "Description" searches by title. Maybe later we can have a
     // full-text search interfacing bugs.kde.org and rename the current one to "By Title".
-    new KAction( i18n("Search by &Description...") ,"find", CTRL+Qt::Key_D, this,
+    new KAction( i18n("Search by &Description...") ,"find", CTRL+TQt::Key_D, TQT_TQOBJECT(this),
                  TQT_SLOT( searchDescription() ), actionCollection(), "search_description" );
 
-//    new KAction( i18n("&Merge"), "view_remove", CTRL+Qt::Key_M, m_mainWidget,
+//    new KAction( i18n("&Merge"), "view_remove", CTRL+TQt::Key_M, TQT_TQOBJECT(m_mainWidget),
 //                 TQT_SLOT( mergeBugs() ), actionCollection(), "cmd_merge" );
-//    new KAction( i18n("&Unmerge"), "view_top_bottom", CTRL+SHIFT+Qt::Key_M, m_mainWidget,
+//    new KAction( i18n("&Unmerge"), "view_top_bottom", CTRL+SHIFT+TQt::Key_M, TQT_TQOBJECT(m_mainWidget),
 //                 TQT_SLOT( unmergeBugs() ), actionCollection(), "cmd_unmerge" );
-    new KAction( i18n("C&lose..."), "edittrash", CTRL+Qt::Key_L, m_mainWidget,
+    new KAction( i18n("C&lose..."), "edittrash", CTRL+TQt::Key_L, TQT_TQOBJECT(m_mainWidget),
                  TQT_SLOT( closeBug() ), actionCollection(), "cmd_close" );
-//    new KAction( i18n("Clos&e Silently"), "edittrash", CTRL+Qt::Key_E, m_mainWidget,
+//    new KAction( i18n("Clos&e Silently"), "edittrash", CTRL+TQt::Key_E, TQT_TQOBJECT(m_mainWidget),
 //                 TQT_SLOT( closeBugSilently() ), actionCollection(), "cmd_close_silently" );
-    new KAction( i18n("Re&open"), "idea", CTRL+Qt::Key_O, m_mainWidget,
+    new KAction( i18n("Re&open"), "idea", CTRL+TQt::Key_O, TQT_TQOBJECT(m_mainWidget),
                  TQT_SLOT( reopenBug() ), actionCollection(), "cmd_reopen" );
-//    new KAction( i18n("Re&assign..."), "folder_new", CTRL+Qt::Key_A, m_mainWidget,
+//    new KAction( i18n("Re&assign..."), "folder_new", CTRL+TQt::Key_A, TQT_TQOBJECT(m_mainWidget),
 //                 TQT_SLOT( reassignBug() ), actionCollection(), "cmd_reassign" );
-//    new KAction( i18n("Change &Title..."), "text_under", CTRL+Qt::Key_T, m_mainWidget,
+//    new KAction( i18n("Change &Title..."), "text_under", CTRL+TQt::Key_T, TQT_TQOBJECT(m_mainWidget),
 //                 TQT_SLOT( titleBug() ), actionCollection(), "cmd_title" );
-//    new KAction( i18n("Change &Severity..."), "edit", CTRL+Qt::Key_S, m_mainWidget,
+//    new KAction( i18n("Change &Severity..."), "edit", CTRL+TQt::Key_S, TQT_TQOBJECT(m_mainWidget),
 //                 TQT_SLOT( severityBug() ), actionCollection(), "cmd_severity" );
-    new KAction( i18n("&Reply..."), "mail_replyall",CTRL+Qt::Key_R , m_mainWidget,
+    new KAction( i18n("&Reply..."), "mail_replyall",CTRL+TQt::Key_R , TQT_TQOBJECT(m_mainWidget),
                  TQT_SLOT( replyBug() ), actionCollection(), "cmd_reply" );
-    new KAction( i18n("Reply &Privately..."), "mail_reply", CTRL+Qt::Key_I, m_mainWidget,
+    new KAction( i18n("Reply &Privately..."), "mail_reply", CTRL+TQt::Key_I, TQT_TQOBJECT(m_mainWidget),
                  TQT_SLOT( replyPrivateBug() ), actionCollection(), "cmd_replyprivate" );
 
-    KStdAction::showMenubar(this, TQT_SLOT( slotToggleMenubar() ), actionCollection() );
+    KStdAction::showMenubar(TQT_TQOBJECT(this), TQT_SLOT( slotToggleMenubar() ), actionCollection() );
 #if KDE_IS_VERSION( 3, 1, 90 )
     createStandardStatusBarAction();
     setStandardToolBarMenuEnabled(true);
 #endif
 
     m_disconnectedAction = new KToggleAction( i18n("&Disconnected Mode"), 0,
-                                              this,
+                                              TQT_TQOBJECT(this),
                                               TQT_SLOT( slotDisconnectedAction() ),
                                               actionCollection(),
                                               "settings_disconnected" );
@@ -215,16 +215,16 @@ void KBBMainWindow::initActions()
     m_pamBookmarks = new KActionMenu( i18n( "&Bookmarks" ), "bookmark", actionCollection(), "bookmarks" );
     m_pBookmarkMenu = new KBookmarkMenu( KBBBookmarkManager::self(), this, m_pamBookmarks->popupMenu(), actionCollection(), true );
 
-    KStdAction::preferences( this, TQT_SLOT(preferences()), actionCollection() );
+    KStdAction::preferences( TQT_TQOBJECT(this), TQT_SLOT(preferences()), actionCollection() );
 
-    KToggleAction *toggleTmp =  new KToggleAction( i18n("Show Closed Bugs"), "recycled", 0, this, TQT_SLOT( slotToggleDone() ),
+    KToggleAction *toggleTmp =  new KToggleAction( i18n("Show Closed Bugs"), "recycled", 0, TQT_TQOBJECT(this), TQT_SLOT( slotToggleDone() ),
                  actionCollection(), "cmd_toggle_done" );
 #if KDE_IS_VERSION( 3, 2, 90 )
     toggleTmp->setCheckedState(i18n("Hide Closed Bugs"));
 #endif
     toggleTmp->setChecked( KBBPrefs::instance()->mShowClosedBugs );
 
-    toggleTmp =new KToggleAction( i18n("Show Wishes"), "bookmark", 0, this, TQT_SLOT( slotToggleWishes() ),
+    toggleTmp =new KToggleAction( i18n("Show Wishes"), "bookmark", 0, TQT_TQOBJECT(this), TQT_SLOT( slotToggleWishes() ),
                  actionCollection(), "cmd_toggle_wishes" );
 #if KDE_IS_VERSION( 3, 2, 90 )
     toggleTmp->setCheckedState(i18n("Hide Wishes"));
@@ -232,7 +232,7 @@ void KBBMainWindow::initActions()
     toggleTmp->setChecked(KBBPrefs::instance()->mShowWishes);
 
     mSelectServerAction = new KSelectAction( i18n( "Select Server" ), 0, 0,
-                                             this,
+                                             TQT_TQOBJECT(this),
                                              TQT_SLOT( slotSelectServer() ),
                                              actionCollection(),
                                              "select_server" );
@@ -240,10 +240,10 @@ void KBBMainWindow::initActions()
     setupSelectServerAction();
 
     if ( KBBPrefs::instance()->mDebugMode ) {
-      new KAction( i18n("Show Last Server Response..."), 0 , this,
+      new KAction( i18n("Show Last Server Response..."), 0 , TQT_TQOBJECT(this),
                    TQT_SLOT( showLastResponse() ), actionCollection(),
                    "debug_lastresponse" );
-      new KAction( i18n("Show Bug HTML Source..."), 0 , this,
+      new KAction( i18n("Show Bug HTML Source..."), 0 , TQT_TQOBJECT(this),
                    TQT_SLOT( showBugSource() ), actionCollection(),
                    "debug_showbugsource" );
     }
@@ -342,7 +342,7 @@ void KBBMainWindow::slotListChanges()
     if (list.count() > 0)
     {
        int ret = KMessageBox::questionYesNoList( this, i18n("List of pending commands:"),
-                                              list, TQString::null, KStdGuiItem::clear(), KStdGuiItem::close() );
+                                              list, TQString(), KStdGuiItem::clear(), KStdGuiItem::close() );
        if ( ret == KMessageBox::Yes )
        {
            // Ask for confirmation, it's too easy to click the wrong button in the above dlg box
@@ -391,7 +391,7 @@ void KBBMainWindow::searchBugNumber()
     bool ok = false;
     TQString result = KInputDialog::getText( i18n("Search for Bug Number"),
                                             i18n("Please enter a bug number:"),
-                                            TQString::null, &ok, this );
+                                            TQString(), &ok, this );
     if ( ok ) {
       //Strip whitespace and # if needed
       result = result.stripWhiteSpace();
@@ -420,7 +420,7 @@ bool KBBMainWindow::queryClose()
     if ( ! BugSystem::self()->server()->commandsPending() ) return true;
 
     int result = KMessageBox::warningYesNoCancel(this,i18n("There are unsent bug commands."
-                                                           " Do you want to send them now?"), TQString::null, i18n("Send"), i18n("Do Not Send"));
+                                                           " Do you want to send them now?"), TQString(), i18n("Send"), i18n("Do Not Send"));
     if ( result == KMessageBox::Cancel ) return false;
     if ( result == KMessageBox::Yes ) {
         BugSystem::self()->sendCommands();
