@@ -149,7 +149,7 @@ bool CachegrindLoader::canLoadTrace(TQFile* file)
 
   if (!file->isOpen()) {
     if (!file->open( IO_ReadOnly ) ) {
-      kdDebug() << TQFile::encodeName(_filename) << ": "
+      kdDebug() << TQFile::encodeName(_filename).data() << ": "
 		<< strerror( errno ) << endl;
       return false;
     }
@@ -181,8 +181,8 @@ bool CachegrindLoader::loadTrace(TracePart* p)
   CachegrindLoader l;
 
   /* emit progress signals via the singleton loader */
-  connect(&l, TQT_SIGNAL(updateStatus(TQString, int)),
-	  this, TQT_SIGNAL(updateStatus(TQString, int)));
+  connect(&l, TQT_SIGNAL(updatetqStatus(TQString, int)),
+	  this, TQT_SIGNAL(updatetqStatus(TQString, int)));
 
   return l.loadTraceInternal(p);
 }
@@ -735,9 +735,9 @@ bool CachegrindLoader::loadTraceInternal(TracePart* part)
     return false;
   }
   kdDebug() << "Loading " << _filename << " ..." << endl;
-  TQString statusMsg = i18n("Loading %1").arg(_filename);
+  TQString statusMsg = i18n("Loading %1").tqarg(_filename);
   int statusProgress = 0;
-  emit updateStatus(statusMsg,statusProgress);
+  emit updatetqStatus(statusMsg,statusProgress);
 
 
 #if USE_FIXCOST
@@ -815,7 +815,7 @@ bool CachegrindLoader::loadTraceInternal(TracePart* part)
 		 * "long operations" (like file loading) are in progress,
 		 * this can temporarly switch to another operation.
 		 */
-		emit updateStatus(statusMsg,statusProgress);
+		emit updatetqStatus(statusMsg,statusProgress);
 	      }
 
 	      continue;
@@ -1308,9 +1308,9 @@ bool CachegrindLoader::loadTraceInternal(TracePart* part)
   }
 
 
-  emit updateStatus(statusMsg,100);
+  emit updatetqStatus(statusMsg,100);
 
-  _part->invalidate();
+  _part->tqinvalidate();
   if (!totalsSet) {
     _part->totals()->clear();
     _part->totals()->addCost(_part);
