@@ -303,8 +303,8 @@ GraphEdge::GraphEdge()
 TQString GraphEdge::prettyName()
 {
     if (_c) return _c->prettyName();
-    if (_from) return i18n("Call(s) from %1").arg(_from->prettyName());
-    if (_to) return i18n("Call(s) to %1").arg(_to->prettyName());
+    if (_from) return i18n("Call(s) from %1").tqarg(_from->prettyName());
+    if (_to) return i18n("Call(s) to %1").tqarg(_to->prettyName());
     return i18n("(unknown call)");
 }
 
@@ -376,7 +376,7 @@ TQString GraphOptions::layoutString(Layout l)
     return TQString("TopDown");
 }
 
-GraphOptions::Layout GraphOptions::layout(TQString s)
+GraphOptions::Layout GraphOptions::tqlayout(TQString s)
 {
     if (s == TQString("Circular")) return Circular;
     if (s == TQString("LeftRight")) return LeftRight;
@@ -413,7 +413,7 @@ GraphExporter::GraphExporter()
     _go = this;
     _tmpFile = 0;
     _item = 0;
-    reset(0, 0, 0, TraceItem::NoCostType, TQString::null);
+    reset(0, 0, 0, TraceItem::NoCostType, TQString());
 }
 
 
@@ -467,7 +467,7 @@ void GraphExporter::reset(TraceData*, TraceItem* i, TraceCostType* ct,
   if (!i) return;
 
   if (filename.isEmpty()) {
-    _tmpFile = new KTempFile(TQString::null, ".dot");
+    _tmpFile = new KTempFile(TQString(), ".dot");
     _dotName = _tmpFile->name();
     _useBox = true;
   }
@@ -519,7 +519,7 @@ void GraphExporter::createGraph()
     TraceFunction *caller, *called;
     caller = c->caller(false);
     called = c->called(false);
-    QPair<TraceFunction*,TraceFunction*> p(caller, called);
+    TQPair<TraceFunction*,TraceFunction*> p(caller, called);
     GraphEdge& e = _edgeMap[p];
     e.setCall(c);
     e.setCaller(p.first);
@@ -562,10 +562,10 @@ void GraphExporter::writeDot()
 
   *stream << "digraph \"callgraph\" {\n";
 
-  if (_go->layout() == LeftRight) {
+  if (_go->tqlayout() == LeftRight) {
       *stream << TQString("  rankdir=LR;\n");
   }
-  else if (_go->layout() == Circular) {
+  else if (_go->tqlayout() == Circular) {
     TraceFunction *f = 0;
     switch(_item->type()) {
     case TraceItem::Function:
@@ -579,7 +579,7 @@ void GraphExporter::writeDot()
       break;
     }
     if (f)
-      *stream << TQString("  center=F%1;\n").arg((long)f, 0, 16);
+      *stream << TQString("  center=F%1;\n").tqarg((long)f, 0, 16);
     *stream << TQString("  overlap=false;\n  splines=true;\n");
   }
 
@@ -619,7 +619,7 @@ void GraphExporter::writeDot()
 	iabr = iabr.left(Configuration::maxSymbolLength()) + "...";
 
       *stream << TQString("subgraph \"cluster%1\" { label=\"%2\";\n")
-	.arg(cluster).arg(iabr);
+	.tqarg(cluster).tqarg(iabr);
     }
 
     GraphNode* np;
@@ -630,17 +630,17 @@ void GraphExporter::writeDot()
       if ((int)abr.length() > Configuration::maxSymbolLength())
 	abr = abr.left(Configuration::maxSymbolLength()) + "...";
       
-      *stream << TQString("  F%1 [").arg((long)f, 0, 16);
+      *stream << TQString("  F%1 [").tqarg((long)f, 0, 16);
       if (_useBox) {
 	// make label 3 lines for CallGraphView
-	*stream << TQString("shape=box,label=\"** %1 **\\n**\\n%2\"];\n")
-	  .arg(abr)
-	  .arg(SubCost(np->incl).pretty());
+	*stream << TQString("tqshape=box,label=\"** %1 **\\n**\\n%2\"];\n")
+	  .tqarg(abr)
+	  .tqarg(SubCost(np->incl).pretty());
       }
       else
 	*stream << TQString("label=\"%1\\n%2\"];\n")
-	  .arg(abr)
-	  .arg(SubCost(np->incl).pretty());
+	  .tqarg(abr)
+	  .tqarg(SubCost(np->incl).pretty());
     }
 
     if (_go->clusterGroups() && i)
@@ -675,17 +675,17 @@ void GraphExporter::writeDot()
     to.callerSet.remove(&e);
 
     *stream << TQString("  F%1 -> F%2 [weight=%3")
-      .arg((long)e.from(), 0, 16)
-      .arg((long)e.to(), 0, 16)
-      .arg((long)log(log(e.cost)));
+      .tqarg((long)e.from(), 0, 16)
+      .tqarg((long)e.to(), 0, 16)
+      .tqarg((long)log(log(e.cost)));
 
     if (_go->detailLevel() ==1)
 	*stream << TQString(",label=\"%1\"")
-	    .arg(SubCost(e.cost).pretty());
+	    .tqarg(SubCost(e.cost).pretty());
     else if (_go->detailLevel() ==2)
 	*stream << TQString(",label=\"%3\\n%4 x\"")
-	    .arg(SubCost(e.cost).pretty())
-	    .arg(SubCost(e.count).pretty());
+	    .tqarg(SubCost(e.cost).pretty())
+	    .tqarg(SubCost(e.count).pretty());
 
     *stream << TQString("];\n");
   }
@@ -707,20 +707,20 @@ void GraphExporter::writeDot()
 	  }
 	  if (costSum > _realCallLimit) {
 
-	      QPair<TraceFunction*,TraceFunction*> p(0, n.function());
+	      TQPair<TraceFunction*,TraceFunction*> p(0, n.function());
 	      e = &(_edgeMap[p]);
 	      e->setCalling(p.second);
 	      e->cost = costSum;
 	      e->count = countSum;
 
-	      *stream << TQString("  R%1 [shape=point,label=\"\"];\n")
-		  .arg((long)n.function(), 0, 16);
+	      *stream << TQString("  R%1 [tqshape=point,label=\"\"];\n")
+		  .tqarg((long)n.function(), 0, 16);
 	      *stream << TQString("  R%1 -> F%2 [label=\"%3\\n%4 x\",weight=%5];\n")
-		  .arg((long)n.function(), 0, 16)
-		  .arg((long)n.function(), 0, 16)
-		  .arg(SubCost(costSum).pretty())
-		  .arg(SubCost(countSum).pretty())
-		  .arg((int)log(costSum));
+		  .tqarg((long)n.function(), 0, 16)
+		  .tqarg((long)n.function(), 0, 16)
+		  .tqarg(SubCost(costSum).pretty())
+		  .tqarg(SubCost(countSum).pretty())
+		  .tqarg((int)log(costSum));
 	  }
 
 	  costSum = countSum = 0.0;
@@ -730,20 +730,20 @@ void GraphExporter::writeDot()
 	  }
 	  if (costSum > _realCallLimit) {
 
-	      QPair<TraceFunction*,TraceFunction*> p(n.function(), 0);
+	      TQPair<TraceFunction*,TraceFunction*> p(n.function(), 0);
 	      e = &(_edgeMap[p]);
 	      e->setCaller(p.first);
 	      e->cost = costSum;
 	      e->count = countSum;
 
-	      *stream << TQString("  S%1 [shape=point,label=\"\"];\n")
-		  .arg((long)n.function(), 0, 16);
+	      *stream << TQString("  S%1 [tqshape=point,label=\"\"];\n")
+		  .tqarg((long)n.function(), 0, 16);
 	      *stream << TQString("  F%1 -> S%2 [label=\"%3\\n%4 x\",weight=%5];\n")
-		  .arg((long)n.function(), 0, 16)
-		  .arg((long)n.function(), 0, 16)
-		  .arg(SubCost(costSum).pretty())
-		  .arg(SubCost(countSum).pretty())
-		  .arg((int)log(costSum));
+		  .tqarg((long)n.function(), 0, 16)
+		  .tqarg((long)n.function(), 0, 16)
+		  .tqarg(SubCost(costSum).pretty())
+		  .tqarg(SubCost(countSum).pretty())
+		  .tqarg((int)log(costSum));
 	  }
       }
   }
@@ -805,7 +805,7 @@ GraphNode* GraphExporter::node(TraceFunction* f)
 
 GraphEdge* GraphExporter::edge(TraceFunction* f1, TraceFunction* f2)
 {
-  GraphEdgeMap::Iterator it = _edgeMap.find(qMakePair(f1, f2));
+  GraphEdgeMap::Iterator it = _edgeMap.find(tqMakePair(f1, f2));
   if (it == _edgeMap.end()) return 0;
 
   return &(*it);
@@ -890,7 +890,7 @@ void GraphExporter::buildGraph(TraceFunction* f, int d,
     // if (count>0.0 && (cost/count < 3)) continue;
 
     double oldCost = 0.0;
-    QPair<TraceFunction*,TraceFunction*> p(toCallings ? f:f2,
+    TQPair<TraceFunction*,TraceFunction*> p(toCallings ? f:f2,
 					   toCallings ? f2:f);
     GraphEdge& e = _edgeMap[p];
     if (e.call() == 0) {
@@ -910,7 +910,7 @@ void GraphExporter::buildGraph(TraceFunction* f, int d,
     if (f2->cycle() == f2) {
       TraceFunction* realF;
       realF = toCallings ? call->called(true) : call->caller(true);
-      QPair<TraceFunction*,TraceFunction*> realP(toCallings ? f:realF,
+      TQPair<TraceFunction*,TraceFunction*> realP(toCallings ? f:realF,
 						 toCallings ? realF:f);
       GraphEdge& e = _edgeMap[realP];
       if (e.call() == 0) {
@@ -969,8 +969,8 @@ PannerView::PannerView(TQWidget * parent, const char * name)
   _movingZoomRect = false;
 
   // why doesn't this avoid flicker ?
-  viewport()->setBackgroundMode(Qt::NoBackground);
-  setBackgroundMode(Qt::NoBackground);
+  viewport()->setBackgroundMode(TQt::NoBackground);
+  setBackgroundMode(TQt::NoBackground);
 }
 
 void PannerView::setZoomRect(TQRect r)
@@ -1057,15 +1057,15 @@ CanvasNode::CanvasNode(CallGraphView* v, GraphNode* n,
         totalCost = (TraceCost*) _view->activeItem();
     }
     else
-	totalCost = _view->data();
+	totalCost = _view->TraceItemView::data();
     double total = totalCost->subCost(_view->costType());
     double inclP  = 100.0 * n->incl / total;
     if (_view->topLevel()->showPercentage())
 	setText(1, TQString("%1 %")
-		.arg(inclP, 0, 'f', Configuration::percentPrecision()));
+		.tqarg(inclP, 0, 'f', Configuration::percentPrecision()));
     else
 	setText(1, SubCost(n->incl).pretty());
-    setPixmap(1, percentagePixmap(25,10,(int)(inclP+.5), Qt::blue, true));
+    setPixmap(1, percentagePixmap(25,10,(int)(inclP+.5), TQt::blue, true));
 }
 
 void CanvasNode::setSelected(bool s)
@@ -1095,8 +1095,8 @@ void CanvasNode::drawShape(TQPainter& p)
   r.setRect(r.x()+2, r.y()+2, r.width()-4, r.height()-4);
 
   if (StoredDrawParams::selected() && _view->hasFocus()) {
-    _view->style().drawPrimitive( TQStyle::PE_FocusRect, &p, r,
-				  _view->colorGroup());
+    _view->tqstyle().tqdrawPrimitive( TQStyle::PE_FocusRect, &p, r,
+				  _view->tqcolorGroup());
   }
 
   // draw afterwards to always get a frame even when zoomed
@@ -1121,7 +1121,7 @@ CanvasEdgeLabel::CanvasEdgeLabel(CallGraphView* v, CanvasEdge* ce,
     if (!e) return;
 
     setPosition(1, DrawParams::TopCenter);
-    setText(1, TQString("%1 x").arg(SubCost(e->count).pretty()));
+    setText(1, TQString("%1 x").tqarg(SubCost(e->count).pretty()));
 
     setPosition(0, DrawParams::BottomCenter);
 
@@ -1137,15 +1137,15 @@ CanvasEdgeLabel::CanvasEdgeLabel(CallGraphView* v, CanvasEdge* ce,
         totalCost = (TraceCost*) _view->activeItem();
     }
     else
-        totalCost = _view->data();
+        totalCost = _view->TraceItemView::data();
     double total = totalCost->subCost(_view->costType());
     double inclP  = 100.0 * e->cost / total;
     if (_view->topLevel()->showPercentage())
         setText(0, TQString("%1 %")
-		.arg(inclP, 0, 'f', Configuration::percentPrecision()));
+		.tqarg(inclP, 0, 'f', Configuration::percentPrecision()));
     else
         setText(0, SubCost(e->cost).pretty());
-    setPixmap(0, percentagePixmap(25,10,(int)(inclP+.5), Qt::blue, true));
+    setPixmap(0, percentagePixmap(25,10,(int)(inclP+.5), TQt::blue, true));
 
     if (e->call() && (e->call()->isRecursion() || e->call()->inCycle())) {
 	TQString icon = "undo";
@@ -1175,7 +1175,7 @@ CanvasEdgeArrow::CanvasEdgeArrow(CanvasEdge* ce, TQCanvas* c)
 
 void CanvasEdgeArrow::drawShape(TQPainter& p)
 {
-    if (_ce->isSelected()) p.setBrush(Qt::red);
+    if (_ce->isSelected()) p.setBrush(TQt::red);
 
     TQCanvasPolygon::drawShape(p);
 }
@@ -1237,7 +1237,7 @@ TQPointArray CanvasEdge::areaPoints() const
 
 void CanvasEdge::drawShape(TQPainter& p)
 {
-    if (isSelected()) p.setPen(Qt::red);
+    if (isSelected()) p.setPen(TQt::red);
 
     p.drawPolyline(poly);
 }
@@ -1265,9 +1265,9 @@ CanvasFrame::CanvasFrame(CanvasNode* n, TQCanvas* c)
     }
 
     _p = new TQPixmap(r.size());
-    _p->fill(Qt::white);
+    _p->fill(TQt::white);
     TQPainter p(_p);
-    p.setPen(Qt::NoPen);
+    p.setPen(TQt::NoPen);
 
     r.moveBy(-r.x(), -r.y());
 
@@ -1302,7 +1302,7 @@ void CanvasFrame::drawShape(TQPainter& p)
 // Tooltips for CallGraphView
 //
 
-class CallGraphTip: public QToolTip
+class CallGraphTip: public TQToolTip
 {
 public:
   CallGraphTip( TQWidget* p ):TQToolTip(p) {}
@@ -1331,7 +1331,7 @@ void CallGraphTip::maybeTip( const TQPoint& pos )
       if (0) qDebug("CallGraphTip: Mouse on Node '%s'",
 		    n->function()->prettyName().ascii());
 
-      TQString tipStr = TQString("%1 (%2)").arg(cn->text(0)).arg(cn->text(1));
+      TQString tipStr = TQString("%1 (%2)").tqarg(cn->text(0)).tqarg(cn->text(1));
       TQPoint vPosTL = cgv->contentsToViewport(i->boundingRect().topLeft());
       TQPoint vPosBR = cgv->contentsToViewport(i->boundingRect().bottomRight());
       tip(TQRect(vPosTL, vPosBR), tipStr);
@@ -1356,7 +1356,7 @@ void CallGraphTip::maybeTip( const TQPoint& pos )
 	  tipStr = e->prettyName();
       else
 	  tipStr = TQString("%1 (%2)")
-	      .arg(ce->label()->text(0)).arg(ce->label()->text(1));
+	      .tqarg(ce->label()->text(0)).tqarg(ce->label()->text(1));
       tip(TQRect(pos.x()-5,pos.y()-5,pos.x()+5,pos.y()+5), tipStr);
   }
 }
@@ -1388,8 +1388,8 @@ CallGraphView::CallGraphView(TraceItemView* parentView,
   _completeView->raise();
   _completeView->hide();
 
-  setFocusPolicy(TQWidget::StrongFocus);
-  setBackgroundMode(Qt::NoBackground);
+  setFocusPolicy(TQ_StrongFocus);
+  setBackgroundMode(TQt::NoBackground);
 
   connect(this, TQT_SIGNAL(contentsMoving(int,int)),
           this, TQT_SLOT(contentsMovingSlot(int,int)));
@@ -1589,7 +1589,7 @@ void CallGraphView::keyPressEvent(TQKeyEvent* e)
 	TraceFunction* f = 0;
 	TraceCall* c = 0;
 
-	// rotate arrow key meaning for LeftRight layout
+	// rotate arrow key meaning for LeftRight tqlayout
 	int key = e->key();
 	if (_layout == LeftRight) {
 	    switch(key) {
@@ -1745,7 +1745,7 @@ void CallGraphView::doUpdate(int changeType)
   }
 
   if (changeType & dataChanged) {
-      // invalidate old selection and graph part
+      // tqinvalidate old selection and graph part
     _exporter.reset(_data, _activeItem, _costType, _groupType);
       _selectedNode = 0;
       _selectedEdge = 0;
@@ -1792,8 +1792,8 @@ void CallGraphView::showRenderWarning()
     s = i18n("Layouting stopped.\n");
   
   s.append(i18n("The call graph has %1 nodes and %2 edges.\n")
-	   .arg(_exporter.nodeCount())
-	   .arg(_exporter.edgeCount()));
+	   .tqarg(_exporter.nodeCount())
+	   .tqarg(_exporter.edgeCount()));
 
   showText(s);
 }
@@ -1805,7 +1805,7 @@ void CallGraphView::stopRendering()
   _renderProcess->kill();
   delete _renderProcess;
   _renderProcess = 0;
-  _unparsedOutput = TQString::null;
+  _unparsedOutput = TQString();
 
   _renderTimer.start(200, true);
 }
@@ -1846,7 +1846,7 @@ void CallGraphView::refresh()
   _exporter.reset(_data, _activeItem, _costType, _groupType);
   _exporter.writeDot();
 
-  _renderProcess = new TQProcess(this);
+  _renderProcess = new TQProcess(TQT_TQOBJECT(this));
   if (_layout == GraphOptions::Circular)
     _renderProcess->addArgument( "twopi" );
   else
@@ -1866,7 +1866,7 @@ void CallGraphView::refresh()
   if ( !_renderProcess->start() ) {
     TQString e = i18n("No call graph is available because the following\n"
 		     "command cannot be run:\n'%1'\n")
-      .arg(_renderProcess->arguments().join(" "));
+      .tqarg(_renderProcess->arguments().join(" "));
     e += i18n("Please check that 'dot' is installed (package GraphViz).");
     showText(e);
 
@@ -1876,7 +1876,7 @@ void CallGraphView::refresh()
     return;
   }
 
-  _unparsedOutput = TQString::null;
+  _unparsedOutput = TQString();
 
   // layouting of more than seconds is dubious
   _renderTimer.start(1000, true);  
@@ -2003,7 +2003,7 @@ void CallGraphView::dotExited()
 	  w = 10, h = 10;
         eItem = new TQCanvasEllipse(w, h, _canvas);
         eItem->move(xx, yy);
-        eItem->setBrush(Qt::gray);
+        eItem->setBrush(TQt::gray);
         eItem->setZ(1.0);
         eItem->show();
         continue;
@@ -2074,11 +2074,11 @@ void CallGraphView::dotExited()
     }
 
     // calls into/out of cycles are special: make them blue
-    TQColor arrowColor = Qt::black;
+    TQColor arrowColor = TQt::black;
     TraceFunction* caller = e->fromNode() ? e->fromNode()->function() : 0;
     TraceFunction* called = e->toNode() ? e->toNode()->function() : 0;
     if ( (caller && (caller->cycle() == caller)) ||
-         (called && (called->cycle() == called)) ) arrowColor = Qt::blue;
+         (called && (called->cycle() == called)) ) arrowColor = TQt::blue;
 
     sItem = new CanvasEdge(e, _canvas);
     e->setCanvasEdge(sItem);
@@ -2206,8 +2206,8 @@ void CallGraphView::dotExited()
     TQString s = i18n("There is no call graph available for function\n"
 		     "\t'%1'\n"
 		     "because it has no cost of the selected event type.");
-    TQCanvasText* t = new TQCanvasText(s.arg(_activeItem->name()), _canvas);
-    //    t->setTextFlags(Qt::AlignHCenter | Qt::AlignVCenter);
+    TQCanvasText* t = new TQCanvasText(s.tqarg(_activeItem->name()), _canvas);
+    //    t->setTextFlags(TQt::AlignHCenter | TQt::AlignVCenter);
     t->move(5,5);
     t->show();
     center(0,0);
@@ -2394,10 +2394,10 @@ void CallGraphView::contentsContextMenuEvent(TQContextMenuEvent* e)
 
       TQString name = f->prettyName();
       popup.insertItem(i18n("Go to '%1'")
-		     .arg(Configuration::shortenSymbol(name)), 93);
+		     .tqarg(Configuration::shortenSymbol(name)), 93);
       if (cycle && (cycle != f)) {
 	name = Configuration::shortenSymbol(cycle->prettyName());
-	popup.insertItem(i18n("Go to '%1'").arg(name), 94);
+	popup.insertItem(i18n("Go to '%1'").tqarg(name), 94);
       }
       popup.insertSeparator();
     }
@@ -2416,7 +2416,7 @@ void CallGraphView::contentsContextMenuEvent(TQContextMenuEvent* e)
       if (c) {
 	  TQString name = c->prettyName();
 	  popup.insertItem(i18n("Go to '%1'")
-			   .arg(Configuration::shortenSymbol(name)), 95);
+			   .tqarg(Configuration::shortenSymbol(name)), 95);
 
 	  popup.insertSeparator();
       }
@@ -2457,7 +2457,7 @@ void CallGraphView::contentsContextMenuEvent(TQContextMenuEvent* e)
   case 10: gpopup1.setItemChecked(104,true); break;
   case 15: gpopup1.setItemChecked(105,true); break;
   default:
-    gpopup1.insertItem(i18n("< %1").arg(_maxCallerDepth), 106);
+    gpopup1.insertItem(i18n("< %1").tqarg(_maxCallerDepth), 106);
     gpopup1.setItemChecked(106,true); break;
   }
 
@@ -2480,7 +2480,7 @@ void CallGraphView::contentsContextMenuEvent(TQContextMenuEvent* e)
   case 10: gpopup2.setItemChecked(114,true); break;
   case 15: gpopup2.setItemChecked(115,true); break;
   default:
-    gpopup2.insertItem(i18n("< %1").arg(_maxCallingDepth), 116);
+    gpopup2.insertItem(i18n("< %1").tqarg(_maxCallingDepth), 116);
     gpopup2.setItemChecked(116,true); break;
   }
 
@@ -2584,7 +2584,7 @@ void CallGraphView::contentsContextMenuEvent(TQContextMenuEvent* e)
 	  TraceFunction* f = activeFunction();
 	  if (!f) break;
 
-	  GraphExporter ge(data(), f, costType(), groupType(),
+	  GraphExporter ge(TraceItemView::data(), f, costType(), groupType(),
 			   TQString("callgraph.dot"));
 	  ge.setGraphOptions(this);
 	  ge.writeDot();
@@ -2701,7 +2701,7 @@ void CallGraphView::readViewConfig(KConfig* c,
     _clusterGroups   = g->readBoolEntry("ClusterGroups",
 					DEFAULT_CLUSTERGROUPS);
     _detailLevel     = g->readNumEntry("DetailLevel", DEFAULT_DETAILLEVEL);
-    _layout          = GraphOptions::layout(g->readEntry("Layout",
+    _layout          = GraphOptions::tqlayout(g->readEntry("Layout",
 					   layoutString(DEFAULT_LAYOUT)));
     _zoomPosition    = zoomPos(g->readEntry("ZoomPosition",
 					    zoomPosString(DEFAULT_ZOOMPOS)));
