@@ -115,12 +115,12 @@ TQString CallMapView::whatsThis() const
              "choose 'Hide incorrect borders'. As this mode can be "
              "<em>very</em> time consuming, you may want to limit "
              "the maximum drawn nesting level before. "
-             "'Best' determinates the split direction for children "
+             "'Best' determinates the split direction for tqchildren "
              "from the aspect ratio of the parent. "
              "'Always Best' decides on remaining space for each "
              "sibling. "
              "'Ignore Proportions' takes space for function name "
-             "drawing <em>before</em> drawing children. Note that "
+             "drawing <em>before</em> drawing tqchildren. Note that "
              "size proportions can get <em>heavily</em> wrong.</p>"
 
              "<p>This is a <em>TreeMap</em> widget. "
@@ -196,13 +196,13 @@ void CallMapView::context(TreeMapItem* i,const TQPoint & p)
   if (i) {
     l1popup.insertSeparator();
     l1popup.insertItem(i18n("Depth of '%1' (%2)")
-                       .arg(shortCurrentName).arg(i->depth()), 55);
+                       .tqarg(shortCurrentName).tqarg(i->depth()), 55);
     l1popup.setItemChecked(55, maxDepth == i->depth());
   }
   if (maxDepth>0) {
     l1popup.insertSeparator();
-    l1popup.insertItem(i18n("Decrement Depth (to %1)").arg(maxDepth-1), 56);
-    l1popup.insertItem(i18n("Increment Depth (to %1)").arg(maxDepth+1), 57);
+    l1popup.insertItem(i18n("Decrement Depth (to %1)").tqarg(maxDepth-1), 56);
+    l1popup.insertItem(i18n("Increment Depth (to %1)").tqarg(maxDepth+1), 57);
   }
 
   l2popup.setCheckable(true);
@@ -256,15 +256,15 @@ void CallMapView::context(TreeMapItem* i,const TQPoint & p)
     currentArea = i->width() * i->height();
     l3popup.insertSeparator();
     l3popup.insertItem(i18n("Area of '%1' (%2)")
-                       .arg(shortCurrentName).arg(currentArea), 67);
+                       .tqarg(shortCurrentName).tqarg(currentArea), 67);
     l3popup.setItemChecked(67, mArea == currentArea);
   }
   if (mArea>0) {
     l3popup.insertSeparator();
     l3popup.insertItem(i18n("Double Area Limit (to %1)")
-                       .arg(mArea*2), 68);
+                       .tqarg(mArea*2), 68);
     l3popup.insertItem(i18n("Half Area Limit (to %1)")
-                       .arg(mArea/2), 69);
+                       .tqarg(mArea/2), 69);
   }
 
   popup.insertSeparator();
@@ -389,7 +389,7 @@ void CallMapView::context(TreeMapItem* i,const TQPoint & p)
   case 56: setMaxDrawingDepth(maxDepth-1); break;
   case 57: setMaxDrawingDepth(maxDepth+1); break;
 
-  case 200: setFieldStop(0, TQString::null); break;
+  case 200: setFieldStop(0, TQString()); break;
 
   case 60: setMinimalArea(-1); break;
   case 61: setMinimalArea(10); break;
@@ -428,7 +428,7 @@ void CallMapView::selectedSlot(TreeMapItem* item, bool kbd)
   if (item->text(0).isEmpty()) return;
 
   if (kbd) {
-      TQString msg = i18n("Call Map: Current is '%1'").arg(item->text(0));
+      TQString msg = i18n("Call Map: Current is '%1'").tqarg(item->text(0));
       if (_topLevel)
 	  _topLevel->showMessage(msg, 5000);
   }
@@ -531,7 +531,7 @@ void CallMapView::doUpdate(int changeType)
 TQColor CallMapView::groupColor(TraceFunction* f) const
 {
   if (!f)
-    return colorGroup().button();
+    return tqcolorGroup().button();
 
   return Configuration::functionColor(_groupType, f);
 }
@@ -601,11 +601,11 @@ TQString CallMapBaseItem::text(int textNo) const
     return _f->prettyName();
   }
 
-  if (!_f) return TQString::null;
+  if (!_f) return TQString();
 
   if (textNo == 2) return _f->prettyLocation();
   if (textNo == 3) return _f->calledCount().pretty();
-  if (textNo != 1) return TQString::null;
+  if (textNo != 1) return TQString();
 
   TraceCostType* ct = ((CallMapView*)widget())->costType();
   TraceCost* t      = ((CallMapView*)widget())->totalCost();
@@ -618,7 +618,7 @@ TQString CallMapBaseItem::text(int textNo) const
 	  sum = 100.0 * _f->inclusive()->subCost(ct) / total;
 
       return TQString("%1 %")
-	  .arg(sum, 0, 'f', Configuration::percentPrecision());
+	  .tqarg(sum, 0, 'f', Configuration::percentPrecision());
   }
   return _f->inclusive()->prettySubCost(ct);
 }
@@ -663,7 +663,7 @@ bool CallMapBaseItem::isMarked(int) const
     return ((CallMapView*)widget())->selectedItem() == _f;
 }
 
-TreeMapItemList* CallMapBaseItem::children()
+TreeMapItemList* CallMapBaseItem::tqchildren()
 {
   if (_f && !initialized()) {
     CallMapView* w = (CallMapView*)widget();
@@ -706,7 +706,7 @@ TreeMapItemList* CallMapBaseItem::children()
     setSorting(-2, false);
   }
 
-  return _children;
+  return _tqchildren;
 }
 
 TQColor CallMapBaseItem::backColor() const
@@ -745,7 +745,7 @@ TQString CallMapCallingItem::text(int textNo) const
 
   if (textNo == 2) return _c->called()->prettyLocation();
   if (textNo == 3) return SubCost(_factor * _c->callCount()).pretty();
-  if (textNo != 1) return TQString::null;
+  if (textNo != 1) return TQString();
 
   TraceCostType* ct;
   ct = ((CallMapView*)widget())->costType();
@@ -756,7 +756,7 @@ TQString CallMapCallingItem::text(int textNo) const
     TraceCost* t = ((CallMapView*)widget())->totalCost();
     double p  = 100.0 * _factor * _c->subCost(ct) / t->subCost(ct);
     return TQString("%1 %")
-      .arg(p, 0, 'f', Configuration::percentPrecision());
+      .tqarg(p, 0, 'f', Configuration::percentPrecision());
   }
   return val.pretty();
 }
@@ -792,7 +792,7 @@ bool CallMapCallingItem::isMarked(int) const
 }
 
 
-TreeMapItemList* CallMapCallingItem::children()
+TreeMapItemList* CallMapCallingItem::tqchildren()
 {
   if (!initialized()) {
     if (0) qDebug("Create Calling subitems (%s)", path(0).join("/").ascii());
@@ -832,7 +832,7 @@ TreeMapItemList* CallMapCallingItem::children()
     setSorting(-2, false);
   }
 
-  return _children;
+  return _tqchildren;
 }
 
 
@@ -862,7 +862,7 @@ TQString CallMapCallerItem::text(int textNo) const
 
   if (textNo == 2) return _c->caller()->prettyLocation();
   if (textNo == 3) return SubCost(_factor * _c->callCount()).pretty();
-  if (textNo != 1) return TQString::null;
+  if (textNo != 1) return TQString();
 
   TraceCostType* ct;
   ct = ((CallMapView*)widget())->costType();
@@ -872,7 +872,7 @@ TQString CallMapCallerItem::text(int textNo) const
     TraceCost* t = ((CallMapView*)widget())->totalCost();
     double p  = 100.0 * _factor * _c->subCost(ct) / t->subCost(ct);
     return TQString("%1 %")
-      .arg(p, 0, 'f', Configuration::percentPrecision());
+      .tqarg(p, 0, 'f', Configuration::percentPrecision());
   }
   return val.pretty();
 }
@@ -904,7 +904,7 @@ bool CallMapCallerItem::isMarked(int) const
 }
 
 
-TreeMapItemList* CallMapCallerItem::children()
+TreeMapItemList* CallMapCallerItem::tqchildren()
 {
   if (!initialized()) {
     //qDebug("Create Caller subitems (%s)", name().ascii());
@@ -939,7 +939,7 @@ TreeMapItemList* CallMapCallerItem::children()
     setSorting(-2, false);
   }
 
-  return _children;
+  return _tqchildren;
 }
 
 TQColor CallMapCallerItem::backColor() const
