@@ -17,7 +17,7 @@
 */
 
 /*
- * For function selection, to be put into a QDockWindow
+ * For function selection, to be put into a TQDockWindow
  */
 
 #include <tqtimer.h>
@@ -72,9 +72,9 @@ FunctionSelection::FunctionSelection( TopLevel* top,
 
   // we start with desending cost sorting
   functionList->setSorting(0,false);
-  functionList->setColumnAlignment(0, Qt::AlignRight);
-  functionList->setColumnAlignment(1, Qt::AlignRight);
-  functionList->setColumnAlignment(2, Qt::AlignRight);
+  functionList->setColumnAlignment(0, TQt::AlignRight);
+  functionList->setColumnAlignment(1, TQt::AlignRight);
+  functionList->setColumnAlignment(2, TQt::AlignRight);
   functionList->setAllColumnsShowFocus(true);
   // functionList->setShowSortIndicator(true);
   // we can have very long function and location names
@@ -84,7 +84,7 @@ FunctionSelection::FunctionSelection( TopLevel* top,
   functionList->setColumnWidth(4, 200);
 
   groupList->setSorting(0,false);
-  groupList->setColumnAlignment(0, Qt::AlignRight);
+  groupList->setColumnAlignment(0, TQt::AlignRight);
   groupList->setAllColumnsShowFocus(true);
   // groupList->setShowSortIndicator(true);
   groupList->setResizeMode(TQListView::LastColumn);
@@ -173,7 +173,7 @@ void FunctionSelection::functionContext(TQListViewItem* i,
   if (i) {
       f = ((FunctionItem*) i)->function();
       if (f) {
-	  popup.insertItem(i18n("Go to %1").arg(f->prettyName()), 93);
+	  popup.insertItem(i18n("Go to %1").tqarg(f->prettyName()), 93);
 	  popup.insertSeparator();
       }
   }
@@ -305,8 +305,8 @@ void FunctionSelection::doUpdate(int changeType)
 	}
 
 	// reset searchEdit (as not activated from this view)
-	_searchString = TQString::null;
-	query(TQString::null);
+	_searchString = TQString();
+	query(TQString());
 
 	// select cost item group of function
 	switch(_groupType) {
@@ -368,8 +368,8 @@ void FunctionSelection::doUpdate(int changeType)
     }
 
     // reset searchEdit
-    _searchString = TQString::null;
-    query(TQString::null);
+    _searchString = TQString();
+    query(TQString());
 
     refresh();
 }
@@ -417,7 +417,7 @@ void FunctionSelection::refresh()
     if (!_data || _data->parts().count()==0) {
 	functionList->clear();
 	groupList->setUpdatesEnabled(true);
-	groupList->repaint();
+	groupList->tqrepaint();
 
 	// this clears all other lists
 	functionList->setSelected(functionList->firstChild(), true);
@@ -547,9 +547,9 @@ void FunctionSelection::refresh()
 	functionList->clearSelection();
 
       //functionList->setUpdatesEnabled(true);
-      //functionList->repaint();
+      //functionList->tqrepaint();
       groupList->setUpdatesEnabled(true);
-      groupList->repaint();
+      groupList->tqrepaint();
       return;
     }
   }
@@ -581,7 +581,7 @@ void FunctionSelection::refresh()
     groupList->clearSelection();
 
   groupList->setUpdatesEnabled(true);
-  groupList->repaint();
+  groupList->tqrepaint();
 }
 
 
@@ -628,7 +628,7 @@ void FunctionSelection::groupSelected(TQListViewItem* i)
 #if 0
   if (total == 0.0) {
       functionList->setUpdatesEnabled(true);
-      functionList->repaint();
+      functionList->tqrepaint();
       return;
   }
 #endif
@@ -668,7 +668,7 @@ void FunctionSelection::groupSelected(TQListViewItem* i)
   }
 
   //functionList->setUpdatesEnabled(true);
-  //functionList->repaint();
+  //functionList->tqrepaint();
 
   // Don't emit signal if cost item was changed programatically
   if (!_inSetGroup) {
