@@ -132,8 +132,8 @@ InstrView::InstrView(TraceItemView* parentView,
   addColumn( i18n( "Source Position" ) );
 
   setAllColumnsShowFocus(true);
-  setColumnAlignment(1, Qt::AlignRight);
-  setColumnAlignment(2, Qt::AlignRight);
+  setColumnAlignment(1, TQt::AlignRight);
+  setColumnAlignment(2, TQt::AlignRight);
 
   connect(this,
           TQT_SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint &, int)),
@@ -188,11 +188,11 @@ void InstrView::context(TQListViewItem* i, const TQPoint & p, int c)
     TQString name = f->name();
     if ((int)name.length()>Configuration::maxSymbolLength())
       name = name.left(Configuration::maxSymbolLength()) + "...";
-    popup.insertItem(i18n("Go to '%1'").arg(name), 93);
+    popup.insertItem(i18n("Go to '%1'").tqarg(name), 93);
     popup.insertSeparator();
   }
   else if (instr) {
-    popup.insertItem(i18n("Go to Address %1").arg(instr->name()), 93);
+    popup.insertItem(i18n("Go to Address %1").tqarg(instr->name()), 93);
     popup.insertSeparator();
   }
 
@@ -618,8 +618,8 @@ bool InstrView::fillInstrRange(TraceFunction* function,
     objfile = objfile.replace(TQRegExp("[\"']"), ""); // security...
     popencmd = TQString("objdump -C -d "
                        "--start-address=0x%1 --stop-address=0x%2 \"%3\"")
-	.arg(dumpStartAddr.toString()).arg(dumpEndAddr.toString())
-	.arg(objfile);
+	.tqarg(dumpStartAddr.toString()).tqarg(dumpEndAddr.toString())
+	.tqarg(objfile);
     if (1) qDebug("Running '%s'...", popencmd.ascii());
 
     // and run...
@@ -875,7 +875,7 @@ bool InstrView::fillInstrRange(TraceFunction* function,
                            "There are %n cost lines without assembler code.", noAssLines));
 	new InstrItem(this, this, 2,
 		      i18n("This happens because the code of"));
-	new InstrItem(this, this, 3, TQString("        %1").arg(objfile));
+	new InstrItem(this, this, 3, TQString("        %1").tqarg(objfile));
 	new InstrItem(this, this, 4,
 		      i18n("does not seem to match the profile data file."));
 	new InstrItem(this, this, 5, "");
