@@ -54,9 +54,9 @@ SourceView::SourceView(TraceItemView* parentView,
   addColumn( i18n( "Source (unknown)" ) );
 
   setAllColumnsShowFocus(true);
-  setColumnAlignment(0, Qt::AlignRight);
-  setColumnAlignment(1, Qt::AlignRight);
-  setColumnAlignment(2, Qt::AlignRight);
+  setColumnAlignment(0, TQt::AlignRight);
+  setColumnAlignment(1, TQt::AlignRight);
+  setColumnAlignment(2, TQt::AlignRight);
   setResizeMode(TQListView::LastColumn);
 
   connect(this,
@@ -113,11 +113,11 @@ void SourceView::context(TQListViewItem* i, const TQPoint & p, int c)
     TQString name = f->name();
     if ((int)name.length()>Configuration::maxSymbolLength())
       name = name.left(Configuration::maxSymbolLength()) + "...";
-    popup.insertItem(i18n("Go to '%1'").arg(name), 93);
+    popup.insertItem(i18n("Go to '%1'").tqarg(name), 93);
     popup.insertSeparator();
   }
   else if (line) {
-    popup.insertItem(i18n("Go to Line %1").arg(line->name()), 93);
+    popup.insertItem(i18n("Go to Line %1").tqarg(line->name()), 93);
     popup.insertSeparator();
   }
 
@@ -513,7 +513,7 @@ void SourceView::fillSourceFile(TraceFunctionSource* sf, int fileno)
 	  new SourceItem(this, this, fileno, 1, false,
 			 i18n("with any source line of this function in file"));
 	  new SourceItem(this, this, fileno, 2, false,
-			 TQString("    '%1'").arg(sf->function()->prettyName()));
+			 TQString("    '%1'").tqarg(sf->function()->prettyName()));
 	  new SourceItem(this, this, fileno, 3, false,
 			 i18n("Thus, no annotated source can be shown."));
 	  return;
@@ -550,13 +550,13 @@ void SourceView::fillSourceFile(TraceFunctionSource* sf, int fileno)
   // do it here, because the source directory could have been set before
   if (childCount()==0) {
     setColumnText(4, validSourceFile ?
-                  i18n("Source ('%1')").arg(filename) :
+                  i18n("Source ('%1')").tqarg(filename) :
                   i18n("Source (unknown)"));
   }
   else {
     new SourceItem(this, this, fileno, 0, true,
                    validSourceFile ?
-                   i18n("--- Inlined from '%1' ---").arg(filename) :
+                   i18n("--- Inlined from '%1' ---").tqarg(filename) :
                    i18n("--- Inlined from unknown source ---"));
   }
 
@@ -564,7 +564,7 @@ void SourceView::fillSourceFile(TraceFunctionSource* sf, int fileno)
     new SourceItem(this, this, fileno, 0, false,
                    i18n("There is no source available for the following function:"));
     new SourceItem(this, this, fileno, 1, false,
-                   TQString("    '%1'").arg(sf->function()->prettyName()));
+                   TQString("    '%1'").tqarg(sf->function()->prettyName()));
     if (sf->file()->name().isEmpty()) {
       new SourceItem(this, this, fileno, 2, false,
                      i18n("This is because no debug information is present."));
@@ -575,14 +575,14 @@ void SourceView::fillSourceFile(TraceFunctionSource* sf, int fileno)
                        i18n("The function is located in this ELF object:"));
         new SourceItem(this, this, fileno, 5, false,
                        TQString("    '%1'")
-                       .arg(sf->function()->object()->prettyName()));
+                       .tqarg(sf->function()->object()->prettyName()));
       }
     }
     else {
       new SourceItem(this, this, fileno, 2, false,
                      i18n("This is because its source file cannot be found:"));
       new SourceItem(this, this, fileno, 3, false,
-                     TQString("    '%1'").arg(sf->file()->name()));
+                     TQString("    '%1'").tqarg(sf->file()->name()));
       new SourceItem(this, this, fileno, 4, false,
                      i18n("Add the folder of this file to the source folder list."));
       new SourceItem(this, this, fileno, 5, false,
