@@ -52,7 +52,7 @@ TabBar::TabBar(TabView* v, TQTabWidget* parent, const char *name)
 
 void TabBar::mousePressEvent(TQMouseEvent *e)
 {
-  if (e->button() == RightButton) {
+  if (e->button() == Qt::RightButton) {
       TQTab *tab = selectTab( e->pos() );
       TQWidget* page;
       page = tab ? _tabWidget->page( indexOf( tab->identifier() ) ) :0;
@@ -114,7 +114,7 @@ void TabBar::mousePressEvent(TQMouseEvent *e)
 // Splitter
 //
 
-Splitter::Splitter(Orientation o, TQWidget* parent, const char* name)
+Splitter::Splitter(Qt::Orientation o, TQWidget* parent, const char* name)
   : TQSplitter(o, parent, name)
 {}
 
@@ -128,8 +128,8 @@ void Splitter::moveEvent(TQMoveEvent* e)
 
 void Splitter::checkVisiblity()
 {
-  const TQObjectList *l = children();
-  TQObjectListIt it( *l );
+  const TQObjectList l = childrenListObject();
+  TQObjectListIt it( l );
   TQObject *obj;
   while ( (obj = it.current()) != 0 ) {
     ++it;
@@ -232,7 +232,7 @@ TabView::TabView(TraceItemView* parentView,
                  TQWidget* parent, const char* name)
   : TQWidget(parent, name), TraceItemView(parentView)
 {
-    setFocusPolicy(TQWidget::StrongFocus);
+    setFocusPolicy(TQ_StrongFocus);
 
   _isCollapsed = true;
 
@@ -419,7 +419,7 @@ void TabView::updateVisibility()
   s.append(100);
 
 
-  // children of mainSplitter
+  // tqchildren of mainSplitter
   if (_rightTW->isHidden() != (r == 0)) {
     if (r == 0) {
       _rightTW->hide();
@@ -441,7 +441,7 @@ void TabView::updateVisibility()
       _leftSplitter->show();
   }
 
-  // children of leftSplitter
+  // tqchildren of leftSplitter
   if (_topTW->isHidden() != (t == 0)) {
     if (t == 0) {
       _topTW->hide();
@@ -463,7 +463,7 @@ void TabView::updateVisibility()
       _bottomSplitter->show();
   }
 
-  // children of bottomSplitter
+  // tqchildren of bottomSplitter
   if (_bottomTW->isHidden() != (b == 0)) {
     if (b == 0) {
       _bottomTW->hide();
@@ -580,7 +580,7 @@ TQString TabView::whatsThis() const
 
 void TabView::installFocusFilters()
 {
-    TQObjectList *l = queryList("TQWidget");
+    TQObjectList *l = queryList(TQWIDGET_OBJECT_NAME_STRING);
     TQObjectListIt it( *l );
     TQObject *obj;
 
@@ -700,7 +700,7 @@ void TabView::resizeEvent(TQResizeEvent* e)
 
 void TabView::selected(TraceItemView*, TraceItem* s)
 {
-    // we set selected item for our own children
+    // we set selected item for our own tqchildren
     select(s);
     updateView();
 
@@ -771,7 +771,7 @@ void TabView::readViewConfig(KConfig* c,
 
       if (withOptions)
 	v->readViewConfig(c, TQString("%1-%2")
-			  .arg(prefix).arg(v->widget()->name()),
+			  .tqarg(prefix).tqarg(v->widget()->name()),
 			  postfix, true);
     }
     if (activeTop)   _topTW->showPage(activeTop->widget());
@@ -883,8 +883,8 @@ void TabView::saveViewConfig(KConfig* c,
 
     if (withOptions)
       for (v=_tabs.first();v;v=_tabs.next())
-	v->saveViewConfig(c, TQString("%1-%2").arg(prefix)
-			  .arg(v->widget()->name()), postfix, true);
+	v->saveViewConfig(c, TQString("%1-%2").tqarg(prefix)
+			  .tqarg(v->widget()->name()), postfix, true);
 }
 
 #include "tabview.moc"
