@@ -51,7 +51,7 @@ StoredDrawParams::StoredDrawParams()
   _shaded = true;
   _rotated = false;
 
-  _backColor = Qt::white;
+  _backColor = TQt::white;
 
   // field array has size 0
 }
@@ -73,7 +73,7 @@ StoredDrawParams::StoredDrawParams(TQColor c,
 TQString StoredDrawParams::text(int f) const
 {
   if ((f<0) || (f >= (int)_field.size()))
-    return TQString::null;
+    return TQString();
 
   return _field[f].text;
 }
@@ -269,7 +269,7 @@ void RectDrawing::drawBack(TQPainter* p, DrawParams* dp)
 
   if (dp->shaded()) {
     // some shading
-    bool goDark = qGray(normal.rgb())>128;
+    bool goDark = tqGray(normal.rgb())>128;
     int rBase, gBase, bBase;
     normal.rgb(&rBase, &gBase, &bBase);
     p->setBrush(TQBrush::NoBrush);
@@ -528,7 +528,7 @@ bool RectDrawing::drawField(TQPainter* p, int f, DrawParams* dp)
   }
 
   p->save();
-  p->setPen( (qGray(dp->backColor().rgb())>100) ? Qt::black : Qt::white);
+  p->setPen( (tqGray(dp->backColor().rgb())>100) ? TQt::black : TQt::white);
   p->setFont(dp->font());
   if (rotate) {
     //p->translate(r.x()+2, r.y()+r.height());
@@ -619,7 +619,7 @@ bool RectDrawing::drawField(TQPainter* p, int f, DrawParams* dp)
       }
     }
     else
-      remaining = TQString::null;
+      remaining = TQString();
 
     /* truncate and add ... if needed */
     if (w>width) {
@@ -658,7 +658,7 @@ bool RectDrawing::drawField(TQPainter* p, int f, DrawParams* dp)
 
     p->drawText( x+pixW, y,
 		 width - pixW, h,
-		 Qt::AlignLeft, name);
+		 TQt::AlignLeft, name);
     y = isBottom ? (y-h) : (y+h);
     lines--;
 
@@ -759,7 +759,7 @@ TreeMapItem::TreeMapItem(TreeMapItem* parent, double value)
   _parent = parent;
 
   _sum = 0;
-  _children = 0;
+  _tqchildren = 0;
   _widget = 0;
   _index = -1;
   _depth = -1; // not set
@@ -792,7 +792,7 @@ TreeMapItem::TreeMapItem(TreeMapItem* parent, double value,
   setText(0, text1);
 
   _sum = 0;
-  _children = 0;
+  _tqchildren = 0;
   _widget = 0;
   _index = -1;
   _depth = -1; // not set
@@ -804,7 +804,7 @@ TreeMapItem::TreeMapItem(TreeMapItem* parent, double value,
 
 TreeMapItem::~TreeMapItem()
 {
-  if (_children) delete _children;
+  if (_tqchildren) delete _tqchildren;
   if (_freeRects) delete _freeRects;
 
   // finally, notify widget about deletion
@@ -845,18 +845,18 @@ void TreeMapItem::redraw()
 
 void TreeMapItem::clear()
 {
-  if (_children) {
+  if (_tqchildren) {
     // delete selected items below this item from selection
     if (_widget) _widget->clearSelection(this);
 
-    delete _children;
-    _children = 0;
+    delete _tqchildren;
+    _tqchildren = 0;
   }
 }
 
 
-// invalidates current children and forces redraw
-// this is only usefull when children are created on demand in items()
+// invalidates current tqchildren and forces redraw
+// this is only usefull when tqchildren are created on demand in items()
 void TreeMapItem::refresh()
 {
   clear();
@@ -890,9 +890,9 @@ int TreeMapItem::depth() const
 
 bool TreeMapItem::initialized()
 {
-  if (!_children) {
-    _children = new TreeMapItemList;
-    _children->setAutoDelete(true);
+  if (!_tqchildren) {
+    _tqchildren = new TreeMapItemList;
+    _tqchildren->setAutoDelete(true);
     return false;
   }
   return true;
@@ -902,16 +902,16 @@ void TreeMapItem::addItem(TreeMapItem* i)
 {
   if (!i) return;
 
-  if (!_children) {
-    _children = new TreeMapItemList;
-    _children->setAutoDelete(true);
+  if (!_tqchildren) {
+    _tqchildren = new TreeMapItemList;
+    _tqchildren->setAutoDelete(true);
   }
   i->setParent(this);
 
   if (sorting(0) == -1)
-    _children->append(i); // preserve insertion order
+    _tqchildren->append(i); // preserve insertion order
   else
-    _children->inSort(i);
+    _tqchildren->inSort(i);
 }
 
 
@@ -977,17 +977,17 @@ void TreeMapItem::setSorting(int textNo, bool ascending)
     _sortAscending = ascending;
     _sortTextNo = textNo;
 
-    if (_children && _sortTextNo != -1) _children->sort();
+    if (_tqchildren && _sortTextNo != -1) _tqchildren->sort();
 }
 
 void TreeMapItem::resort(bool recursive)
 {
-  if (!_children) return;
+  if (!_tqchildren) return;
 
-  if (_sortTextNo != -1) _children->sort();
+  if (_sortTextNo != -1) _tqchildren->sort();
 
   if (recursive)
-    for (TreeMapItem* i=_children->first(); i; i=_children->next())
+    for (TreeMapItem* i=_tqchildren->first(); i; i=_tqchildren->next())
       i->resort(recursive);
 }
 
@@ -1005,13 +1005,13 @@ int TreeMapItem::rtti() const
   return 0;
 }
 
-TreeMapItemList* TreeMapItem::children()
+TreeMapItemList* TreeMapItem::tqchildren()
 {
-  if (!_children) {
-    _children = new TreeMapItemList;
-    _children->setAutoDelete(true);
+  if (!_tqchildren) {
+    _tqchildren = new TreeMapItemList;
+    _tqchildren->setAutoDelete(true);
   }
-  return _children;
+  return _tqchildren;
 }
 
 void TreeMapItem::clearItemRect()
@@ -1075,7 +1075,7 @@ void TreeMapItem::addFreeRect(const TQRect& r)
 
 // Tooltips for TreeMapWidget
 
-class TreeMapTip: public QToolTip
+class TreeMapTip: public TQToolTip
 {
 public:
   TreeMapTip( TQWidget* p ):TQToolTip(p) {}
@@ -1147,8 +1147,8 @@ TreeMapWidget::TreeMapWidget(TreeMapItem* base,
   _lastOver = 0;
   _needsRefresh = _base;
 
-  setBackgroundMode(Qt::NoBackground);
-  setFocusPolicy(TQWidget::StrongFocus);
+  setBackgroundMode(TQt::NoBackground);
+  setFocusPolicy(TQ_StrongFocus);
   _tip = new TreeMapTip(this);
 }
 
@@ -1278,7 +1278,7 @@ void TreeMapWidget::setMaxDrawingDepth(int d)
 
 TQString TreeMapWidget::defaultFieldType(int f) const
 {
-  return i18n("Text %1").arg(f+1);
+  return i18n("Text %1").tqarg(f+1);
 }
 
 TQString TreeMapWidget::defaultFieldStop(int) const
@@ -1504,11 +1504,11 @@ TreeMapItem* TreeMapWidget::item(int x, int y) const
   TreeMapItem* p = _base;
   TreeMapItem* i;
 
-  if (!rect().contains(x, y)) return 0;
+  if (!TQT_TQRECT_OBJECT(rect()).contains(x, y)) return 0;
   if (DEBUG_DRAWING) kdDebug(90100) << "item(" << x << "," << y << "):" << endl;
 
   while (1) {
-    TreeMapItemList* list = p->children();
+    TreeMapItemList* list = p->tqchildren();
     if (!list)
       i = 0;
     else {
@@ -1517,11 +1517,11 @@ TreeMapItem* TreeMapWidget::item(int x, int y) const
 
         if (DEBUG_DRAWING)
 	    kdDebug(90100) << "  Checking " << i->path(0).join("/") << " ("
-		      << i->itemRect().x() << "/" << i->itemRect().y()
-		      << "-" << i->itemRect().width() 
-		      << "x" << i->itemRect().height() << ")" << endl;
+		      << i->tqitemRect().x() << "/" << i->tqitemRect().y()
+		      << "-" << i->tqitemRect().width() 
+		      << "x" << i->tqitemRect().height() << ")" << endl;
 
-        if (i->itemRect().contains(x, y)) {
+        if (i->tqitemRect().contains(x, y)) {
 
 	    if (DEBUG_DRAWING) kdDebug(90100) << "  .. Got. Index " << idx << endl;
 
@@ -1539,7 +1539,7 @@ TreeMapItem* TreeMapWidget::item(int x, int y) const
         if (DEBUG_DRAWING)
 	    kdDebug(90100) << "item(" << x << "," << y << "): Got " 
 		      << p->path(0).join("/") << " (Size " 
-		      << p->itemRect().width() << "x" << p->itemRect().height()
+		      << p->tqitemRect().width() << "x" << p->tqitemRect().height()
 		      << ", Val " << p->value() << ")" << endl;
       }
 
@@ -1568,16 +1568,16 @@ TreeMapItem* TreeMapWidget::visibleItem(TreeMapItem* i) const
 {
   if (i) {
     /* Must have a visible area */
-    while(i && ((i->itemRect().width() <1) ||
-                (i->itemRect().height() <1))) {
+    while(i && ((i->tqitemRect().width() <1) ||
+                (i->tqitemRect().height() <1))) {
       TreeMapItem* p = i->parent();
       if (!p) break;
-      int idx = p->children()->findRef(i);
+      int idx = p->tqchildren()->findRef(i);
       idx--;
       if (idx<0)
         i = p;
       else
-        i = p->children()->at(idx);
+        i = p->tqchildren()->at(idx);
     }
   }
   return i;
@@ -1771,7 +1771,7 @@ TreeMapItem* TreeMapWidget::setTmpRangeSelection(TreeMapItem* i1,
     i2 = i2->parent();
   if (!i2) return changed;
 
-  TreeMapItemList* list = commonParent->children();
+  TreeMapItemList* list = commonParent->tqchildren();
   if (!list) return changed;
 
   TreeMapItem* i = list->first();
@@ -1794,11 +1794,11 @@ void TreeMapWidget::contextMenuEvent( TQContextMenuEvent* e )
 {
   //kdDebug(90100) << "TreeMapWidget::contextMenuEvent" << endl;
 
-  if ( receivers( TQT_SIGNAL(contextMenuRequested(TreeMapItem*, const TQPoint &)) ) )
+  if ( tqreceivers( TQT_SIGNAL(contextMenuRequested(TreeMapItem*, const TQPoint &)) ) )
     e->accept();
 
   if ( e->reason() == TQContextMenuEvent::Keyboard ) {
-    TQRect r = (_current) ? _current->itemRect() : _base->itemRect();
+    TQRect r = (_current) ? _current->tqitemRect() : _base->tqitemRect();
     TQPoint p = TQPoint(r.left() + r.width()/2, r.top() + r.height()/2);
     emit contextMenuRequested(_current, p);
   }
@@ -1852,7 +1852,7 @@ void TreeMapWidget::mousePressEvent( TQMouseEvent* e )
   }
 
   // item under mouse always selected on right button press
-  if (e->button() == RightButton) {
+  if (e->button() == Qt::RightButton) {
     TreeMapItem* changed2 = setTmpSelected(item, true);
     if (changed2) changed = changed2->commonParent(changed);
   }
@@ -1862,7 +1862,7 @@ void TreeMapWidget::mousePressEvent( TQMouseEvent* e )
   if (changed)
     redraw(changed);
 
-  if (e->button() == RightButton) {    
+  if (e->button() == Qt::RightButton) {
 
     // emit selection change
     if (! (_tmpSelection == _selection)) {
@@ -1962,14 +1962,14 @@ void TreeMapWidget::mouseDoubleClickEvent( TQMouseEvent* e )
 int nextVisible(TreeMapItem* i)
 {
   TreeMapItem* p = i->parent();
-  if (!p || p->itemRect().isEmpty()) return -1;
+  if (!p || p->tqitemRect().isEmpty()) return -1;
 
-  int idx = p->children()->findRef(i);
+  int idx = p->tqchildren()->findRef(i);
   if (idx<0) return -1;
 
-  while (idx < (int)p->children()->count()-1) {
+  while (idx < (int)p->tqchildren()->count()-1) {
     idx++;
-    TQRect r = p->children()->at(idx)->itemRect();
+    TQRect r = p->tqchildren()->at(idx)->tqitemRect();
     if (r.width()>1 && r.height()>1)
       return idx;
   }
@@ -1980,14 +1980,14 @@ int nextVisible(TreeMapItem* i)
 int prevVisible(TreeMapItem* i)
 {
   TreeMapItem* p = i->parent();
-  if (!p || p->itemRect().isEmpty()) return -1;
+  if (!p || p->tqitemRect().isEmpty()) return -1;
 
-  int idx = p->children()->findRef(i);
+  int idx = p->tqchildren()->findRef(i);
   if (idx<0) return -1;
 
   while (idx > 0) {
     idx--;
-    TQRect r = p->children()->at(idx)->itemRect();
+    TQRect r = p->tqchildren()->at(idx)->tqitemRect();
     if (r.width()>1 && r.height()>1)
       return idx;
   }
@@ -2068,24 +2068,24 @@ void TreeMapWidget::keyPressEvent( TQKeyEvent* e )
     int newIdx = goBack ? nextVisible(_current) : prevVisible(_current);
     if (p && newIdx>=0) {
       p->setIndex(newIdx);
-      setCurrent(p->children()->at(newIdx), true);
+      setCurrent(p->tqchildren()->at(newIdx), true);
     }
   }
   else if (e->key() == Key_Right) {
     int newIdx = goBack ? prevVisible(_current) : nextVisible(_current);
     if (p && newIdx>=0) {
       p->setIndex(newIdx);
-      setCurrent(p->children()->at(newIdx), true);
+      setCurrent(p->tqchildren()->at(newIdx), true);
     }
   }
   else if (e->key() == Key_Down) {
-    if (_current->children() && _current->children()->count()>0) {
+    if (_current->tqchildren() && _current->tqchildren()->count()>0) {
       int newIdx = _current->index();
       if (newIdx<0)
-        newIdx = goBack ? (_current->children()->count()-1) : 0;
-      if (newIdx>=(int)_current->children()->count())
-        newIdx = _current->children()->count()-1;
-      newItem = visibleItem(_current->children()->at(newIdx));
+        newIdx = goBack ? (_current->tqchildren()->count()-1) : 0;
+      if (newIdx>=(int)_current->tqchildren()->count())
+        newIdx = _current->tqchildren()->count()-1;
+      newItem = visibleItem(_current->tqchildren()->at(newIdx));
       setCurrent(newItem, true);
     }
   }
@@ -2162,7 +2162,7 @@ void TreeMapWidget::drawTreeMap()
     }
     else {
       // only subitem
-      if (!_needsRefresh->itemRect().isValid()) return;
+      if (!_needsRefresh->tqitemRect().isValid()) return;
     }
 
     // reset cached font object; it could have been changed
@@ -2173,14 +2173,14 @@ void TreeMapWidget::drawTreeMap()
     _needsRefresh = 0;
   }
 
-  bitBlt( this, 0, 0, &_pixmap, 0, 0,
+  bitBlt( TQT_TQPAINTDEVICE(this), 0, 0, TQT_TQPAINTDEVICE(&_pixmap), 0, 0,
           TQWidget::width(), TQWidget::height(), CopyROP, true);
 
   if (hasFocus()) {
     TQPainter p(this);
-    style().drawPrimitive( TQStyle::PE_FocusRect, &p,
+    tqstyle().tqdrawPrimitive( TQStyle::PE_FocusRect, &p,
                            TQRect(0, 0, TQWidget::width(), TQWidget::height()),
-                           colorGroup() );
+                           tqcolorGroup() );
   }
 }
 
@@ -2226,7 +2226,7 @@ void TreeMapWidget::drawItem(TQPainter* p,
   int dd = item->depth();
   if (isTransparent(dd)) return;
 
-  RectDrawing d(item->itemRect());
+  RectDrawing d(item->tqitemRect());
   item->setSelected(isSelected);
   item->setCurrent(isCurrent);
   item->setShaded(_shading);
@@ -2261,25 +2261,25 @@ void TreeMapWidget::drawItems(TQPainter* p,
 {
     if (DEBUG_DRAWING)
 	kdDebug(90100) << "+drawItems(" << item->path(0).join("/") << ", "
-		  << item->itemRect().x() << "/" << item->itemRect().y()
-		  << "-" << item->itemRect().width() << "x"
-		  << item->itemRect().height() << "), Val " << item->value()
+		  << item->tqitemRect().x() << "/" << item->tqitemRect().y()
+		  << "-" << item->tqitemRect().width() << "x"
+		  << item->tqitemRect().height() << "), Val " << item->value()
 		  << ", Sum " << item->sum() << endl;
 
   drawItem(p, item);
   item->clearFreeRects();
 
-  TQRect origRect = item->itemRect();
+  TQRect origRect = item->tqitemRect();
   int bw = item->borderWidth();
   TQRect r = TQRect(origRect.x()+bw, origRect.y()+bw,
                   origRect.width()-2*bw, origRect.height()-2*bw);
 
-  TreeMapItemList* list = item->children();
+  TreeMapItemList* list = item->tqchildren();
   TreeMapItem* i;
 
   bool stopDrawing = false;
 
-  // only subdivide if there are children
+  // only subdivide if there are tqchildren
   if (!list || list->count()==0)
     stopDrawing = true;
 
@@ -2312,12 +2312,12 @@ void TreeMapWidget::drawItems(TQPainter* p,
 
   if (stopDrawing) {
     if (list) {
-      // invalidate rects
+      // tqinvalidate rects
       for (i=list->first();i;i=list->next())
         i->clearItemRect();
     }
     // tooltip apears on whole item rect
-    item->addFreeRect(item->itemRect());
+    item->addFreeRect(item->tqitemRect());
 
     // if we have space for text...
     if ((r.height() < _fontHeight) || (r.width() < _fontHeight)) return;
@@ -2428,7 +2428,7 @@ void TreeMapWidget::drawItems(TQPainter* p,
       r.setRect(r.x(), r.y()+sr.height(), r.width(), r.height()-sr.height());
     }
 
-    // set selfRect (not occupied by children) for tooltip
+    // set selfRect (not occupied by tqchildren) for tooltip
     item->addFreeRect(sr);
 
     if (0) kdDebug(90100) << "Item " << item->path(0).join("/") << ": SelfR "
@@ -2566,16 +2566,16 @@ void TreeMapWidget::drawItems(TQPainter* p,
       kdDebug(90100) << "-drawItems(" << item->path(0).join("/") << ")" << endl;
 }
 
-// fills area with a pattern if to small to draw children
+// fills area with a pattern if to small to draw tqchildren
 void TreeMapWidget::drawFill(TreeMapItem* i, TQPainter* p, TQRect& r)
 {
-  p->setBrush(Qt::Dense4Pattern);
-  p->setPen(Qt::NoPen);
+  p->setBrush(TQt::Dense4Pattern);
+  p->setPen(TQt::NoPen);
   p->drawRect(r);
   i->addFreeRect(r);
 }
 
-// fills area with a pattern if to small to draw children
+// fills area with a pattern if to small to draw tqchildren
 void TreeMapWidget::drawFill(TreeMapItem* i, TQPainter* p, TQRect& r,
                              TreeMapItemListIterator it, int len, bool goBack)
 {
@@ -2584,8 +2584,8 @@ void TreeMapWidget::drawFill(TreeMapItem* i, TQPainter* p, TQRect& r,
 		<< "-" << r.width() << "x" << r.height()
 		<< ", len " << len << ")" << endl;
 
-  p->setBrush(Qt::Dense4Pattern);
-  p->setPen(Qt::NoPen);
+  p->setBrush(TQt::Dense4Pattern);
+  p->setPen(TQt::NoPen);
   p->drawRect(r);
   i->addFreeRect(r);
 
@@ -2874,10 +2874,10 @@ void TreeMapWidget::addVisualizationItems(TQPopupMenu* popup, int id)
   popup->insertItem(i18n("Border"), bpopup, id+1);
   bpopup->insertItem(i18n("Correct Borders Only"), id+2);
   bpopup->insertSeparator();
-  bpopup->insertItem(i18n("Width %1").arg(0), id+3);
-  bpopup->insertItem(i18n("Width %1").arg(1), id+4);
-  bpopup->insertItem(i18n("Width %1").arg(2), id+5);
-  bpopup->insertItem(i18n("Width %1").arg(3), id+6);
+  bpopup->insertItem(i18n("Width %1").tqarg(0), id+3);
+  bpopup->insertItem(i18n("Width %1").tqarg(1), id+4);
+  bpopup->insertItem(i18n("Width %1").tqarg(2), id+5);
+  bpopup->insertItem(i18n("Width %1").tqarg(3), id+6);
   bpopup->setItemChecked(id+2, skipIncorrectBorder());
   bpopup->setItemChecked(id+3, borderWidth()==0);
   bpopup->setItemChecked(id+4, borderWidth()==1);
@@ -2963,7 +2963,7 @@ void TreeMapWidget::addSelectionItems(TQPopupMenu* popup,
 
 void TreeMapWidget::fieldStopActivated(int id)
 {
-  if (id == _fieldStopID) setFieldStop(0, TQString::null);
+  if (id == _fieldStopID) setFieldStop(0, TQString());
   else {
     TreeMapItem* i = _menuItem;
     id -= _fieldStopID+1;
@@ -2984,7 +2984,7 @@ void TreeMapWidget::addFieldStopItems(TQPopupMenu* popup,
   connect(popup, TQT_SIGNAL(activated(int)),
           this, TQT_SLOT(fieldStopActivated(int)));
 
-  popup->insertItem(i18n("No %1 Limit").arg(fieldType(0)), id);
+  popup->insertItem(i18n("No %1 Limit").tqarg(fieldType(0)), id);
   popup->setItemChecked(id, fieldStop(0).isEmpty());
   _menuItem = i;
   bool foundFieldStop = false;
@@ -3043,7 +3043,7 @@ void TreeMapWidget::addAreaStopItems(TQPopupMenu* popup,
     int area = i->width() * i->height();
     popup->insertSeparator();
     popup->insertItem(i18n("Area of '%1' (%2)")
-                       .arg(i->text(0)).arg(area), id+1);
+                       .tqarg(i->text(0)).tqarg(area), id+1);
     if (area == minimalArea()) {
       popup->setItemChecked(id+1, true);
       foundArea = true;
@@ -3069,9 +3069,9 @@ void TreeMapWidget::addAreaStopItems(TQPopupMenu* popup,
     }
 
     popup->insertItem(i18n("Double Area Limit (to %1)")
-                       .arg(minimalArea()*2), id+5);
+                       .tqarg(minimalArea()*2), id+5);
     popup->insertItem(i18n("Halve Area Limit (to %1)")
-                       .arg(minimalArea()/2), id+6);
+                       .tqarg(minimalArea()/2), id+6);
   }
 }
 
@@ -3105,7 +3105,7 @@ void TreeMapWidget::addDepthStopItems(TQPopupMenu* popup,
     int d = i->depth();
     popup->insertSeparator();
     popup->insertItem(i18n("Depth of '%1' (%2)")
-                       .arg(i->text(0)).arg(d), id+1);
+                       .tqarg(i->text(0)).tqarg(d), id+1);
     if (d == maxDrawingDepth()) {
       popup->setItemChecked(id+1, true);
       foundDepth = true;
@@ -3115,14 +3115,14 @@ void TreeMapWidget::addDepthStopItems(TQPopupMenu* popup,
   if (maxDrawingDepth()>1) {
     popup->insertSeparator();
     if (!foundDepth) {
-      popup->insertItem(i18n("Depth %1").arg(maxDrawingDepth()), id+10);
+      popup->insertItem(i18n("Depth %1").tqarg(maxDrawingDepth()), id+10);
       popup->setItemChecked(id+10, true);
     }
 
     popup->insertItem(i18n("Decrement (to %1)")
-                       .arg(maxDrawingDepth()-1), id+2);
+                       .tqarg(maxDrawingDepth()-1), id+2);
     popup->insertItem(i18n("Increment (to %1)")
-                       .arg(maxDrawingDepth()+1), id+3);
+                       .tqarg(maxDrawingDepth()+1), id+3);
   }
 }
 
@@ -3145,13 +3145,13 @@ void TreeMapWidget::saveOptions(KConfigGroup* config, TQString prefix)
   int f, fCount = _attr.size();
   config->writeEntry(prefix+"FieldCount", fCount);
   for (f=0;f<fCount;f++) {
-    config->writeEntry(TQString(prefix+"FieldVisible%1").arg(f),
+    config->writeEntry(TQString(prefix+"FieldVisible%1").tqarg(f),
                        _attr[f].visible);
-    config->writeEntry(TQString(prefix+"FieldForced%1").arg(f),
+    config->writeEntry(TQString(prefix+"FieldForced%1").tqarg(f),
                        _attr[f].forced);
-    config->writeEntry(TQString(prefix+"FieldStop%1").arg(f),
+    config->writeEntry(TQString(prefix+"FieldStop%1").tqarg(f),
                        _attr[f].stop);
-    config->writeEntry(TQString(prefix+"FieldPosition%1").arg(f),
+    config->writeEntry(TQString(prefix+"FieldPosition%1").tqarg(f),
                        fieldPositionString(f));
   }
 }
@@ -3195,18 +3195,18 @@ void TreeMapWidget::restoreOptions(KConfigGroup* config, TQString prefix)
 
   int f;
   for (f=0;f<num;f++) {
-    str = TQString(prefix+"FieldVisible%1").arg(f);
+    str = TQString(prefix+"FieldVisible%1").tqarg(f);
     if (config->hasKey(str))
       setFieldVisible(f, config->readBoolEntry(str));
 
-    str = TQString(prefix+"FieldForced%1").arg(f);
+    str = TQString(prefix+"FieldForced%1").tqarg(f);
     if (config->hasKey(str))
       setFieldForced(f, config->readBoolEntry(str));
 
-    str = config->readEntry(TQString(prefix+"FieldStop%1").arg(f));
+    str = config->readEntry(TQString(prefix+"FieldStop%1").tqarg(f));
     setFieldStop(f, str);
 
-    str = config->readEntry(TQString(prefix+"FieldPosition%1").arg(f));
+    str = config->readEntry(TQString(prefix+"FieldPosition%1").tqarg(f));
     if (!str.isEmpty()) setFieldPosition(f, str);
   }
 }
