@@ -81,7 +81,7 @@ public:
   virtual int      maxLines(int) const { return 0; }
   virtual int      fieldCount() const { return 0; }
 
-  virtual TQColor   backColor() const { return Qt::white; }
+  virtual TQColor   backColor() const { return TQt::white; }
   virtual const TQFont& font() const = 0;
 
   virtual bool selected() const { return false; }
@@ -222,7 +222,7 @@ typedef TQPtrListIterator<TreeMapItem> TreeMapItemListIterator;
  *
  * If you want more flexibility, reimplement TreeMapItem and
  * override the corresponding methods. For dynamic creation of child
- * items on demand, reimplement children().
+ * items on demand, reimplement tqchildren().
  */
 class TreeMapItem: public StoredDrawParams
 {
@@ -234,10 +234,10 @@ public:
    *              longest side of rectangle left for drawing
    *  Best:       Choose split direction for all subitems of an area
    *              depending on longest side
-   *  HAlternate: Horizontal at top;  alternate direction on depth step
-   *  VAlternate: Vertical at top; alternate direction on depth step
-   *  Horizontal: Always horizontal split direction
-   *  Vertical:   Always vertical split direction
+   *  HAlternate:Qt::Horizontal at top;  alternate direction on depth step
+   *  VAlternate:Qt::Vertical at top; alternate direction on depth step
+   * Qt::Horizontal: Always horizontal split direction
+   * Qt::Vertical:   Always vertical split direction
    */
   enum SplitMode { Bisection, Columns, Rows,
                    AlwaysBest, Best,
@@ -246,8 +246,8 @@ public:
 
   TreeMapItem(TreeMapItem* parent = 0, double value = 1.0 );
   TreeMapItem(TreeMapItem* parent, double value,
-              TQString text1, TQString text2 = TQString::null,
-              TQString text3 = TQString::null, TQString text4 = TQString::null);
+              TQString text1, TQString text2 = TQString(),
+              TQString text3 = TQString(), TQString text4 = TQString());
   virtual ~TreeMapItem();
 
   bool isChildOf(TreeMapItem*);
@@ -257,7 +257,7 @@ public:
   // force a redraw of this item
   void redraw();
 
-  // delete all children
+  // delete all tqchildren
   void clear();
 
   // force new child generation & refresh
@@ -297,7 +297,7 @@ public:
    */
   void setItemRect(const TQRect& r) { _rect = r; }
   void clearItemRect();
-  const TQRect& itemRect() const { return _rect; }
+  const TQRect& tqitemRect() const { return _rect; }
   int width() const { return _rect.width(); }
   int height() const { return _rect.height(); }
 
@@ -350,7 +350,7 @@ public:
    * For value() sorting, use <textNo> = -2
    *
    * For fast sorting, set this to -1 before child insertions and call
-   * again after inserting all children.
+   * again after inserting all tqchildren.
    */
   void setSorting(int textNo, bool ascending = true);
 
@@ -358,18 +358,18 @@ public:
    * Resort according to the already set sorting.
    *
    * This has to be done if the sorting base changes (e.g. text or values
-   * change). If this is only true for the children of this item, you can
+   * change). If this is only true for the tqchildren of this item, you can
    * set the recursive parameter to false.
    */
   void resort(bool recursive = true);
 
   virtual SplitMode splitMode() const;
   virtual int rtti() const;
-  // not const as this can create children on demand
-  virtual TreeMapItemList* children();
+  // not const as this can create tqchildren on demand
+  virtual TreeMapItemList* tqchildren();
 
 protected:
-  TreeMapItemList* _children;
+  TreeMapItemList* _tqchildren;
   double _sum, _value;
 
 private:
@@ -379,7 +379,7 @@ private:
   int _sortTextNo;
   bool _sortAscending;
 
-  // temporary layout
+  // temporary tqlayout
   TQRect _rect;
   TQPtrList<TQRect>* _freeRects;
   int _depth;
@@ -396,14 +396,15 @@ private:
  * Class for visualization of a metric of hierarchically
  * nested items as 2D areas.
  */
-class TreeMapWidget: public QWidget
+class TreeMapWidget: public TQWidget
 {
   Q_OBJECT
+  TQ_OBJECT
 
 public:
 
   /**
-   * Same as in QListBox/QListView
+   * Same as in TQListBox/TQListView
    */
   enum SelectionMode { Single, Multi, Extended, NoSelection };
 
@@ -443,7 +444,7 @@ public:
   /**
    * Selects or unselects an item.
    * In multiselection mode, the constrain that a selected item
-   * has no selected children or parents stays true.
+   * has no selected tqchildren or parents stays true.
    */
   void setSelected(TreeMapItem*, bool selected = true);
 
@@ -459,7 +460,7 @@ public:
   void setMarked(int markNo = 1, bool redraw = true);
 
   /**
-   * Clear selection of all selected items which are children of
+   * Clear selection of all selected items which are tqchildren of
    * parent. When parent == 0, clears whole selection
    * Returns true if selection changed.
    */
@@ -471,7 +472,7 @@ public:
    * Range means for a hierarchical widget:
    * - select/unselect i1 and i2 according selected
    * - search common parent of i1 and i2, and select/unselect the
-   *   range of direct children between but excluding the child
+   *   range of direct tqchildren between but excluding the child
    *   leading to i1 and the child leading to i2.
    */
   void setRangeSelection(TreeMapItem* i1,
@@ -531,7 +532,7 @@ public:
   void setVisibleWidth(int width, bool reuseSpace = false);
 
   /**
-   * If a children value() is almost the parents sum(),
+   * If a tqchildren value() is almost the parents sum(),
    * it can happen that the border to be drawn for visibilty of
    * nesting relations takes to much space, and the
    * parent/child size relation can not be mapped to a correct
@@ -613,8 +614,8 @@ public:
   /**
    * Save/restore options.
    */
-  void saveOptions(KConfigGroup*, TQString prefix = TQString::null);
-  void restoreOptions(KConfigGroup*, TQString prefix = TQString::null);
+  void saveOptions(KConfigGroup*, TQString prefix = TQString());
+  void restoreOptions(KConfigGroup*, TQString prefix = TQString());
 
   /**
    * These functions populate given popup menus.
@@ -643,7 +644,7 @@ public:
   virtual TQString tipString(TreeMapItem* i) const;
 
   /**
-   * Redraws an item with all children.
+   * Redraws an item with all tqchildren.
    * This takes changed values(), sums(), colors() and text() into account.
    */
   void redraw(TreeMapItem*);
