@@ -3,7 +3,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Waldo Bastian <bastian@kde.org>
  *
- * $Id: kconf_update.cpp 1157647 2010-07-31 19:46:43Z tpearson $
+ * $Id: kconf_update.cpp 1246075 2011-08-10 06:08:18Z tpearson $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -201,7 +201,7 @@ KonfUpdate::log()
       }
    }
    
-   (*m_textStream) << TQDateTime::currentDateTime().toString( Qt::ISODate ) << " ";
+   (*m_textStream) << TQDateTime::tqcurrentDateTime().toString( Qt::ISODate ) << " ";
    
    return *m_textStream;
 }
