@@ -5,10 +5,10 @@
  * TQString -> int hash. From Qt's TQGDict::hashKeyString().
  */
 
-static int QHash(TQString key)
+static int TQHash(TQString key)
 {
     int g, h = 0;
-    const TQChar *p = key.unicode();
+    const TQChar *p = key.tqunicode();
     for (unsigned i=0; i < key.length(); i++) {
         h = (h << 4) + p[i].cell();
         if ((g = (h & 0xf0000000)))
