@@ -33,7 +33,7 @@
 
 #include "kticon.h"
 
-class KTPushButton : public QPushButton
+class KTPushButton : public TQPushButton
 {
 public:
    KTPushButton(TQWidget * parent, const char * name = 0 ) 
@@ -156,8 +156,8 @@ KTTask::KTTask(CTTask* _cttask, const TQString & _caption)
 
   leCommand->setText(TQString::fromLocal8Bit(cttask->command.c_str()));
 
-  labComment->setFixedWidth( QMAX( labComment->width(), labCommand->width()) );
-  labCommand->setFixedWidth( QMAX( labComment->width(), labCommand->width()) );
+  labComment->setFixedWidth( TQMAX( labComment->width(), labCommand->width()) );
+  labCommand->setFixedWidth( TQMAX( labComment->width(), labCommand->width()) );
 
   slotCommandChanged();
 
@@ -269,7 +269,7 @@ KTTask::KTTask(CTTask* _cttask, const TQString & _caption)
   v4->addSpacing( 2 * KDialogBase::spacingHint() );
 
   labAM = new TQLabel( i18n("AM"), bgHour, "labAM");
-  labAM->setAlignment(AlignRight | AlignVCenter);
+  labAM->tqsetAlignment(AlignRight | AlignVCenter);
   v4->addWidget( labAM );
 
 
@@ -292,7 +292,7 @@ KTTask::KTTask(CTTask* _cttask, const TQString & _caption)
   }
 
   labPM = new TQLabel( i18n("PM"), bgHour, "labPM");
-  labPM->setAlignment(AlignRight | AlignVCenter);
+  labPM->tqsetAlignment(AlignRight | AlignVCenter);
   v4->addWidget( labPM );
 
   hhours = new TQHBoxLayout( v4, KDialogBase::spacingHint() );
@@ -398,12 +398,12 @@ KTTask::KTTask(CTTask* _cttask, const TQString & _caption)
  
   // key acceleration
   key_accel = new KAccel(this);
-  key_accel->insert(KStdAccel::Open, this, TQT_SLOT(slotOK()));
-  key_accel->insert(KStdAccel::Close, this, TQT_SLOT(slotCancel()));
-  key_accel->insert(KStdAccel::Quit, this, TQT_SLOT(slotCancel()));
+  key_accel->insert(KStdAccel::Open, TQT_TQOBJECT(this), TQT_SLOT(slotOK()));
+  key_accel->insert(KStdAccel::Close, TQT_TQOBJECT(this), TQT_SLOT(slotCancel()));
+  key_accel->insert(KStdAccel::Quit, TQT_TQOBJECT(this), TQT_SLOT(slotCancel()));
   key_accel->readSettings();
 
-  setFixedSize( minimumSize() );
+  setFixedSize( tqminimumSize() );
   slotDailyChanged();
   slotMonthChanged();
   slotDayOfMonthChanged();
@@ -636,7 +636,7 @@ void KTTask::slotOK()
   // save work in process
   if (!cttask->user.empty())
   {
-    cttask->user = TQFile::encodeName(leUser->text());
+    cttask->user = TQFile::encodeName(leUser->text()).data();
   }
   else
   {
