@@ -22,6 +22,10 @@
 
 #include "kdelibs_export.h"
 
+#ifdef Q_MOC_RUN
+#define Q_OS_UNIX
+#endif // Q_MOC_RUN
+
 #ifdef Q_OS_UNIX
 
 #include <sys/time.h>
@@ -63,7 +67,7 @@ class KExtendedSocketPrivate;
  * only difference is that the passiveSocket flag must be passed either to
  * the constructor or to setSocketFlags(). If passiveSocket is used, the class will
  * enable functions listen() and accept() and related signals, and will
- * also disable readBlock() and writeBlock().
+ * also disable tqreadBlock() and tqwriteBlock().
  *
  * To create a Unix socket, one would pass flag unixSocket to the constructor
  * or setSocketFlags(). The hostname and service/port can be set to whatever is
@@ -91,6 +95,7 @@ class KExtendedSocketPrivate;
 class KDECORE_EXPORT KExtendedSocket: public KBufferedIO // public TQObject, public QIODevice
 {
   Q_OBJECT
+  TQ_OBJECT
 
 public:
   /**
@@ -622,7 +627,7 @@ public:
    * @return true if successful, false when an error occurred or the most was
    *         not correct
    */
-  virtual bool open(int mode = IO_Raw | IO_ReadWrite);
+  virtual bool open(TQ_OpenMode mode = (TQ_OpenMode)(IO_Raw | IO_ReadWrite));
 
   /**
    * Closes the socket. If we have data still in the write buffer yet to be
@@ -672,7 +677,7 @@ public:
    * ready to receive data, it will block, unless this is a non-blocking socket.
    *
    * This function does not touch the read buffer. You can empty it by calling
-   * readBlock() with a null destination buffer.
+   * tqreadBlock() with a null destination buffer.
    */
   virtual void flush();
 
@@ -681,7 +686,7 @@ public:
    * @return the length of this socket, or 0 if unsupported
    */
 #ifdef USE_QT3
-  virtual inline Q_ULONG size() const
+  virtual inline TQ_ULONG size() const
 #endif // USE_QT3
 #ifdef USE_QT4
   virtual inline qint64 size() const
@@ -692,7 +697,7 @@ public:
    * Returns relative position from start. This call is not supported on sockets.
    * @return the relative position from the start, or 0 if unsupported
    */
-  virtual inline Q_ULONG at() const
+  virtual inline TQ_ULONG at() const
   { return 0; }
 
   /**
@@ -740,7 +745,7 @@ public:
    * This function returns 0, if the function detected end-of-file condition
    * (socket was closed)
    */
-  virtual Q_LONG readBlock(char *data, Q_ULONG maxlen);
+  virtual TQT_TQIO_LONG tqreadBlock(char *data, TQT_TQIO_ULONG maxlen);
 
   /**
    * Writes a block of data to the socket.
@@ -765,7 +770,7 @@ public:
    * The return value might be less than @p len if the output buffers cannot
    * accommodate that many bytes and -1 in the case of an errro.
    */
-  virtual Q_LONG writeBlock(const char *data, Q_ULONG len);
+  virtual TQT_TQIO_LONG tqwriteBlock(const char *data, TQT_TQIO_ULONG len);
 
   /**
    * Peeks at a block of data from the socket.
