@@ -35,7 +35,7 @@
 #include <win32_utils.h>
 static QRgb qt_colorref2qrgb(COLORREF col)
 {
-    return qRgb(GetRValue(col),GetGValue(col),GetBValue(col));
+    return tqRgb(GetRValue(col),GetGValue(col),GetBValue(col));
 }
 #endif
 
@@ -69,7 +69,7 @@ TQFont *KGlobalSettings::_menuFont = 0;
 TQFont *KGlobalSettings::_windowTitleFont = 0;
 TQFont *KGlobalSettings::_taskbarFont = 0;
 TQFont *KGlobalSettings::_largeFont = 0;
-TQColor *KGlobalSettings::_kde34Blue = 0;
+TQColor *KGlobalSettings::_trinity4Blue = 0;
 TQColor *KGlobalSettings::_inactiveBackground = 0;
 TQColor *KGlobalSettings::_inactiveForeground = 0;
 TQColor *KGlobalSettings::_activeBackground = 0;
@@ -194,7 +194,7 @@ TQColor KGlobalSettings::toolBarHighlightColor()
 {
     initColors();
     KConfigGroup g( KGlobal::config(), "Toolbar style" );
-    return g.readColorEntry("HighlightColor", _kde34Blue);
+    return g.readColorEntry("HighlightColor", _trinity4Blue);
 }
 
 TQColor KGlobalSettings::inactiveTitleColor()
@@ -265,7 +265,7 @@ TQColor KGlobalSettings::buttonTextColor()
 }
 
 // IMPORTANT:
-//  This function should be get in sync with
+//  This function should be kept in sync with
 //   KApplication::kdisplaySetPalette()
 TQColor KGlobalSettings::baseColor()
 {
@@ -274,7 +274,7 @@ TQColor KGlobalSettings::baseColor()
 }
 
 // IMPORTANT:
-//  This function should be get in sync with
+//  This function should be kept in sync with
 //   KApplication::kdisplaySetPalette()
 TQColor KGlobalSettings::textColor()
 {
@@ -283,7 +283,7 @@ TQColor KGlobalSettings::textColor()
 }
 
 // IMPORTANT:
-//  This function should be get in sync with
+//  This function should be kept in sync with
 //   KApplication::kdisplaySetPalette()
 TQColor KGlobalSettings::highlightedTextColor()
 {
@@ -292,7 +292,7 @@ TQColor KGlobalSettings::highlightedTextColor()
 }
 
 // IMPORTANT:
-//  This function should be get in sync with
+//  This function should be kept in sync with
 //   KApplication::kdisplaySetPalette()
 TQColor KGlobalSettings::highlightColor()
 {
@@ -451,7 +451,7 @@ TQFont KGlobalSettings::taskbarFont()
 TQFont KGlobalSettings::largeFont(const TQString &text)
 {
     TQFontDatabase db;
-    TQStringList fam = db.families();
+    TQStringList fam = db.tqfamilies();
 
     // Move a bunch of preferred fonts to the front.
     if (fam.remove("Arial"))
@@ -522,7 +522,7 @@ void KGlobalSettings::initStatic() // should be called initPaths(). Don't put an
 	readXdgUserDirs(s_desktopPath, s_documentPath);
 	
     if (s_desktopPath->isEmpty() == true) {
-      *s_desktopPath = QDir::homeDirPath() + "/Desktop/";
+      *s_desktopPath = TQDir::homeDirPath() + "/Desktop/";
     }
     *s_desktopPath = TQDir::cleanDirPath( *s_desktopPath );
     if ( !s_desktopPath->endsWith("/") )
@@ -566,11 +566,11 @@ void KGlobalSettings::initStatic() // should be called initPaths(). Don't put an
 
 void KGlobalSettings::initColors()
 {
-    if (!_kde34Blue) {
+    if (!_trinity4Blue) {
       if (TQPixmap::defaultDepth() > 8)
-        _kde34Blue = new TQColor(103,141,178);
+        _trinity4Blue = new TQColor(103,141,178);
       else
-        _kde34Blue = new TQColor(0, 0, 192);
+        _trinity4Blue = new TQColor(0, 0, 192);
     }
     if (!alternateColor)
       alternateColor = new TQColor(237, 244, 249);
