@@ -176,8 +176,8 @@ static const TransKey g_rgQtToSymX[] =
 	{ Qt::Key_Up,         XK_Up },
 	{ Qt::Key_Right,      XK_Right },
 	{ Qt::Key_Down,       XK_Down },
-	{ Qt::Key_Prior,      XK_Prior },
-	{ Qt::Key_Next,       XK_Next },
+	{ TQt::Key_Prior,      XK_Prior },
+	{ TQt::Key_Next,       XK_Next },
 	//{ Qt::Key_Shift,      0 },
 	//{ Qt::Key_Control,    0 },
 	//{ Qt::Key_Meta,       0 },
@@ -285,7 +285,7 @@ static const TransKey g_rgQtToSymX[] =
 	{ Qt::Key_VolumeUp,   XF86XK_AudioRaiseVolume },
 	{ Qt::Key_MediaPlay,  XF86XK_AudioPlay },
 	{ Qt::Key_MediaStop,  XF86XK_AudioStop },
-	{ Qt::Key_MediaPrev,  XF86XK_AudioPrev },
+	{ TQt::Key_MediaPrev,  XF86XK_AudioPrev },
 	{ Qt::Key_MediaNext,  XF86XK_AudioNext },
 	{ Qt::Key_HomePage,   XF86XK_HomePage },
 	{ Qt::Key_LaunchMail, XF86XK_Mail },
@@ -406,7 +406,7 @@ bool Sym::initQt( int keyQt )
 	int symQt = keyQt & 0xffff;
 
 	if( (keyQt & Qt::UNICODE_ACCEL) || symQt < 0x1000 ) {
-		m_sym = TQChar(symQt).lower().unicode();
+		m_sym = TQChar(symQt).lower().tqunicode();
 		return true;
 	}
 
@@ -434,9 +434,9 @@ bool Sym::initQt( int keyQt )
 
 bool Sym::init( const TQString& s )
 {
-	// If it's a single character, get unicode value.
+	// If it's a single character, get tqunicode value.
 	if( s.length() == 1 ) {
-		m_sym = s[0].lower().unicode();
+		m_sym = s[0].lower().tqunicode();
 		return true;
 	}
 
@@ -490,7 +490,7 @@ int Sym::qt() const
 		if( g_rgQtToSymX[i].keySymX == m_sym )
 			return g_rgQtToSymX[i].keySymQt;
 #endif
-	return Qt::Key_unknown;
+	return TQt::Key_unknown;
 }
 
 TQString Sym::toString( bool bUserSpace ) const
@@ -498,7 +498,7 @@ TQString Sym::toString( bool bUserSpace ) const
 	if( m_sym == 0 )
 		return TQString::null;
 
-	// If it's a unicode character,
+	// If it's a tqunicode character,
 #ifdef Q_WS_WIN
 	else if( m_sym < 0x1000 ) {
 #else
@@ -526,7 +526,7 @@ TQString Sym::toString( bool bUserSpace ) const
 	s = XKeysymToString( m_sym );
 #endif
 	capitalizeKeyname( s );
-	return bUserSpace ? i18n("TQAccel", s.latin1()) : s;
+	return bUserSpace ? i18n(TQACCEL_OBJECT_NAME_STRING, s.latin1()) : s;
 }
 
 TQString Sym::toStringInternal() const { return toString( false ); }
@@ -542,7 +542,7 @@ uint Sym::getModsRequired() const
 
 	if( m_sym < 0x3000 ) {
 		TQChar c(m_sym);
-		if( c.isLetter() && c.lower() != c.upper() && m_sym == c.upper().unicode() )
+		if( c.isLetter() && c.lower() != c.upper() && m_sym == c.upper().tqunicode() )
 			return KKey::SHIFT;
 	}
 
@@ -646,7 +646,7 @@ bool symToKeyQt( uint keySym, int& keyQt )
 {
 	Sym sym( keySym );
 	keyQt = sym.qt();
-	return (keyQt != Qt::Key_unknown);
+	return (keyQt != TQt::Key_unknown);
 }
 
 bool modToModQt( uint mod, int& modQt )
@@ -671,7 +671,7 @@ bool modXToModQt( uint modX, int& modQt )
 	return modToModQt( modX, modQt );
 }
 
-KDECORE_EXPORT int qtButtonStateToMod( Qt::ButtonState s )
+KDECORE_EXPORT int qtButtonStateToMod( TQt::ButtonState s )
 {
 	int modQt = 0;
 	if (s & Qt::ShiftButton) modQt |= KKey::SHIFT;
@@ -823,7 +823,7 @@ uint stringUserToMod( const TQString& mod )
 	// Get code of just the primary key
 	keySymQt = keyCombQt & 0xffff;
 
-	// If unicode value beneath 0x1000 (special Qt codes begin thereafter),
+	// If tqunicode value beneath 0x1000 (special Qt codes begin thereafter),
 	if( keySymQt < 0x1000 ) {
 		// For reasons unbeknownst to me, Qt converts 'a-z' to 'A-Z'.
 		// So convert it back to lowercase if SHIFT isn't held down.
@@ -1041,7 +1041,7 @@ void KKey::simplify()
 
 	// If this is a letter, don't remove any modifiers.
 	if( m_sym < 0x3000 && TQChar(m_sym).isLetter() )
-		m_sym = TQChar(m_sym).lower().unicode();
+		m_sym = TQChar(m_sym).lower().tqunicode();
 
 	// Remove modifers from modifier list which are implicit in the symbol.
 	// Ex. Shift+Plus => Plus (en)
