@@ -1225,7 +1225,7 @@ private:
   static TQCString encodeFileNameUTF8( const TQString & fileName );
 #endif // USE_QT3
 #ifdef USE_QT4
-  static TQByteArray encodeFileNameUTF8( const TQString & fileName );
+  static QByteArray encodeFileNameUTF8( const QString & fileName );
 #endif // USE_QT4
 
   /**
@@ -1235,7 +1235,7 @@ private:
   static TQString decodeFileNameUTF8( const TQCString & localFileName );
 #endif // USE_QT3
 #ifdef USE_QT4
-  static TQString decodeFileNameUTF8( const TQByteArray & localFileName );
+  static QString decodeFileNameUTF8( const QByteArray & localFileName );
 #endif // USE_QT4
 
   /**
