@@ -1,4 +1,4 @@
-// $Id: klocaletest.h 1158447 2010-08-02 19:23:47Z tpearson $
+// $Id: klocaletest.h 1214149 2011-01-13 08:32:36Z tpearson $
 
 #ifndef KLOCALETEST_H
 #define KLOCALETEST_H
@@ -9,7 +9,7 @@ class TQLabel;
 
 /** test: a small test program for KLocale
     */
-class Test : public QWidget
+class Test : public TQWidget
 {
   Q_OBJECT
   
