@@ -156,7 +156,7 @@ void Kded::initModules()
 {
      m_dontLoad.clear();
      KConfig *config = kapp->config();
-     bool kde_running = !( getenv( "KDE_FULL_SESSION" ) == NULL || getenv( "KDE_FULL_SESSION" )[ 0 ] == '\0' );
+     bool kde_running = !( getenv( "TDE_FULL_SESSION" ) == NULL || getenv( "TDE_FULL_SESSION" )[ 0 ] == '\0' );
     // not the same user like the one running the session (most likely we're run via sudo or something)
     if( getenv( "KDE_SESSION_UID" ) != NULL && uid_t( atoi( getenv( "KDE_SESSION_UID" ))) != getuid())
         kde_running = false;
@@ -577,7 +577,7 @@ void Kded::readDirectory( const TQString& _path )
 
   if ( !d.exists() )                            // exists&isdir?
   {
-    kdDebug(7020) << TQString("Does not exist! (%1)").arg(_path) << endl;
+    kdDebug(7020) << TQString(TQString("Does not exist! (%1)").arg(_path)) << endl;
     return;                             // return false
   }
 
@@ -873,7 +873,7 @@ public:
 extern "C" KDE_EXPORT int kdemain(int argc, char *argv[])
 {
      KAboutData aboutData( "kded", I18N_NOOP("KDE Daemon"),
-        "$Id: kded.cpp 1158447 2010-08-02 19:23:47Z tpearson $",
+        "$Id: kded.cpp 1248149 2011-08-20 06:06:53Z tpearson $",
         I18N_NOOP("KDE Daemon - triggers Sycoca database updates when needed"));
 
      KApplication::installSigpipeHandler();
