@@ -26,7 +26,7 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 */
 
-// $Id: kimageeffect.h 1158447 2010-08-02 19:23:47Z tpearson $
+// $Id: kimageeffect.h 1247329 2011-08-15 08:41:49Z tpearson $
 
 #ifndef __KIMAGE_EFFECT_H
 #define __KIMAGE_EFFECT_H
@@ -773,6 +773,16 @@ public:
                           int ambient, bool compensate, bool invert,
                           BumpmapType type, bool tiled);
 
+    /**
+     * Convert an image with standard alpha to premultiplied alpha
+     *
+     * @param img the image you want convert
+     *
+     * @return The destination image (dst) containing the result.
+     * @author Timothy Pearson <kb9vqf@pearsoncomputing.net>
+     */
+    static TQImage convertToPremultipliedAlpha(TQImage input);
+
 private:
 
     /**
