@@ -47,6 +47,7 @@
 #include <tqstylefactory.h>
 #include <tqtabbar.h>
 #include <tqtoolbar.h>
+#include <tqframe.h>
 
 #include <kpixmap.h>
 #include <kpixmapeffect.h>
@@ -62,6 +63,11 @@
 #undef HAVE_XRENDER
 #endif
 
+#ifdef HAVE_XCOMPOSITE
+#include <X11/extensions/Xrender.h>
+#include <X11/extensions/Xcomposite.h>
+#include <dlfcn.h>
+#endif
 
 #include <limits.h>
 
@@ -117,14 +123,14 @@ namespace
 
 	static bool useDropShadow(TQWidget* w)
 	{
-		return w && w->metaObject() && 
-			w->metaObject()->findProperty("KStyleMenuDropShadow") != -1;
+		return w && w->tqmetaObject() && 
+			w->tqmetaObject()->findProperty("KStyleMenuDropShadow") != -1;
 	}
 }
 
 namespace
 {
-class TransparencyHandler : public QObject
+class TransparencyHandler : public TQObject
 {
 	public:
 		TransparencyHandler(KStyle* style, TransparencyEngine tEngine,
@@ -138,6 +144,8 @@ class TransparencyHandler : public QObject
 #ifdef HAVE_XRENDER
 		void XRenderBlendToPixmap(const TQWidget* p);
 #endif
+		bool haveX11RGBASupport();
+		TQImage handleRealAlpha(TQImage);
 		void createShadowWindows(const TQWidget* p);
 		void removeShadowWindows(const TQWidget* p);
 		void rightShadow(TQImage& dst);
@@ -251,14 +259,13 @@ TQString KStyle::defaultStyle()
 	   return TQString("light, 3rd revision");
 }
 
-
 void KStyle::polish( TQWidget* widget )
 {
 	if ( d->useFilledFrameWorkaround )
 	{
-		if ( TQFrame *frame = tqqt_cast< TQFrame* >( widget ) ) {
-			TQFrame::Shape shape = frame->frameShape();
-			if (shape == TQFrame::ToolBarPanel || shape == TQFrame::MenuBarPanel)
+		if ( TQFrame *frame = ::tqqt_cast< TQFrame* >( widget ) ) {
+			TQFrame::Shape tqshape = frame->frameShape();
+			if (tqshape == TQFrame::ToolBarPanel || tqshape == TQFrame::MenuBarPanel)
 				widget->installEventFilter(this);
 		} 
 	}
@@ -277,9 +284,9 @@ void KStyle::unPolish( TQWidget* widget )
 {
 	if ( d->useFilledFrameWorkaround )
 	{
-		if ( TQFrame *frame = tqqt_cast< TQFrame* >( widget ) ) {
-			TQFrame::Shape shape = frame->frameShape();
-			if (shape == TQFrame::ToolBarPanel || shape == TQFrame::MenuBarPanel)
+		if ( TQFrame *frame = ::tqqt_cast< TQFrame* >( widget ) ) {
+			TQFrame::Shape tqshape = frame->frameShape();
+			if (tqshape == TQFrame::ToolBarPanel || tqshape == TQFrame::MenuBarPanel)
 				widget->removeEventFilter(this);
 		}
 	}
@@ -371,7 +378,7 @@ void KStyle::drawKStylePrimitive( KStylePrimitive kpe,
 			p2.fillRect(pix.rect(), cg.brush(TQColorGroup::Highlight));
 			p2.setPen(cg.highlightedText());
 			p2.setFont(fnt);
-			p2.drawText(pix.rect(), TQAlignCenter, title);
+			p2.drawText(pix.rect(), AlignCenter, title);
 			p2.end();
 
 			// Draw a sunken bevel
@@ -435,7 +442,7 @@ void KStyle::drawKStylePrimitive( KStylePrimitive kpe,
 				int i;
 				for( i=0; i < 64; i++ )
 					a.setPoint( i, 0, i*2+1 );
-				p2.setPen( tqcolor1 );
+				p2.setPen( color1 );
 				p2.drawPoints( a );
 				p2.end();
 				TQApplication::flushX();
@@ -444,7 +451,7 @@ void KStyle::drawKStylePrimitive( KStylePrimitive kpe,
 				p2.begin( d->horizontalLine );
 				for( i=0; i < 64; i++ )
 					a.setPoint( i, i*2+1, 0 );
-				p2.setPen( tqcolor1 );
+				p2.setPen( color1 );
 				p2.drawPoints( a );
 				p2.end();
 				TQApplication::flushX();
@@ -536,25 +543,25 @@ int KStyle::kPixelMetric( KStylePixelMetric kpm, const TQWidget* /* widget */) c
 
 // #ifdef USE_QT4 // kdebindings / smoke needs this function declaration available at all times.  Furthermore I don't think it would hurt to have the declaration available at all times...so leave these commented out for now
 
-void KStyle::drawPrimitive( ControlElement pe,
-							TQPainter* p,
-							const TQRect &r,
-							const TQColorGroup &cg,
-							SFlags flags,
-							const TQStyleOption& opt ) const
-{
-	// FIXME:
-	// What should "widget" be in actuality?  How should I get it?  From where?
-	// Almost certainly it should not be null!
-	TQWidget *widget = 0;
-	drawControl(pe, p, widget, r, cg, flags, opt);
-}
+//void KStyle::tqdrawPrimitive( TQ_ControlElement pe,
+//							TQPainter* p,
+//							const TQRect &r,
+//							const TQColorGroup &cg,
+//							SFlags flags,
+//							const TQStyleOption& opt ) const
+//{
+//	// FIXME:
+//	// What should "widget" be in actuality?  How should I get it?  From where?
+//	// Almost certainly it should not be null!
+//	TQWidget *widget = 0;
+//	tqdrawControl(pe, p, widget, r, cg, flags, opt);
+//}
 
 // #endif // USE_QT4
 
 // -----------------------------------------------------------------------------
 
-void KStyle::drawPrimitive( PrimitiveElement pe,
+void KStyle::tqdrawPrimitive( TQ_PrimitiveElement pe,
 							TQPainter* p,
 							const TQRect &r,
 							const TQColorGroup &cg,
@@ -576,13 +583,13 @@ void KStyle::drawPrimitive( PrimitiveElement pe,
 
 		// Check if we are a normal toolbar or a hidden dockwidget.
 		if ( parent &&
-			(parent->inherits("QToolBar") ||		// Normal toolbar
-			(parent->inherits("QMainWindow")) ))	// Collapsed dock
+			(parent->inherits(TQTOOLBAR_OBJECT_NAME_STRING) ||		// Normal toolbar
+			(parent->inherits(TQMAINWINDOW_OBJECT_NAME_STRING)) ))	// Collapsed dock
 
 			// Draw a toolbar handle
 			drawKStylePrimitive( KPE_ToolBarHandle, p, widget, r, cg, flags, opt );
 
-		else if ( widget->inherits("QDockWindowHandle") )
+		else if ( widget->inherits(TQDOCKWINDOWHANDLE_OBJECT_NAME_STRING) )
 
 			// Draw a dock window handle
 			drawKStylePrimitive( KPE_DockWindowHandle, p, widget, r, cg, flags, opt );
@@ -620,9 +627,9 @@ void KStyle::drawPrimitive( PrimitiveElement pe,
 			}
 		
 			XRenderFillRectangle(
-					p->device()->x11Display(),
+					p->tqdevice()->x11Display(),
 					PictOpOver,
-					p->device()->x11RenderHandle(),
+					p->tqdevice()->x11RenderHandle(),
 					&clr,
 					rect.x() + point.x(),
 					rect.y() + point.y(),
@@ -630,9 +637,9 @@ void KStyle::drawPrimitive( PrimitiveElement pe,
 					rect.height() );
 
 			p->save();
-			p->setRasterOp( Qt::CopyROP );
+			p->setRasterOp( TQt::CopyROP );
 			p->setPen( TQPen( cg.highlight().dark( 160 ), 1 ) );
-			p->setBrush( TQNoBrush );
+			p->setBrush( NoBrush );
 			p->drawRect(
 					rect.x() + point.x(),
 					rect.y() + point.y(),
@@ -642,12 +649,12 @@ void KStyle::drawPrimitive( PrimitiveElement pe,
 #endif
 #endif
 	} else
-		TQCommonStyle::drawPrimitive( pe, p, r, cg, flags, opt );
+		TQCommonStyle::tqdrawPrimitive( pe, p, r, cg, flags, opt );
 }
 
 
 
-void KStyle::drawControl( ControlElement element,
+void KStyle::tqdrawControl( TQ_ControlElement element,
 						  TQPainter* p,
 						  const TQWidget* widget,
 						  const TQRect &r,
@@ -661,7 +668,7 @@ void KStyle::drawControl( ControlElement element,
 		// ------------------------------------------------------------------------
 		case CE_TabBarTab: {
 			const TQTabBar* tb  = (const TQTabBar*) widget;
-			TQTabBar::Shape tbs = tb->shape();
+			TQTabBar::Shape tbs = tb->tqshape();
 			bool selected      = flags & Style_Selected;
 			int x = r.x(), y=r.y(), bottom=r.bottom(), right=r.right();
 
@@ -765,7 +772,7 @@ void KStyle::drawControl( ControlElement element,
 					p->setPen  (selected ? cg.background() : cg.mid());
 					p->setBrush(selected ? cg.background() : cg.mid());
 					p->drawPolygon(a);
-					p->setBrush(TQNoBrush);
+					p->setBrush(NoBrush);
 					if (!selected) {
 						p->translate(0,-1);
 						p->setPen(cg.light());
@@ -808,7 +815,7 @@ void KStyle::drawControl( ControlElement element,
 					p->setPen  (selected ? cg.background() : cg.mid());
 					p->setBrush(selected ? cg.background() : cg.mid());
 					p->drawPolygon(a);
-					p->setBrush(TQNoBrush);
+					p->setBrush(NoBrush);
 					if (!selected) {
 						p->translate(0,1);
 						p->setPen(cg.dark());
@@ -825,8 +832,8 @@ void KStyle::drawControl( ControlElement element,
 		// ------------------------------------------------------------------------
 		case CE_PopupMenuScroller: {
 			p->fillRect(r, cg.background());
-			drawPrimitive(PE_ButtonTool, p, r, cg, Style_Enabled);
-			drawPrimitive((flags & Style_Up) ? PE_ArrowUp : PE_ArrowDown, p, r, cg, Style_Enabled);
+			tqdrawPrimitive(PE_ButtonTool, p, r, cg, Style_Enabled);
+			tqdrawPrimitive((flags & Style_Up) ? PE_ArrowUp : PE_ArrowDown, p, r, cg, Style_Enabled);
 			break;
 		}
 
@@ -835,7 +842,7 @@ void KStyle::drawControl( ControlElement element,
 		// ------------------------------------------------------------------------
 		case CE_ProgressBarGroove: {
 			TQRect fr = subRect(SR_ProgressBarGroove, widget);
-			drawPrimitive(PE_Panel, p, fr, cg, Style_Sunken, TQStyleOption::TQSO_Default);
+			tqdrawPrimitive(PE_Panel, p, fr, cg, Style_Sunken, TQStyleOption::SO_Default);
 			break;
 		}
 
@@ -930,22 +937,22 @@ void KStyle::drawControl( ControlElement element,
 					
 				p->save();
 				p->setPen(pb->isEnabled() ? (reverse ? cg.text() : cg.highlightedText()) : cg.text());
-				p->drawText(r, TQAlignCenter, pb->progressString());
+				p->drawText(r, AlignCenter, pb->progressString());
 				p->setClipRect(crect);
 				p->setPen(reverse ? cg.highlightedText() : cg.text());
-				p->drawText(r, TQAlignCenter, pb->progressString());
+				p->drawText(r, AlignCenter, pb->progressString());
 				p->restore();
 
 			} else {
 				p->setPen(cg.text());
-				p->drawText(r, TQAlignCenter, pb->progressString());
+				p->drawText(r, AlignCenter, pb->progressString());
 			}
 
 			break;
 		}
 
 		default:
-			TQCommonStyle::drawControl(element, p, widget, r, cg, flags, opt);
+			TQCommonStyle::tqdrawControl(element, p, widget, r, cg, flags, opt);
 	}
 }
 
@@ -972,7 +979,7 @@ TQRect KStyle::subRect(SubRect r, const TQWidget* widget) const
 }
 
 
-int KStyle::pixelMetric(PixelMetric m, const TQWidget* widget) const
+int KStyle::tqpixelMetric(PixelMetric m, const TQWidget* widget) const
 {
 	switch(m)
 	{
@@ -988,12 +995,12 @@ int KStyle::pixelMetric(PixelMetric m, const TQWidget* widget) const
 			// Check that we are not a normal toolbar or a hidden dockwidget,
 			// in which case we need to adjust the height for font size
 			if (widget && (parent = widget->parentWidget() )
-				&& !parent->inherits("QToolBar")
-				&& !parent->inherits("QMainWindow")
-				&& widget->inherits("QDockWindowHandle") )
+				&& !parent->inherits(TQTOOLBAR_OBJECT_NAME_STRING)
+				&& !parent->inherits(TQMAINWINDOW_OBJECT_NAME_STRING)
+				&& widget->inherits(TQDOCKWINDOWHANDLE_OBJECT_NAME_STRING) )
 					return widget->fontMetrics().lineSpacing();
 			else
-				return TQCommonStyle::pixelMetric(m, widget);
+				return TQCommonStyle::tqpixelMetric(m, widget);
 		}
 
 		// TABS
@@ -1003,8 +1010,8 @@ int KStyle::pixelMetric(PixelMetric m, const TQWidget* widget) const
 
 		case PM_TabBarTabVSpace: {
 			const TQTabBar * tb = (const TQTabBar *) widget;
-			if ( tb->shape() == TQTabBar::RoundedAbove ||
-				 tb->shape() == TQTabBar::RoundedBelow )
+			if ( tb->tqshape() == TQTabBar::RoundedAbove ||
+				 tb->tqshape() == TQTabBar::RoundedBelow )
 				return 10;
 			else
 				return 4;
@@ -1012,7 +1019,7 @@ int KStyle::pixelMetric(PixelMetric m, const TQWidget* widget) const
 
 		case PM_TabBarTabOverlap: {
 			const TQTabBar* tb = (const TQTabBar*)widget;
-			TQTabBar::Shape tbs = tb->shape();
+			TQTabBar::Shape tbs = tb->tqshape();
 
 			if ( (tbs == TQTabBar::RoundedAbove) ||
 				 (tbs == TQTabBar::RoundedBelow) )
@@ -1034,7 +1041,7 @@ int KStyle::pixelMetric(PixelMetric m, const TQWidget* widget) const
 		case PM_SliderControlThickness: {
 			const TQSlider* slider   = (const TQSlider*)widget;
 			TQSlider::TickSetting ts = slider->tickmarks();
-			int thickness = (slider->orientation() == TQ_Horizontal) ?
+			int thickness = (slider->orientation() == Qt::Horizontal) ?
 							 slider->height() : slider->width();
 			switch (ts) {
 				case TQSlider::NoMarks:				// Use total area.
@@ -1077,10 +1084,10 @@ int KStyle::pixelMetric(PixelMetric m, const TQWidget* widget) const
 			return 0;
 
 		case PM_PopupMenuScrollerHeight:
-			return pixelMetric( PM_ScrollBarExtent, 0);
+			return tqpixelMetric( PM_ScrollBarExtent, 0);
 
 		default:
-			return TQCommonStyle::pixelMetric( m, widget );
+			return TQCommonStyle::tqpixelMetric( m, widget );
 	}
 }
 
@@ -1097,7 +1104,7 @@ static TQListViewItem* nextVisibleSibling(TQListViewItem* item)
     return sibling;
 }
 
-void KStyle::drawComplexControl( ComplexControl control,
+void KStyle::tqdrawComplexControl( TQ_ComplexControl control,
 								 TQPainter* p,
 								 const TQWidget* widget,
 								 const TQRect &r,
@@ -1139,50 +1146,50 @@ void KStyle::drawComplexControl( ComplexControl control,
 
 			// Draw the up/left button set
 			if ((controls & SC_ScrollBarSubLine) && subline.isValid()) {
-				drawPrimitive(PE_ScrollBarSubLine, p, subline, cg,
+				tqdrawPrimitive(PE_ScrollBarSubLine, p, subline, cg,
 							sflags | (active == SC_ScrollBarSubLine ?
 								Style_Down : Style_Default));
 
 				if (useThreeButtonScrollBar && subline2.isValid())
-					drawPrimitive(PE_ScrollBarSubLine, p, subline2, cg,
+					tqdrawPrimitive(PE_ScrollBarSubLine, p, subline2, cg,
 							sflags | (active == SC_ScrollBarSubLine ?
 								Style_Down : Style_Default));
 			}
 
 			if ((controls & SC_ScrollBarAddLine) && addline.isValid())
-				drawPrimitive(PE_ScrollBarAddLine, p, addline, cg,
+				tqdrawPrimitive(PE_ScrollBarAddLine, p, addline, cg,
 							sflags | ((active == SC_ScrollBarAddLine) ?
 										Style_Down : Style_Default));
 
 			if ((controls & SC_ScrollBarSubPage) && subpage.isValid())
-				drawPrimitive(PE_ScrollBarSubPage, p, subpage, cg,
+				tqdrawPrimitive(PE_ScrollBarSubPage, p, subpage, cg,
 							sflags | ((active == SC_ScrollBarSubPage) ?
 										Style_Down : Style_Default));
 
 			if ((controls & SC_ScrollBarAddPage) && addpage.isValid())
-				drawPrimitive(PE_ScrollBarAddPage, p, addpage, cg,
+				tqdrawPrimitive(PE_ScrollBarAddPage, p, addpage, cg,
 							sflags | ((active == SC_ScrollBarAddPage) ?
 										Style_Down : Style_Default));
 
 			if ((controls & SC_ScrollBarFirst) && first.isValid())
-				drawPrimitive(PE_ScrollBarFirst, p, first, cg,
+				tqdrawPrimitive(PE_ScrollBarFirst, p, first, cg,
 							sflags | ((active == SC_ScrollBarFirst) ?
 										Style_Down : Style_Default));
 
 			if ((controls & SC_ScrollBarLast) && last.isValid())
-				drawPrimitive(PE_ScrollBarLast, p, last, cg,
+				tqdrawPrimitive(PE_ScrollBarLast, p, last, cg,
 							sflags | ((active == SC_ScrollBarLast) ?
 										Style_Down : Style_Default));
 
 			if ((controls & SC_ScrollBarSlider) && slider.isValid()) {
-				drawPrimitive(PE_ScrollBarSlider, p, slider, cg,
+				tqdrawPrimitive(PE_ScrollBarSlider, p, slider, cg,
 							sflags | ((active == SC_ScrollBarSlider) ?
 										Style_Down : Style_Default));
 				// Draw focus rect
 				if (sb->hasFocus()) {
 					TQRect fr(slider.x() + 2, slider.y() + 2,
 							 slider.width() - 5, slider.height() - 5);
-					drawPrimitive(PE_FocusRect, p, fr, cg, Style_Default);
+					tqdrawPrimitive(PE_FocusRect, p, fr, cg, Style_Default);
 				}
 			}
 			break;
@@ -1215,12 +1222,12 @@ void KStyle::drawComplexControl( ComplexControl control,
 
 				// Draw the focus rect around the groove
 				if (slider->hasFocus())
-					drawPrimitive(PE_FocusRect, &p2, groove, cg);
+					tqdrawPrimitive(PE_FocusRect, &p2, groove, cg);
 			}
 
 			// Draw the tickmarks
 			if (controls & SC_SliderTickmarks)
-				TQCommonStyle::drawComplexControl(control, &p2, widget,
+				TQCommonStyle::tqdrawComplexControl(control, &p2, widget,
 						r, cg, flags, SC_SliderTickmarks, active, opt);
 
 			// Draw the slider handle
@@ -1246,7 +1253,7 @@ void KStyle::drawComplexControl( ComplexControl control,
 
 			// Paint the icon and text.
 			if ( controls & SC_ListView )
-				TQCommonStyle::drawComplexControl( control, p, widget, r, cg, flags, controls, active, opt );
+				TQCommonStyle::tqdrawComplexControl( control, p, widget, r, cg, flags, controls, active, opt );
 
 			// If we're have a branch or are expanded...
 			if ( controls & (SC_ListViewBranch | SC_ListViewExpand) )
@@ -1386,14 +1393,14 @@ void KStyle::drawComplexControl( ComplexControl control,
 		}
 
 		default:
-			TQCommonStyle::drawComplexControl( control, p, widget, r, cg,
+			TQCommonStyle::tqdrawComplexControl( control, p, widget, r, cg,
 											  flags, controls, active, opt );
 			break;
 	}
 }
 
 
-TQStyle::SubControl KStyle::querySubControl( ComplexControl control,
+TQStyle::SubControl KStyle::querySubControl( TQ_ComplexControl control,
 											const TQWidget* widget,
 											const TQPoint &pos,
 											const TQStyleOption &opt ) const
@@ -1409,7 +1416,7 @@ TQStyle::SubControl KStyle::querySubControl( ComplexControl control,
 }
 
 
-TQRect KStyle::querySubControlMetrics( ComplexControl control,
+TQRect KStyle::querySubControlMetrics( TQ_ComplexControl control,
 									  const TQWidget* widget,
 									  SubControl sc,
 									  const TQStyleOption &opt ) const
@@ -1425,7 +1432,7 @@ TQRect KStyle::querySubControlMetrics( ComplexControl control,
 		const TQScrollBar *sb = (const TQScrollBar*)widget;
 		bool horizontal = sb->orientation() == Qt::Horizontal;
 		int sliderstart = sb->sliderStart();
-		int sbextent    = pixelMetric(PM_ScrollBarExtent, widget);
+		int sbextent    = tqpixelMetric(PM_ScrollBarExtent, widget);
 		int maxlen      = (horizontal ? sb->width() : sb->height())
 						  - (sbextent * (threeButtonScrollBar ? 3 : 2));
 		int sliderlen;
@@ -1436,7 +1443,7 @@ TQRect KStyle::querySubControlMetrics( ComplexControl control,
 			uint range = sb->maxValue() - sb->minValue();
 			sliderlen = (sb->pageStep() * maxlen) /	(range + sb->pageStep());
 
-			int slidermin = pixelMetric( PM_ScrollBarSliderMin, widget );
+			int slidermin = tqpixelMetric( PM_ScrollBarSliderMin, widget );
 			if ( sliderlen < slidermin || range > INT_MAX / 2 )
 				sliderlen = slidermin;
 			if ( sliderlen > maxlen )
@@ -1826,8 +1833,8 @@ TQPixmap KStyle::stylePixmap( StylePixmap stylepixmap,
 }
 
 
-int KStyle::styleHint( StyleHint sh, const TQWidget* w,
-					   const TQStyleOption &opt, QStyleHintReturn* shr) const
+int KStyle::tqstyleHint( TQ_StyleHint sh, const TQWidget* w,
+					   const TQStyleOption &opt, TQStyleHintReturn* shr) const
 {
 	switch (sh)
 	{
@@ -1841,7 +1848,7 @@ int KStyle::styleHint( StyleHint sh, const TQWidget* w,
 			return d->menuAltKeyNavigation ? 1 : 0;
 
 		case SH_PopupMenu_SubMenuPopupDelay:
-			if ( styleHint( SH_PopupMenu_SloppySubMenus, w ) )
+			if ( tqstyleHint( SH_PopupMenu_SloppySubMenus, w ) )
 				return QMIN( 100, d->popupMenuDelay );
 			else
 				return d->popupMenuDelay;
@@ -1877,7 +1884,7 @@ int KStyle::styleHint( StyleHint sh, const TQWidget* w,
 		}
 
 		default:
-			return TQCommonStyle::styleHint(sh, w, opt, shr);
+			return TQCommonStyle::tqstyleHint(sh, w, opt, shr);
 	}
 }
 
@@ -1890,19 +1897,19 @@ bool KStyle::eventFilter( TQObject* object, TQEvent* event )
 		// ensure that the filled frame contents are properly painted.
 		// We essentially modify the paintEvent's rect to include the
 		// panel border, which also paints the widget's interior.
-		// This is nasty, but I see no other way to properly repaint
+		// This is nasty, but I see no other way to properly tqrepaint
 		// filled frames in all QMenuBars and QToolBars.
 		// -- Karol.
 		TQFrame *frame = 0;
 		if ( event->type() == TQEvent::Paint
-				&& (frame = tqqt_cast<TQFrame*>(object)) )
+				&& (frame = ::tqqt_cast<TQFrame*>(object)) )
 		{
 			if (frame->frameShape() != TQFrame::ToolBarPanel && frame->frameShape() != TQFrame::MenuBarPanel)
 				return false;
 				
 			bool horizontal = true;
 			TQPaintEvent* pe = (TQPaintEvent*)event;
-			TQToolBar *toolbar = tqqt_cast< TQToolBar *>( frame );
+			TQToolBar *toolbar = ::tqqt_cast< TQToolBar *>( frame );
 			TQRect r = pe->rect();
 
 			if (toolbar && toolbar->orientation() == Qt::Vertical)
@@ -1952,9 +1959,24 @@ TransparencyHandler::~TransparencyHandler()
 {
 }
 
+bool TransparencyHandler::haveX11RGBASupport()
+{
+	// Simple way to determine if we have ARGB support
+	if (TQPaintDevice::x11AppDepth() == 32) {
+		return true;
+	}
+	else {
+		return false;
+	}
+}
+
+#define REAL_ALPHA_STRENGTH 255.0
+
 // This is meant to be ugly but fast.
 void TransparencyHandler::rightShadow(TQImage& dst)
 {
+	bool have_composite = haveX11RGBASupport();
+
 	if (dst.depth() != 32)
 		dst = dst.convertDepth(32);
 
@@ -1966,34 +1988,60 @@ void TransparencyHandler::rightShadow(TQImage& dst)
 	register unsigned char* data = dst.bits();		// Skip alpha
 #endif
 	for(register int i = 0; i < 16; i++) {
-		*data = (unsigned char)((*data)*top_right_corner[i]); data++;
-		*data = (unsigned char)((*data)*top_right_corner[i]); data++;
-		*data = (unsigned char)((*data)*top_right_corner[i]); data++;
-		data++;	// skip alpha
+		if (have_composite) {
+			data++;
+			data++;
+			data++;
+			*data = (unsigned char)(REAL_ALPHA_STRENGTH*(1.0-top_right_corner[i])); data++;
+		}
+		else {
+			*data = (unsigned char)((*data)*top_right_corner[i]); data++;
+			*data = (unsigned char)((*data)*top_right_corner[i]); data++;
+			*data = (unsigned char)((*data)*top_right_corner[i]); data++;
+			data++;	// skip alpha
+		}
 	}
 
 	pixels -= 32;	// tint right strip without rounded edges.
 	register int c = 0;
 	for(register int i = 0; i < pixels; i++) {
-		*data = (unsigned char)((*data)*shadow_strip[c]); data++;
-		*data = (unsigned char)((*data)*shadow_strip[c]); data++;
-		*data = (unsigned char)((*data)*shadow_strip[c]); data++;
-		data++; // skip alpha
-	        ++c;
+		if (have_composite) {
+			data++;
+			data++;
+			data++;;
+			*data = (unsigned char)(REAL_ALPHA_STRENGTH*(1.0-shadow_strip[c])); data++;
+		}
+		else {
+			*data = (unsigned char)((*data)*shadow_strip[c]); data++;
+			*data = (unsigned char)((*data)*shadow_strip[c]); data++;
+			*data = (unsigned char)((*data)*shadow_strip[c]); data++;
+			data++; // skip alpha
+		}
+		++c;
 		c %= 4;
 	}
 
 	// tint bottom edge
 	for(register int i = 0; i < 16; i++) {
-		*data = (unsigned char)((*data)*bottom_right_corner[i]); data++;
-		*data = (unsigned char)((*data)*bottom_right_corner[i]); data++;
-		*data = (unsigned char)((*data)*bottom_right_corner[i]); data++;
-		data++;	// skip alpha
+		if (have_composite) {
+			data++;
+			data++;
+			data++;
+			*data = (unsigned char)(REAL_ALPHA_STRENGTH*(1.0-bottom_right_corner[i])); data++;
+		}
+		else {
+			*data = (unsigned char)((*data)*bottom_right_corner[i]); data++;
+			*data = (unsigned char)((*data)*bottom_right_corner[i]); data++;
+			*data = (unsigned char)((*data)*bottom_right_corner[i]); data++;
+			data++;	// skip alpha
+		}
 	}
 }
 
 void TransparencyHandler::bottomShadow(TQImage& dst)
 {
+	bool have_composite = haveX11RGBASupport();
+
 	if (dst.depth() != 32)
 		dst = dst.convertDepth(32);
 
@@ -2012,25 +2060,59 @@ void TransparencyHandler::bottomShadow(TQImage& dst)
 	{
 		// Bottom-left Corner
 		for(register int x = 0; x < 4; x++) {
-			*data = (unsigned char)((*data)*(*corner)); data++;
-			*data = (unsigned char)((*data)*(*corner)); data++;
-			*data = (unsigned char)((*data)*(*corner)); data++;
-			data++; // skip alpha
+			if (have_composite) {
+				data++;
+				data++;
+				data++;
+				*data = (unsigned char)(REAL_ALPHA_STRENGTH*(1.0-(*corner))); data++;
+			}
+			else {
+				*data = (unsigned char)((*data)*(*corner)); data++;
+				*data = (unsigned char)((*data)*(*corner)); data++;
+				*data = (unsigned char)((*data)*(*corner)); data++;
+				data++; // skip alpha
+			}
 			corner++;
 		}
 
 		// Scanline
 		for(register int x = 0; x < width; x++) {
-			*data = (unsigned char)((*data)*strip_data); data++;
-			*data = (unsigned char)((*data)*strip_data); data++;
-			*data = (unsigned char)((*data)*strip_data); data++;
-			data++;
+			if (have_composite) {
+				data++;
+				data++;
+				data++;
+				*data = (unsigned char)(REAL_ALPHA_STRENGTH*(1.0-strip_data)); data++;
+			}
+			else {
+				*data = (unsigned char)((*data)*strip_data); data++;
+				*data = (unsigned char)((*data)*strip_data); data++;
+				*data = (unsigned char)((*data)*strip_data); data++;
+				data++; // skip alpha
+			}
 		}
 
 		strip_data = shadow_strip[++line];
 	}
 }
 
+TQImage TransparencyHandler::handleRealAlpha(TQImage img) {
+	TQImage clearImage = img.convertDepth(32);
+	clearImage.setAlphaBuffer(true);
+
+	int w = clearImage.width();
+	int h = clearImage.height();
+
+	for (int y = 0; y < h; ++y) {
+		TQRgb *ls = (TQRgb *)clearImage.scanLine( y );
+		for (int x = 0; x < w; ++x) {
+			TQRgb l = ls[x];
+			ls[x] = tqRgba( 0, 0, 0, 0 );
+		}
+	}
+
+	return clearImage;
+}
+
 // Create a shadow of thickness 4.
 void TransparencyHandler::createShadowWindows(const TQWidget* p)
 {
@@ -2040,10 +2122,12 @@ void TransparencyHandler::createShadowWindows(const TQWidget* p)
 	TQRect shadow1(x2, p->y() + 4, 4, p->height());
 	TQRect shadow2(p->x() + 4, y2, p->width() - 4, 4);
 
+	bool have_composite = haveX11RGBASupport();
+
 	// Create a fake drop-down shadow effect via blended Xwindows
 	ShadowElements se;
-	se.w1 = new TQWidget(0, 0, WStyle_Customize | WType_Popup | WX11BypassWM );
-	se.w2 = new TQWidget(0, 0, WStyle_Customize | WType_Popup | WX11BypassWM );
+	se.w1 = new TQWidget(0, 0, (WFlags)(WStyle_Customize | WType_Popup | WX11BypassWM) );
+	se.w2 = new TQWidget(0, 0, (WFlags)(WStyle_Customize | WType_Popup | WX11BypassWM) );
 	se.w1->setGeometry(shadow1);
 	se.w2->setGeometry(shadow2);
 	XSelectInput(qt_xdisplay(), se.w1->winId(), StructureNotifyMask );
@@ -2053,16 +2137,26 @@ void TransparencyHandler::createShadowWindows(const TQWidget* p)
 	shadowMap()[p] = se;
 
 	// Some hocus-pocus here to create the drop-shadow.
-	TQPixmap pix_shadow1 = TQPixmap::grabWindow(qt_xrootwin(),
-			shadow1.x(), shadow1.y(), shadow1.width(), shadow1.height());
-	TQPixmap pix_shadow2 = TQPixmap::grabWindow(qt_xrootwin(),
-			shadow2.x(), shadow2.y(), shadow2.width(), shadow2.height());
+	TQPixmap pix_shadow1;
+	TQPixmap pix_shadow2;
+	if (have_composite) {
+		pix_shadow1 = TQPixmap(shadow1.width(), shadow1.height());
+		pix_shadow2 = TQPixmap(shadow2.width(), shadow2.height());
+	}
+	else {
+		pix_shadow1 = TQPixmap::grabWindow(qt_xrootwin(),
+				shadow1.x(), shadow1.y(), shadow1.width(), shadow1.height());
+		pix_shadow2 = TQPixmap::grabWindow(qt_xrootwin(),
+				shadow2.x(), shadow2.y(), shadow2.width(), shadow2.height());
+	}
 
 	TQImage img;
 	img = pix_shadow1.convertToImage();
+	if (have_composite) img = handleRealAlpha(img);
 	rightShadow(img);
 	pix_shadow1.convertFromImage(img);
 	img = pix_shadow2.convertToImage();
+	if (have_composite) img = handleRealAlpha(img);
 	bottomShadow(img);
 	pix_shadow2.convertFromImage(img);
 
@@ -2128,12 +2222,12 @@ bool TransparencyHandler::eventFilter( TQObject* object, TQEvent* event )
 				case XRender:
 #endif
 				case SoftwareBlend:
-					blendToPixmap(p->colorGroup(), p);
+					blendToPixmap(p->tqcolorGroup(), p);
 					break;
 
 				case SoftwareTint:
 				default:
-					blendToColor(p->colorGroup().button());
+					blendToColor(p->tqcolorGroup().button());
 			};
 
 			p->setErasePixmap(pix);
@@ -2198,8 +2292,8 @@ void TransparencyHandler::blendToPixmap(const TQColorGroup &cg, const TQWidget*
 		return;
 
 	// Allow styles to define the blend pixmap - allows for some interesting effects.
-	if (::qt_cast<TQPopupMenu*>(p))
-		kstyle->renderMenuBlendPixmap( blendPix, cg, ::qt_cast<TQPopupMenu*>(p) );
+	if (::tqqt_cast<TQPopupMenu*>(p))
+		kstyle->renderMenuBlendPixmap( blendPix, cg, ::tqqt_cast<TQPopupMenu*>(p) );
 	else
 		blendPix.fill(cg.button());	// Just tint as the default behavior
 
@@ -2220,11 +2314,11 @@ void TransparencyHandler::XRenderBlendToPixmap(const TQWidget* p)
 	renderPix.resize( pix.width(), pix.height() );
 
 	// Allow styles to define the blend pixmap - allows for some interesting effects.
-	if (::qt_cast<TQPopupMenu*>(p))
-	   kstyle->renderMenuBlendPixmap( renderPix, p->colorGroup(),
-			   ::qt_cast<TQPopupMenu*>(p) );
+	if (::tqqt_cast<TQPopupMenu*>(p))
+	   kstyle->renderMenuBlendPixmap( renderPix, p->tqcolorGroup(),
+			   ::tqqt_cast<TQPopupMenu*>(p) );
 	else
-		renderPix.fill(p->colorGroup().button());	// Just tint as the default behavior
+		renderPix.fill(p->tqcolorGroup().button());	// Just tint as the default behavior
 
 	Display* dpy = qt_xdisplay();
 	Pixmap   alphaPixmap;
