@@ -29,7 +29,7 @@ public:
 	virtual ~KLpdFactory();
 
 protected:
-	TQObject* createObject(TQObject *parent = 0, const char *name = 0, const char *className = "TQObject", const TQStringList& args = TQStringList());
+	TQObject* createObject(TQObject *parent = 0, const char *name = 0, const char *className = TQOBJECT_OBJECT_NAME_STRING, const TQStringList& args = TQStringList());
 };
 
 #endif
