@@ -23,7 +23,7 @@
 
 TQString maticFile(PrintcapEntry *entry)
 {
-	QString	s(entry->field("af"));
+	TQString	s(entry->field("af"));
 	if (s.isEmpty())
 	{
 		s = entry->field("filter_options");
