@@ -26,7 +26,7 @@ class KConfig;
 class TQLineEdit;
 class TQCheckBox;
 
-class KMProxyWidget : public QGroupBox
+class KMProxyWidget : public TQGroupBox
 {
 public:
 	KMProxyWidget(TQWidget *parent = 0, const char *name = 0);
@@ -35,9 +35,9 @@ public:
 	void saveConfig(KConfig*);
 
 private:
-	QLineEdit	*m_proxyhost;
-	QLineEdit	*m_proxyport;
-	QCheckBox	*m_useproxy;
+	TQLineEdit	*m_proxyhost;
+	TQLineEdit	*m_proxyport;
+	TQCheckBox	*m_useproxy;
 };
 
 #endif
