@@ -76,11 +76,9 @@
 #define KDESU_ERR strerror(errno)
 
 Minicli::Minicli( TQWidget *parent, const char *name)
-        :KDialog( parent, name, false, WType_TopLevel ),
-         m_autoCheckedRunInTerm(false)
+        :KDialog( parent, name, false, (WFlags)WType_TopLevel ),
+         m_autoCheckedRunInTerm(false), m_pURLCompletion(NULL), m_pEXECompletion(NULL)
 {
-  m_pURLCompletion = 0L;
-
   setPlainCaption( i18n("Run Command") );
   KWin::setIcons( winId(), DesktopIcon("run"), SmallIcon("run") );
 
@@ -89,7 +87,7 @@ Minicli::Minicli( TQWidget *parent, const char *name)
   mainLayout->addWidget(m_dlg);
 
   m_dlg->lbRunIcon->setPixmap(DesktopIcon("kmenu"));
-  m_dlg->lbComment->setAlignment( Qt::WordBreak );
+  m_dlg->lbComment->tqsetAlignment( TQt::WordBreak );
 
   m_dlg->cbCommand->setDuplicatesEnabled( false );
   m_dlg->cbCommand->setTrapReturnKey( true );
@@ -129,9 +127,12 @@ Minicli::Minicli( TQWidget *parent, const char *name)
   // Autocomplete system
   m_filesystemAutocomplete = 0;
   m_histfilesystemAutocomplete = 0;
-  m_pURLCompletion = new KURLCompletion();
+  m_systempathAutocomplete = 0;
+  m_pURLCompletion = new KURLCompletion(KURLCompletion::FileCompletion);
+  m_pEXECompletion = new KURLCompletion(KURLCompletion::SystemExeCompletion);
   //m_pURLCompletion->setCompletionMode( KGlobalSettings::completionMode() );
   connect( m_pURLCompletion, TQT_SIGNAL( match(const TQString&) ), TQT_SLOT( slotMatch(const TQString&) ));
+  connect( m_pEXECompletion, TQT_SIGNAL( match(const TQString&) ), TQT_SLOT( slotEXEMatch(const TQString&) ));
 
   // Main widget buttons...
   connect( m_dlg->pbRun, TQT_SIGNAL(clicked()), this, TQT_SLOT(accept()) );
@@ -152,6 +153,7 @@ Minicli::Minicli( TQWidget *parent, const char *name)
   connect(m_dlg->cbPriority, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotChangeScheduler(bool)));
   connect(m_dlg->slPriority, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotPriority(int)));
   connect(m_dlg->cbRealtime, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotRealtime(bool)));
+  connect(m_dlg->cbAppcomplete, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotAppcompleteToggled(bool)));
   connect(m_dlg->cbAutocomplete, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotAutocompleteToggled(bool)));
   connect(m_dlg->cbAutohistory, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotAutohistoryToggled(bool)));
   connect(m_dlg->cbRunAsOther, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotChangeUid(bool)));
@@ -167,6 +169,7 @@ Minicli::~Minicli()
 {
   delete m_filterData;
   delete m_pURLCompletion;
+  delete m_pEXECompletion;
 }
 
 void Minicli::setCommand(const TQString& command)
@@ -179,9 +182,9 @@ void Minicli::setCommand(const TQString& command)
   }
 }
 
-TQSize Minicli::sizeHint() const
+TQSize Minicli::tqsizeHint() const
 {
-  int maxWidth = qApp->desktop()->screenGeometry((TQWidget*)this).width();
+  int maxWidth = tqApp->desktop()->screenGeometry((TQWidget*)this).width();
   if (maxWidth < 603)
   {
     // a sensible max for smaller screens
@@ -217,9 +220,11 @@ void Minicli::loadConfig()
   m_dlg->cbCommand->blockSignals( block );
 
   m_dlg->cbAutocomplete->setChecked( KDesktopSettings::miniCLIFilesystemAutoComplete() );
+  m_dlg->cbAppcomplete->setChecked( KDesktopSettings::miniCLISystempathAutoComplete() );
   m_dlg->cbAutohistory->setChecked( KDesktopSettings::miniCLIHistoryAndFilesystemAutoComplete() );
 
   m_filesystemAutocomplete = KDesktopSettings::miniCLIFilesystemAutoComplete();
+  m_systempathAutocomplete = KDesktopSettings::miniCLISystempathAutoComplete();
   m_histfilesystemAutocomplete = KDesktopSettings::miniCLIHistoryAndFilesystemAutoComplete();
 
   if (m_histfilesystemAutocomplete == true) {
@@ -275,6 +280,7 @@ void Minicli::saveConfig()
   //KDesktopSettings::setCompletionItems( m_dlg->cbCommand->completionObject()->items() );
   KDesktopSettings::setCompletionMode( m_dlg->cbCommand->completionMode() );
   KDesktopSettings::setMiniCLIFilesystemAutoComplete( m_filesystemAutocomplete );
+  KDesktopSettings::setMiniCLISystempathAutoComplete( m_systempathAutocomplete );
   KDesktopSettings::setMiniCLIHistoryAndFilesystemAutoComplete( m_histfilesystemAutocomplete );
   KDesktopSettings::writeConfig();
 }
@@ -319,7 +325,7 @@ void Minicli::accept()
      int kicker_screen_number = qt_xscreen();
      if ( kicker_screen_number )
          appname.sprintf("kdesktop-screen-%d", kicker_screen_number);
-     kapp->dcopClient()->send(appname, "KScreensaverIface", "lock()", "");
+     kapp->dcopClient()->send(appname, "KScreensaverIface", "lock()", TQString(""));
   }
 }
 
@@ -414,13 +420,13 @@ int Minicli::runCommand()
     cmd = uri.url();
     
   TQCString asn;
-  if( qApp->desktop()->isVirtualDesktop())
+  if( tqApp->desktop()->isVirtualDesktop())
   {
     asn = KStartupInfo::createNewStartupId();
     KStartupInfoId id;
     id.initId( asn );
     KStartupInfoData data;
-    data.setXinerama( qApp->desktop()->screenNumber( this ));
+    data.setXinerama( tqApp->desktop()->screenNumber( this ));
     KStartupInfo::sendChange( id, data );
   }
 
@@ -678,6 +684,15 @@ void Minicli::slotCmdChanged(const TQString& text)
         TQString completion = m_pURLCompletion->makeCompletion( text );
     }
   }
+  if ((m_systempathAutocomplete == true) && ( m_pEXECompletion )) {
+    // Attempt to autocomplete the entered URL if it starts with the / character, meaning I am looking for something on the filesystem
+    // Also use autocompletion if it appears that I am using some kind of ioslave, except the http:// ioslave
+    m_exeCompletionStarted = true; // flag for slotEXEMatch()
+
+    if (!((text.startsWith( "/" ) || text.startsWith( "~" ) || (text.contains("://", false) != 0)) && (text.contains("http://", false) == 0))) {
+        TQString completion = m_pEXECompletion->makeCompletion( text );
+    }
+  }
 
   m_parseTimer->start(250, true);
 }
@@ -721,6 +736,45 @@ void Minicli::slotMatch( const TQString &match )
   }
 }
 
+// Handle match() from m_pEXECompletion
+void Minicli::slotEXEMatch( const TQString &match )
+{
+  TQString current_text;
+  TQStringList histList = KDesktopSettings::history();
+  int maxHistory = KDesktopSettings::historyLength();
+  int maxAutocompletion = KDesktopSettings::miniCLIAutocompletionLength();
+
+  if ( match.isEmpty() ) // this case is handled directly
+    return;
+
+  // Check flag to avoid match() raised by rotation
+  if ( m_exeCompletionStarted ) {
+    m_exeCompletionStarted = false;
+
+    if (m_systempathAutocomplete == true) {
+        bool block = m_dlg->cbCommand->signalsBlocked();
+        m_dlg->cbCommand->blockSignals( true );
+        TQStringList items = m_pEXECompletion->allMatches();
+        items.sort();
+        if (m_histfilesystemAutocomplete == true) {
+            // Add the history to the list
+            histList += items;
+            maxHistory += maxAutocompletion;
+        }
+        else {
+            histList = items;
+            maxHistory = maxAutocompletion;
+        }
+        current_text = m_dlg->cbCommand->currentText();
+        //histList.prepend ( current_text );	// Add the current text to the autocompletion list
+        m_dlg->cbCommand->setMaxCount( maxHistory );
+        m_dlg->cbCommand->completionObject()->setItems( histList );
+        m_dlg->cbCommand->setCurrentText( current_text );
+        m_dlg->cbCommand->blockSignals( block );
+    }
+  }
+}
+
 void Minicli::slotAdvanced()
 {
   if (m_dlg->gbAdvanced->isHidden())
@@ -730,7 +784,7 @@ void Minicli::slotAdvanced()
 
     // Set the focus back to the widget that had it to begin with, i.e.
     // do not put the focus on the "Options" button.
-    m_FocusWidget = focusWidget();
+    m_FocusWidget = tqfocusWidget();
 
     if( m_FocusWidget )
       m_FocusWidget->setFocus();
@@ -792,7 +846,7 @@ void Minicli::parseLine( bool final )
 void Minicli::setIcon ()
 {
   if( m_iconName.isEmpty() || m_iconName == "unknown" || m_iconName == "kde" )
-    m_iconName = TQString::fromLatin1("kmenu");
+    m_iconName = TQString::tqfromLatin1("kmenu");
 
   TQPixmap icon = DesktopIcon( m_iconName );
 
@@ -810,7 +864,7 @@ void Minicli::setIcon ()
       {
         TQBitmap mask = *icon.mask();
         bitBlt( &mask, x, y,
-                overlay.mask() ? const_cast<TQBitmap *>(overlay.mask()) : &overlay,
+                overlay.mask() ? TQT_TQPIXMAP(const_cast<TQBitmap *>(overlay.mask())) : &overlay,
                 0, 0, overlay.width(), overlay.height(),
                 overlay.mask() ? OrROP : SetROP );
         icon.setMask(mask);
@@ -837,9 +891,9 @@ void Minicli::updateAuthLabel()
       m_prevChecked = m_dlg->cbRunAsOther->isChecked();
       m_prevCached = true;
     }
-    if (m_dlg->leUsername->text() != TQString::fromLatin1("root"))
+    if (m_dlg->leUsername->text() != TQString::tqfromLatin1("root"))
       m_dlg->lePassword->setText(TQString::null);
-    m_dlg->leUsername->setText(TQString::fromLatin1("root"));
+    m_dlg->leUsername->setText(TQString::tqfromLatin1("root"));
     m_dlg->cbRunAsOther->setChecked(true);
     m_dlg->cbRunAsOther->setEnabled(false);
     m_dlg->leUsername->setEnabled(false);
@@ -884,7 +938,7 @@ void Minicli::slotTerminal(bool enable)
   if (enable)
   {
     m_prevIconName = m_iconName;
-    m_iconName = TQString::fromLatin1( "konsole" );
+    m_iconName = TQString::tqfromLatin1( "konsole" );
     setIcon();
   }
   else if (!m_prevIconName.isEmpty())
@@ -961,6 +1015,14 @@ void Minicli::slotAutocompleteToggled(bool enabled)
   m_dlg->cbCommand->setCurrentText( current_text );    // Force an update of the autocompletion list
 }
 
+void Minicli::slotAppcompleteToggled(bool enabled)
+{
+  m_systempathAutocomplete = enabled;
+
+  TQString current_text = m_dlg->cbCommand->currentText();
+  m_dlg->cbCommand->setCurrentText( current_text );    // Force an update of the autocompletion list
+}
+
 void Minicli::slotAutohistoryToggled(bool enabled)
 {
   if (enabled)
