@@ -21,7 +21,7 @@
     the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
     Boston, MA 02110-1301, USA.
 */
-//$Id: kaction.h 1158447 2010-08-02 19:23:47Z tpearson $
+//$Id: kaction.h 1214149 2011-01-13 08:32:36Z tpearson $
 
 #ifndef __kaction_h__
 #define __kaction_h__
@@ -199,7 +199,7 @@ class KMainWindow;
  *
  * @see KStdAction
  */
-class KDEUI_EXPORT KAction : public QObject
+class KDEUI_EXPORT KAction : public TQObject
 {
   friend class KActionCollection;
   Q_OBJECT
@@ -570,7 +570,7 @@ protected slots:
     /// @since 3.4
     void slotPopupActivated(); // KDE4: make virtual
     /// @since 3.4
-    void slotButtonClicked( int, Qt::ButtonState state ); // KDE4: make virtual
+    void slotButtonClicked( int, TQt::ButtonState state ); // KDE4: make virtual
 
 protected:
     KToolBar* toolBar( int index ) const;
@@ -620,7 +620,7 @@ signals:
      *
      * @since 3.4
      */
-    void activated( KAction::ActivationReason reason, Qt::ButtonState state );
+    void activated( KAction::ActivationReason reason, TQt::ButtonState state );
     void enabled( bool );
 
 private:
