@@ -110,7 +110,7 @@ KActionCollection::KActionCollection( TQObject *parent, const char *name,
   kdWarning(129) << "KActionCollection::KActionCollection( TQObject *parent, const char *name, KInstance *instance )" << endl; //ellis
   kdDebug(129) << kdBacktrace() << endl;
   d = new KActionCollectionPrivate;
-  TQWidget* w = dynamic_cast<TQWidget*>( parent );
+  TQWidget* w = tqt_dynamic_cast<TQWidget*>( parent );
   if( w )
     setWidget( w );
   //d->m_bOneKAccelOnly = (d->m_kaccelList.count() > 0);
@@ -250,8 +250,8 @@ void KActionCollection::removeWidget( TQWidget* w )
         }
         delete pKAccel;
 
-        d->m_widgetList.remove( d->m_widgetList.at( i ) );
-        d->m_kaccelList.remove( d->m_kaccelList.at( i ) );
+        d->m_widgetList.remove( d->m_widgetList.tqat( i ) );
+        d->m_kaccelList.remove( d->m_kaccelList.tqat( i ) );
 
         if( d->m_iWidgetCurrent == (int)i )
           d->m_iWidgetCurrent = -1;
@@ -402,7 +402,7 @@ KAction* KActionCollection::action( int index ) const
   TQAsciiDictIterator<KAction> it( d->m_actionDict );
   it += index;
   return it.current();
-//  return d->m_actions.at( index );
+//  return d->m_actions.tqat( index );
 }
 
 bool KActionCollection::readShortcutSettings( const TQString& sConfigGroup, KConfigBase* pConfig )
@@ -501,14 +501,14 @@ void KActionCollection::connectHighlight( TQWidget *container, KAction *action )
   {
     actionList = new TQPtrList<KAction>;
 
-    if ( ::qt_cast<TQPopupMenu *>( container ) )
+    if ( ::tqqt_cast<TQPopupMenu *>( container ) )
     {
       connect( container, TQT_SIGNAL( highlighted( int ) ),
                this, TQT_SLOT( slotMenuItemHighlighted( int ) ) );
       connect( container, TQT_SIGNAL( aboutToHide() ),
                this, TQT_SLOT( slotMenuAboutToHide() ) );
     }
-    else if ( ::qt_cast<KToolBar *>( container ) )
+    else if ( ::tqqt_cast<KToolBar *>( container ) )
     {
       connect( container, TQT_SIGNAL( highlighted( int, bool ) ),
                this, TQT_SLOT( slotToolBarButtonHighlighted( int, bool ) ) );
@@ -547,7 +547,7 @@ void KActionCollection::slotMenuItemHighlighted( int id )
   if ( d->m_currentHighlightAction )
     emit actionHighlighted( d->m_currentHighlightAction, false );
 
-  TQWidget *container = static_cast<TQWidget *>( const_cast<TQObject *>( sender() ) );
+  TQWidget *container = const_cast<TQWidget*>(TQT_TQWIDGET_CONST( sender() ));
 
   d->m_currentHighlightAction = findAction( container, id );
 
@@ -581,7 +581,7 @@ void KActionCollection::slotToolBarButtonHighlighted( int id, bool highlight )
   if ( !d->m_highlight )
     return;
 
-  TQWidget *container = static_cast<TQWidget *>( const_cast<TQObject *>( sender() ) );
+  TQWidget *container = const_cast<TQWidget*>(TQT_TQWIDGET_CONST( sender() ));
 
   KAction *action = findAction( container, id );
 
@@ -606,7 +606,7 @@ void KActionCollection::slotToolBarButtonHighlighted( int id, bool highlight )
 
 void KActionCollection::slotDestroyed()
 {
-    d->m_dctHighlightContainers.remove( reinterpret_cast<void *>( const_cast<TQObject *>(sender()) ) );
+    d->m_dctHighlightContainers.remove( reinterpret_cast<void *>( const_cast<TQObject*>(TQT_TQOBJECT_CONST(sender())) ) );
 }
 
 KAction *KActionCollection::findAction( TQWidget *container, int id )
@@ -713,8 +713,8 @@ bool KActionShortcutList::save() const
 	if( m_actions.xmlFile().isEmpty() )
 		return writeSettings();
 
-	TQString attrShortcut  = TQString::fromLatin1("shortcut");
-	TQString attrAccel     = TQString::fromLatin1("accel"); // Depricated attribute
+	TQString attrShortcut  = TQString::tqfromLatin1("shortcut");
+	TQString attrAccel     = TQString::tqfromLatin1("accel"); // Depricated attribute
 
 	// Read XML file
 	TQString sXml( KXMLGUIFactory::readConfigFile( xmlFile, false, instance() ) );
