@@ -100,9 +100,10 @@ namespace KMDI
  *
  * @author Max Judin (documentation: Falk Brettschneider).
  */
-class KDEUI_EXPORT KDockWidgetAbstractHeader : public QFrame
+class KDEUI_EXPORT KDockWidgetAbstractHeader : public TQFrame
 {
   Q_OBJECT
+  TQ_OBJECT
 public:
 
   /**
@@ -149,9 +150,10 @@ private:
  *
  * @author Max Judin (documentation: Falk Brettschneider).
  */
-class KDEUI_EXPORT KDockWidgetAbstractHeaderDrag : public QFrame
+class KDEUI_EXPORT KDockWidgetAbstractHeaderDrag : public TQFrame
 {
   Q_OBJECT
+  TQ_OBJECT
 public:
 
   /**
@@ -197,6 +199,7 @@ private:
 class KDEUI_EXPORT KDockWidgetHeaderDrag : public KDockWidgetAbstractHeaderDrag
 {
   Q_OBJECT
+  TQ_OBJECT
 public:
 
   /**
@@ -238,6 +241,7 @@ private:
 class KDEUI_EXPORT KDockWidgetHeader : public KDockWidgetAbstractHeader
 {
   Q_OBJECT
+  TQ_OBJECT
 public:
 
   /**
@@ -360,9 +364,10 @@ private:
  *
  * @author Max Judin (documentation: Falk Brettschneider).
  */
-class KDEUI_EXPORT KDockTabGroup : public QTabWidget
+class KDEUI_EXPORT KDockTabGroup : public TQTabWidget
 {
   Q_OBJECT
+  TQ_OBJECT
 public:
   /**
    * Constructs this. It just calls the method of the base class.
@@ -420,9 +425,10 @@ private:
  *
  * @author Max Judin (documentation: Falk Brettschneider).
  */
-class KDEUI_EXPORT KDockWidget: public QWidget
+class KDEUI_EXPORT KDockWidget: public TQWidget
 {
   Q_OBJECT
+  TQ_OBJECT
 friend class KDockManager;
 friend class KDockSplitter;
 friend class KDockMainWindow;
@@ -446,7 +452,7 @@ public:
    */
   KDockWidget( KDockManager* dockManager, const char* name,
                const TQPixmap &pixmap, TQWidget* parent = 0L, const TQString& strCaption = TQString::null,
-               const TQString& strTabPageLabel = TQString::fromLatin1( " " ), WFlags f = 0);
+               const TQString& strTabPageLabel = TQString::tqfromLatin1( " " ), WFlags f = 0);
 
   /**
    * Destructs a dockwidget.
@@ -906,9 +912,10 @@ private:
  *
  * @author Max Judin (documentation: Falk Brettschneider).
  */
-class KDEUI_EXPORT KDockManager: public QObject
+class KDEUI_EXPORT KDockManager: public TQObject
 {
   Q_OBJECT
+  TQ_OBJECT
 friend class KDockWidget;
 friend class KDockMainWindow;
 
@@ -1307,6 +1314,7 @@ private:
 class KDEUI_EXPORT KDockMainWindow : public KMainWindow
 {
   Q_OBJECT
+  TQ_OBJECT
 
 friend class KDockManager;
 
@@ -1324,7 +1332,11 @@ public:
    * @param name internal object name
    * @param f Qt::WidgetFlags widget flags
    */
+#ifdef qdoc
   KDockMainWindow( TQWidget* parent = 0L, const char *name = 0L, WFlags f = WType_TopLevel | WDestructiveClose );
+#else
+  KDockMainWindow( TQWidget* parent = 0L, const char *name = 0L, WFlags f = (WFlags)(WType_TopLevel | WDestructiveClose) );
+#endif
 
   /**
    * Destructs a dockmainwindow.
@@ -1365,7 +1377,7 @@ public:
    * @return    a pointer to the new created dockwidget
    */
   KDockWidget* createDockWidget( const TQString& name, const TQPixmap &pixmap, TQWidget* parent = 0L,
-    const TQString& strCaption = TQString::null, const TQString& strTabPageLabel = TQString::fromLatin1( " " ) );
+    const TQString& strCaption = TQString::null, const TQString& strTabPageLabel = TQString::tqfromLatin1( " " ) );
 
   /**
    * Saves the current dock window layout into a DOM tree below the given element.
@@ -1470,9 +1482,10 @@ private:
   KDockMainWindowPrivate *d;
 };
 
-class KDEUI_EXPORT KDockArea : public QWidget
+class KDEUI_EXPORT KDockArea : public TQWidget
 {
   Q_OBJECT
+  TQ_OBJECT
 
 friend class KDockManager;
 
@@ -1490,7 +1503,7 @@ public:
   KDockWidget* getMainDockWidget(){ return mainDockWidget; }
 
   KDockWidget* createDockWidget( const TQString& name, const TQPixmap &pixmap, TQWidget* parent = 0L,
-    const TQString& strCaption = TQString::null, const TQString& strTabPageLabel = TQString::fromLatin1( " " ) );
+    const TQString& strCaption = TQString::null, const TQString& strTabPageLabel = TQString::tqfromLatin1( " " ) );
 
   void writeDockConfig(TQDomElement &base);
   void readDockConfig(TQDomElement &base);
@@ -1537,3 +1550,4 @@ private:
 #endif
 
 
+
