@@ -404,7 +404,7 @@ bool KSpell::addPersonal( const TQString & word )
 
 bool KSpell::writePersonalDictionary()
 {
-  return proc->writeStdin("#");
+  return proc->writeStdin(TQString("#"));
 }
 
 bool KSpell::ignore( const TQString & word )
@@ -505,7 +505,7 @@ bool KSpell::checkWord( const TQString & buffer, bool _usedialog )
   OUTPUT(checkWord2);
   //  connect (this, TQT_SIGNAL (dialog3()), this, TQT_SLOT (checkWord3()));
 
-  proc->writeStdin( "%" ); // turn off terse mode
+  proc->writeStdin(TQString("%")); // turn off terse mode
   proc->writeStdin( buffer ); // send the word to ispell
 
   return true;
@@ -549,7 +549,7 @@ bool KSpell::checkWord( const TQString & buffer, bool _usedialog, bool suggest )
   OUTPUT(checkWord2);
   //  connect (this, TQT_SIGNAL (dialog3()), this, TQT_SLOT (checkWord3()));
 
-  proc->writeStdin( "%" ); // turn off terse mode
+  proc->writeStdin(TQString("%")); // turn off terse mode
   proc->writeStdin( buffer ); // send the word to ispell
 
   return true;
@@ -794,7 +794,7 @@ bool KSpell::checkList (TQStringList *_wordlist, bool _usedialog)
   //set the dialog signal handler
   dialog3slot = TQT_SLOT (checkList4 ());
 
-  proc->writeStdin ("%"); // turn off terse mode & check one word at a time
+  proc->writeStdin (TQString("%")); // turn off terse mode & check one word at a time
 
   //lastpos now counts which *word number* we are at in checkListReplaceCurrent()
   lastpos = -1;
@@ -995,7 +995,7 @@ bool KSpell::check( const TQString &_buffer, bool _usedialog )
   //         origbuffer since I got errors otherwise
   if ( !origbuffer.endsWith("\n\n" ) )
   {
-    if (origbuffer.at(origbuffer.length()-1)!='\n')
+    if (origbuffer.tqat(origbuffer.length()-1)!='\n')
     {
       origbuffer+='\n';
       origbuffer+='\n'; //shouldn't these be removed at some point?
@@ -1008,7 +1008,7 @@ bool KSpell::check( const TQString &_buffer, bool _usedialog )
 
   // KProcIO calls check2 when read from ispell
   OUTPUT( check2 );
-  proc->writeStdin( "!" );
+  proc->writeStdin(TQString("!"));
 
   //lastpos is a position in newbuffer (it has offset in it)
   offset = lastlastline = lastpos = lastline = 0;
@@ -1220,10 +1220,10 @@ void KSpell::dialog( const TQString & word, TQStringList & sugg, const char *_sl
   TQString marker( "_MARKER_" );
   tmpBuf.replace( lastpos, word.length(), marker );
   TQString context = tmpBuf.mid(QMAX(lastpos-18,0), 2*18+marker.length());
-  context.replace( '\n',TQString::fromLatin1(" "));
-  context.replace( '<', TQString::fromLatin1("&lt;") );
-  context.replace( '>', TQString::fromLatin1("&gt;") );
-  context.replace( marker, TQString::fromLatin1("<b>%1</b>").arg( word ) );
+  context.replace( '\n',TQString::tqfromLatin1(" "));
+  context.replace( '<', TQString::tqfromLatin1("&lt;") );
+  context.replace( '>', TQString::tqfromLatin1("&gt;") );
+  context.replace( marker, TQString::tqfromLatin1("<b>%1</b>").arg( word ) );
   context = "<qt>" + context + "</qt>";
 
   ksdlg->init( word, &sugg, context );
@@ -1419,7 +1419,7 @@ void KSpell::slotSpellCheckerCorrected( const TQString & oldText, const TQString
 
 void KSpell::slotModalReady()
 {
-  //kdDebug() << qApp->loopLevel() << endl;
+  //kdDebug() << tqApp->loopLevel() << endl;
   //kdDebug(750) << "MODAL READY------------------" << endl;
 
   Q_ASSERT( m_status == Running );
@@ -1439,7 +1439,7 @@ void KSpell::slotModalDone( const TQString &/*_buffer*/ )
   cleanUp();
 
   //kdDebug() << "ABOUT TO EXIT LOOP" << endl;
-  //qApp->exit_loop();
+  //tqApp->exit_loop();
 
   //modalWidgetHack->close(true);
   slotModalSpellCheckerFinished();
