@@ -148,14 +148,14 @@ int KSyntaxHighlighter::highlightParagraph( const TQString &text, int )
     }
 
     TQString simplified = text;
-    simplified = simplified.replace( TQRegExp( "\\s" ), TQString::null ).replace( '|', TQString::fromLatin1(">") );
-    while ( simplified.startsWith( TQString::fromLatin1(">>>>") ) )
+    simplified = TQString(simplified.replace( TQRegExp( "\\s" ), TQString() )).replace( '|', TQString::tqfromLatin1(">") );
+    while ( simplified.startsWith( TQString::tqfromLatin1(">>>>") ) )
 	simplified = simplified.mid(3);
-    if	( simplified.startsWith( TQString::fromLatin1(">>>") ) || simplified.startsWith( TQString::fromLatin1("> >	>") ) )
+    if	( simplified.startsWith( TQString::tqfromLatin1(">>>") ) || simplified.startsWith( TQString::tqfromLatin1("> >	>") ) )
 	setFormat( 0, text.length(), d->col2 );
-    else if	( simplified.startsWith( TQString::fromLatin1(">>") ) || simplified.startsWith( TQString::fromLatin1("> >") ) )
+    else if	( simplified.startsWith( TQString::tqfromLatin1(">>") ) || simplified.startsWith( TQString::tqfromLatin1("> >") ) )
 	setFormat( 0, text.length(), d->col3 );
-    else if	( simplified.startsWith( TQString::fromLatin1(">") ) )
+    else if	( simplified.startsWith( TQString::tqfromLatin1(">") ) )
 	setFormat( 0, text.length(), d->col4 );
     else
 	setFormat( 0, text.length(), d->col5 );
@@ -609,7 +609,7 @@ void KDictSpellingHighlighter::slotKSpellNotResponding()
 
 bool KDictSpellingHighlighter::eventFilter( TQObject *o, TQEvent *e)
 {
-    if (o == textEdit() && (e->type() == TQEvent::FocusIn)) {
+    if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(textEdit()) && (e->type() == TQEvent::FocusIn)) {
         if ( d->globalConfig ) {
             TQString skey = spellKey();
             if ( d->spell && d->spellKey != skey ) {
@@ -619,8 +619,8 @@ bool KDictSpellingHighlighter::eventFilter( TQObject *o, TQEvent *e)
         }
     }
 
-    if (o == textEdit() && (e->type() == TQEvent::KeyPress)) {
-	TQKeyEvent *k = static_cast<TQKeyEvent *>(e);
+    if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(textEdit()) && (e->type() == TQEvent::KeyPress)) {
+	TQKeyEvent *k = TQT_TQKEYEVENT(e);
 	d->autoReady = true;
 	if (d->rehighlightRequest->isActive()) // try to stay out of the users way
 	    d->rehighlightRequest->changeInterval( 500 );
@@ -661,7 +661,7 @@ bool KDictSpellingHighlighter::eventFilter( TQObject *o, TQEvent *e)
 	}
     }
 
-    else if ( o == textEdit()->viewport() &&
+    else if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(textEdit()->viewport()) &&
 	 ( e->type() == TQEvent::MouseButtonPress )) {
 	d->autoReady = true;
 	if ( intraWordEditing() ) {
