@@ -1,15 +1,15 @@
 /**********************************************************************
 ** Copyright (C) 2000-2002 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
 ** Agreement provided with the Software.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
 ** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-**   information about Qt Commercial License Agreements.
+**   information about TQt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -105,7 +105,7 @@ bool QDesignerAction::addTo( TQWidget *w )
     if ( !widgetToInsert )
 	return TQAction::addTo( w );
 
-    if ( ::qt_cast<TQPopupMenu*>(w) )
+    if ( ::tqqt_cast<TQPopupMenu*>(w) )
 	return FALSE;
 
     widgetToInsert->reparent( w, TQPoint( 0, 0 ), FALSE );
@@ -127,23 +127,23 @@ void QDesignerAction::remove()
 {
     if ( !widgetToInsert )
 	return;
-    MainWindow::self->formWindow()->selectWidget( widgetToInsert, FALSE );
+    MainWindow::self->formWindow()->selectWidget( TQT_TQOBJECT(widgetToInsert), FALSE );
     widgetToInsert->reparent( 0, TQPoint( 0, 0 ), FALSE );
 }
 
-QDesignerToolBarSeparator::QDesignerToolBarSeparator(Orientation o , TQToolBar *parent,
+QDesignerToolBarSeparator::QDesignerToolBarSeparator(Qt::Orientation o , TQToolBar *parent,
                                      const char* name )
     : TQWidget( parent, name )
 {
-    connect( parent, TQT_SIGNAL(orientationChanged(Orientation)),
-             this, TQT_SLOT(setOrientation(Orientation)) );
+    connect( parent, TQT_SIGNAL(orientationChanged(Qt::Orientation)),
+             this, TQT_SLOT(setOrientation(Qt::Orientation)) );
     setOrientation( o );
     setBackgroundMode( parent->backgroundMode() );
     setBackgroundOrigin( ParentOrigin );
-    setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
+    tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
 }
 
-void QDesignerToolBarSeparator::setOrientation( Orientation o )
+void QDesignerToolBarSeparator::setOrientation( Qt::Orientation o )
 {
     orient = o;
 }
@@ -153,11 +153,11 @@ void QDesignerToolBarSeparator::styleChange( TQStyle& )
     setOrientation( orient );
 }
 
-TQSize QDesignerToolBarSeparator::sizeHint() const
+TQSize QDesignerToolBarSeparator::tqsizeHint() const
 {
-    int extent = style().pixelMetric( TQStyle::PM_DockWindowSeparatorExtent,
+    int extent = tqstyle().tqpixelMetric( TQStyle::PM_DockWindowSeparatorExtent,
 				      this );
-    if ( orient == Horizontal )
+    if ( orient ==Qt::Horizontal )
 	return TQSize( extent, 0 );
     else
 	return TQSize( 0, extent );
@@ -168,11 +168,11 @@ void QDesignerToolBarSeparator::paintEvent( TQPaintEvent * )
     TQPainter p( this );
     TQStyle::SFlags flags = TQStyle::Style_Default;
 
-    if ( orientation() == Horizontal )
+    if ( orientation() ==Qt::Horizontal )
 	flags |= TQStyle::Style_Horizontal;
 
-    style().drawPrimitive( TQStyle::PE_DockWindowSeparator, &p, rect(),
-			   colorGroup(), flags );
+    tqstyle().tqdrawPrimitive( TQStyle::PE_DockWindowSeparator, &p, rect(),
+			   tqcolorGroup(), flags );
 }
 
 
@@ -184,11 +184,11 @@ QSeparatorAction::QSeparatorAction( TQObject *parent )
 
 bool QSeparatorAction::addTo( TQWidget *w )
 {
-    if ( ::qt_cast<TQToolBar*>(w) ) {
+    if ( ::tqqt_cast<TQToolBar*>(w) ) {
 	TQToolBar *tb = (TQToolBar*)w;
 	wid = new QDesignerToolBarSeparator( tb->orientation(), tb );
 	return TRUE;
-    } else if ( ::qt_cast<TQPopupMenu*>(w) ) {
+    } else if ( ::tqqt_cast<TQPopupMenu*>(w) ) {
 	idx = ( (TQPopupMenu*)w )->count();
 	( (TQPopupMenu*)w )->insertSeparator( idx );
 	return TRUE;
@@ -198,10 +198,10 @@ bool QSeparatorAction::addTo( TQWidget *w )
 
 bool QSeparatorAction::removeFrom( TQWidget *w )
 {
-    if ( ::qt_cast<TQToolBar*>(w) ) {
+    if ( ::tqqt_cast<TQToolBar*>(w) ) {
 	delete wid;
 	return TRUE;
-    } else if ( ::qt_cast<TQPopupMenu*>(w) ) {
+    } else if ( ::tqqt_cast<TQPopupMenu*>(w) ) {
 	( (TQPopupMenu*)w )->removeItemAt( idx );
 	return TRUE;
     }
@@ -221,7 +221,7 @@ QDesignerToolBar::QDesignerToolBar( TQMainWindow *mw )
     insertAnchor = 0;
     afterAnchor = TRUE;
     setAcceptDrops( TRUE );
-    MetaDataBase::addEntry( this );
+    MetaDataBase::addEntry( TQT_TQOBJECT(this) );
     lastIndicatorPos = TQPoint( -1, -1 );
     indicator = new QDesignerIndicatorWidget( this );
     indicator->hide();
@@ -232,14 +232,14 @@ QDesignerToolBar::QDesignerToolBar( TQMainWindow *mw )
 }
 
 QDesignerToolBar::QDesignerToolBar( TQMainWindow *mw, Dock dock )
-    : TQToolBar( TQString::null, mw, dock), lastIndicatorPos( -1, -1 )
+    : TQToolBar( TQString(), mw, dock), lastIndicatorPos( -1, -1 )
 {
     insertAnchor = 0;
     afterAnchor = TRUE;
     setAcceptDrops( TRUE );
     indicator = new QDesignerIndicatorWidget( this );
     indicator->hide();
-    MetaDataBase::addEntry( this );
+    MetaDataBase::addEntry( TQT_TQOBJECT(this) );
     installEventFilter( this );
     widgetInserting = FALSE;
     findFormWindow();
@@ -250,7 +250,7 @@ void QDesignerToolBar::findFormWindow()
 {
     TQWidget *w = this;
     while ( w ) {
-	formWindow = ::qt_cast<FormWindow*>(w);
+	formWindow = ::tqqt_cast<FormWindow*>(w);
 	if ( formWindow )
 	    break;
 	w = w->parentWidget();
@@ -261,10 +261,10 @@ void QDesignerToolBar::addAction( TQAction *a )
 {
     actionList.append( a );
     connect( a, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( actionRemoved() ) );
-    if ( ::qt_cast<TQActionGroup*>(a) ) {
+    if ( ::tqqt_cast<TQActionGroup*>(a) ) {
 	( (QDesignerActionGroup*)a )->widget()->installEventFilter( this );
 	actionMap.insert( ( (QDesignerActionGroup*)a )->widget(), a );
-    } else if ( ::qt_cast<QSeparatorAction*>(a) ) {
+    } else if ( ::tqqt_cast<QSeparatorAction*>(a) ) {
 	( (QSeparatorAction*)a )->widget()->installEventFilter( this );
 	actionMap.insert( ( (QSeparatorAction*)a )->widget(), a );
     } else {
@@ -275,22 +275,22 @@ void QDesignerToolBar::addAction( TQAction *a )
 
 static void fixObject( TQObject *&o )
 {
-    while ( o && o->parent() && !::qt_cast<QDesignerToolBar*>(o->parent()) )
+    while ( o && o->parent() && !::tqqt_cast<QDesignerToolBar*>(o->parent()) )
 	o = o->parent();
 }
 
 bool QDesignerToolBar::eventFilter( TQObject *o, TQEvent *e )
 {
-    if ( !o || !e || o->inherits( "QDockWindowHandle" ) || o->inherits( "QDockWindowTitleBar" ) )
+    if ( !o || !e || o->inherits( TQDOCKWINDOWHANDLE_OBJECT_NAME_STRING ) || o->inherits( "TQDockWindowTitleBar" ) )
 	return TQToolBar::eventFilter( o, e );
 
-    if ( o == this && e->type() == TQEvent::MouseButtonPress &&
-	 ( ( TQMouseEvent*)e )->button() == LeftButton ) {
+    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) && e->type() == TQEvent::MouseButtonPress &&
+	 ( ( TQMouseEvent*)e )->button() == Qt::LeftButton ) {
 	mousePressEvent( (TQMouseEvent*)e );
 	return TRUE;
     }
 
-    if ( o == this )
+    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) )
 	return TQToolBar::eventFilter( o, e );
 
     if ( e->type() == TQEvent::MouseButtonPress ) {
@@ -349,7 +349,7 @@ void QDesignerToolBar::contextMenuEvent( TQContextMenuEvent *e )
     menu.insertItem( i18n( "Delete Toolbar" ), 1 );
     int res = menu.exec( e->globalPos() );
     if ( res != -1 ) {
-	RemoveToolBarCommand *cmd = new RemoveToolBarCommand( i18n( "Delete Toolbar '%1'" ).arg( name() ),
+	RemoveToolBarCommand *cmd = new RemoveToolBarCommand( i18n( "Delete Toolbar '%1'" ).tqarg( name() ),
 							      formWindow, 0, this );
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
@@ -359,7 +359,7 @@ void QDesignerToolBar::contextMenuEvent( TQContextMenuEvent *e )
 void QDesignerToolBar::mousePressEvent( TQMouseEvent *e )
 {
     widgetInserting = FALSE;
-    if ( e->button() == LeftButton &&
+    if ( e->button() == Qt::LeftButton &&
 	 MainWindow::self->currentTool() != POINTER_TOOL &&
 	 MainWindow::self->currentTool() != ORDER_TOOL &&
 	 MainWindow::self->currentTool() != CONNECT_TOOL &&
@@ -393,7 +393,7 @@ void QDesignerToolBar::buttonContextMenuEvent( TQContextMenuEvent *e, TQObject *
     const int ID_SEP = 2;
     const int ID_DELTOOLBAR = 3;
     TQMap<TQWidget*, TQAction*>::Iterator it = actionMap.find( (TQWidget*)o );
-    if ( it != actionMap.end() && ::qt_cast<QSeparatorAction*>(*it) )
+    if ( it != actionMap.end() && ::tqqt_cast<QSeparatorAction*>(*it) )
 	menu.insertItem( i18n( "Delete Separator" ), ID_DELETE );
     else
 	menu.insertItem( i18n( "Delete Item" ), ID_DELETE );
@@ -409,7 +409,7 @@ void QDesignerToolBar::buttonContextMenuEvent( TQContextMenuEvent *e, TQObject *
 	int index = actionList.find( a );
 	RemoveActionFromToolBarCommand *cmd = new RemoveActionFromToolBarCommand(
 	    i18n( "Delete Action '%1' From Toolbar '%2'" ).
-	    arg( a->name() ).arg( caption() ),
+	    tqarg( a->name() ).tqarg( caption() ),
 	    formWindow, a, this, index );
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
@@ -429,7 +429,7 @@ void QDesignerToolBar::buttonContextMenuEvent( TQContextMenuEvent *e, TQObject *
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
     } else if ( res == ID_DELTOOLBAR ) {
-	RemoveToolBarCommand *cmd = new RemoveToolBarCommand( i18n( "Delete Toolbar '%1'" ).arg( name() ),
+	RemoveToolBarCommand *cmd = new RemoveToolBarCommand( i18n( "Delete Toolbar '%1'" ).tqarg( name() ),
 							      formWindow, 0, this );
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
@@ -440,10 +440,10 @@ void QDesignerToolBar::buttonMousePressEvent( TQMouseEvent *e, TQObject * )
 {
     widgetInserting = FALSE;
 
-    if ( e->button() == MidButton )
+    if ( e->button() == Qt::MidButton )
 	return;
 
-    if ( e->button() == LeftButton &&
+    if ( e->button() == Qt::LeftButton &&
 	 MainWindow::self->currentTool() != POINTER_TOOL &&
 	 MainWindow::self->currentTool() != ORDER_TOOL &&
 	 MainWindow::self->currentTool() != CONNECT_TOOL &&
@@ -464,7 +464,7 @@ void QDesignerToolBar::removeWidget( TQWidget *w )
     int index = actionList.find( a );
     RemoveActionFromToolBarCommand *cmd =
 	new RemoveActionFromToolBarCommand( i18n( "Delete Action '%1' From Toolbar '%2'" ).
-					    arg( a->name() ).arg( caption() ),
+					    tqarg( a->name() ).tqarg( caption() ),
 					    formWindow, a, this, index );
     formWindow->commandHistory()->addCommand( cmd );
     cmd->execute();
@@ -474,9 +474,9 @@ void QDesignerToolBar::removeWidget( TQWidget *w )
 
 void QDesignerToolBar::buttonMouseMoveEvent( TQMouseEvent *e, TQObject *o )
 {
-    if ( widgetInserting || ( e->state() & LeftButton ) == 0 )
+    if ( widgetInserting || ( e->state() & Qt::LeftButton ) == 0 )
 	return;
-    if ( QABS( TQPoint( dragStartPos - e->pos() ).manhattanLength() ) < TQApplication::startDragDistance() )
+    if ( TQABS( TQPoint( dragStartPos - e->pos() ).manhattanLength() ) < TQApplication::startDragDistance() )
 	return;
     TQMap<TQWidget*, TQAction*>::Iterator it = actionMap.find( (TQWidget*)o );
     if ( it == actionMap.end() )
@@ -487,24 +487,24 @@ void QDesignerToolBar::buttonMouseMoveEvent( TQMouseEvent *e, TQObject *o )
     int index = actionList.find( a );
     RemoveActionFromToolBarCommand *cmd =
 	new RemoveActionFromToolBarCommand( i18n( "Delete Action '%1' From Toolbar '%2'" ).
-					    arg( a->name() ).arg( caption() ),
+					    tqarg( a->name() ).tqarg( caption() ),
 					    formWindow, a, this, index );
     formWindow->commandHistory()->addCommand( cmd );
     cmd->execute();
     TQApplication::sendPostedEvents();
     adjustSize();
 
-    TQString type = ::qt_cast<TQActionGroup*>(a) ? TQString( "application/x-designer-actiongroup" ) :
-	::qt_cast<QSeparatorAction*>(a) ? TQString( "application/x-designer-separator" ) : TQString( "application/x-designer-actions" );
+    TQString type = ::tqqt_cast<TQActionGroup*>(a) ? TQString( "application/x-designer-actiongroup" ) :
+	::tqqt_cast<QSeparatorAction*>(a) ? TQString( "application/x-designer-separator" ) : TQString( "application/x-designer-actions" );
     TQStoredDrag *drag = new ActionDrag( type, a, this );
     drag->setPixmap( a->iconSet().pixmap() );
-    if ( ::qt_cast<QDesignerAction*>(a) ) {
+    if ( ::tqqt_cast<QDesignerAction*>(a) ) {
 	if ( formWindow->widgets()->find( ( (QDesignerAction*)a )->widget() ) )
-	    formWindow->selectWidget( ( (QDesignerAction*)a )->widget(), FALSE );
+	    formWindow->selectWidget( ( TQT_TQOBJECT(( (QDesignerAction*)a )->widget())), FALSE );
     }
     if ( !drag->drag() ) {
 	AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( i18n( "Add Action '%1' to Toolbar '%2'" ).
-									arg( a->name() ).arg( caption() ),
+									tqarg( a->name() ).tqarg( caption() ),
 									formWindow, a, this, index );
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
@@ -513,7 +513,7 @@ void QDesignerToolBar::buttonMouseMoveEvent( TQMouseEvent *e, TQObject *o )
     indicator->hide();
 }
 
-#ifndef QT_NO_DRAGANDDROP
+#ifndef TQT_NO_DRAGANDDROP
 
 void QDesignerToolBar::dragEnterEvent( TQDragEnterEvent *e )
 {
@@ -555,11 +555,11 @@ void QDesignerToolBar::dropEvent( TQDropEvent *e )
     if ( e->provides( "application/x-designer-actions" ) ||
 	 e->provides( "application/x-designer-separator" ) ) {
 	if ( e->provides( "application/x-designer-actions" ) )
-	    a = ::qt_cast<QDesignerAction*>(ActionDrag::action());
+	    a = ::tqqt_cast<QDesignerAction*>(ActionDrag::action());
 	else
-	    a = ::qt_cast<QSeparatorAction*>(ActionDrag::action());
+	    a = ::tqqt_cast<QSeparatorAction*>(ActionDrag::action());
     } else {
-	a = ::qt_cast<QDesignerActionGroup*>(ActionDrag::action());
+	a = ::tqqt_cast<QDesignerActionGroup*>(ActionDrag::action());
     }
 
     if ( actionList.findRef( a ) != -1 ) {
@@ -571,7 +571,7 @@ void QDesignerToolBar::dropEvent( TQDropEvent *e )
     }
 
     AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( i18n( "Add Action '%1' to Toolbar '%2'" ).
-								    arg( a->name() ).arg( caption() ),
+								    tqarg( a->name() ).tqarg( caption() ),
 								    formWindow, a, this, index );
     formWindow->commandHistory()->addCommand( cmd );
     cmd->execute();
@@ -588,14 +588,14 @@ void QDesignerToolBar::reInsert()
     clear();
     for ( a = actionList.first(); a; a = actionList.next() ) {
 	a->addTo( this );
-	if ( ::qt_cast<TQActionGroup*>(a) ) {
+	if ( ::tqqt_cast<TQActionGroup*>(a) ) {
 	    actionMap.insert( ( (QDesignerActionGroup*)a )->widget(), a );
 	    if ( ( (QDesignerActionGroup*)a )->widget() )
 		( (QDesignerActionGroup*)a )->widget()->installEventFilter( this );
-	} else if ( ::qt_cast<QDesignerAction*>(a) ) {
+	} else if ( ::tqqt_cast<QDesignerAction*>(a) ) {
 	    actionMap.insert( ( (QDesignerAction*)a )->widget(), a );
 	    ( (QDesignerAction*)a )->widget()->installEventFilter( this );
-	} else if ( ::qt_cast<QSeparatorAction*>(a) ) {
+	} else if ( ::tqqt_cast<QSeparatorAction*>(a) ) {
 	    actionMap.insert( ( (QSeparatorAction*)a )->widget(), a );
 	    ( (QSeparatorAction*)a )->widget()->installEventFilter( this );
 	}
@@ -611,14 +611,15 @@ void QDesignerToolBar::actionRemoved()
 
 TQPoint QDesignerToolBar::calcIndicatorPos( const TQPoint &pos )
 {
-    if ( orientation() == Horizontal ) {
+    if ( orientation() ==Qt::Horizontal ) {
 	TQPoint pnt( width() - 2, 0 );
 	insertAnchor = 0;
 	afterAnchor = TRUE;
-	if ( !children() )
+	TQObjectList clo = childrenListObject();
+	if ( clo.isEmpty() )
 	    return pnt;
 	pnt = TQPoint( 13, 0 );
-	TQObjectListIt it( *children() );
+	TQObjectListIt it( clo );
 	TQObject * obj;
 	while( (obj=it.current()) != 0 ) {
 	    ++it;
@@ -637,10 +638,11 @@ TQPoint QDesignerToolBar::calcIndicatorPos( const TQPoint &pos )
 	TQPoint pnt( 0, height() - 2 );
 	insertAnchor = 0;
 	afterAnchor = TRUE;
-	if ( !children() )
+	TQObjectList clo = childrenListObject();
+	if ( clo.isEmpty() )
 	    return pnt;
 	pnt = TQPoint( 0, 13 );
-	TQObjectListIt it( *children() );
+	TQObjectListIt it( clo );
 	TQObject * obj;
 	while( (obj=it.current()) != 0 ) {
 	    ++it;
@@ -663,7 +665,7 @@ void QDesignerToolBar::drawIndicator( const TQPoint &pos )
     if ( lastIndicatorPos == pos )
 	return;
     bool wasVsisible = indicator->isVisible();
-    if ( orientation() == Horizontal ) {
+    if ( orientation() ==Qt::Horizontal ) {
 	indicator->resize( 3, height() );
 	if ( pos != TQPoint( -1, -1 ) )
 	     indicator->move( pos.x() - 1, 0 );
@@ -697,7 +699,7 @@ void QDesignerToolBar::doInsertWidget( const TQPoint &p )
     if ( !insertAnchor )
 	index = 0;
     AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( i18n( "Add Widget '%1' to Toolbar '%2'" ).
-								    arg( w->name() ).arg( caption() ),
+								    tqarg( w->name() ).tqarg( caption() ),
 								    formWindow, a, this, index );
     formWindow->commandHistory()->addCommand( cmd );
     cmd->execute();
@@ -707,7 +709,7 @@ void QDesignerToolBar::doInsertWidget( const TQPoint &p )
 void QDesignerToolBar::clear()
 {
     for ( TQAction *a = actionList.first(); a; a = actionList.next() ) {
-	if ( ::qt_cast<QDesignerAction*>(a) )
+	if ( ::tqqt_cast<QDesignerAction*>(a) )
 	    ( (QDesignerAction*)a )->remove();
     }
     TQToolBar::clear();
@@ -717,7 +719,7 @@ void QDesignerToolBar::installEventFilters( TQWidget *w )
 {
     if ( !w )
 	return;
-    TQObjectList *l = w->queryList( "TQWidget" );
+    TQObjectList *l = w->queryList( TQWIDGET_OBJECT_NAME_STRING );
     for ( TQObject *o = l->first(); o; o = l->next() )
 	o->installEventFilter( this );
     delete l;
