@@ -1,15 +1,15 @@
 /**********************************************************************
 ** Copyright (C) 2000-2002 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
 ** Agreement provided with the Software.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
 ** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-**   information about Qt Commercial License Agreements.
+**   information about TQt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -62,7 +62,7 @@ class PopupMenuEditor;
 class PopupMenuEditorItem;
 class ActionEditor;
 
-class Command : public Qt
+class Command : public TQt
 {
 public:
     Command( const TQString &n, FormWindow *fw );
@@ -147,9 +147,10 @@ private:
 
 };
 
-class CommandHistory : public QObject
+class CommandHistory : public TQObject
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     CommandHistory( int s );
@@ -207,7 +208,7 @@ public:
 
 private:
     TQWidget *widget;
-    TQRect geometry;
+    TQRect tqgeometry;
 
 };
 
@@ -289,7 +290,7 @@ public:
     Type type() const { return LayoutHorizontal; }
 
 private:
-    HorizontalLayout layout;
+   HorizontalLayout tqlayout;
 
 };
 
@@ -305,7 +306,7 @@ public:
     Type type() const { return LayoutHorizontalSplitter; }
 
 private:
-    HorizontalLayout layout;
+   HorizontalLayout tqlayout;
 
 };
 
@@ -321,7 +322,7 @@ public:
     Type type() const { return LayoutVertical; }
 
 private:
-    VerticalLayout layout;
+   VerticalLayout tqlayout;
 
 };
 
@@ -337,7 +338,7 @@ public:
     Type type() const { return LayoutVerticalSplitter; }
 
 private:
-    VerticalLayout layout;
+   VerticalLayout tqlayout;
 
 };
 
@@ -353,7 +354,7 @@ public:
     Type type() const { return LayoutGrid; }
 
 private:
-    GridLayout layout;
+    GridLayout tqlayout;
 
 };
 
@@ -368,7 +369,7 @@ public:
     Type type() const { return BreakLayout; }
 
 private:
-    Layout *layout;
+    Layout *tqlayout;
     int spacing;
     int margin;
     TQWidget *lb;
@@ -774,7 +775,7 @@ public:
     {
 	TQString text;
 	TQPixmap pix;
-	Q_DUMMY_COMPARISON_OPERATOR( Item )
+	TQ_DUMMY_COMPARISON_OPERATOR( Item )
     };
 
     PopulateListBoxCommand( const TQString &n, FormWindow *fw,
@@ -798,7 +799,7 @@ public:
     {
 	TQString text;
 	TQPixmap pix;
-	Q_DUMMY_COMPARISON_OPERATOR( Item )
+	TQ_DUMMY_COMPARISON_OPERATOR( Item )
     };
 
     PopulateIconViewCommand( const TQString &n, FormWindow *fw,
@@ -856,7 +857,7 @@ public:
     {
 	TQString text;
 	TQPixmap pix;
-	Q_DUMMY_COMPARISON_OPERATOR( Row )
+	TQ_DUMMY_COMPARISON_OPERATOR( Row )
     };
 
     struct Column
@@ -864,7 +865,7 @@ public:
 	TQString text;
 	TQPixmap pix;
 	TQString field;
-	Q_DUMMY_COMPARISON_OPERATOR( Column )
+	TQ_DUMMY_COMPARISON_OPERATOR( Column )
     };
 
     PopulateTableCommand( const TQString &n, FormWindow *fw, TQTable *t,
@@ -941,7 +942,7 @@ public:
 
 };
 
-struct QWidgetContainerInterfacePrivate;
+struct TQWidgetContainerInterfacePrivate;
 
 class AddContainerPageCommand : public Command
 {
@@ -961,7 +962,7 @@ private:
     int index;
     TQString pageLabel;
     TQWidget *page;
-    QWidgetContainerInterfacePrivate *wiface;
+    TQWidgetContainerInterfacePrivate *wiface;
 
 };
 
@@ -982,7 +983,7 @@ private:
     int index;
     TQString pageLabel;
     TQWidget *page;
-    QWidgetContainerInterfacePrivate *wiface;
+    TQWidgetContainerInterfacePrivate *wiface;
 
 };
 
@@ -1003,7 +1004,7 @@ private:
     TQWidget *container;
     int index;
     TQString oldLabel, newLabel;
-    QWidgetContainerInterfacePrivate *wiface;
+    TQWidgetContainerInterfacePrivate *wiface;
 
 };
 
