@@ -1,15 +1,15 @@
 /**********************************************************************
 ** Copyright (C) 2000 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
 ** Agreement provided with the Software.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
 ** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-**   information about Qt Commercial License Agreements.
+**   information about TQt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -73,10 +73,10 @@ CustomWidgetEditor::CustomWidgetEditor( TQWidget *parent, MainWindow *mw )
     sizeVer->setEnabled( FALSE );
     checkContainer->setEnabled( FALSE );
     localGlobalCombo->setEnabled( FALSE );
-    editClass->setValidator( new AsciiValidator( TQString(":"), editClass ) );
-    editSignal->setValidator( new AsciiValidator( TRUE, editSignal ) );
-    editSlot->setValidator( new AsciiValidator( TRUE, editSignal ) );
-    editProperty->setValidator( new AsciiValidator( editSignal ) );
+    editClass->setValidator( new AsciiValidator( TQString(":"), TQT_TQOBJECT(editClass) ) );
+    editSignal->setValidator( new AsciiValidator( TRUE, TQT_TQOBJECT(editSignal) ) );
+    editSlot->setValidator( new AsciiValidator( TRUE, TQT_TQOBJECT(editSignal) ) );
+    editProperty->setValidator( new AsciiValidator( TQT_TQOBJECT(editSignal) ) );
     editSignal->setEnabled( FALSE );
     buttonRemoveSignal->setEnabled( FALSE );
 
@@ -199,8 +199,8 @@ void CustomWidgetEditor::currentWidgetChanged( TQListBoxItem *i )
 	previewPixmap->setPixmap( *w->pixmap );
     else
 	previewPixmap->setText( "" );
-    spinWidth->setValue( w->sizeHint.width() );
-    spinHeight->setValue( w->sizeHint.height() );
+    spinWidth->setValue( w->tqsizeHint.width() );
+    spinHeight->setValue( w->tqsizeHint.height() );
     sizeHor->setCurrentItem( size_type_to_int( w->sizePolicy.horData() ) );
     sizeVer->setCurrentItem( size_type_to_int( w->sizePolicy.verData() ) );
     checkContainer->setChecked( w->isContainer );
@@ -222,7 +222,7 @@ void CustomWidgetEditor::addWidgetClicked()
 	TQMessageBox::information( this, i18n( "Adding Custom Widget" ),
 				  i18n( "Custom widget names must be unique.\n"
 				      "A custom widget called '%1' already exists, so it is not possible "
-				      "to add another widget with this name." ).arg( s ) );
+				      "to add another widget with this name." ).tqarg( s ) );
 	return;
     }
 
@@ -310,7 +310,7 @@ void CustomWidgetEditor::heightChanged( int h )
     if ( !i || !w )
 	return;
 
-    w->sizeHint.setHeight( h );
+    w->tqsizeHint.setHeight( h );
     updateCustomWidgetSizes();
 }
 
@@ -354,7 +354,7 @@ void CustomWidgetEditor::widthChanged( int wid )
     if ( !i || !w )
 	return;
 
-    w->sizeHint.setWidth( wid );
+    w->tqsizeHint.setWidth( wid );
     updateCustomWidgetSizes();
 }
 
@@ -376,7 +376,7 @@ void CustomWidgetEditor::chooseHeader()
     if ( !i || !w )
 	return;
 
-    TQString h = KFileDialog::getOpenFileName( TQString::null, i18n( "*.h *.h++ *.hxx *.hh|Header Files" ), this );
+    TQString h = KFileDialog::getOpenFileName( TQString(), i18n( "*.h *.h++ *.hxx *.hh|Header Files" ), this );
     if ( h.isEmpty() )
 	return;
     editHeader->setText( h );
@@ -397,10 +397,10 @@ void CustomWidgetEditor::checkWidgetName()
 	TQMessageBox::information( this, i18n( "Renaming Custom Widget" ),
 				  i18n( "Custom widget names must be unique.\n"
 				      "A custom widget called '%1' already exists, so it is not possible "
-				      "to rename this widget with this name." ).arg( s ) );
+				      "to rename this widget with this name." ).tqarg( s ) );
 	if ( i != boxWidgets->item( boxWidgets->currentItem() ) ) {
 	    boxWidgets->setCurrentItem( i );
-	    qApp->processEvents();
+	    tqApp->processEvents();
 	}
 	editClass->setText( w->className );
 	classNameChanged( w->className );
@@ -681,7 +681,7 @@ static TQString entitize2( const TQString &s )
 
 void CustomWidgetEditor::saveDescription()
 {
-    TQString fn = KFileDialog::getSaveFileName( TQString::null, i18n( "*.cw|Custom-Widget Description\n*|All Files" ), this );
+    TQString fn = KFileDialog::getSaveFileName( TQString(), i18n( "*.cw|Custom-Widget Description\n*|All Files" ), this );
     if ( fn.isEmpty() )
 	return;
 
@@ -710,8 +710,8 @@ void CustomWidgetEditor::saveDescription()
 	   << "\">" << w->includeFile << "</header>" << endl;
 	ts << makeIndent2( indent ) << "<sizehint>" << endl;
 	indent++;
-	ts << makeIndent2( indent ) << "<width>" << w->sizeHint.width() << "</width>" << endl;
-	ts << makeIndent2( indent ) << "<height>" << w->sizeHint.height() << "</height>" << endl;
+	ts << makeIndent2( indent ) << "<width>" << w->tqsizeHint.width() << "</width>" << endl;
+	ts << makeIndent2( indent ) << "<height>" << w->tqsizeHint.height() << "</height>" << endl;
 	indent--;
 	ts << makeIndent2( indent ) << "</sizehint>" << endl;
 	ts << makeIndent2( indent ) << "<container>" << (int)w->isContainer << "</container>" << endl;
@@ -749,7 +749,7 @@ void CustomWidgetEditor::saveDescription()
 
 void CustomWidgetEditor::loadDescription()
 {
-    TQString fn = KFileDialog::getOpenFileName( TQString::null, i18n( "*.cw|Custom-Widget Description\n*|All Files" ), this );
+    TQString fn = KFileDialog::getOpenFileName( TQString(), i18n( "*.cw|Custom-Widget Description\n*|All Files" ), this );
     if ( fn.isEmpty() )
 	return;
 
@@ -802,7 +802,7 @@ void CustomWidgetEditor::horDataChanged( int a )
 	CustomWidget *cw = (CustomWidget*)o;
 	if ( cw->realClassName() == boxWidgets->currentText() ) {
 	    if ( cw->sizePolicy() == osp )
-		cw->setSizePolicy( w->sizePolicy );
+		cw->tqsetSizePolicy( w->sizePolicy );
 	}
     }
 }
@@ -823,7 +823,7 @@ void CustomWidgetEditor::verDataChanged( int a )
 	CustomWidget *cw = (CustomWidget*)o;
 	if ( cw->realClassName() == boxWidgets->currentText() ) {
 	    if ( cw->sizePolicy() == osp )
-		cw->setSizePolicy( w->sizePolicy );
+		cw->tqsetSizePolicy( w->sizePolicy );
 	}
     }
 }
