@@ -146,15 +146,15 @@ void KDevDesignerPart::setupActions( )
 
     action = new KAction(i18n("Adjust &Size"), createPartIconSet("designer_adjustsize.png"), CTRL + Key_J, this, TQT_SLOT(layoutAdjustSize()), actionCollection(), "layout_adjustsize");
     stateSync(action, m_widget->actionEditAdjustSize);
-    action = new KAction(i18n("Lay Out &Horizontally"), createPartIconSet("designer_edithlayout.png"), CTRL + Key_H, this, TQT_SLOT(layoutHLayout()), actionCollection(), "layout_h");
+    action = new KAction(i18n("Lay Out &Horizontally"), createPartIconSet("designer_edithtqlayout.png"), CTRL + Key_H, this, TQT_SLOT(layoutHLayout()), actionCollection(), "layout_h");
     stateSync(action, m_widget->actionEditHLayout);
-    action = new KAction(i18n("Lay Out &Vertically"), createPartIconSet("designer_editvlayout.png"), CTRL + Key_V, this, TQT_SLOT(layoutVLayout()), actionCollection(), "layout_v");
+    action = new KAction(i18n("Lay Out &Vertically"), createPartIconSet("designer_editvtqlayout.png"), CTRL + Key_V, this, TQT_SLOT(layoutVLayout()), actionCollection(), "layout_v");
     stateSync(action, m_widget->actionEditVLayout);
     action = new KAction(i18n("Lay Out in &Grid"), createPartIconSet("designer_editgrid.png"), CTRL + Key_G, this, TQT_SLOT(layoutGridLayout()), actionCollection(), "layout_grid");
     stateSync(action, m_widget->actionEditGridLayout);
-    action = new KAction(i18n("Lay Out Horizontally (in S&plitter)"), createPartIconSet("designer_editvlayoutsplit.png"), 0, this, TQT_SLOT(layoutSplitHLayout()), actionCollection(), "layout_splith");
+    action = new KAction(i18n("Lay OutQt::Horizontally (in S&plitter)"), createPartIconSet("designer_editvlayoutsplit.png"), 0, this, TQT_SLOT(layoutSplitHLayout()), actionCollection(), "layout_splith");
     stateSync(action, m_widget->actionEditSplitHorizontal);
-    action = new KAction(i18n("Lay Out Vertically (in Sp&litter)"), createPartIconSet("designer_edithlayoutsplit.png"), 0, this, TQT_SLOT(layoutSplitVLayout()), actionCollection(), "layout_splitv");
+    action = new KAction(i18n("Lay OutQt::Vertically (in Sp&litter)"), createPartIconSet("designer_edithlayoutsplit.png"), 0, this, TQT_SLOT(layoutSplitVLayout()), actionCollection(), "layout_splitv");
     stateSync(action, m_widget->actionEditSplitVertical);
     action = new KAction(i18n("&Break Layout"), createPartIconSet("designer_editbreaklayout.png"), CTRL + Key_B, this, TQT_SLOT(layoutBreak()), actionCollection(), "layout_break");
     stateSync(action, m_widget->actionEditBreakLayout);
@@ -509,7 +509,7 @@ void KDevDesignerPart::openProject( const TQString & // projectFile
 
 KInterfaceDesigner::DesignerType KDevDesignerPart::designerType( )
 {
-    return KInterfaceDesigner::QtDesigner;
+    return KInterfaceDesigner::TQtDesigner;
 }
 
 void KDevDesignerPart::emitAddedFunction( const TQString & form, KInterfaceDesigner::Function func )
@@ -552,9 +552,9 @@ void KDevDesignerPart::emitEditSource(const TQString &formName)
     emit editSource(designerType(), formName);
 }
 
-void KDevDesignerPart::emitNewStatus(const TQString &formName, int status)
+void KDevDesignerPart::emitNewtqStatus(const TQString &formName, int status)
 {
-    emit newStatus(formName, status);
+    emit newtqStatus(formName, status);
 }
 
 void KDevDesignerPart::toolsEditCustomWidgets( )
