@@ -1,15 +1,15 @@
 /**********************************************************************
 ** Copyright (C) 2000 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
 ** Agreement provided with the Software.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
 ** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-**   information about Qt Commercial License Agreements.
+**   information about TQt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -25,7 +25,7 @@
 **********************************************************************/
 
 #include "formwindow.h"
-#include "layout.h"
+#include "tqlayout.h"
 #include <widgetdatabase.h>
 #include "widgetfactory.h"
 
@@ -44,7 +44,7 @@ bool operator<( const TQGuardedPtr<TQWidget> &p1, const TQGuardedPtr<TQWidget> &
 }
 
 /*!
-  \class Layout layout.h
+  \class Layout tqlayout.h
   \brief Baseclass for layouting widgets in the Designer
 
   Classes derived from this abstract base class are used for layouting
@@ -67,7 +67,7 @@ Layout::Layout( const TQWidgetList &wl, TQWidget *p, FormWindow *fw, TQWidget *l
     widgets.setAutoDelete( FALSE );
     layoutBase = lb;
     if ( !doSetup && layoutBase )
-	oldGeometry = layoutBase->geometry();
+	oldGeometry = layoutBase->tqgeometry();
 }
 
 /*!  The widget list we got in the constructor might contain too much
@@ -85,7 +85,7 @@ void Layout::setup()
     TQWidget *w = 0;
 
     // Go through all widgets of the list we got. As we can only
-    // layout widgets which have the same parent, we first do some
+    // tqlayout widgets which have the same parent, we first do some
     // sorting which means create a list for each parent containing
     // its child here. After that we keep working on the list of
     // childs which has the most entries.
@@ -120,11 +120,11 @@ void Layout::setup()
     }
 
     // If we found no list (because no widget did fit at all) or the
-    // best list has only one entry and we do not layout a container,
+    // best list has only one entry and we do not tqlayout a container,
     // we leave here.
     if ( !lastList || ( lastList->count() < 2 &&
 			( !layoutBase ||
-			  ( !WidgetDatabase::isContainer( WidgetDatabase::idFromClassName( WidgetFactory::classNameOf( layoutBase ) ) ) &&
+			  ( !WidgetDatabase::isContainer( WidgetDatabase::idFromClassName( WidgetFactory::classNameOf( TQT_TQOBJECT(layoutBase) ) ) ) &&
 			    layoutBase != formWindow->mainContainer() ) )
 			) ) {
 	widgets.clear();
@@ -133,23 +133,23 @@ void Layout::setup()
     }
 
     // Now we have a new and clean widget list, which makes sense
-    // to layout
+    // to tqlayout
     widgets = *lastList;
     // Also use the only correct parent later, so store it
     parent = WidgetFactory::widgetOfContainer( widgets.first()->parentWidget() );
-    // Now calculate the position where the layout-meta-widget should
+    // Now calculate the position where the tqlayout-meta-widget should
     // be placed and connect to widgetDestroyed() signals of the
     // widgets to get informed if one gets deleted to be able to
     // handle that and do not crash in this case
     for ( w = widgets.first(); w; w = widgets.next() ) {
 	connect( w, TQT_SIGNAL( destroyed() ),
 		 this, TQT_SLOT( widgetDestroyed() ) );
-	startPoint = TQPoint( QMIN( startPoint.x(), w->x() ),
-			     QMIN( startPoint.y(), w->y() ) );
+	startPoint = TQPoint( TQMIN( startPoint.x(), w->x() ),
+			     TQMIN( startPoint.y(), w->y() ) );
 	geometries.insert( w, TQRect( w->pos(), w->size() ) );
 	// Change the Z-order, as saving/loading uses the Z-order for
 	// writing/creating widgets and this has to be the same as in
-	// the layout. Else saving + loading will give different results
+	// the tqlayout. Else saving + loading will give different results
 	w->raise();
     }
 }
@@ -167,13 +167,13 @@ bool Layout::prepareLayout( bool &needMove, bool &needReparent )
     for ( TQWidget *w = widgets.first(); w; w = widgets.next() )
 	w->raise();
     needMove = !layoutBase;
-    needReparent = needMove || ::qt_cast<QLayoutWidget*>(layoutBase) || ::qt_cast<TQSplitter*>(layoutBase);
+    needReparent = needMove || ::tqqt_cast<TQLayoutWidget*>(layoutBase) || ::tqqt_cast<TQSplitter*>(layoutBase);
     if ( !layoutBase ) {
 	if ( !useSplitter )
-	    layoutBase = WidgetFactory::create( WidgetDatabase::idFromClassName( "QLayoutWidget" ),
+	    layoutBase = WidgetFactory::create( WidgetDatabase::idFromClassName( TQLAYOUTWIDGET_OBJECT_NAME_STRING ),
 						WidgetFactory::containerOfWidget( parent ) );
 	else
-	    layoutBase = WidgetFactory::create( WidgetDatabase::idFromClassName( "TQSplitter" ),
+	    layoutBase = WidgetFactory::create( WidgetDatabase::idFromClassName( TQSPLITTER_OBJECT_NAME_STRING ),
 						WidgetFactory::containerOfWidget( parent ) );
     } else {
 	WidgetFactory::deleteLayout( layoutBase );
@@ -182,7 +182,7 @@ bool Layout::prepareLayout( bool &needMove, bool &needReparent )
     return TRUE;
 }
 
-void Layout::finishLayout( bool needMove, TQLayout *layout )
+void Layout::finishLayout( bool needMove, TQLayout *tqlayout )
 {
     if ( needMove )
 	layoutBase->move( startPoint );
@@ -193,9 +193,9 @@ void Layout::finishLayout( bool needMove, TQLayout *layout )
 	layoutBase->setGeometry( oldGeometry );
     oldGeometry = g;
     layoutBase->show();
-    layout->activate();
+    tqlayout->activate();
     formWindow->insertWidget( layoutBase );
-    formWindow->selectWidget( layoutBase );
+    formWindow->selectWidget( TQT_TQOBJECT(layoutBase) );
     TQString n = layoutBase->name();
     if ( n.find( "qt_dead_widget_" ) != -1 ) {
 	n.remove( 0, TQString( "qt_dead_widget_" ).length() );
@@ -214,9 +214,9 @@ void Layout::undoLayout()
 	it.key()->reparent( WidgetFactory::containerOfWidget( parent ), 0, ( *it ).topLeft(), it.key()->isVisibleTo( formWindow ) );
 	it.key()->resize( ( *it ).size() );
     }
-    formWindow->selectWidget( layoutBase, FALSE );
+    formWindow->selectWidget( TQT_TQOBJECT(layoutBase), FALSE );
     WidgetFactory::deleteLayout( layoutBase );
-    if ( parent != layoutBase && !::qt_cast<TQMainWindow*>(layoutBase) ) {
+    if ( parent != layoutBase && !::tqqt_cast<TQMainWindow*>(layoutBase) ) {
 	layoutBase->hide();
 	TQString n = layoutBase->name();
 	n.prepend( "qt_dead_widget_" );
@@ -225,9 +225,9 @@ void Layout::undoLayout()
 	layoutBase->setGeometry( oldGeometry );
     }
     if ( widgets.first() )
-	formWindow->selectWidget( widgets.first() );
+	formWindow->selectWidget( TQT_TQOBJECT(widgets.first()) );
     else
-	formWindow->selectWidget( formWindow );
+	formWindow->selectWidget( TQT_TQOBJECT(formWindow) );
 }
 
 void Layout::breakLayout()
@@ -236,14 +236,14 @@ void Layout::breakLayout()
     if ( !widgets.isEmpty() ) {
 	TQWidget *w;
 	for ( w = widgets.first(); w; w = widgets.next() )
-	    rects.insert( w, w->geometry() );
+	    rects.insert( w, w->tqgeometry() );
     }
     WidgetFactory::deleteLayout( layoutBase );
-    bool needReparent = qstrcmp( layoutBase->className(), "QLayoutWidget" ) == 0 ||
-			qstrcmp( layoutBase->className(), "TQSplitter" ) == 0 ||
-			( !WidgetDatabase::isContainer( WidgetDatabase::idFromClassName( WidgetFactory::classNameOf( layoutBase ) ) ) &&
+    bool needReparent = qstrcmp( layoutBase->className(), TQLAYOUTWIDGET_OBJECT_NAME_STRING ) == 0 ||
+			qstrcmp( layoutBase->className(), TQSPLITTER_OBJECT_NAME_STRING ) == 0 ||
+			( !WidgetDatabase::isContainer( WidgetDatabase::idFromClassName( WidgetFactory::classNameOf( TQT_TQOBJECT(layoutBase) ) ) ) &&
 			  layoutBase != formWindow->mainContainer() );
-    bool needResize = qstrcmp( layoutBase->className(), "TQSplitter" ) == 0;
+    bool needResize = qstrcmp( layoutBase->className(), TQSPLITTER_OBJECT_NAME_STRING ) == 0;
     bool add = geometries.isEmpty();
     for ( TQWidget *w = widgets.first(); w; w = widgets.next() ) {
 	if ( needReparent )
@@ -267,12 +267,12 @@ void Layout::breakLayout()
 	parent = layoutBase;
     }
     if ( widgets.first() && widgets.first()->isVisibleTo( formWindow ) )
-	formWindow->selectWidget( widgets.first() );
+	formWindow->selectWidget( TQT_TQOBJECT(widgets.first()) );
     else
-	formWindow->selectWidget( formWindow );
+	formWindow->selectWidget( TQT_TQOBJECT(formWindow) );
 }
 
-class HorizontalLayoutList : public QWidgetList
+class HorizontalLayoutList : public TQWidgetList
 {
 public:
     HorizontalLayoutList( const TQWidgetList &l )
@@ -311,32 +311,32 @@ void HorizontalLayout::doLayout()
     if ( !prepareLayout( needMove, needReparent ) )
 	return;
 
-    TQHBoxLayout *layout = (TQHBoxLayout*)WidgetFactory::createLayout( layoutBase, 0, WidgetFactory::HBox );
+    TQHBoxLayout *tqlayout = (TQHBoxLayout*)WidgetFactory::createLayout( layoutBase, 0, WidgetFactory::HBox );
 
     for ( TQWidget *w = widgets.first(); w; w = widgets.next() ) {
-	if ( needReparent && w->parent() != layoutBase )
+	if ( needReparent && TQT_BASE_OBJECT(w->parent()) != TQT_BASE_OBJECT(layoutBase) )
 	    w->reparent( layoutBase, 0, TQPoint( 0, 0 ), FALSE );
 	if ( !useSplitter ) {
 	    if ( qstrcmp( w->className(), "Spacer" ) == 0 )
-		layout->addWidget( w, 0, ( (Spacer*)w )->alignment() );
+		tqlayout->addWidget( w, 0, ( (Spacer*)w )->tqalignment() );
 	    else
-		layout->addWidget( w );
-	    if ( ::qt_cast<QLayoutWidget*>(w) )
-		( (QLayoutWidget*)w )->updateSizePolicy();
+		tqlayout->addWidget( w );
+	    if ( ::tqqt_cast<TQLayoutWidget*>(w) )
+		( (TQLayoutWidget*)w )->updateSizePolicy();
 	}
 	w->show();
     }
 
-    if ( ::qt_cast<TQSplitter*>(layoutBase) )
+    if ( ::tqqt_cast<TQSplitter*>(layoutBase) )
 	( (TQSplitter*)layoutBase )->setOrientation( Qt::Horizontal );
 
-    finishLayout( needMove, layout );
+    finishLayout( needMove, tqlayout );
 }
 
 
 
 
-class VerticalLayoutList : public QWidgetList
+class VerticalLayoutList : public TQWidgetList
 {
 public:
     VerticalLayoutList( const TQWidgetList &l )
@@ -375,26 +375,26 @@ void VerticalLayout::doLayout()
     if ( !prepareLayout( needMove, needReparent ) )
 	return;
 
-    TQVBoxLayout *layout = (TQVBoxLayout*)WidgetFactory::createLayout( layoutBase, 0, WidgetFactory::VBox );
+    TQVBoxLayout *tqlayout = (TQVBoxLayout*)WidgetFactory::createLayout( layoutBase, 0, WidgetFactory::VBox );
 
     for ( TQWidget *w = widgets.first(); w; w = widgets.next() ) {
-	if ( needReparent && w->parent() != layoutBase )
+	if ( needReparent && TQT_BASE_OBJECT(w->parent()) != TQT_BASE_OBJECT(layoutBase) )
 	    w->reparent( layoutBase, 0, TQPoint( 0, 0 ), FALSE );
 	if ( !useSplitter ) {
 	    if ( qstrcmp( w->className(), "Spacer" ) == 0 )
-		layout->addWidget( w, 0, ( (Spacer*)w )->alignment() );
+		tqlayout->addWidget( w, 0, ( (Spacer*)w )->tqalignment() );
 	    else
-		layout->addWidget( w );
-	    if ( ::qt_cast<QLayoutWidget*>(w) )
-		( (QLayoutWidget*)w )->updateSizePolicy();
+		tqlayout->addWidget( w );
+	    if ( ::tqqt_cast<TQLayoutWidget*>(w) )
+		( (TQLayoutWidget*)w )->updateSizePolicy();
 	}
 	w->show();
     }
 
-    if ( ::qt_cast<TQSplitter*>(layoutBase) )
+    if ( ::tqqt_cast<TQSplitter*>(layoutBase) )
 	( (TQSplitter*)layoutBase )->setOrientation( Qt::Vertical );
 
-    finishLayout( needMove, layout );
+    finishLayout( needMove, tqlayout );
 }
 
 
@@ -747,7 +747,7 @@ void GridLayout::doLayout()
     if ( !prepareLayout( needMove, needReparent ) )
 	return;
 
-    QDesignerGridLayout *layout = (QDesignerGridLayout*)WidgetFactory::createLayout( layoutBase, 0, WidgetFactory::Grid );
+    QDesignerGridLayout *tqlayout = (QDesignerGridLayout*)WidgetFactory::createLayout( layoutBase, 0, WidgetFactory::Grid );
 
     if ( !grid )
 	buildGrid();
@@ -756,21 +756,21 @@ void GridLayout::doLayout()
     int r, c, rs, cs;
     for ( w = widgets.first(); w; w = widgets.next() ) {
 	if ( grid->locateWidget( w, r, c, rs, cs) ) {
-	    if ( needReparent && w->parent() != layoutBase )
+	    if ( needReparent && TQT_BASE_OBJECT(w->parent()) != TQT_BASE_OBJECT(layoutBase) )
 		w->reparent( layoutBase, 0, TQPoint( 0, 0 ), FALSE );
 	    if ( rs * cs == 1 ) {
-		layout->addWidget( w, r, c, ::qt_cast<Spacer*>(w) ? ( (Spacer*)w )->alignment() : 0 );
+		tqlayout->addWidget( w, r, c, ::tqqt_cast<Spacer*>(w) ? ( (Spacer*)w )->tqalignment() : 0 );
 	    } else {
-		layout->addMultiCellWidget( w, r, r+rs-1, c, c+cs-1, ::qt_cast<Spacer*>(w) ? ( (Spacer*)w )->alignment() : 0 );
+		tqlayout->addMultiCellWidget( w, r, r+rs-1, c, c+cs-1, ::tqqt_cast<Spacer*>(w) ? ( (Spacer*)w )->tqalignment() : 0 );
 	    }
-	    if ( ::qt_cast<QLayoutWidget*>(w) )
-		( (QLayoutWidget*)w )->updateSizePolicy();
+	    if ( ::tqqt_cast<TQLayoutWidget*>(w) )
+		( (TQLayoutWidget*)w )->updateSizePolicy();
 	    w->show();
 	} else {
-	    qWarning("ooops, widget '%s' does not fit in layout", w->name() );
+	    qWarning("ooops, widget '%s' does not fit in tqlayout", w->name() );
 	}
     }
-    finishLayout( needMove, layout );
+    finishLayout( needMove, tqlayout );
 }
 
 void GridLayout::setup()
@@ -787,7 +787,7 @@ void GridLayout::buildGrid()
     // Pixel to cell conversion:
     // By keeping a list of start'n'stop values (x & y) for each widget,
     // it is possible to create a very small grid of cells to represent
-    // the widget layout.
+    // the widget tqlayout.
     // -----------------------------------------------------------------
 
     // We need a list of both start and stop values for x- & y-axis
@@ -798,7 +798,7 @@ void GridLayout::buildGrid()
     int index  = 0;
     TQWidget* w = 0;
     for ( w = widgets.first(); w; w = widgets.next() ) {
-	TQRect widgetPos = w->geometry();
+	TQRect widgetPos = w->tqgeometry();
 	x[index]   = widgetPos.left();
 	x[index+1] = widgetPos.right();
 	y[index]   = widgetPos.top();
@@ -829,7 +829,7 @@ void GridLayout::buildGrid()
 		current++;
     }
 
-    // Create the smallest grid possible to represent the current layout
+    // Create the smallest grid possible to represent the current tqlayout
     // Since no widget will be placed in the last row and column, we'll
     // skip them to increase speed even further
     delete grid;
@@ -837,7 +837,7 @@ void GridLayout::buildGrid()
 
     // Mark the cells in the grid that contains a widget
     for ( w = widgets.first(); w; w = widgets.next() ) {
-	TQRect c(0,0,0,0), widgetPos = w->geometry();
+	TQRect c(0,0,0,0), widgetPos = w->tqgeometry();
 	// From left til right (not including)
 	for (uint cw=0; cw<x.size(); cw++) {
 	    if ( x[cw] == widgetPos.left() )
@@ -865,7 +865,7 @@ void GridLayout::buildGrid()
 
 Spacer::Spacer( TQWidget *parent, const char *name )
     : TQWidget( parent, name, WMouseNoMask ),
-      orient( Vertical ), interactive(TRUE), sh( TQSize(20,20) )
+      orient(Qt::Vertical ), interactive(TRUE), sh( TQSize(20,20) )
 {
     setSizeType( Expanding );
     setAutoMask( TRUE );
@@ -874,11 +874,11 @@ Spacer::Spacer( TQWidget *parent, const char *name )
 void Spacer::paintEvent( TQPaintEvent * )
 {
     TQPainter p( this );
-    p.setPen( Qt::blue );
+    p.setPen( TQt::blue );
 
-    if ( orient == Horizontal ) {
+    if ( orient ==Qt::Horizontal ) {
 	const int dist = 3;
-	const int amplitude = QMIN( 3, height() / 3 );
+	const int amplitude = TQMIN( 3, height() / 3 );
 	const int base = height() / 2;
 	int i = 0;
 	p.setPen( white );
@@ -891,7 +891,7 @@ void Spacer::paintEvent( TQPaintEvent * )
 	p.drawLine( width() - 1, 0, width() - 1, height());
     } else {
 	const int dist = 3;
-	const int amplitude = QMIN( 3, width() / 3 );
+	const int amplitude = TQMIN( 3, width() / 3 );
 	const int base = width() / 2;
 	int i = 0;
 	p.setPen( white );
@@ -915,13 +915,13 @@ void Spacer::resizeEvent( TQResizeEvent* e)
 void Spacer::updateMask()
 {
     TQRegion r( rect() );
-    if ( orient == Horizontal ) {
-	const int amplitude = QMIN( 3, height() / 3 );
+    if ( orient ==Qt::Horizontal ) {
+	const int amplitude = TQMIN( 3, height() / 3 );
 	const int base = height() / 2;
 	r = r.subtract( TQRect(1, 0, width() - 2, base - amplitude ) );
 	r = r.subtract( TQRect(1, base + amplitude, width() - 2, height() - base - amplitude ) );
     } else {
-	const int amplitude = QMIN( 3, width() / 3 );
+	const int amplitude = TQMIN( 3, width() / 3 );
 	const int base = width() / 2;
 	r = r.subtract( TQRect(0, 1, base - amplitude, height() - 2 ) );
 	r = r.subtract( TQRect( base + amplitude, 1, width() - base - amplitude, height() - 2 ) );
@@ -932,40 +932,40 @@ void Spacer::updateMask()
 void Spacer::setSizeType( SizeType t )
 {
     TQSizePolicy sizeP;
-    if ( orient == Vertical )
+    if ( orient ==Qt::Vertical )
 	sizeP = TQSizePolicy( TQSizePolicy::Minimum, (TQSizePolicy::SizeType)t );
     else
 	sizeP = TQSizePolicy( (TQSizePolicy::SizeType)t, TQSizePolicy::Minimum );
-    setSizePolicy( sizeP );
+    tqsetSizePolicy( sizeP );
 }
 
 
 Spacer::SizeType Spacer::sizeType() const
 {
-    if ( orient == Vertical )
-	return (SizeType)sizePolicy().verData();
-    return (SizeType)sizePolicy().horData();
+    if ( orient ==Qt::Vertical )
+	return (SizeType)tqsizePolicy().verData();
+    return (SizeType)tqsizePolicy().horData();
 }
 
-int Spacer::alignment() const
+int Spacer::tqalignment() const
 {
-    if ( orient == Vertical )
+    if ( orient ==Qt::Vertical )
 	return AlignHCenter;
     return AlignVCenter;
 }
 
-TQSize Spacer::minimumSize() const
+TQSize Spacer::tqminimumSize() const
 {
     TQSize s = TQSize( 20,20 );
     if ( sizeType() == Expanding )
-	if ( orient == Vertical )
+	if ( orient ==Qt::Vertical )
 	    s.rheight() = 0;
 	else
 	    s.rwidth() = 0;
     return s;
 }
 
-TQSize Spacer::sizeHint() const
+TQSize Spacer::tqsizeHint() const
 {
     return sh;
 }
@@ -975,7 +975,7 @@ void Spacer::setSizeHint( const TQSize &s )
 {
     sh = s;
     if ( !parentWidget() || WidgetFactory::layoutType( parentWidget() ) == WidgetFactory::NoLayout )
-	resize( sizeHint() );
+	resize( tqsizeHint() );
     updateGeometry();
 }
 
