@@ -1,15 +1,15 @@
 /**********************************************************************
 ** Copyright (C) 2000 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
 ** Agreement provided with the Software.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
 ** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-**   information about Qt Commercial License Agreements.
+**   information about TQt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -68,13 +68,13 @@ ListViewEditor::ListViewEditor( TQWidget *parent, TQListView *lv, FormWindow *fw
 	itemsPreview->setSelected( itemsPreview->firstChild(), TRUE );
     }
 
-    // Clamp on drag and drop to QListView
+    // Clamp on drag and drop to TQListView
     ListViewDnd *itemsDnd = new ListViewDnd( itemsPreview );
     itemsDnd->setDragMode( ListViewDnd::Internal | ListViewDnd::Move );
     TQObject::connect( itemsDnd, TQT_SIGNAL( dropped( TQListViewItem * ) ),
 		      itemsDnd, TQT_SLOT( confirmDrop( TQListViewItem * ) ) );
 
-    // Enable rename for all QListViewItems
+    // Enable rename for all TQListViewItems
     TQListViewItemIterator it = ((TQListView *)itemsPreview)->firstChild();
     for ( ; *it; it++ )
 	(*it)->setRenameEnabled( 0, TRUE );
@@ -86,7 +86,7 @@ ListViewEditor::ListViewEditor( TQWidget *parent, TQListView *lv, FormWindow *fw
 		      TQT_SLOT( emitItemRenamed(TQListViewItem*, int, const TQString&) ) );
 
     // Connect signal-relay to TQLineEdit "itemText"
-    TQObjectList *l = parent->queryList( "TQLineEdit", "itemText" );
+    TQObjectList *l = parent->queryList( TQLINEEDIT_OBJECT_NAME_STRING, "itemText" );
     TQObject *obj;
     TQObjectListIt itemsLineEditIt( *l );
     while ( (obj = itemsLineEditIt.current()) != 0 ) {
@@ -98,13 +98,13 @@ ListViewEditor::ListViewEditor( TQWidget *parent, TQListView *lv, FormWindow *fw
     }
     delete l;
 
-    // Clamp on drag and drop to QListBox
+    // Clamp on drag and drop to TQListBox
     ListBoxDnd *columnsDnd = new ListBoxDnd( colPreview );
     columnsDnd->setDragMode( ListBoxDnd::Internal | ListBoxDnd::Move );
     TQObject::connect( columnsDnd, TQT_SIGNAL( dropped( TQListBoxItem * ) ),
 		      columnsDnd, TQT_SLOT( confirmDrop( TQListBoxItem * ) ) );
 
-    // Clamp on rename to QListBox
+    // Clamp on rename to TQListBox
     ListBoxRename *columnsRename = new ListBoxRename( colPreview );
     TQObject::connect( columnsRename,
 		      TQT_SIGNAL( itemTextChanged( const TQString & ) ),
@@ -112,7 +112,7 @@ ListViewEditor::ListViewEditor( TQWidget *parent, TQListView *lv, FormWindow *fw
 		      TQT_SLOT( columnTextChanged( const TQString & ) ) );
 
     // Find TQLineEdit "colText" and connect
-    l = parent->queryList( "TQLineEdit", "colText" );
+    l = parent->queryList( TQLINEEDIT_OBJECT_NAME_STRING, "colText" );
     TQObjectListIt columnsLineEditIt( *l );
     while ( (obj = columnsLineEditIt.current()) != 0 ) {
         ++columnsLineEditIt;
@@ -127,7 +127,7 @@ ListViewEditor::ListViewEditor( TQWidget *parent, TQListView *lv, FormWindow *fw
 void ListViewEditor::applyClicked()
 {
     setupItems();
-    PopulateListViewCommand *cmd = new PopulateListViewCommand( i18n( "Edit the Items and Columns of '%1'" ).arg( listview->name() ),
+    PopulateListViewCommand *cmd = new PopulateListViewCommand( i18n( "Edit the Items and Columns of '%1'" ).tqarg( listview->name() ),
 								formwindow, listview, itemsPreview );
     cmd->execute();
     formwindow->commandHistory()->addCommand( cmd );
@@ -592,7 +592,7 @@ void ListViewEditor::setupColumns()
 void ListViewEditor::setupItems()
 {
     itemColumn->setMinValue( 0 );
-    itemColumn->setMaxValue( QMAX( numColumns - 1, 0 ) );
+    itemColumn->setMaxValue( TQMAX( numColumns - 1, 0 ) );
     int i = 0;
     TQHeader *header = itemsPreview->header();
     for ( TQListBoxItem *item = colPreview->firstItem(); item; item = item->next() ) {
@@ -609,7 +609,7 @@ void ListViewEditor::setupItems()
     while ( itemsPreview->columns() > i )
 	itemsPreview->removeColumn( i );
 
-    itemColumn->setValue( QMIN( numColumns - 1, itemColumn->value() ) );
+    itemColumn->setValue( TQMIN( numColumns - 1, itemColumn->value() ) );
 }
 
 ListViewEditor::Column *ListViewEditor::findColumn( TQListBoxItem *i )
