@@ -1,15 +1,15 @@
 /**********************************************************************
 ** Copyright (C) 2003 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
 ** Agreement provided with the Software.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
 ** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-**   information about Qt Commercial License Agreements.
+**   information about TQt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -43,7 +43,7 @@ extern void find_accel( const TQString &txt, TQMap<TQChar, TQWidgetList > &accel
 
 // Drag Object Declaration -------------------------------------------
 
-class MenuBarEditorItemPtrDrag : public QStoredDrag
+class MenuBarEditorItemPtrDrag : public TQStoredDrag
 {
 public:
     MenuBarEditorItemPtrDrag( MenuBarEditorItem * item,
@@ -61,9 +61,9 @@ MenuBarEditorItemPtrDrag::MenuBarEditorItemPtrDrag( MenuBarEditorItem * item,
 						    const char * name )
     : TQStoredDrag( "qt/menubareditoritemptr", parent, name )
 {
-    TQByteArray data( sizeof( Q_LONG ) );
+    TQByteArray data( sizeof( TQ_LONG ) );
     TQDataStream stream( data, IO_WriteOnly );
-    stream << ( Q_LONG ) item;
+    stream << ( TQ_LONG ) item;
     setEncodedData( data );
 }
 
@@ -74,13 +74,13 @@ bool MenuBarEditorItemPtrDrag::canDecode( TQDragMoveEvent * e )
 
 bool MenuBarEditorItemPtrDrag::decode( TQDropEvent * e, MenuBarEditorItem ** i )
 {
-    TQByteArray data = e->encodedData( "qt/menubareditoritemptr" );
+    TQByteArray data = e->tqencodedData( "qt/menubareditoritemptr" );
     TQDataStream stream( data, IO_ReadOnly );
 
     if ( !data.size() )
 	return FALSE;
 
-    Q_LONG p = 0;
+    TQ_LONG p = 0;
     stream >> p;
     *i = ( MenuBarEditorItem *) p;
 
@@ -152,7 +152,7 @@ MenuBarEditor::MenuBarEditor( FormWindow * fw, TQWidget * parent, const char * n
       hasSeparator( FALSE )
 {
     setAcceptDrops( TRUE );
-    setFocusPolicy( StrongFocus );
+    setFocusPolicy( TQ_StrongFocus );
 
     addItem.setMenuText( i18n("new menu") );
     addSeparator.setMenuText( i18n("new separator") );
@@ -165,8 +165,8 @@ MenuBarEditor::MenuBarEditor( FormWindow * fw, TQWidget * parent, const char * n
     lineEdit->setBackgroundOrigin(ParentOrigin);
     lineEdit->installEventFilter( this );
 
-    dropLine = new TQWidget( this, "menubar dropline", Qt::WStyle_NoBorder | WStyle_StaysOnTop );
-    dropLine->setBackgroundColor( Qt::red );
+    dropLine = new TQWidget( this, "menubar dropline", TQt::WStyle_NoBorder | WStyle_StaysOnTop );
+    dropLine->setBackgroundColor( TQt::red );
     dropLine->hide();
 
     setMinimumHeight( fontMetrics().height() + 2 * borderSize() );
@@ -502,7 +502,7 @@ void MenuBarEditor::deleteItem( int index )
     }
 }
 
-TQSize MenuBarEditor::sizeHint() const
+TQSize MenuBarEditor::tqsizeHint() const
 {
     return TQSize( parentWidget()->width(), heightForWidth( parentWidget()->width() ) );
 }
@@ -571,12 +571,12 @@ void MenuBarEditor::paste()
 
 bool MenuBarEditor::eventFilter( TQObject * o, TQEvent * e )
 {
-    if ( o == lineEdit && e->type() == TQEvent::FocusOut ) {
+    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(lineEdit) && e->type() == TQEvent::FocusOut ) {
 	leaveEditMode();
 	lineEdit->hide();
 	update();
     } else if ( e->type() == TQEvent::LayoutHint ) {
-	resize( sizeHint() );
+	resize( tqsizeHint() );
      }
     return TQMenuBar::eventFilter( o, e );
 }
@@ -585,8 +585,8 @@ void MenuBarEditor::paintEvent( TQPaintEvent * )
 {
     TQPainter p( this );
     TQRect r = rect();
-    style().drawPrimitive( TQStyle::PE_PanelMenuBar, &p,
-			   r, colorGroup() );
+    tqstyle().tqdrawPrimitive( TQStyle::PE_PanelMenuBar, &p,
+			   r, tqcolorGroup() );
     drawItems( p );
 }
 
@@ -719,67 +719,67 @@ void MenuBarEditor::keyPressEvent( TQKeyEvent * e )
     if ( lineEdit->isHidden() ) { // In navigation mode
 	switch ( e->key() ) {
 
-	case Qt::Key_Delete:
+	case TQt::Key_Delete:
 	    hideItem();
 	    deleteItem();
 	    showItem();
 	    break;
 
-	case Qt::Key_Left:
+	case TQt::Key_Left:
 	    e->accept();
-	    navigateLeft( e->state() & Qt::ControlButton );
+	    navigateLeft( e->state() & TQt::ControlButton );
 	    return;
 
-	case Qt::Key_Right:
+	case TQt::Key_Right:
 	    e->accept();
-	    navigateRight( e->state() & Qt::ControlButton );
+	    navigateRight( e->state() & TQt::ControlButton );
 	    return; // no update
 
-	case Qt::Key_Down:
+	case TQt::Key_Down:
 	    e->accept();
 	    focusItem();
 	    return; // no update
 
-	case Qt::Key_PageUp:
+	case TQt::Key_PageUp:
 	    currentIndex = 0;
 	    break;
 
-	case Qt::Key_PageDown:
+	case TQt::Key_PageDown:
 	    currentIndex = itemList.count();
 	    break;
 
-	case Qt::Key_Enter:
-	case Qt::Key_Return:
-	case Qt::Key_F2:
+	case TQt::Key_Enter:
+	case TQt::Key_Return:
+	case TQt::Key_F2:
 	    e->accept();
 	    enterEditMode();
 	    return; // no update
 
-	case Qt::Key_Up:
-	case Qt::Key_Alt:
-	case Qt::Key_Shift:
-	case Qt::Key_Control:
-	case Qt::Key_Escape:
+	case TQt::Key_Up:
+	case TQt::Key_Alt:
+	case TQt::Key_Shift:
+	case TQt::Key_Control:
+	case TQt::Key_Escape:
 	    e->ignore();
 	    setFocus(); // FIXME: this is because some other widget get the focus when CTRL is pressed
 	    return; // no update
 
-	case Qt::Key_C:
-	    if ( e->state() & Qt::ControlButton && currentIndex < (int)itemList.count() ) {
+	case TQt::Key_C:
+	    if ( e->state() & TQt::ControlButton && currentIndex < (int)itemList.count() ) {
 		copy( currentIndex );
 		break;
 	    }
 
-	case Qt::Key_X:
-	    if ( e->state() & Qt::ControlButton && currentIndex < (int)itemList.count() ) {
+	case TQt::Key_X:
+	    if ( e->state() & TQt::ControlButton && currentIndex < (int)itemList.count() ) {
 		hideItem();
 		cut( currentIndex );
 		showItem();
 		break;
 	    }
 
-	case Qt::Key_V:
-	    if ( e->state() & Qt::ControlButton ) {
+	case TQt::Key_V:
+	    if ( e->state() & TQt::ControlButton ) {
 		hideItem();
 		paste( currentIndex < (int)itemList.count() ? currentIndex + 1: itemList.count() );
 		showItem();
@@ -799,13 +799,13 @@ void MenuBarEditor::keyPressEvent( TQKeyEvent * e )
     } else { // In edit mode
 
 	switch ( e->key() ) {
-	case Qt::Key_Control:
+	case TQt::Key_Control:
 	    e->ignore();
 	    return;
-	case Qt::Key_Enter:
-	case Qt::Key_Return:
+	case TQt::Key_Enter:
+	case TQt::Key_Return:
 	    leaveEditMode();
-	case Qt::Key_Escape:
+	case TQt::Key_Escape:
 	    lineEdit->hide();
 	    setFocus();
 	    break;
@@ -817,8 +817,8 @@ void MenuBarEditor::keyPressEvent( TQKeyEvent * e )
 
 void MenuBarEditor::focusOutEvent( TQFocusEvent * e )
 {
-    TQWidget * fw = qApp->focusWidget();
-    if ( e->lostFocus() && !::qt_cast<PopupMenuEditor*>(fw) )
+    TQWidget * fw = tqApp->tqfocusWidget();
+    if ( e->lostFocus() && !::tqqt_cast<PopupMenuEditor*>(fw) )
 	hideItem();
     update();
 }
@@ -834,7 +834,7 @@ void MenuBarEditor::drawItems( TQPainter & p )
     TQPoint pos( borderSize(), 0 );
     uint c = 0;
 
-    p.setPen( colorGroup().buttonText() );
+    p.setPen( tqcolorGroup().buttonText() );
 
     MenuBarEditorItem * i = itemList.first();
     while ( i ) {
@@ -866,7 +866,7 @@ void MenuBarEditor::drawItem( TQPainter & p,
 	drawSeparator( p, pos );
     } else {
 	int flags = TQPainter::AlignLeft | TQPainter::AlignVCenter |
-	    Qt::ShowPrefix | Qt::SingleLine;
+	    TQt::ShowPrefix | TQt::SingleLine;
 	p.drawText( pos.x() + borderSize(), pos.y(), w - borderSize(), itemHeight,
 		    flags, i->menuText() );
     }
@@ -892,7 +892,7 @@ void MenuBarEditor::drawSeparator( TQPainter & p, TQPoint & pos )
 
     p.fillRect( left, pos.y() + borderSize() * 2,
 		separatorWidth - 1, itemHeight - borderSize() * 4,
-		TQBrush( darkBlue, Qt::Dense5Pattern ) );
+		TQBrush( darkBlue, TQt::Dense5Pattern ) );
 
     p.restore();
 }
