@@ -1,15 +1,15 @@
 /**********************************************************************
 ** Copyright (C) 2000-2002 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
 ** Agreement provided with the Software.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
 ** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-**   information about Qt Commercial License Agreements.
+**   information about TQt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -50,7 +50,7 @@
 #include <tqwidgetlist.h>
 #include <tqmainwindow.h>
 #include <tqregexp.h>
-#include <private/qpluginmanager_p.h>
+#include <tqpluginmanager_p.h>
 #include <tqdatetime.h>
 #include <tqfile.h>
 #include <tqfileinfo.h>
@@ -88,7 +88,7 @@ static TQPtrList<MetaDataBase::CustomWidget> *cWidgets = 0;
 static bool doUpdate = TRUE;
 static TQStringList langList;
 static TQStringList editorLangList;
-static QPluginManager<LanguageInterface> *languageInterfaceManager = 0;
+static TQPluginManager<LanguageInterface> *languageInterfaceManager = 0;
 
 /*!
   \class MetaDataBase metadatabase.h
@@ -167,14 +167,14 @@ void MetaDataBase::setPropertyChanged( TQObject *o, const TQString &property, bo
     if ( doUpdate &&
 	 ( property == "hAlign" || property == "vAlign" || property == "wordwrap" ) ) {
 	doUpdate = FALSE;
-	setPropertyChanged( o, "alignment", changed ||
+	setPropertyChanged( o, "tqalignment", changed ||
 			    isPropertyChanged( o, "hAlign" ) ||
 			    isPropertyChanged( o, "vAlign" ) ||
 			    isPropertyChanged( o, "wordwrap" ) );
 	doUpdate = TRUE;
     }
 
-    if ( doUpdate && property == "alignment" ) {
+    if ( doUpdate && property == "tqalignment" ) {
 	doUpdate = FALSE;
 	setPropertyChanged( o, "hAlign", changed );
 	setPropertyChanged( o, "vAlign", changed );
@@ -238,7 +238,7 @@ TQString MetaDataBase::propertyComment( TQObject *o, const TQString &property )
     if ( !r ) {
 	qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
 		  o, o->name(), o->className() );
-	return TQString::null;
+	return TQString();
     }
 
     return *r->propertyComments.find( property );
@@ -303,16 +303,16 @@ void MetaDataBase::setSpacing( TQObject *o, int spacing )
     }
 
     r->spacing = spacing;
-    TQLayout * layout = 0;
-    WidgetFactory::layoutType( (TQWidget*)o, layout );
-    if ( layout ) {
+    TQLayout * tqlayout = 0;
+    WidgetFactory::layoutType( (TQWidget*)o, tqlayout );
+    if ( tqlayout ) {
 	int spadef = 6;
 	if ( MainWindow::self->formWindow() )
 	    spadef = MainWindow::self->formWindow()->layoutDefaultSpacing();
 	if ( spacing == -1 )
-	    layout->setSpacing( spadef );
+	    tqlayout->setSpacing( spadef );
 	else
-	    layout->setSpacing( spacing );
+	    tqlayout->setSpacing( spacing );
     }
 }
 
@@ -321,8 +321,8 @@ int MetaDataBase::spacing( TQObject *o )
     if ( !o )
 	return -1;
     setupDataBase();
-    if ( ::qt_cast<TQMainWindow*>(o) )
-	o = ( (TQMainWindow*)o )->centralWidget();
+    if ( ::tqqt_cast<TQMainWindow*>(o) )
+	o = TQT_TQOBJECT(( (TQMainWindow*)o )->centralWidget());
     MetaDataBaseRecord *r = db->find( (void*)o );
     if ( !r || !o->isWidgetType() ) {
 	qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
@@ -346,30 +346,30 @@ void MetaDataBase::setMargin( TQObject *o, int margin )
     }
 
     r->margin = margin;
-    TQLayout * layout = 0;
-    WidgetFactory::layoutType( (TQWidget*)o, layout );
+    TQLayout * tqlayout = 0;
+    WidgetFactory::layoutType( (TQWidget*)o, tqlayout );
 
     bool isInnerLayout = TRUE;
 
     TQWidget *widget = (TQWidget*)o;
-    if ( widget && !::qt_cast<QLayoutWidget*>(widget) &&
-	( WidgetDatabase::isContainer( WidgetDatabase::idFromClassName( WidgetFactory::classNameOf( widget ) ) ) ||
-	widget && widget->parentWidget() && ::qt_cast<FormWindow*>(widget->parentWidget()) ) )
+    if ( widget && !::tqqt_cast<TQLayoutWidget*>(widget) &&
+	( WidgetDatabase::isContainer( WidgetDatabase::idFromClassName( WidgetFactory::classNameOf( TQT_TQOBJECT(widget) ) ) ) ||
+	widget && widget->parentWidget() && ::tqqt_cast<FormWindow*>(widget->parentWidget()) ) )
 	isInnerLayout = FALSE;
 
 
-    if ( layout ) {
+    if ( tqlayout ) {
 	int mardef = 11;
 	if ( MainWindow::self->formWindow() )
 	    mardef = MainWindow::self->formWindow()->layoutDefaultMargin();
 	if ( margin == -1 ) {
 	    if ( isInnerLayout )
-		layout->setMargin( 1 );
+		tqlayout->setMargin( 1 );
 	    else
-		layout->setMargin( QMAX( 1, mardef ) );
+		tqlayout->setMargin( TQMAX( 1, mardef ) );
 	}
 	else
-	    layout->setMargin( QMAX( 1, margin ) );
+	    tqlayout->setMargin( TQMAX( 1, margin ) );
     }
 }
 
@@ -378,8 +378,8 @@ int MetaDataBase::margin( TQObject *o )
     if ( !o )
 	return -1;
     setupDataBase();
-    if ( ::qt_cast<TQMainWindow*>(o) )
-	o = ( (TQMainWindow*)o )->centralWidget();
+    if ( ::tqqt_cast<TQMainWindow*>(o) )
+	o = TQT_TQOBJECT(( (TQMainWindow*)o )->centralWidget());
     MetaDataBaseRecord *r = db->find( (void*)o );
     if ( !r || !o->isWidgetType() ) {
 	qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
@@ -407,15 +407,15 @@ void MetaDataBase::setResizeMode( TQObject *o, const TQString &mode )
 TQString MetaDataBase::resizeMode( TQObject *o )
 {
     if ( !o )
-	return TQString::null;
+	return TQString();
     setupDataBase();
-    if ( ::qt_cast<TQMainWindow*>(o) )
-	o = ( (TQMainWindow*)o )->centralWidget();
+    if ( ::tqqt_cast<TQMainWindow*>(o) )
+	o = TQT_TQOBJECT(( (TQMainWindow*)o )->centralWidget());
     MetaDataBaseRecord *r = db->find( (void*)o );
     if ( !r || !o->isWidgetType() ) {
 	qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
 		  o, o->name(), o->className() );
-	return TQString::null;
+	return TQString();
     }
     return r->resizeMode;
 }
@@ -440,15 +440,15 @@ void MetaDataBase::addConnection( TQObject *o, TQObject *sender, const TQCString
     r->connections.append( conn );
     if ( addCode ) {
 	TQString rec = receiver->name();
-	if ( ::qt_cast<FormWindow*>(o) && receiver == ( (FormWindow*)o )->mainContainer() )
+	if ( ::tqqt_cast<FormWindow*>(o) && TQT_BASE_OBJECT(receiver) ==( (FormWindow*)o )->mainContainer() )
 	    rec = "this";
 	TQString sen = sender->name();
-	if ( ::qt_cast<FormWindow*>(o) && sender == ( (FormWindow*)o )->mainContainer() )
+	if ( ::tqqt_cast<FormWindow*>(o) && TQT_BASE_OBJECT(sender) ==( (FormWindow*)o )->mainContainer() )
 	    sen = "this";
 	FormFile *ff = 0;
-	if ( ::qt_cast<FormFile*>(o) )
+	if ( ::tqqt_cast<FormFile*>(o) )
 	    ff = (FormFile*)o;
-	else if ( ::qt_cast<FormWindow*>(o) )
+	else if ( ::tqqt_cast<FormWindow*>(o) )
 	    ff = ( (FormWindow*)o )->formFile();
 	ff->addConnection( sen, signal, rec, slot );
     }
@@ -468,17 +468,17 @@ void MetaDataBase::removeConnection( TQObject *o, TQObject *sender, const TQCStr
 	return;
     for ( TQValueList<Connection>::Iterator it = r->connections.begin(); it != r->connections.end(); ++it ) {
 	Connection conn = *it;
-	if ( conn.sender == sender &&
+	if ( TQT_BASE_OBJECT(conn.sender) ==sender &&
 	     conn.signal == signal &&
-	     conn.receiver == receiver &&
+	     TQT_BASE_OBJECT(conn.receiver) ==receiver &&
 	     conn.slot == slot ) {
 	    r->connections.remove( it );
 	    break;
 	}
     }
-    if ( ::qt_cast<FormWindow*>(o) ) {
+    if ( ::tqqt_cast<FormWindow*>(o) ) {
 	TQString rec = receiver->name();
-	if ( receiver == ( (FormWindow*)o )->mainContainer() )
+	if ( TQT_BASE_OBJECT(receiver) ==( (FormWindow*)o )->mainContainer() )
 	    rec = "this";
 	( (FormWindow*)o )->formFile()->removeConnection( sender->name(), signal, rec, slot );
     }
@@ -494,7 +494,7 @@ void MetaDataBase::setupConnections( TQObject *o, const TQValueList<LanguageInte
 	return;
     }
 
-    if ( !::qt_cast<FormFile*>(o) )
+    if ( !::tqqt_cast<FormFile*>(o) )
 	return;
 
     FormFile *formfile = (FormFile*)o;
@@ -514,8 +514,8 @@ void MetaDataBase::setupConnections( TQObject *o, const TQValueList<LanguageInte
 	    sender = formfile->project()->objectForFakeFormFile( formfile );
 	if ( !sender && senderName == "this" )
 	    sender = formfile->formWindow() ?
-		     formfile->formWindow()->mainContainer() :
-		     formfile->project()->objectForFakeFormFile( formfile );
+		     TQT_TQOBJECT(formfile->formWindow()->mainContainer()) :
+		     TQT_TQOBJECT(formfile->project()->objectForFakeFormFile( formfile ));
 	if ( !sender )
 	    continue;
 	MetaDataBase::addConnection( formfile->formWindow() ?
@@ -524,8 +524,8 @@ void MetaDataBase::setupConnections( TQObject *o, const TQValueList<LanguageInte
 				     sender,
 				     (*cit).signal.latin1(),
 				     formfile->formWindow() ?
-				     formfile->formWindow()->mainContainer() :
-				     formfile->project()->objectForFakeFormFile( formfile ),
+				     TQT_TQOBJECT(formfile->formWindow()->mainContainer()) :
+				     TQT_TQOBJECT(formfile->project()->objectForFakeFormFile( formfile )),
 				     (*cit).slot.latin1(),
 				     FALSE );
     }
@@ -544,9 +544,9 @@ bool MetaDataBase::hasConnection( TQObject *o, TQObject *sender, const TQCString
 
     for ( TQValueList<Connection>::Iterator it = r->connections.begin(); it != r->connections.end(); ++it ) {
 	Connection conn = *it;
-	if ( conn.sender == sender &&
+	if ( TQT_BASE_OBJECT(conn.sender) ==sender &&
 	     conn.signal == signal &&
-	     conn.receiver == receiver &&
+	     TQT_BASE_OBJECT(conn.receiver) ==receiver &&
 	     conn.slot == slot )
 	    return TRUE;
     }
@@ -581,8 +581,8 @@ TQValueList<MetaDataBase::Connection> MetaDataBase::connections( TQObject *o, TQ
     TQValueList<Connection>::Iterator conn;
     while ( ( conn = it ) != r->connections.end() ) {
 	++it;
-	if ( (*conn).sender == sender &&
-	     (*conn).receiver == receiver )
+	if ( TQT_BASE_OBJECT((*conn).sender) ==sender &&
+	     TQT_BASE_OBJECT((*conn).receiver) ==receiver )
 	    ret << *conn;
     }
 
@@ -603,8 +603,8 @@ TQValueList<MetaDataBase::Connection> MetaDataBase::connections( TQObject *o, TQ
     TQValueList<Connection>::Iterator conn;
     while ( ( conn = it ) != r->connections.end() ) {
 	++it;
-	if ( (*conn).sender == object ||
-	     (*conn).receiver == object )
+	if ( TQT_BASE_OBJECT((*conn).sender) ==object ||
+	     TQT_BASE_OBJECT((*conn).receiver) ==object )
 	    ret << *conn;
     }
     return ret;
@@ -648,12 +648,12 @@ void MetaDataBase::doConnections( TQObject *o )
 	    delete l;
 	}
 	TQString s = "2""%1";
-	s = s.arg( conn.signal );
+	s = s.tqarg( conn.signal.data() );
 	TQString s2 = "1""%1";
-	s2 = s2.arg( conn.slot );
+	s2 = s2.tqarg( conn.slot.data() );
 
-	TQStrList signalList = sender->metaObject()->signalNames( TRUE );
-	TQStrList slotList = receiver->metaObject()->slotNames( TRUE );
+	TQStrList signalList = sender->tqmetaObject()->signalNames( TRUE );
+	TQStrList slotList = receiver->tqmetaObject()->slotNames( TRUE );
 
 	// avoid warnings
 	if ( signalList.find( conn.signal ) == -1 ||
@@ -675,18 +675,18 @@ bool MetaDataBase::hasSlot( TQObject *o, const TQCString &slot, bool onlyCustom
     }
 
     if ( !onlyCustom ) {
-	TQStrList slotList = o->metaObject()->slotNames( TRUE );
+	TQStrList slotList = o->tqmetaObject()->slotNames( TRUE );
 	if ( slotList.find( slot ) != -1 )
 	    return TRUE;
 
-	if ( ::qt_cast<FormWindow*>(o) ) {
-	    o = ( (FormWindow*)o )->mainContainer();
-	    slotList = o->metaObject()->slotNames( TRUE );
+	if ( ::tqqt_cast<FormWindow*>(o) ) {
+	    o = TQT_TQOBJECT(( (FormWindow*)o )->mainContainer());
+	    slotList = o->tqmetaObject()->slotNames( TRUE );
 	    if ( slotList.find( slot ) != -1 )
 		return TRUE;
 	}
 
-	//if ( ::qt_cast<CustomWidget*>(o) ) {
+	//if ( ::tqqt_cast<CustomWidget*>(o) ) {
 	if ( o->inherits( "CustomWidget" ) ) {
 	    MetaDataBase::CustomWidget *w = ( (::CustomWidget*)o )->customWidget();
 	    for ( TQValueList<Function>::Iterator it = w->lstSlots.begin(); it != w->lstSlots.end(); ++it ) {
@@ -905,18 +905,18 @@ bool MetaDataBase::hasFunction( TQObject *o, const TQCString &function, bool onl
     }
 
     if ( !onlyCustom ) {
-	TQStrList functionList = o->metaObject()->slotNames( TRUE );
+	TQStrList functionList = o->tqmetaObject()->slotNames( TRUE );
 	if ( functionList.find( function ) != -1 )
 	    return TRUE;
 
-	if ( ::qt_cast<FormWindow*>(o) ) {
-	    o = ( (FormWindow*)o )->mainContainer();
-	    functionList = o->metaObject()->slotNames( TRUE );
+	if ( ::tqqt_cast<FormWindow*>(o) ) {
+	    o = TQT_TQOBJECT(( (FormWindow*)o )->mainContainer());
+	    functionList = o->tqmetaObject()->slotNames( TRUE );
 	    if ( functionList.find( function ) != -1 )
 		return TRUE;
 	}
 
-	//if ( ::qt_cast<CustomWidget*>(o) ) {
+	//if ( ::tqqt_cast<CustomWidget*>(o) ) {
 	if ( o->inherits( "CustomWidget" ) ) {
 	    MetaDataBase::CustomWidget *w = ( (::CustomWidget*)o )->customWidget();
 	    for ( TQValueList<Function>::Iterator it = w->lstSlots.begin(); it != w->lstSlots.end(); ++it ) {
@@ -945,7 +945,7 @@ TQString MetaDataBase::languageOfFunction( TQObject *o, const TQCString &functio
     if ( !r ) {
 	qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
 		  o, o->name(), o->className() );
-	return TQString::null;
+	return TQString();
     }
 
     TQString fu = normalizeFunction( function );
@@ -953,7 +953,7 @@ TQString MetaDataBase::languageOfFunction( TQObject *o, const TQCString &functio
 	if ( fu == normalizeFunction( (*it).function ) )
 	    return (*it).language;
     }
-    return TQString::null;
+    return TQString();
 }
 
 bool MetaDataBase::addCustomWidget( CustomWidget *wid )
@@ -1276,7 +1276,7 @@ MetaDataBase::CustomWidget::CustomWidget()
     className = "MyCustomWidget";
     includeFile = "mywidget.h";
     includePolicy = Local;
-    sizeHint = TQSize( -1, -1 );
+    tqsizeHint = TQSize( -1, -1 );
     pixmap = new TQPixmap( BarIcon( "designer_customwidget.png", KDevDesignerPartFactory::instance() ) );
     id = -1;
     sizePolicy = TQSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Preferred );
@@ -1288,7 +1288,7 @@ MetaDataBase::CustomWidget::CustomWidget( const CustomWidget &w )
     className = w.className;
     includeFile = w.includeFile;
     includePolicy = w.includePolicy;
-    sizeHint = w.sizeHint;
+    tqsizeHint = w.tqsizeHint;
     if ( w.pixmap )
 	pixmap = new TQPixmap( *w.pixmap );
     else
@@ -1339,7 +1339,7 @@ MetaDataBase::CustomWidget &MetaDataBase::CustomWidget::operator=( const CustomW
     className = w.className;
     includeFile = w.includeFile;
     includePolicy = w.includePolicy;
-    sizeHint = w.sizeHint;
+    tqsizeHint = w.tqsizeHint;
     if ( w.pixmap )
 	pixmap = new TQPixmap( *w.pixmap );
     else
@@ -1354,7 +1354,7 @@ MetaDataBase::CustomWidget &MetaDataBase::CustomWidget::operator=( const CustomW
 
 bool MetaDataBase::CustomWidget::hasSignal( const TQCString &signal ) const
 {
-    TQStrList sigList = TQWidget::staticMetaObject()->signalNames( TRUE );
+    TQStrList sigList = TQWidget::tqstaticMetaObject()->signalNames( TRUE );
     if ( sigList.find( signal ) != -1 )
 	return TRUE;
     for ( TQValueList<TQCString>::ConstIterator it = lstSignals.begin(); it != lstSignals.end(); ++it ) {
@@ -1366,7 +1366,7 @@ bool MetaDataBase::CustomWidget::hasSignal( const TQCString &signal ) const
 
 bool MetaDataBase::CustomWidget::hasSlot( const TQCString &slot ) const
 {
-    TQStrList slotList = TQWidget::staticMetaObject()->slotNames( TRUE );
+    TQStrList slotList = TQWidget::tqstaticMetaObject()->slotNames( TRUE );
     if ( slotList.find( normalizeFunction( slot ) ) != -1 )
 	return TRUE;
 
@@ -1379,7 +1379,7 @@ bool MetaDataBase::CustomWidget::hasSlot( const TQCString &slot ) const
 
 bool MetaDataBase::CustomWidget::hasProperty( const TQCString &prop ) const
 {
-    TQStrList propList = TQWidget::staticMetaObject()->propertyNames( TRUE );
+    TQStrList propList = TQWidget::tqstaticMetaObject()->propertyNames( TRUE );
     if ( propList.find( prop ) != -1 )
 	return TRUE;
 
@@ -1409,13 +1409,13 @@ void MetaDataBase::setPixmapArgument( TQObject *o, int pixmap, const TQString &a
 TQString MetaDataBase::pixmapArgument( TQObject *o, int pixmap )
 {
     if ( !o )
-	return TQString::null;
+	return TQString();
     setupDataBase();
     MetaDataBaseRecord *r = db->find( (void*)o );
     if ( !r ) {
 	qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
 		  o, o->name(), o->className() );
-	return TQString::null;
+	return TQString();
     }
 
     return *r->pixmapArguments.find( pixmap );
@@ -1460,7 +1460,7 @@ void MetaDataBase::setPixmapKey( TQObject *o, int pixmap, const TQString &arg )
 TQString MetaDataBase::pixmapKey( TQObject *o, int pixmap )
 {
     if ( !o )
-	return TQString::null;
+	return TQString();
     setupDataBase();
     if ( o->isA( "PropertyObject" ) )
 	return ( (PropertyObject*)o )->mdPixmapKey( pixmap );
@@ -1468,7 +1468,7 @@ TQString MetaDataBase::pixmapKey( TQObject *o, int pixmap )
     if ( !r ) {
 	qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
 		  o, o->name(), o->className() );
-	return TQString::null;
+	return TQString();
     }
 
     TQString s = *r->pixmapKeys.find( pixmap );
@@ -1543,7 +1543,7 @@ void MetaDataBase::setupInterfaceManagers( const TQString &plugDir )
 {
     if ( !languageInterfaceManager ) {
 	languageInterfaceManager =
-	    new QPluginManager<LanguageInterface>( IID_Language,
+	    new TQPluginManager<LanguageInterface>( IID_Language,
 						   TQApplication::libraryPaths(),
 //						   kapp->dirs()->resourceDirs("qtplugins"),
 						   plugDir );
@@ -1636,17 +1636,17 @@ void MetaDataBase::setBreakPointCondition( TQObject *o, int line, const TQString
 TQString MetaDataBase::breakPointCondition( TQObject *o, int line )
 {
     if ( !o )
-	return TQString::null;
+	return TQString();
     setupDataBase();
     MetaDataBaseRecord *r = db->find( (void*)o );
     if ( !r ) {
 	qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
 		  o, o->name(), o->className() );
-	return TQString::null;
+	return TQString();
     }
     TQMap<int, TQString>::Iterator it = r->breakPointConditions.find( line );
     if ( it == r->breakPointConditions.end() )
-	return TQString::null;
+	return TQString();
     return *it;
 }
 
