@@ -1,15 +1,15 @@
 /**********************************************************************
 ** Copyright (C) 2000 Trolltech AS.  All rights reserved.
 **
-**1 This file is part of Qt Designer.
+**1 This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
 ** Agreement provided with the Software.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
 ** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-**   information about Qt Commercial License Agreements.
+**   information about TQt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -29,7 +29,7 @@
 #include "designerappiface.h"
 #include "../interfaces/languageinterface.h"
 #include "pixmapcollection.h"
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 #include "dbconnectionimpl.h"
 #endif
 #include "resource.h"
@@ -48,7 +48,7 @@
 #include "mainwindow.h"
 #include <tqworkspace.h>
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 #include <tqsqldatabase.h>
 #include <tqsqlrecord.h>
 #include <tqdatatable.h>
@@ -61,7 +61,7 @@
 
 #include <klocale.h>
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 DatabaseConnection::~DatabaseConnection()
 {
     delete iface;
@@ -69,7 +69,7 @@ DatabaseConnection::~DatabaseConnection()
 
 bool DatabaseConnection::refreshCatalog()
 {
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
     if ( loaded )
 	return TRUE;
     if ( !open() )
@@ -91,7 +91,7 @@ bool DatabaseConnection::refreshCatalog()
 #endif
 }
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 void DatabaseConnection::remove()
 {
     if ( nm == "(default)" )
@@ -105,7 +105,7 @@ void DatabaseConnection::remove()
 
 bool DatabaseConnection::open( bool suppressDialog )
 {
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
     // register our name, if nec
     if ( nm == "(default)" ) {
 	if ( !TQSqlDatabase::contains() ) // default doesn't exists?
@@ -152,7 +152,7 @@ bool DatabaseConnection::open( bool suppressDialog )
 					  + TQString( "[" + conn->lastError().driverText() + "\n" +
 						     conn->lastError().databaseText() + "]\n" ),
 					  i18n( "&OK" ),
-					  i18n( "&Cancel" ), TQString::null, 0, 1 ) ) {
+					  i18n( "&Cancel" ), TQString(), 0, 1 ) ) {
 	    case 0: // OK or Enter
 		continue;
 	    case 1: // Cancel or Escape
@@ -178,7 +178,7 @@ void DatabaseConnection::close()
 {
     if ( !loaded )
 	return;
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
     if ( conn ) {
 	conn->close();
     }
@@ -202,7 +202,7 @@ bool Project::isDummy() const
 }
 
 Project::Project( const TQString &fn, const TQString &pName,
-		  QPluginManager<ProjectSettingsInterface> *pm, bool isDummy,
+		  TQPluginManager<ProjectSettingsInterface> *pm, bool isDummy,
 		  const TQString &l )
     : proName( pName ), projectSettingsPluginManager( pm ), isDummyProject( isDummy )
 {
@@ -236,7 +236,7 @@ void Project::setModified( bool b )
     emit projectModified();
 }
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 DatabaseConnection *Project::databaseConnection( const TQString &name )
 {
     for ( DatabaseConnection *conn = dbConnections.first();
@@ -389,7 +389,7 @@ TQStringList parse_multiline_part( const TQString &contents, const TQString &key
 		       c == '$' || c == '-' || c == '(' || c == ')' || c == ':'  || c == '+' || c == ',' || c == '~' ) &&
 		     c != ' ' && c != '\t' && c != '\n' ) {
 		    if ( !inName )
-			currName = TQString::null;
+			currName = TQString();
 		    if ( c != '\\' || contents[i+1] != '\n' ) {
 			currName += c;
 			inName = TRUE;
@@ -691,7 +691,7 @@ void Project::save( bool onlyProjectFile )
  	contents +=
  	    "unix {\n"
  	    "  UI_DIR = .ui\n"
- 	    "  MOC_DIR = .moc\n"
+ 	    "  TQMOC_DIR = .tqmoc\n"
  	    "  OBJECTS_DIR = .obj\n"
  	    "}\n";
     }
@@ -778,21 +778,21 @@ void Project::save( bool onlyProjectFile )
     }
 }
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 TQPtrList<DatabaseConnection> Project::databaseConnections() const
 {
     return dbConnections;
 }
 #endif
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 void Project::setDatabaseConnections( const TQPtrList<DatabaseConnection> &lst )
 {
     dbConnections = lst;
 }
 #endif
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 void Project::addDatabaseConnection( DatabaseConnection *conn )
 {
     dbConnections.append( conn );
@@ -800,7 +800,7 @@ void Project::addDatabaseConnection( DatabaseConnection *conn )
 }
 #endif
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 void Project::removeDatabaseConnection( const TQString &c )
 {
     for ( DatabaseConnection *conn = dbConnections.first(); conn; conn = dbConnections.next() ) {
@@ -814,7 +814,7 @@ void Project::removeDatabaseConnection( const TQString &c )
 }
 #endif
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 TQStringList Project::databaseConnectionList()
 {
     TQStringList lst;
@@ -824,7 +824,7 @@ TQStringList Project::databaseConnectionList()
 }
 #endif
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 TQStringList Project::databaseTableList( const TQString &connection )
 {
     DatabaseConnection *conn = databaseConnection( connection );
@@ -835,7 +835,7 @@ TQStringList Project::databaseTableList( const TQString &connection )
 }
 #endif
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 TQStringList Project::databaseFieldList( const TQString &connection, const TQString &table )
 {
     DatabaseConnection *conn = databaseConnection( connection );
@@ -845,7 +845,7 @@ TQStringList Project::databaseFieldList( const TQString &connection, const TQStr
 }
 #endif
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 static TQString makeIndent( int indent )
 {
     TQString s;
@@ -854,7 +854,7 @@ static TQString makeIndent( int indent )
 }
 #endif
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 static void saveSingleProperty( TQTextStream &ts, const TQString& name, const TQString& value, int indent )
 {
     ts << makeIndent( indent ) << "<property name=\"" << name << "\">" << endl;
@@ -867,7 +867,7 @@ static void saveSingleProperty( TQTextStream &ts, const TQString& name, const TQ
 
 void Project::saveConnections()
 {
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
     if ( dbFile.isEmpty() ) {
 	TQFileInfo fi( fileName() );
 	setDatabaseDescription( fi.baseName() + ".db" );
@@ -934,7 +934,7 @@ void Project::saveConnections()
 #endif
 }
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 static TQDomElement loadSingleProperty( TQDomElement e, const TQString& name )
 {
     TQDomElement n;
@@ -950,7 +950,7 @@ static TQDomElement loadSingleProperty( TQDomElement e, const TQString& name )
 
 void Project::loadConnections()
 {
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
     if ( dbFile.isEmpty() || !TQFile::exists( makeAbsolute( dbFile ) ) )
 	return;
 
@@ -1021,7 +1021,7 @@ can be closed again with closeDatabase().
 
 bool Project::openDatabase( const TQString &connection, bool suppressDialog )
 {
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
     DatabaseConnection *conn = databaseConnection( connection );
     if ( connection.isEmpty() && !conn )
 	conn = databaseConnection( "(default)" );
@@ -1040,7 +1040,7 @@ bool Project::openDatabase( const TQString &connection, bool suppressDialog )
 */
 void Project::closeDatabase( const TQString &connection )
 {
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
     DatabaseConnection *conn = databaseConnection( connection );
     if ( connection.isEmpty() && !conn )
 	conn = databaseConnection( "(default)" );
@@ -1066,7 +1066,7 @@ TQObjectList *Project::formList( bool resolveFakeObjects ) const
 	    if ( resolveFakeObjects && f->formWindow()->isFake() )
 		l->append( objectForFakeForm( f->formWindow() ) );
 	    else
-		l->append( f->formWindow()->child( 0, "TQWidget" ) );
+		l->append( f->formWindow()->child( 0, TQWIDGET_OBJECT_NAME_STRING ) );
 	} else if ( f->isFake() ) {
 	    l->append( objectForFakeFormFile( f ) );
 	}
@@ -1115,14 +1115,14 @@ void Project::updateCustomSettings()
 
 /*
     ProjectSettingsInterface *iface = 0;
-    projectSettingsPluginManager->queryInterface( lang, (QUnknownInterface**)&iface );
+    projectSettingsPluginManager->queryInterface( lang, (TQUnknownInterface**)&iface );
     if ( !iface )
 	return;
     csList = iface->projectSettings();
     iface->release();
 */
 
-    QInterfacePtr<ProjectSettingsInterface> iface;
+    TQInterfacePtr<ProjectSettingsInterface> iface;
     projectSettingsPluginManager->queryInterface( lang, &iface );
     if ( !iface )
 	return;
@@ -1223,8 +1223,8 @@ void Project::readPlatformSettings( const TQString &contents,
 				    const TQString &setting,
 				    TQMap<TQString, TQString> &res )
 {
-    const TQString platforms[] = { "", "win32", "unix", "mac", TQString::null };
-    for ( int i = 0; platforms[ i ] != TQString::null; ++i ) {
+    const TQString platforms[] = { "", "win32", "unix", "mac", TQString() };
+    for ( int i = 0; platforms[ i ] != TQString(); ++i ) {
 	TQString p = platforms[ i ];
 	if ( !p.isEmpty() )
 	    p += ":";
@@ -1239,8 +1239,8 @@ void Project::readPlatformSettings( const TQString &contents,
 
 void Project::removePlatformSettings( TQString &contents, const TQString &setting )
 {
-    const TQString platforms[] = { "win32", "unix", "mac", "", TQString::null };
-    for ( int i = 0; platforms[ i ] != TQString::null; ++i ) {
+    const TQString platforms[] = { "win32", "unix", "mac", "", TQString() };
+    for ( int i = 0; platforms[ i ] != TQString(); ++i ) {
 	TQString p = platforms[ i ];
 	if ( !p.isEmpty() )
 	    p += ":";
@@ -1251,14 +1251,14 @@ void Project::removePlatformSettings( TQString &contents, const TQString &settin
 void Project::writePlatformSettings( TQString &contents, const TQString &setting,
 				     const TQMap<TQString, TQString> &input )
 {
-    const TQString platforms[] = { "", "win32", "unix", "mac", TQString::null };
+    const TQString platforms[] = { "", "win32", "unix", "mac", TQString() };
     int i;
     LanguageInterface *iface = MetaDataBase::languageInterface( lang );
     if (iface && (setting == "SOURCES" || setting == "HEADERS")) // The (all) part will be saved later on
         i = 1;
     else
 	i = 0;
-    for (; platforms[ i ] != TQString::null; ++i ) {
+    for (; platforms[ i ] != TQString(); ++i ) {
 	TQString p = platforms[ i ];
 	if ( !p.isEmpty() )
 	    p += ":";
@@ -1396,7 +1396,7 @@ void Project::removeTempProject()
     }
     d.remove( TQFileInfo( filename ).dirPath() );
 #if defined(Q_OS_UNIX)
-    // ##### implement for all platforms, ideally should be in Qt
+    // ##### implement for all platforms, ideally should be in TQt
     ::rmdir( TQFile::encodeName( d.absPath() ) );
 #endif
 }
@@ -1509,13 +1509,13 @@ void Project::formOpened( FormWindow *fw )
 TQString Project::locationOfObject( TQObject *o )
 {
     if ( !o )
-	return TQString::null;
+	return TQString();
 
     if ( MainWindow::self ) {
 	TQWidgetList windows = MainWindow::self->qWorkspace()->windowList();
 	for ( TQWidget *w = windows.first(); w; w = windows.next() ) {
-	    FormWindow *fw = ::qt_cast<FormWindow*>(w);
-	    SourceEditor *se = ::qt_cast<SourceEditor*>(w);
+	    FormWindow *fw = ::tqqt_cast<FormWindow*>(w);
+	    SourceEditor *se = ::tqqt_cast<SourceEditor*>(w);
 	    if ( fw ) {
 		if ( fw->isFake() )
 		    return objectForFakeForm( fw )->name() + TQString( " [Source]" );
@@ -1532,7 +1532,7 @@ TQString Project::locationOfObject( TQObject *o )
 	}
     }
 
-    if ( ::qt_cast<SourceFile*>(o) ) {
+    if ( ::tqqt_cast<SourceFile*>(o) ) {
 	for ( TQPtrListIterator<SourceFile> sources = sourceFiles();
 	      sources.current(); ++sources ) {
 	    SourceFile* f = sources.current();
@@ -1544,7 +1544,7 @@ TQString Project::locationOfObject( TQObject *o )
     extern TQMap<TQWidget*, TQString> *qwf_forms;
     if ( !qwf_forms ) {
 	qWarning( "Project::locationOfObject: qwf_forms is NULL!" );
-	return TQString::null;
+	return TQString();
     }
 
     TQString s = makeRelative( *qwf_forms->find( (TQWidget*)o ) );
@@ -1554,5 +1554,5 @@ TQString Project::locationOfObject( TQObject *o )
 
 bool Project::hasGUI() const
 {
-    return qApp->type() != TQApplication::Tty;
+    return tqApp->type() != TQApplication::Tty;
 }
