@@ -1,15 +1,15 @@
 /**********************************************************************
 ** Copyright (C) 2000 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
 ** Agreement provided with the Software.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
 ** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-**   information about Qt Commercial License Agreements.
+**   information about TQt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -55,11 +55,11 @@ class FormWindow;
 class TQCloseEvent;
 class TQResizeEvent;
 class PropertyWhatsThis;
-class QDateEdit;
-class QTimeEdit;
-class QDateTimeEdit;
+class TQDateEdit;
+class TQTimeEdit;
+class TQDateTimeEdit;
 
-class PropertyItem : public QListViewItem
+class PropertyItem : public TQListViewItem
 {
 public:
     PropertyItem( PropertyList *l, PropertyItem *after, PropertyItem *prop, const TQString &propName );
@@ -129,7 +129,7 @@ private:
     bool open, changed;
     PropertyItem *property;
     TQString propertyName;
-    TQPtrList<PropertyItem> children;
+    TQPtrList<PropertyItem> tqchildren;
     TQColor backColor;
     TQPushButton *resetButton;
 
@@ -139,6 +139,7 @@ class PropertyTextItem : public TQObject,
 			 public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyTextItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -175,6 +176,7 @@ class PropertyBoolItem : public TQObject,
 			 public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyBoolItem( PropertyList *l, PropertyItem *after, PropertyItem *prop, const TQString &propName );
@@ -199,6 +201,7 @@ class PropertyIntItem : public TQObject,
 			public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyIntItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -224,6 +227,7 @@ class PropertyLayoutItem : public TQObject,
 			public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyLayoutItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -248,6 +252,7 @@ class PropertyDoubleItem : public TQObject,
 			public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyDoubleItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -271,6 +276,7 @@ class PropertyListItem : public TQObject,
 			 public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyListItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -306,6 +312,7 @@ class PropertyFontItem : public TQObject,
 			 public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyFontItem( PropertyList *l, PropertyItem *after, PropertyItem *prop, const TQString &propName );
@@ -335,6 +342,7 @@ class PropertyCoordItem : public TQObject,
 			  public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     enum Type { Rect, Size, Point };
@@ -364,10 +372,11 @@ class PropertyColorItem : public TQObject,
 			  public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyColorItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
-		       const TQString &propName, bool children );
+		       const TQString &propName, bool tqchildren );
     ~PropertyColorItem();
 
     virtual void createChildren();
@@ -398,6 +407,7 @@ class PropertyPixmapItem : public TQObject,
 			   public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     enum Type { Pixmap, IconSet, Image };
@@ -430,6 +440,7 @@ class PropertySizePolicyItem : public TQObject,
 			  public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertySizePolicyItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -456,6 +467,7 @@ class PropertyPaletteItem : public TQObject,
 			    public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyPaletteItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -484,6 +496,7 @@ class PropertyCursorItem : public TQObject,
 			   public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyCursorItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -508,6 +521,7 @@ class PropertyKeysequenceItem : public TQObject,
 				public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyKeysequenceItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -538,6 +552,7 @@ class PropertyDatabaseItem : public TQObject,
 			     public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyDatabaseItem( PropertyList *l, PropertyItem *after, PropertyItem *prop, const TQString &propName, bool wField );
@@ -564,7 +579,7 @@ private:
 struct EnumItem {
     EnumItem( const TQString &k, bool s )
 	: key( k ), selected( s ) {}
-    EnumItem() : key( TQString::null ), selected( FALSE ) {}
+    EnumItem() : key( TQString() ), selected( FALSE ) {}
     bool operator==( const EnumItem &item ) const {
 	return key == item.key;
     }
@@ -572,9 +587,10 @@ struct EnumItem {
     bool selected;
 };
 
-class EnumPopup : public QFrame
+class EnumPopup : public TQFrame
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     EnumPopup( TQWidget *parent, const char *name, WFlags f=0 );
@@ -596,9 +612,10 @@ private:
     TQVBoxLayout *popLayout;
 };
 
-class EnumBox : public QComboBox
+class EnumBox : public TQComboBox
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     EnumBox( TQWidget *parent, const char *name = 0 );
@@ -633,6 +650,7 @@ class PropertyEnumItem : public TQObject,
 			 public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyEnumItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -656,9 +674,10 @@ private:
     TQString enumString;
 };
 
-class PropertyList : public QListView
+class PropertyList : public TQListView
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyList( PropertyEditor *e );
@@ -721,6 +740,7 @@ private:
 class EventList : public HierarchyList
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     EventList( TQWidget *parent, FormWindow *fw, PropertyEditor *e );
@@ -745,9 +765,10 @@ private:
 };
 
 
-class PropertyEditor : public QTabWidget
+class PropertyEditor : public TQTabWidget
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyEditor( TQWidget *parent );
@@ -768,7 +789,7 @@ public:
 
     TQString currentProperty() const;
     TQString classOfCurrentProperty() const;
-    TQMetaObject* metaObjectOfCurrentProperty() const;
+    TQMetaObject* tqmetaObjectOfCurrentProperty() const;
 
     void resetFocus();
 
@@ -799,6 +820,7 @@ class PropertyDateItem : public TQObject,
 			 public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyDateItem( PropertyList *l, PropertyItem *after, PropertyItem *prop, const TQString &propName );
@@ -813,8 +835,8 @@ private slots:
     void setValue();
 
 private:
-    QDateEdit *lined();
-    TQGuardedPtr<QDateEdit> lin;
+    TQDateEdit *lined();
+    TQGuardedPtr<TQDateEdit> lin;
 
 };
 
@@ -822,6 +844,7 @@ class PropertyTimeItem : public TQObject,
 			 public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyTimeItem( PropertyList *l, PropertyItem *after, PropertyItem *prop, const TQString &propName );
@@ -836,8 +859,8 @@ private slots:
     void setValue();
 
 private:
-    QTimeEdit *lined();
-    TQGuardedPtr<QTimeEdit> lin;
+    TQTimeEdit *lined();
+    TQGuardedPtr<TQTimeEdit> lin;
 
 };
 
@@ -845,6 +868,7 @@ class PropertyDateTimeItem : public TQObject,
 			 public PropertyItem
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     PropertyDateTimeItem( PropertyList *l, PropertyItem *after, PropertyItem *prop, const TQString &propName );
@@ -859,8 +883,8 @@ private slots:
     void setValue();
 
 private:
-    QDateTimeEdit *lined();
-    TQGuardedPtr<QDateTimeEdit> lin;
+    TQDateTimeEdit *lined();
+    TQGuardedPtr<TQDateTimeEdit> lin;
 
 };
 
