@@ -5,10 +5,10 @@
 #include <tqwidgetlist.h>
 #include <tqcursor.h>
 
-class PropertyObject : public QObject
+class PropertyObject : public TQObject
 {
 public:
-    TQMetaObject *metaObject() const { return (TQMetaObject*)mobj; }
+    TQMetaObject *tqmetaObject() const { return (TQMetaObject*)mobj; }
     const char *className() const { return "PropertyObject"; }
     TQObject* qObject() { return (TQObject*)this; }
 private:
