@@ -1,7 +1,7 @@
 /****************************************************************************
 ** ui.h extension file, included from the uic-generated form implementation.
 **
-** If you wish to add, delete or rename slots use Qt Designer which will
+** If you wish to add, delete or rename slots use TQt Designer which will
 ** update this file, preserving your code. Create an init() slot in place of
 ** a constructor, and a destroy() slot in place of a destructor.
 *****************************************************************************/
@@ -11,12 +11,12 @@
 void RichTextFontDialog::init()
 {
     TQFontDatabase *db = new TQFontDatabase();
-    fontCombo->insertStringList( db->families() );
+    fontCombo->insertStringList( db->tqfamilies() );
 }
 
 void RichTextFontDialog::selectColor()
 {
-    color = QColorDialog::getColor( "", this );   
+    color = TQColorDialog::getColor( "", this );   
     if( color.isValid() )
 	colorButton->setPaletteBackgroundColor( color );
 }
