@@ -1,15 +1,15 @@
 /**********************************************************************
 ** Copyright (C) 2000-2002 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
 ** Agreement provided with the Software.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
 ** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-**   information about Qt Commercial License Agreements.
+**   information about TQt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -115,16 +115,16 @@ void WorkspaceItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
 {
     TQColorGroup g( cg );
     g.setColor( TQColorGroup::Base, backgroundColor() );
-    g.setColor( TQColorGroup::Foreground, Qt::black );
+    g.setColor( TQColorGroup::Foreground, TQt::black );
 
     if ( type() == FormSourceType &&
 	 ( !formFile->hasFormCode() || ( formFile->codeFileState() == FormFile::Deleted && formFile->formWindow() ) ) &&
 	 parent() && parent()->parent() && ( (WorkspaceItem*)parent()->parent() )->project &&
 	 ( (WorkspaceItem*)parent()->parent() )->project->isCpp() ) {
-	g.setColor( TQColorGroup::Text, listView()->palette().disabled().color( TQColorGroup::Text) );
-	g.setColor( TQColorGroup::HighlightedText, listView()->palette().disabled().color( TQColorGroup::Text) );
+	g.setColor( TQColorGroup::Text, listView()->tqpalette().disabled().color( TQColorGroup::Text) );
+	g.setColor( TQColorGroup::HighlightedText, listView()->tqpalette().disabled().color( TQColorGroup::Text) );
     } else {
-	g.setColor( TQColorGroup::Text, Qt::black );
+	g.setColor( TQColorGroup::Text, TQt::black );
     }
     p->save();
 
@@ -177,7 +177,7 @@ TQString WorkspaceItem::text( int column ) const
 	return project->qualifiedName( object );
     }
 
-    return TQString::null; // shut up compiler
+    return TQString(); // shut up compiler
 }
 
 void WorkspaceItem::fillCompletionList( TQStringList& completion )
@@ -284,7 +284,7 @@ Workspace::Workspace( TQWidget *parent, MainWindow *mw )
     header()->hide();
     setSorting( 0 );
     setResizePolicy( TQScrollView::Manual );
-#ifndef Q_WS_MAC
+#ifndef TQ_WS_MAC
     TQPalette p( palette() );
     p.setColor( TQColorGroup::Base, TQColor( *backColor2 ) );
     (void)*selectedBack; // hack
@@ -419,9 +419,9 @@ void Workspace::update( FormFile* ff )
 {
     TQListViewItem* i = findItem( ff );
     if ( i ) {
-	i->repaint();
+	i->tqrepaint();
 	if ( (i = i->firstChild()) )
-	    i->repaint();
+	    i->tqrepaint();
     }
 }
 
@@ -523,7 +523,7 @@ void Workspace::itemDoubleClicked( TQListViewItem *i )
 
 void Workspace::itemClicked( int button, TQListViewItem *i, const TQPoint& )
 {
-    if ( !i || button != LeftButton )
+    if ( !i || button != Qt::LeftButton )
 	return;
 
     closeAutoOpenItems();
@@ -640,7 +640,7 @@ void Workspace::rmbClicked( TQListViewItem *i, const TQPoint& pos )
     case OPEN_SOURCE:
     case OPEN_FORM:
     case OPEN_FORM_SOURCE:
-	itemClicked( LeftButton, i, pos );
+	itemClicked( Qt::LeftButton, i, pos );
 	break;
     }
 }
@@ -648,7 +648,7 @@ void Workspace::rmbClicked( TQListViewItem *i, const TQPoint& pos )
 bool Workspace::eventFilter( TQObject *o, TQEvent * e )
 {
     // Reggie, on what type of events do we have to execute updateBufferEdit()
-    if ( o ==bufferEdit && e->type() != TQEvent::ChildRemoved )
+    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(bufferEdit) && e->type() != TQEvent::ChildRemoved )
 	updateBufferEdit();
     return TQListView::eventFilter( o, e );
 }
@@ -689,7 +689,7 @@ void Workspace::bufferChosen( const TQString &buffer )
     TQListViewItemIterator it( this );
     while ( it.current() ) {
 	if ( ( (WorkspaceItem*)it.current())->checkCompletion( buffer ) ) {
-	    itemClicked( LeftButton, it.current(), TQPoint() );
+	    itemClicked( Qt::LeftButton, it.current(), TQPoint() );
 	    break;
 	}
 	++it;
