@@ -1,15 +1,15 @@
 /**********************************************************************
 ** Copyright (C) 2000-2002 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
 ** Agreement provided with the Software.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
 **
 ** See http://www.trolltech.com/gpl/ for GPL licensing information.
 ** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-**   information about Qt Commercial License Agreements.
+**   information about TQt Commercial License Agreements.
 **
 ** Contact info@trolltech.com if any conditions of this licensing are
 ** not clear to you.
@@ -56,11 +56,11 @@ static int dbcustomcount = 200;
 static TQStrList *wGroups;
 static TQStrList *invisibleGroups;
 static bool whatsThisLoaded = FALSE;
-static QPluginManager<WidgetInterface> *widgetPluginManager = 0;
+static TQPluginManager<WidgetInterface> *widgetPluginManager = 0;
 static bool plugins_set_up = FALSE;
 static bool was_in_setup = FALSE;
 
-TQCleanupHandler<QPluginManager<WidgetInterface> > cleanup_manager;
+TQCleanupHandler<TQPluginManager<WidgetInterface> > cleanup_manager;
 
 WidgetDatabaseRecord::WidgetDatabaseRecord()
 {
@@ -135,7 +135,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_pushbutton.png";
-    r->name = "TQPushButton";
+    r->name = TQPUSHBUTTON_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Buttons" );
     r->toolTip = "Push Button";
     r->isCommon = TRUE;
@@ -144,7 +144,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_toolbutton.png";
-    r->name = "TQToolButton";
+    r->name = TQTOOLBUTTON_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Buttons" );
     r->toolTip = "Tool Button";
 
@@ -152,7 +152,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_radiobutton.png";
-    r->name = "TQRadioButton";
+    r->name = TQRADIOBUTTON_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Buttons" );
     r->toolTip = "Radio Button";
     r->isCommon = TRUE;
@@ -161,7 +161,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_checkbox.png";
-    r->name = "TQCheckBox";
+    r->name = TQCHECKBOX_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Buttons" );
     r->toolTip = "Check Box";
     r->isCommon = TRUE;
@@ -170,7 +170,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_groupbox.png";
-    r->name = "TQGroupBox";
+    r->name = TQGROUPBOX_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Containers" );
     r->toolTip = "Group Box";
     r->isContainer = TRUE;
@@ -179,7 +179,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_buttongroup.png";
-    r->name = "TQButtonGroup";
+    r->name = TQBUTTONGROUP_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Containers" );
     r->toolTip = "Button Group";
     r->isContainer = TRUE;
@@ -189,7 +189,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_frame.png";
-    r->name = "TQFrame";
+    r->name = TQFRAME_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Containers" );
     r->toolTip = "Frame";
     r->isContainer = TRUE;
@@ -198,7 +198,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_tabwidget.png";
-    r->name = "TQTabWidget";
+    r->name = TQTABWIDGET_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Containers" );
     r->toolTip = "Tabwidget";
     r->isContainer = TRUE;
@@ -207,7 +207,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_widgetstack.png";
-    r->name = "TQWidgetStack";
+    r->name = TQWIDGETSTACK_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Containers" );
     r->toolTip = "Widget Stack";
     r->isContainer = TRUE;
@@ -216,7 +216,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_toolbox.png";
-    r->name = "TQToolBox";
+    r->name = TQTOOLBOX_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Containers" );
     r->toolTip = "Tool Box";
     r->isContainer = TRUE;
@@ -225,7 +225,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_listbox.png";
-    r->name = "TQListBox";
+    r->name = TQLISTBOX_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Views" );
     r->toolTip = "List Box";
     r->isCommon = TRUE;
@@ -234,37 +234,37 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_listview.png";
-    r->name = "TQListView";
+    r->name = TQLISTVIEW_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Views" );
     r->toolTip = "List View";
 
     append( r );
 
-#if !defined(QT_NO_ICONVIEW) || defined(UIC)
+#if !defined(TQT_NO_ICONVIEW) || defined(UIC)
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_iconview.png";
-    r->name = "TQIconView";
+    r->name = TQICONVIEW_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Views" );
     r->toolTip = "Icon View";
 
     append( r );
 #endif
 
-#if !defined(QT_NO_TABLE)
+#if !defined(TQT_NO_TABLE)
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_table.png";
-    r->name = "TQTable";
+    r->name = TQTABLE_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Views" );
     r->toolTip = "Table";
 
     append( r );
 #endif
 
-#if !defined(QT_NO_SQL)
+#if !defined(TQT_NO_SQL)
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_datatable.png";
     r->includeFile = "tqdatatable.h";
-    r->name = "TQDataTable";
+    r->name = TQDATATABLE_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Database" );
     r->toolTip = "Data Table";
 
@@ -273,7 +273,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_lineedit.png";
-    r->name = "TQLineEdit";
+    r->name = TQLINEEDIT_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Input" );
     r->toolTip = "Line Edit";
     r->isCommon = TRUE;
@@ -282,7 +282,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_spinbox.png";
-    r->name = "TQSpinBox";
+    r->name = TQSPINBOX_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Input" );
     r->toolTip = "Spin Box";
     r->isCommon = TRUE;
@@ -291,7 +291,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_dateedit.png";
-    r->name = "QDateEdit";
+    r->name = TQDATEEDIT_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Input" );
     r->toolTip = "Date Edit";
     r->includeFile = "tqdatetimeedit.h";
@@ -300,7 +300,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_timeedit.png";
-    r->name = "QTimeEdit";
+    r->name = TQTIMEEDIT_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Input" );
     r->toolTip = "Time Edit";
     r->includeFile = "tqdatetimeedit.h";
@@ -309,7 +309,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_datetimeedit.png";
-    r->name = "QDateTimeEdit";
+    r->name = TQDATETIMEEDIT_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Input" );
     r->toolTip = "Date-Time Edit";
     r->includeFile = "tqdatetimeedit.h";
@@ -318,7 +318,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_multilineedit.png";
-    r->name = "TQMultiLineEdit";
+    r->name = TQMULTILINEEDIT_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Temp" );
     r->toolTip = "Multi Line Edit";
 
@@ -326,7 +326,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_richtextedit.png";
-    r->name = "TQTextEdit";
+    r->name = TQTEXTEDIT_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Input" );
     r->toolTip = "Rich Text Edit";
     r->isCommon = TRUE;
@@ -335,7 +335,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_combobox.png";
-    r->name = "TQComboBox";
+    r->name = TQCOMBOBOX_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Input" );
     r->toolTip = "Combo Box";
     r->isCommon = TRUE;
@@ -344,7 +344,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_slider.png";
-    r->name = "TQSlider";
+    r->name = TQSLIDER_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Input" );
     r->toolTip = "Slider";
 
@@ -352,7 +352,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_scrollbar.png";
-    r->name = "TQScrollBar";
+    r->name = TQSCROLLBAR_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Input" );
     r->toolTip = "Scrollbar";
 
@@ -360,7 +360,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_dial.png";
-    r->name = "TQDial";
+    r->name = TQDIAL_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Input" );
     r->toolTip = "Dial";
 
@@ -368,7 +368,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_label.png";
-    r->name = "TQLabel";
+    r->name = TQLABEL_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Temp" );
     r->toolTip = "Label";
 
@@ -395,7 +395,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_lcdnumber.png";
-    r->name = "TQLCDNumber";
+    r->name = TQLCDNUMBER_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Display" );
     r->toolTip = "LCD Number";
 
@@ -413,7 +413,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_progress.png";
-    r->name = "TQProgressBar";
+    r->name = TQPROGRESSBAR_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Display" );
     r->toolTip = "Progress Bar";
 
@@ -421,7 +421,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_textview.png";
-    r->name = "TQTextView";
+    r->name = TQTEXTVIEW_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Temp" );
     r->toolTip = "Text View";
 
@@ -429,7 +429,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_textbrowser.png";
-    r->name = "TQTextBrowser";
+    r->name = TQTEXTBROWSER_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Display" );
     r->toolTip = "Text Browser";
 
@@ -445,35 +445,35 @@ void WidgetDatabase::setupDataBase( int id )
     append( r );
 
     r = new WidgetDatabaseRecord;
-    r->name = "TQWidget";
+    r->name = TQWIDGET_OBJECT_NAME_STRING;
     r->isForm = TRUE;
     r->group = widgetGroup( "Forms" );
 
     append( r );
 
     r = new WidgetDatabaseRecord;
-    r->name = "TQDialog";
+    r->name = TQDIALOG_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Forms" );
     r->isForm = TRUE;
 
     append( r );
 
     r = new WidgetDatabaseRecord;
-    r->name = "TQWizard";
+    r->name = TQWIZARD_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Forms" );
     r->isContainer = TRUE;
 
     append( r );
 
     r = new WidgetDatabaseRecord;
-    r->name = "QDesignerWizard";
+    r->name = "TQDesignerWizard";
     r->group = widgetGroup( "Forms" );
     r->isContainer = TRUE;
 
     append( r );
 
     r = new WidgetDatabaseRecord;
-    r->name = "QLayoutWidget";
+    r->name = TQLAYOUTWIDGET_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Temp" );
     r->includeFile = "";
     r->isContainer = TRUE;
@@ -481,7 +481,7 @@ void WidgetDatabase::setupDataBase( int id )
     append( r );
 
     r = new WidgetDatabaseRecord;
-    r->name = "TQSplitter";
+    r->name = TQSPLITTER_OBJECT_NAME_STRING;
     r->group = widgetGroup( "Temp" );
     r->includeFile = "tqsplitter.h";
     r->isContainer = TRUE;
@@ -490,7 +490,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_tabwidget.png";
-    r->name = "QDesignerTabWidget";
+    r->name = "TQDesignerTabWidget";
     r->group = widgetGroup( "Temp" );
     r->isContainer = TRUE;
 
@@ -498,7 +498,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_tabwidget.png";
-    r->name = "QDesignerWidget";
+    r->name = "TQDesignerWidget";
     r->group = widgetGroup( "Temp" );
     r->isContainer = TRUE;
 
@@ -506,7 +506,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "designer_tabwidget.png";
-    r->name = "QDesignerDialog";
+    r->name = "TQDesignerDialog";
     r->group = widgetGroup( "Temp" );
     r->isContainer = TRUE;
 
@@ -514,7 +514,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "";
-    r->name = "TQMainWindow";
+    r->name = TQMAINWINDOW_OBJECT_NAME_STRING;
     r->includeFile = "tqmainwindow.h";
     r->group = widgetGroup( "Temp" );
     r->isContainer = TRUE;
@@ -523,7 +523,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "";
-    r->name = "QDesignerAction";
+    r->name = "TQDesignerAction";
     r->includeFile = "tqaction.h";
     r->group = widgetGroup( "Temp" );
     r->isContainer = FALSE;
@@ -532,7 +532,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "";
-    r->name = "QDesignerActionGroup";
+    r->name = "TQDesignerActionGroup";
     r->includeFile = "tqaction.h";
     r->group = widgetGroup( "Temp" );
     r->isContainer = FALSE;
@@ -541,17 +541,17 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "";
-    r->name = "TQScrollView";
+    r->name = TQSCROLLVIEW_OBJECT_NAME_STRING;
     r->includeFile = "tqscrollview.h";
     r->group = widgetGroup( "Temp" );
     r->isContainer = TRUE;
 
     append( r );
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
     r = new WidgetDatabaseRecord;
     r->iconSet = "";
-    r->name = "TQDataBrowser";
+    r->name = TQDATABROWSER_OBJECT_NAME_STRING;
     r->includeFile = "tqdatabrowser.h";
     r->group = widgetGroup( "Database" );
     r->toolTip = "Data Browser";
@@ -562,7 +562,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "";
-    r->name = "TQDataView";
+    r->name = TQDATAVIEW_OBJECT_NAME_STRING;
     r->includeFile = "tqdataview.h";
     r->group = widgetGroup( "Database" );
     r->toolTip = "Data View";
@@ -666,7 +666,7 @@ TQString WidgetDatabase::className( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return TQString::null;
+	return TQString();
     return r->name;
 }
 
@@ -679,7 +679,7 @@ TQString WidgetDatabase::group( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return TQString::null;
+	return TQString();
     return r->group;
 }
 
@@ -692,7 +692,7 @@ TQString WidgetDatabase::toolTip( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return TQString::null;
+	return TQString();
     return r->toolTip;
 }
 
@@ -705,7 +705,7 @@ TQString WidgetDatabase::whatsThis( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return TQString::null;
+	return TQString();
     return r->whatsThis;
 }
 
@@ -718,7 +718,7 @@ TQString WidgetDatabase::includeFile( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return TQString::null;
+	return TQString();
     if ( r->includeFile.isNull() )
 	return r->name.lower() + ".h";
     return r->includeFile;
@@ -735,7 +735,7 @@ bool WidgetDatabase::isForm( int id )
     return r->isForm;
 }
 
-/*!  Returns whether the widget registered as \a id can have children.
+/*!  Returns whether the widget registered as \a id can have tqchildren.
 */
 
 bool WidgetDatabase::isContainer( int id )
@@ -760,7 +760,7 @@ TQString WidgetDatabase::createWidgetName( int id )
 {
     setupDataBase( id );
     TQString n = className( id );
-    if ( n == "QLayoutWidget" )
+    if ( n == TQLAYOUTWIDGET_OBJECT_NAME_STRING )
 	n = "Layout";
     if ( n[ 0 ] == 'Q' && n[ 1 ].lower() != n[ 1 ] )
 	n = n.mid( 1 );
@@ -787,7 +787,7 @@ int WidgetDatabase::idFromClassName( const TQString &name )
     if ( i )
 	return *i;
     if ( name == "FormWindow" )
-	return idFromClassName( "QLayoutWidget" );
+	return idFromClassName( TQLAYOUTWIDGET_OBJECT_NAME_STRING );
 #ifdef UIC
     setupDataBase( -2 );
     i = className2Id->find( name );
@@ -820,7 +820,7 @@ void WidgetDatabase::insert( int index, WidgetDatabaseRecord *r )
     db[ index ] = r;
     className2Id->insert( r->name, new int( index ) );
     if ( index < dbcustom )
-	dbcount = QMAX( dbcount, index );
+	dbcount = TQMAX( dbcount, index );
 }
 
 void WidgetDatabase::append( WidgetDatabaseRecord *r )
@@ -832,8 +832,8 @@ void WidgetDatabase::append( WidgetDatabaseRecord *r )
 
 TQString WidgetDatabase::widgetGroup( const TQString &g )
 {
-    if ( wGroups->find( g ) == -1 )
-	wGroups->append( g );
+    if ( wGroups->find( g.ascii() ) == -1 )
+	wGroups->append( g.ascii() );
     return g;
 }
 
@@ -854,7 +854,7 @@ TQString WidgetDatabase::widgetGroup( int i )
     setupDataBase( -1 );
     if ( i >= 0 && i < (int)wGroups->count() )
 	return wGroups->at( i );
-    return TQString::null;
+    return TQString();
 }
 
 int WidgetDatabase::numWidgetGroups()
@@ -866,7 +866,7 @@ int WidgetDatabase::numWidgetGroups()
 bool WidgetDatabase::isGroupVisible( const TQString &g )
 {
     setupDataBase( -1 );
-    return invisibleGroups->find( g ) == -1;
+    return invisibleGroups->find( g.ascii() ) == -1;
 }
 
 int WidgetDatabase::addCustomWidget( WidgetDatabaseRecord *r )
@@ -927,7 +927,7 @@ void WidgetDatabase::loadWhatsThis( const TQString &docPath )
 }
 
 
-// ### Qt 3.1: make these publically accessible via QWidgetDatabase API
+// ### TQt 3.1: make these publically accessible via TQWidgetDatabase API
 #if defined(UIC)
 bool dbnounload = FALSE;
 TQStringList *dbpaths = 0;
@@ -936,7 +936,7 @@ extern TQString *qwf_plugin_dir;
 #endif
 
 
-QPluginManager<WidgetInterface> *widgetManager()
+TQPluginManager<WidgetInterface> *widgetManager()
 {
     if ( !widgetPluginManager ) {
 	TQString pluginDir = "/designer";
@@ -944,7 +944,7 @@ QPluginManager<WidgetInterface> *widgetManager()
 	if ( qwf_plugin_dir )
 	    pluginDir = *qwf_plugin_dir;
 #endif
-	widgetPluginManager = new QPluginManager<WidgetInterface>( IID_Widget, TQApplication::libraryPaths(), pluginDir );
+	widgetPluginManager = new TQPluginManager<WidgetInterface>( IID_Widget, TQApplication::libraryPaths(), pluginDir );
 	cleanup_manager.add( &widgetPluginManager );
 #if defined(UIC)
 	if ( dbnounload )
