@@ -1,5 +1,5 @@
 /* -*- Mode: C++ -*-
-   $Id: KDGanttView.h 1158452 2010-08-02 19:28:10Z tpearson $
+   $Id: KDGanttView.h 1246260 2011-08-10 22:19:39Z tpearson $
    KDChart - a multi-platform charting engine
 */
 
@@ -27,8 +27,8 @@
  ** licensing are not clear to you.
  **
  ** As a special exception, permission is given to link this program
- ** with any edition of Qt, and distribute the resulting executable,
- ** without including the source code for Qt in the source distribution.
+ ** with any edition of TQt, and distribute the resulting executable,
+ ** without including the source code for TQt in the source distribution.
  **
  **********************************************************************/
 
@@ -70,43 +70,44 @@ class KDGanttMinimizeSplitter;
 class KDGanttView : public KDGanttMinimizeSplitter
 {
     Q_OBJECT
+    TQ_OBJECT
 
-    Q_PROPERTY( bool showLegend READ showLegend WRITE setShowLegend )
-    Q_PROPERTY( bool showListView READ showListView WRITE setShowListView )
-    Q_PROPERTY( bool showTaskLinks READ showTaskLinks WRITE setShowTaskLinks )
-    Q_PROPERTY( bool editorEnabled READ editorEnabled WRITE setEditorEnabled )
-    Q_PROPERTY( TQDateTime horizonStart READ horizonStart WRITE setHorizonStart )
-    Q_PROPERTY( TQDateTime horizonEnd READ horizonEnd WRITE setHorizonEnd )
-    Q_PROPERTY( Scale scale READ scale WRITE setScale )
-    Q_PROPERTY( YearFormat yearFormat READ yearFormat WRITE setYearFormat )
-    Q_PROPERTY( HourFormat hourFormat READ hourFormat WRITE setHourFormat )
-    Q_PROPERTY( bool showMinorTicks READ showMinorTicks WRITE setShowMinorTicks )
-    Q_PROPERTY( bool showMajorTicks READ showMajorTicks WRITE setShowMajorTicks )
-    Q_PROPERTY( bool editable READ editable WRITE setEditable )
-    Q_PROPERTY( TQColor textColor READ textColor WRITE setTextColor )
-    Q_PROPERTY( int majorScaleCount READ majorScaleCount WRITE setMajorScaleCount )
-    Q_PROPERTY( int minorScaleCount READ minorScaleCount WRITE setMinorScaleCount )
-    Q_PROPERTY( int autoScaleMinorTickCount READ autoScaleMinorTickCount WRITE setAutoScaleMinorTickCount )
-    Q_PROPERTY( Scale maximumScale READ maximumScale WRITE setMaximumScale )
-    Q_PROPERTY( Scale minimumScale READ minimumScale WRITE setMinimumScale )
-    Q_PROPERTY( int minimumColumnWidth READ minimumColumnWidth WRITE setMinimumColumnWidth )
-    Q_PROPERTY( int ganttMaximumWidth READ ganttMaximumWidth WRITE setGanttMaximumWidth )
-    Q_PROPERTY( TQColor weekendBackgroundColor READ weekendBackgroundColor WRITE setWeekendBackgroundColor )
-    Q_PROPERTY( TQColor ganttViewBackgroundColor READ gvBackgroundColor WRITE setGvBackgroundColor )
-    Q_PROPERTY( TQColor listViewBackgroundColor READ lvBackgroundColor WRITE setLvBackgroundColor )
-    Q_PROPERTY( TQColor timeHeaderBackgroundColor READ timeHeaderBackgroundColor WRITE setTimeHeaderBackgroundColor )
-    Q_PROPERTY( TQColor legendHeaderBackgroundColor READ legendHeaderBackgroundColor WRITE setLegendHeaderBackgroundColor )
-    Q_PROPERTY( double zoomFactor READ zoomFactor )
-    Q_PROPERTY( bool showHeaderPopupMenu READ showHeaderPopupMenu WRITE setShowHeaderPopupMenu )
-    Q_PROPERTY( bool showTimeTablePopupMenu READ showTimeTablePopupMenu WRITE setShowTimeTablePopupMenu )
-    Q_PROPERTY( bool headerVisible READ headerVisible WRITE setHeaderVisible )
-    Q_PROPERTY( bool showLegendButton READ showLegendButton	WRITE setShowLegendButton )
-    Q_PROPERTY( bool legendIsDockwindow READ legendIsDockwindow WRITE setLegendIsDockwindow )
-    Q_PROPERTY( bool displayEmptyTasksAsLine READ displayEmptyTasksAsLine WRITE setDisplayEmptyTasksAsLine )
-    Q_PROPERTY( TQBrush noInformationBrush READ noInformationBrush WRITE setNoInformationBrush )
-    Q_PROPERTY( bool dragEnabled READ dragEnabled WRITE setDragEnabled )
-    Q_PROPERTY( bool dropEnabled READ dropEnabled WRITE setDropEnabled )
-    Q_PROPERTY( bool calendarMode READ calendarMode WRITE setCalendarMode )
+    TQ_PROPERTY( bool showLegend READ showLegend WRITE setShowLegend )
+    TQ_PROPERTY( bool showListView READ showListView WRITE setShowListView )
+    TQ_PROPERTY( bool showTaskLinks READ showTaskLinks WRITE setShowTaskLinks )
+    TQ_PROPERTY( bool editorEnabled READ editorEnabled WRITE setEditorEnabled )
+    TQ_PROPERTY( TQDateTime horizonStart READ horizonStart WRITE setHorizonStart )
+    TQ_PROPERTY( TQDateTime horizonEnd READ horizonEnd WRITE setHorizonEnd )
+    TQ_PROPERTY( Scale scale READ scale WRITE setScale )
+    TQ_PROPERTY( YearFormat yearFormat READ yearFormat WRITE setYearFormat )
+    TQ_PROPERTY( HourFormat hourFormat READ hourFormat WRITE setHourFormat )
+    TQ_PROPERTY( bool showMinorTicks READ showMinorTicks WRITE setShowMinorTicks )
+    TQ_PROPERTY( bool showMajorTicks READ showMajorTicks WRITE setShowMajorTicks )
+    TQ_PROPERTY( bool editable READ editable WRITE setEditable )
+    TQ_PROPERTY( TQColor textColor READ textColor WRITE setTextColor )
+    TQ_PROPERTY( int majorScaleCount READ majorScaleCount WRITE setMajorScaleCount )
+    TQ_PROPERTY( int minorScaleCount READ minorScaleCount WRITE setMinorScaleCount )
+    TQ_PROPERTY( int autoScaleMinorTickCount READ autoScaleMinorTickCount WRITE setAutoScaleMinorTickCount )
+    TQ_PROPERTY( Scale maximumScale READ maximumScale WRITE setMaximumScale )
+    TQ_PROPERTY( Scale minimumScale READ minimumScale WRITE setMinimumScale )
+    TQ_PROPERTY( int minimumColumnWidth READ minimumColumnWidth WRITE setMinimumColumnWidth )
+    TQ_PROPERTY( int ganttMaximumWidth READ ganttMaximumWidth WRITE setGanttMaximumWidth )
+    TQ_PROPERTY( TQColor weekendBackgroundColor READ weekendBackgroundColor WRITE setWeekendBackgroundColor )
+    TQ_PROPERTY( TQColor ganttViewBackgroundColor READ gvBackgroundColor WRITE setGvBackgroundColor )
+    TQ_PROPERTY( TQColor listViewBackgroundColor READ lvBackgroundColor WRITE setLvBackgroundColor )
+    TQ_PROPERTY( TQColor timeHeaderBackgroundColor READ timeHeaderBackgroundColor WRITE setTimeHeaderBackgroundColor )
+    TQ_PROPERTY( TQColor legendHeaderBackgroundColor READ legendHeaderBackgroundColor WRITE setLegendHeaderBackgroundColor )
+    TQ_PROPERTY( double zoomFactor READ zoomFactor )
+    TQ_PROPERTY( bool showHeaderPopupMenu READ showHeaderPopupMenu WRITE setShowHeaderPopupMenu )
+    TQ_PROPERTY( bool showTimeTablePopupMenu READ showTimeTablePopupMenu WRITE setShowTimeTablePopupMenu )
+    TQ_PROPERTY( bool headerVisible READ headerVisible WRITE setHeaderVisible )
+    TQ_PROPERTY( bool showLegendButton READ showLegendButton	WRITE setShowLegendButton )
+    TQ_PROPERTY( bool legendIsDockwindow READ legendIsDockwindow WRITE setLegendIsDockwindow )
+    TQ_PROPERTY( bool displayEmptyTasksAsLine READ displayEmptyTasksAsLine WRITE setDisplayEmptyTasksAsLine )
+    TQ_PROPERTY( TQBrush noInformationBrush READ noInformationBrush WRITE setNoInformationBrush )
+    TQ_PROPERTY( bool dragEnabled READ dragEnabled WRITE setDragEnabled )
+    TQ_PROPERTY( bool dropEnabled READ dropEnabled WRITE setDropEnabled )
+    TQ_PROPERTY( bool calendarMode READ calendarMode WRITE setCalendarMode )
 
     Q_ENUMS( Scale )
     Q_ENUMS( YearFormat )
@@ -152,7 +153,7 @@ public:
     void setHorBackgroundLines( int count = 2,
 				TQBrush brush =
 				TQBrush( TQColor ( 200,200,200 ),
-					Qt::Dense6Pattern ));
+					TQt::Dense6Pattern ));
     int horBackgroundLines( TQBrush& brush );
     bool saveProject( TQIODevice* );
     bool loadProject( TQIODevice* );
@@ -192,7 +193,7 @@ public:
                     KDGanttViewItem::Shape middle,
                     KDGanttViewItem::Shape end,
 		    bool overwriteExisting = true  );
-    bool shapes( KDGanttViewItem::Type type,
+    bool tqshapes( KDGanttViewItem::Type type,
                  KDGanttViewItem::Shape& start,
                  KDGanttViewItem::Shape& middle,
                  KDGanttViewItem::Shape& end ) const;
@@ -227,7 +228,7 @@ public:
     TQPtrList<KDGanttViewTaskLinkGroup> taskLinkGroups() const;
 
     // Legend-related stuff
-    void addLegendItem( KDGanttViewItem::Shape shape, const TQColor& shapeColor, const TQString& text );
+    void addLegendItem( KDGanttViewItem::Shape tqshape, const TQColor& tqshapeColor, const TQString& text );
     void clearLegend();
     // Header-related stuff
     void setHorizonStart( const TQDateTime& start );
@@ -297,7 +298,7 @@ public:
     void setWeekendDays( int start, int end );
     void weekendDays( int& start, int& end ) const;
 
-    static TQPixmap getPixmap( KDGanttViewItem::Shape shape, const TQColor& shapeColor,const TQColor& backgroundColor, int itemSize);
+    static TQPixmap getPixmap( KDGanttViewItem::Shape tqshape, const TQColor& tqshapeColor,const TQColor& backgroundColor, int itemSize);
 
     void setHeaderVisible( bool );
     bool headerVisible() const;
@@ -305,7 +306,7 @@ public:
     void setShowLegendButton( bool show );
     bool showLegendButton() const;
 
-    // Pass-through methods from QListView
+    // Pass-through methods from TQListView
     virtual int addColumn( const TQString& label, int width = -1 );
     virtual int addColumn( const TQIconSet& iconset, const TQString& label,
                            int width = -1 );
@@ -329,7 +330,7 @@ public:
     virtual void lvStartDrag (KDGanttViewItem*);
     virtual bool lvDragMoveEvent (TQDragMoveEvent * e,KDGanttViewItem*, KDGanttViewItem*);
     virtual void lvDragEnterEvent (TQDragEnterEvent * e );
-    virtual TQSize sizeHint() const;
+    virtual TQSize tqsizeHint() const;
     KDGanttViewItem* getItemByName( const TQString& name ) const;
     TQDateTime getDateTimeForCoordX(int coordX, bool global = true ) const;
     KDGanttViewItem* getItemByListViewPos( const TQPoint& pos ) const;
@@ -421,7 +422,7 @@ private slots:
     void slot_lvDropped(TQDropEvent* e, KDGanttViewItem* droppedItem, KDGanttViewItem* itemBelowMouse );
 private:
     struct legendItem {
-      KDGanttViewItem::Shape shape;
+      KDGanttViewItem::Shape tqshape;
       TQColor color;
       TQString text;
     };
