@@ -1,5 +1,5 @@
 /* -*- Mode: C++ -*-
-   $Id: KDGanttViewItem.cpp 1157655 2010-07-31 19:53:50Z tpearson $
+   $Id: KDGanttViewItem.cpp 1246260 2011-08-10 22:19:39Z tpearson $
    KDGantt - a multi-platform charting engine
 */
 
@@ -27,8 +27,8 @@
  ** licensing are not clear to you.
  **
  ** As a special exception, permission is given to link this program
- ** with any edition of Qt, and distribute the resulting executable,
- ** without including the source code for Qt in the source distribution.
+ ** with any edition of TQt, and distribute the resulting executable,
+ ** without including the source code for TQt in the source distribution.
  **
  **********************************************************************/
 
@@ -52,20 +52,20 @@
   directly. Instead, you should create items of one of the
   subclasses. This class provides methods common to all Gantt items.
 
-  The initialization of the shapes/colors of the item works as follows:
+  The initialization of the tqshapes/colors of the item works as follows:
 
   Shapes:
-  When a new item is created, the shapes are set to the default values
+  When a new item is created, the tqshapes are set to the default values
   for items of the type of this item, defined in the KDGanttView class with
   void setShapes( KDGanttViewItem::Type type,
   KDGanttViewItem::Shape start,
   KDGanttViewItem::Shape middle,
   KDGanttViewItem::Shape end );
   If there is no default value defined for this type,
-  the shapes are set as follows:
-  For TaskViewItems all three shapes are set to Square.
-  For SummaryViewItems all three shapes are set to TriangleDown.
-  For EventViewItems all three shapes are set to Diamond.
+  the tqshapes are set as follows:
+  For TaskViewItems all three tqshapes are set to Square.
+  For SummaryViewItems all three tqshapes are set to TriangleDown.
+  For EventViewItems all three tqshapes are set to Diamond.
 
   Colors:
   When a new item is created, the colors are set to the default values
@@ -75,7 +75,7 @@
   const TQColor& middle,
   const TQColor& end );
   If there is no default value defined for this type,
-  the colors of the shapes are set to the default color for items of this type,
+  the colors of the tqshapes are set to the default color for items of this type,
   defined in the KDGanttView class with:
   void setDefaultColor( KDGanttViewItem::Type type, const TQColor& );
   The initial default color in the KDGanttView class is set to
@@ -92,7 +92,7 @@
   const TQColor& middle,
   const TQColor& end );
   If there is no default value defined for this type,
-  the highlight colors of the shapes are set to the default color for
+  the highlight colors of the tqshapes are set to the default color for
   items of this type, defined in the KDGanttView class with:
   void setDefaultHighlightColor( KDGanttViewItem::Type type, const TQColor& );
   The initial default highlight color in the KDGanttView class is set to red
@@ -122,15 +122,15 @@
   shown or not.
   In the other mode (set with setDisplaySubitemsAsGroup( true ); ),
   called "calendar mode", the item is displayed as follows:
-  If the item has no children, it is displayed as usual.
-  If the item is opened (i.e., its children are displayed), the
+  If the item has no tqchildren, it is displayed as usual.
+  If the item is opened (i.e., its tqchildren are displayed), the
   start/end time of this item is computed automatically according to
-  the earliest start time/latest end time of its children. The item
-  and its children are displayed as usual.
-  If the item is closed (i.e., its children are hidden in the left
-  list view), the item itself is hidden, and its children are displayed
+  the earliest start time/latest end time of its tqchildren. The item
+  and its tqchildren are displayed as usual.
+  If the item is closed (i.e., its tqchildren are hidden in the left
+  list view), the item itself is hidden, and its tqchildren are displayed
   on the timeline of this item instead. To control the painting of
-  overlapping children, call \a setPriority() for the childs.
+  overlapping tqchildren, call \a setPriority() for the childs.
 
   Blocking of user interaction to open item:
   If you want to block users to open items used as parents of calendar items,
@@ -138,7 +138,7 @@
 
   Example 1, Color:
   If you create an instance of a KDGanttView class and add a SummaryViewItem
-  without setting any color/shape values, you get an item with three shapes
+  without setting any color/tqshape values, you get an item with three tqshapes
   of the form TriangleDown in the color magenta. If the item is highlighted,
   the color will change to the highlight color red.
 
@@ -147,12 +147,12 @@
   \a KDGanttView::setCalendarMode( true );
   \a KDGanttView::setDisplaySubitemsAsGroup( true );
   Insert root items in the Gantt view.
-  Insert items as children of these root item in the Gantt view.
+  Insert items as tqchildren of these root item in the Gantt view.
   You may use any item type as parent and child; there are no limitations.
   It is, however, recommended to use KDGanttViewTaskItems
-  Actually, you may add child items to the children themselves.
+  Actually, you may add child items to the tqchildren themselves.
   Such a child behaves then like a parent.
-  Now set the start/end time of the children to specify a time
+  Now set the start/end time of the tqchildren to specify a time
   interval for these items.
 */
 
@@ -327,7 +327,7 @@ TQString KDGanttViewItem::name() const
 
 KDGanttViewItem* KDGanttViewItem::find( const TQString& name )
 {
-    if (name.isEmpty()) // avoid error msg from QDict
+    if (name.isEmpty()) // avoid error msg from TQDict
         return 0;
     return sItemDict.find( name );
 }
@@ -451,7 +451,7 @@ bool KDGanttViewItem::editable() const
   Useful to get a so called "calendar view" with many items in one row.
   When \a displaySubitemsAsGroup() is set to true, this item has a normal view,
   when it is expanded. If it is not expanded (and has at least one child),
-  the item itself is hidden, and all children are displayed instead.
+  the item itself is hidden, and all tqchildren are displayed instead.
   To manage the painting priority of the childs (if overlapping),
   you may set \a priority() of these items.
 
@@ -735,7 +735,7 @@ TQString KDGanttViewItem::whatsThisText() const
 /*!
   Specifies whether this item should be shown highlighted. The user
   can also highlight items with the mouse.
-  If the item displays its subitems (children) as a group
+  If the item displays its subitems (tqchildren) as a group
   (displaySubitemsAsGroup() == true),
   all changes apply to all subitems as well.
 
@@ -773,16 +773,16 @@ bool KDGanttViewItem::highlight() const
 
 
 /*!
-  Specifies the shapes to be used for this item.
+  Specifies the tqshapes to be used for this item.
 
-  It is advisable not to use this method, but rather set the shapes
+  It is advisable not to use this method, but rather set the tqshapes
   for all items of a type with KDGanttView::setShapes() in order to
   get a uniform Gantt view.
 
-  \param start the start shape
-  \param middle the middle shape
-  \param end the end shape
-  \sa shapes(), setColors(), colors()
+  \param start the start tqshape
+  \param middle the middle tqshape
+  \param end the end tqshape
+  \sa tqshapes(), setColors(), colors()
 */
 void KDGanttViewItem::setShapes( Shape start, Shape middle, Shape end )
 {
@@ -799,20 +799,20 @@ void KDGanttViewItem::setShapes( Shape start, Shape middle, Shape end )
 
 
 /*!
-  Creates shapes of the specified type \a shape.
-  The background shape color is set to black and the background shape
-  is slightly bit bigger than the foreground shape to have a black border
-  around the foreground shape.
+  Creates tqshapes of the specified type \a tqshape.
+  The background tqshape color is set to black and the background tqshape
+  is slightly bit bigger than the foreground tqshape to have a black border
+  around the foreground tqshape.
 
-  \param itemShape the foreground shape
-  \param middle itemShapeBack  the background shape
-  \param shape the type of the shape
+  \param itemShape the foreground tqshape
+  \param middle itemShapeBack  the background tqshape
+  \param tqshape the type of the tqshape
    (may be TriangleDown, TriangleUp, Diamond, Square, Circle)
-  \sa shapes(), setColors(), colors()
+  \sa tqshapes(), setColors(), colors()
 */
 void KDGanttViewItem::createShape( KDCanvasPolygonItem* &itemShape,
                                    KDCanvasPolygonItem* &itemShapeBack,
-                                   Shape shape )
+                                   Shape tqshape )
 {
   if ( itemShape && type() ==  Task )
     return;
@@ -823,7 +823,7 @@ void KDGanttViewItem::createShape( KDCanvasPolygonItem* &itemShape,
     TQCanvasPolygonalItem * itemBack;
     int size = myItemSize+2;
     int hei = (myItemSize/3)/2;
-    switch (shape) {
+    switch (tqshape) {
     case TriangleDown:
         {
             item = new KDCanvasPolygon(myGanttView->myTimeTable, this,Type_is_KDGanttViewItem);
@@ -912,8 +912,8 @@ void KDGanttViewItem::createShape( KDCanvasPolygonItem* &itemShape,
             break;
         }
     default:
-        // Uninitialized shape, can e.g. be the case with free-busy
-        // items which don't have any shapes
+        // Uninitialized tqshape, can e.g. be the case with free-busy
+        // items which don't have any tqshapes
         return;
     }
     item->setBrush(Qt::SolidPattern);
@@ -927,14 +927,14 @@ void KDGanttViewItem::createShape( KDCanvasPolygonItem* &itemShape,
 
 
 /*!
-  Returns the shapes used for this item
+  Returns the tqshapes used for this item
 
-  \param start returns the start shape
-  \param middle returns the middle shape
-  \param end returns the end shape
+  \param start returns the start tqshape
+  \param middle returns the middle tqshape
+  \param end returns the end tqshape
   \sa setShapes(), setColors(), colors()
 */
-void KDGanttViewItem::shapes( Shape& start, Shape& middle, Shape& end ) const
+void KDGanttViewItem::tqshapes( Shape& start, Shape& middle, Shape& end ) const
 {
     start = myStartShape;
     middle = myMiddleShape;
@@ -943,16 +943,16 @@ void KDGanttViewItem::shapes( Shape& start, Shape& middle, Shape& end ) const
 
 
 /*!
-  Specifies the colors in which to draw the shapes of this item.
+  Specifies the colors in which to draw the tqshapes of this item.
 
   It is advisable not to use this method, but rather set the colors
   for all items of a type with KDGanttView::setColors() in order to
   get a uniform Gantt view.
 
-  \param start the color for the start shape
-  \param middle the color for the middle shape
-  \param end the color for the end shape
-  \sa colors(), setShapes(), shapes(), setDefaultColor(), defaultColor()
+  \param start the color for the start tqshape
+  \param middle the color for the middle tqshape
+  \param end the color for the end tqshape
+  \sa colors(), setShapes(), tqshapes(), setDefaultColor(), defaultColor()
 */
 void KDGanttViewItem::setColors( const TQColor& start, const TQColor& middle,
                                  const TQColor& end )
@@ -980,7 +980,7 @@ void KDGanttViewItem::setColors( const TQColor& start, const TQColor& middle,
   \param start returns the start color
   \param middle returns the middle color
   \param end returns the end color
-  \sa setColors(), setShapes(), shapes(), setDefaultColor(), defaultColor()
+  \sa setColors(), setShapes(), tqshapes(), setDefaultColor(), defaultColor()
 */
 void KDGanttViewItem::colors( TQColor& start, TQColor& middle, TQColor& end ) const
 {
@@ -992,21 +992,21 @@ void KDGanttViewItem::colors( TQColor& start, TQColor& middle, TQColor& end ) co
 
 
 /*!
-  Specifies the highlight colors in which to draw the shapes of this item.
+  Specifies the highlight colors in which to draw the tqshapes of this item.
 
   It is advisable not to use this method, but rather set the highlight
   colors for all items of a type with
   KDGanttView::setHighlightColors() in order to get a uniform Gantt
   view.
 
-  If the item displays its subitems (children) as a group,
+  If the item displays its subitems (tqchildren) as a group,
   (displaySubitemsAsGroup() == true)
   all changes apply to all subitems as well.
 
-  \param start the highlight color for the start shape
-  \param middle the highlight color for the middle shape
-  \param end the highlight color for the end shape
-  \sa highlightColors(), setShapes(), shapes()
+  \param start the highlight color for the start tqshape
+  \param middle the highlight color for the middle tqshape
+  \param end the highlight color for the end tqshape
+  \sa highlightColors(), setShapes(), tqshapes()
 */
 void KDGanttViewItem::setHighlightColors( const TQColor& start, const TQColor& middle, const TQColor& end )
 {
@@ -1032,7 +1032,7 @@ void KDGanttViewItem::setHighlightColors( const TQColor& start, const TQColor& m
   \param start returns the start highlight color
   \param middle returns the middle highlight color
   \param end returns the end highlight color
-  \sa setHighlightColors(), setShapes(), shapes()
+  \sa setHighlightColors(), setShapes(), tqshapes()
 */
 void KDGanttViewItem::highlightColors( TQColor& start, TQColor& middle, TQColor& end ) const
 {
@@ -1048,7 +1048,7 @@ void KDGanttViewItem::highlightColors( TQColor& start, TQColor& middle, TQColor&
   It is advisable not to use this method, but rather set the text color
   for all items with KDGanttView::setTextColor() in order to get a
   uniform Gantt view.
-  If the item displays its subitems (children) as a group,
+  If the item displays its subitems (tqchildren) as a group,
   (displaySubitemsAsGroup() == true)
   all changes apply to all subitems as well.
   \param color the text color
@@ -1086,7 +1086,7 @@ TQColor KDGanttViewItem::textColor() const
 /*!
   \enum KDGanttViewItem::Shape
 
-  This enum is used in order to specify the shapes of a Gantt chart
+  This enum is used in order to specify the tqshapes of a Gantt chart
   item.
 */
 
@@ -1140,7 +1140,7 @@ const TQPixmap* KDGanttViewItem::pixmap( int column ) const
   for all items of a type with KDGanttView::setDefaultColor() in order to
   get a uniform Gantt view.
 
-  If the item displays its subitems (children) as a group,
+  If the item displays its subitems (tqchildren) as a group,
   (displaySubitemsAsGroup() == true)
   all changes apply to all subitems as well.
 
@@ -1187,7 +1187,7 @@ TQColor KDGanttViewItem::defaultColor() const
   for all items of a type with KDGanttView::setDefaultHighlightColor()
   in order to get a uniform Gantt view.
 
-  If the item displays its subitems (children) as a group,
+  If the item displays its subitems (tqchildren) as a group,
   (displaySubitemsAsGroup() == true)
   all changes apply to all subitems as well.
 
@@ -1226,7 +1226,7 @@ TQColor KDGanttViewItem::defaultHighlightColor() const
 /*!
   Returns the first child of this item.
 
-  \return the first child of this item, 0 if this item has no children
+  \return the first child of this item, 0 if this item has no tqchildren
 */
 KDGanttViewItem* KDGanttViewItem::firstChild() const
 {
@@ -1338,7 +1338,7 @@ void KDGanttViewItem::updateCanvasItems()
         endLine->setPen(p);
       }
     } else {
-      //TQColor discol = Qt::lightGray;
+      //TQColor discol = TQt::lightGray;
         TQColor discol = TQColor(232,232,232);
 	textCanvas->setColor( TQColor(150,150,150) );
         b.setStyle(Qt::SolidPattern);
@@ -1458,7 +1458,7 @@ void KDGanttViewItem::initColorAndShapes(Type t)
     startLineBack->setZ(1);endLineBack->setZ(1);
     actualEnd = new KDCanvasLine(myGanttView->myTimeTable,this,Type_is_KDGanttViewItem);
     actualEnd->setZ(5);
-    actualEnd->setPen( TQPen ( Qt::red, 3 ) );
+    actualEnd->setPen( TQPen ( TQt::red, 3 ) );
 
     textCanvas = new KDCanvasText(myGanttView->myTimeTable,this,Type_is_KDGanttViewItem);
     textCanvas->setText("");
@@ -1469,10 +1469,10 @@ void KDGanttViewItem::initColorAndShapes(Type t)
     setDefaultColor( myGanttView->defaultColor(myType));
     // set default highlight color
     setDefaultHighlightColor(myGanttView->defaultHighlightColor(myType));
-    // set shapes
-    if (!( shapeDefined = (myGanttView->shapes(myType,myStartShape,myMiddleShape,myEndShape)))) {
+    // set tqshapes
+    if (!( tqshapeDefined = (myGanttView->tqshapes(myType,myStartShape,myMiddleShape,myEndShape)))) {
 
-        //qDebug("KDGantt::KDGanttViewItem created with not user defined shapes");
+        //qDebug("KDGantt::KDGanttViewItem created with not user defined tqshapes");
     };
 
     setShapes(myStartShape,myMiddleShape,myEndShape);
@@ -1486,12 +1486,12 @@ void KDGanttViewItem::initColorAndShapes(Type t)
     floatStartShape = (KDCanvasPolygonItem*)new  KDCanvasRectangle(myGanttView->myTimeTable,this,Type_is_KDGanttViewItem);
     floatEndShape = (KDCanvasPolygonItem*)new  KDCanvasRectangle(myGanttView->myTimeTable,this,Type_is_KDGanttViewItem);
 
-    // set color of shapes
+    // set color of tqshapes
     if (!( colorDefined = (myGanttView->colors(myType,myStartColor,myMiddleColor,myEndColor)))) {
 
     };
     setColors(defaultColor(),defaultColor(), defaultColor());
-    // set highlight color of shapes
+    // set highlight color of tqshapes
     if (!( colorHLDefined = (myGanttView->highlightColors(myType,myStartColorHL,myMiddleColorHL,myEndColorHL)))) {
 
     };
@@ -1508,9 +1508,9 @@ void KDGanttViewItem::initColorAndShapes(Type t)
 }
 
 
-TQString KDGanttViewItem::shapeToString( Shape shape )
+TQString KDGanttViewItem::tqshapeToString( Shape tqshape )
 {
-    switch( shape ) {
+    switch( tqshape ) {
     case TriangleDown:
         return "TriangleDown";
     case TriangleUp:
@@ -1571,13 +1571,13 @@ void KDGanttViewItem::createNode( TQDomDocument& doc,
     KDGanttXML::createBoolNode( doc, itemElement, "Open", isOpen() );
     KDGanttXML::createBoolNode( doc, itemElement, "Highlight", highlight() );
     Shape startShape, middleShape, endShape;
-    shapes( startShape, middleShape, endShape );
+    tqshapes( startShape, middleShape, endShape );
     KDGanttXML::createStringNode( doc, itemElement, "StartShape",
-                             shapeToString( startShape ) );
+                             tqshapeToString( startShape ) );
     KDGanttXML::createStringNode( doc, itemElement, "MiddleShape",
-                             shapeToString( middleShape ) );
+                             tqshapeToString( middleShape ) );
     KDGanttXML::createStringNode( doc, itemElement, "EndShape",
-                             shapeToString( endShape ) );
+                             tqshapeToString( endShape ) );
     KDGanttXML::createColorNode( doc, itemElement, "DefaultColor", defaultColor() );
     TQColor startColor, middleColor, endColor;
     colors( startColor, middleColor, endColor );
@@ -1944,9 +1944,9 @@ void KDGanttViewItem::showSubitemTree( int CoordY )
 
 
 /*!
-  Returns the start time of the children of this item.
+  Returns the start time of the tqchildren of this item.
 
-  \return the start time of the children of this item
+  \return the start time of the tqchildren of this item
 */
 TQDateTime KDGanttViewItem::myChildStartTime()
 {
@@ -1978,9 +1978,9 @@ TQDateTime KDGanttViewItem::myChildStartTime()
 
 
 /*!
-  Returns the end time of the children of this item.
+  Returns the end time of the tqchildren of this item.
 
-  \return the end time of the children of this item
+  \return the end time of the tqchildren of this item
 */
 TQDateTime KDGanttViewItem::myChildEndTime()
 {
@@ -2030,7 +2030,7 @@ bool KDGanttViewItem::showNoInformation()
   The height of the line is the height of the item.
   The brush of the line is specified by KDGanttView::setNoInformationBrush().
   (i.e. the same brush for all items of the Gantt view).
-  The default brush is TQBrush(  TQColor ( 100,100,100 ), Qt::FDiagPattern );
+  The default brush is TQBrush(  TQColor ( 100,100,100 ), TQt::FDiagPattern );
   \param show if true, the 'showNoInformation' line  is shown for this item
   \sa  showNoInformation(), KDGanttView::setNoInformationBrush(), KDGanttView::noInformationBrush()
 */
@@ -2044,7 +2044,7 @@ void KDGanttViewItem::setShowNoInformation( bool show )
 /*!
   If the name of this item is \a name (i.e., listViewText() == name),
   the pointer to this item is returned.  Otherwise, it looks for an
-  item with name \a name in the set of children and subchildren of
+  item with name \a name in the set of tqchildren and subtqchildren of
   this item.
   \param  name the name of the item
   \return the pointer to the item with name \a name
@@ -2365,37 +2365,37 @@ bool KDGanttViewItem::isCalendar( ) const
 /*!
   \var KDGanttViewItem::startShape
 
-  the shape at the beginning of the item
+  the tqshape at the beginning of the item
 */
 
 /*!
   \var KDGanttViewItem::midShape
 
-  the shape in the middle of the item
+  the tqshape in the middle of the item
 */
 
 /*!
   \var KDGanttViewItem::endShape
 
-  the shape at the end of the item
+  the tqshape at the end of the item
 */
 
 /*!
   \var KDGanttViewItem::startShapeBack
 
-  the background shape at the beginning of the item
+  the background tqshape at the beginning of the item
 */
 
 /*!
   \var KDGanttViewItem::midShapeBack
 
-  the background shape in the middle of the item
+  the background tqshape in the middle of the item
 */
 
 /*!
   \var KDGanttViewItem::endShapeBack
 
-  the background shape at the end of the item
+  the background tqshape at the end of the item
 */
 
 
@@ -2524,8 +2524,8 @@ bool KDGanttViewItem::isMyTextCanvas(TQCanvasItem *tc)
 
 void KDGanttViewItem::setProgress(int percent)
 {
-    myProgress = QMAX(0, percent);
-    myProgress = QMIN(100, myProgress);
+    myProgress = TQMAX(0, percent);
+    myProgress = TQMIN(100, myProgress);
 }
 
 /*!
