@@ -1,5 +1,5 @@
 /* -*- Mode: C++ -*-
-   $Id: KDGanttViewSubwidgets.h 1157655 2010-07-31 19:53:50Z tpearson $
+   $Id: KDGanttViewSubwidgets.h 1246260 2011-08-10 22:19:39Z tpearson $
    KDGantt - a multi-platform charting engine
 */
 
@@ -27,8 +27,8 @@
  ** licensing are not clear to you.
  **
  ** As a special exception, permission is given to link this program
- ** with any edition of Qt, and distribute the resulting executable,
- ** without including the source code for Qt in the source distribution.
+ ** with any edition of TQt, and distribute the resulting executable,
+ ** without including the source code for TQt in the source distribution.
  **
  **********************************************************************/
 
@@ -73,9 +73,10 @@ class KDToolTip;
 class KDCanvasRectangle;
 class KDTimeHeaderToolTip;
 
-class KDTimeHeaderWidget : public QWidget
+class KDTimeHeaderWidget : public TQWidget
 {
    Q_OBJECT
+  TQ_OBJECT
 
 public:
    typedef KDGanttView::Scale Scale;
@@ -250,9 +251,10 @@ private:
 /* KDTimeTableWidget */
 class KDListView ;
 
-class KDTimeTableWidget : public QCanvas
+class KDTimeTableWidget : public TQCanvas
 {
    Q_OBJECT
+  TQ_OBJECT
 
 public:
    KDTimeTableWidget (TQWidget* parent,KDGanttView* my);
@@ -329,12 +331,13 @@ private:
 class KDLegendWidget : public KDGanttSemiSizingControl
 {
    Q_OBJECT
+  TQ_OBJECT
 
 public:
   KDLegendWidget ( TQWidget* parent, KDGanttMinimizeSplitter* legendParent );
   void showMe(bool);
   bool isShown();
-  void addLegendItem( KDGanttViewItem::Shape shape, const TQColor& shapeColor, const TQString& text );
+  void addLegendItem( KDGanttViewItem::Shape tqshape, const TQColor& tqshapeColor, const TQString& text );
   void clearLegend();
   void setFont( TQFont );
   void drawToPainter( TQPainter *p );
@@ -352,9 +355,10 @@ public:
 };
 
 class KDGanttView;
-class KDListView : public QListView
+class KDListView : public TQListView
 {
    Q_OBJECT
+  TQ_OBJECT
 
 public:
    KDListView (TQWidget* parent,KDGanttView* gv );
@@ -396,7 +400,7 @@ private slots:
 };
 
 
-class KDCanvasText : public QCanvasText
+class KDCanvasText : public TQCanvasText
 {
 public:
     KDCanvasText( KDTimeTableWidget* canvas, void* parentItem, int type );
@@ -405,7 +409,7 @@ public:
 };
 
 
-class KDCanvasLine : public QCanvasLine
+class KDCanvasLine : public TQCanvasLine
 {
 public:
     KDCanvasLine( KDTimeTableWidget* canvas, void* parentItem, int type );
@@ -414,7 +418,7 @@ public:
 };
 
 
-class KDCanvasPolygonItem: public QCanvasPolygonalItem
+class KDCanvasPolygonItem: public TQCanvasPolygonalItem
 {
 public:
     KDCanvasPolygonItem( KDTimeTableWidget* canvas, void* parentItem,
@@ -424,7 +428,7 @@ public:
 };
 
 
-class KDCanvasPolygon: public QCanvasPolygon
+class KDCanvasPolygon: public TQCanvasPolygon
 {
 public:
     KDCanvasPolygon( KDTimeTableWidget* canvas, void* parentItem, int type );
@@ -433,7 +437,7 @@ public:
 };
 
 
-class KDCanvasEllipse: public QCanvasEllipse
+class KDCanvasEllipse: public TQCanvasEllipse
 {
 public:
     KDCanvasEllipse( KDTimeTableWidget* canvas, void* parentItem, int type );
@@ -442,7 +446,7 @@ public:
 };
 
 
-class KDCanvasRectangle: public QCanvasRectangle
+class KDCanvasRectangle: public TQCanvasRectangle
 {
 public:
     KDCanvasRectangle( KDTimeTableWidget* canvas, void* parentItem, int type );
@@ -467,7 +471,7 @@ public:
   enum HitTest { Start, Middle, End };
   HitTest hitTest( KDTimeHeaderWidget* timeHeader, const TQPoint& pos ) const;
 
-  void layout( KDTimeHeaderWidget* timeHeader, int height );
+  void tqlayout( KDTimeHeaderWidget* timeHeader, int height );
 
   static const int RTTI = 0x0c58;
   /*reimp*/ int rtti() const { return RTTI; }
@@ -480,9 +484,10 @@ private:
 
 class KDCanvasToolTip;
 
-class KDGanttCanvasView : public QCanvasView
+class KDGanttCanvasView : public TQCanvasView
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     KDGanttCanvasView(KDGanttView* sender, TQCanvas* canvas = 0, TQWidget* parent = 0, const char* name = 0 );
@@ -559,7 +564,7 @@ private:
   TQTimer scrollBarTimer;
 };
 
-class KDTimeHeaderToolTip :public QToolTip
+class KDTimeHeaderToolTip :public TQToolTip
 {
 
 public:
@@ -585,7 +590,7 @@ private:
   KDTimeHeaderWidget * _header;
 };
 
-class KDCanvasToolTip :public QToolTip
+class KDCanvasToolTip :public TQToolTip
 {
 
 public:
@@ -611,7 +616,7 @@ private:
   KDGanttCanvasView * _canview;
 };
 
-class KDCanvasWhatsThis :public QWhatsThis
+class KDCanvasWhatsThis :public TQWhatsThis
 {
 public:
   KDCanvasWhatsThis( TQWidget *wid, KDGanttCanvasView* canview ) : TQWhatsThis( wid ), _wid(wid),_canview (canview) { };
@@ -626,7 +631,7 @@ private:
   KDGanttCanvasView * _canview;
 };
 
-class KDListViewWhatsThis :public QWhatsThis
+class KDListViewWhatsThis :public TQWhatsThis
 {
 public:
   KDListViewWhatsThis( TQWidget *wid, KDListView* view ) : TQWhatsThis( wid ), _wid(wid),_view (view) { };
