@@ -104,14 +104,14 @@ static KCmdLineOptions options[] =
 // this class hooks into the eventloop and outputs the id
 // of shown dialogs or makes the dialog transient for other winids.
 // Will destroy itself on app exit.
-class WinIdEmbedder: public QObject
+class WinIdEmbedder: public TQObject
 {
 public:
     WinIdEmbedder(bool printID, WId winId):
-        TQObject(qApp), print(printID), id(winId)
+        TQObject(tqApp), print(printID), id(winId)
     {
-        if (qApp)
-            qApp->installEventFilter(this);
+        if (tqApp)
+            tqApp->installEventFilter(this);
     }
 protected:
     bool eventFilter(TQObject *o, TQEvent *e);
@@ -125,7 +125,7 @@ bool WinIdEmbedder::eventFilter(TQObject *o, TQEvent *e)
     if (e->type() == TQEvent::Show && o->isWidgetType()
         && o->inherits("KDialog"))
     {
-        TQWidget *w = static_cast<TQWidget*>(o);
+        TQWidget *w = TQT_TQWIDGET(o);
         if (print)
             cout << "winId: " << w->winId() << endl;
 #ifdef Q_WS_X11
@@ -241,9 +241,9 @@ static int directCommand(KCmdLineArgs *args)
 
         TQString text = TQString::fromLocal8Bit(args->getOption( option ));
         int pos;
-        while ((pos = text.find( TQString::fromLatin1("\\n") )) >= 0)
+        while ((pos = text.find( TQString::tqfromLatin1("\\n") )) >= 0)
         {
-            text.replace(pos, 2, TQString::fromLatin1("\n"));
+            text.replace(pos, 2, TQString::tqfromLatin1("\n"));
         }
 
         if ( type == KMessageBox::WarningContinueCancel ) {
@@ -492,7 +492,7 @@ static int directCommand(KCmdLineArgs *args)
             filter = TQString::fromLocal8Bit(args->arg(0));
         }
 	// copied from KFileDialog::getSaveFileName(), so we can add geometry
-	bool specialDir = ( startDir.at(0) == ':' );
+	bool specialDir = ( startDir.tqat(0) == ':' );
 	KFileDialog dlg( specialDir ? startDir : TQString::null, filter, 0, "filedialog", true );
 	if ( !specialDir )
 	    dlg.setSelection( startDir );
@@ -597,43 +597,43 @@ static int directCommand(KCmdLineArgs *args)
             contextStr = TQString::fromLocal8Bit(args->arg(0));
         }
         KIcon::Group group = KIcon::NoGroup;
-        if ( groupStr == TQString::fromLatin1( "Desktop" ) )
+        if ( groupStr == TQString::tqfromLatin1( "Desktop" ) )
             group = KIcon::Desktop;
-        else if ( groupStr == TQString::fromLatin1( "Toolbar" ) )
+        else if ( groupStr == TQString::tqfromLatin1( "Toolbar" ) )
             group = KIcon::Toolbar;
-        else if ( groupStr == TQString::fromLatin1( "MainToolbar" ) )
+        else if ( groupStr == TQString::tqfromLatin1( "MainToolbar" ) )
             group = KIcon::MainToolbar;
-        else if ( groupStr == TQString::fromLatin1( "Small" ) )
+        else if ( groupStr == TQString::tqfromLatin1( "Small" ) )
             group = KIcon::Small;
-        else if ( groupStr == TQString::fromLatin1( "Panel" ) )
+        else if ( groupStr == TQString::tqfromLatin1( "Panel" ) )
             group = KIcon::Panel;
-        else if ( groupStr == TQString::fromLatin1( "User" ) )
+        else if ( groupStr == TQString::tqfromLatin1( "User" ) )
             group = KIcon::User;
         KIcon::Context context = KIcon::Any;
         // From kicontheme.cpp
-        if ( contextStr == TQString::fromLatin1( "Devices" ) )
+        if ( contextStr == TQString::tqfromLatin1( "Devices" ) )
             context = KIcon::Device;
-        else if ( contextStr == TQString::fromLatin1( "MimeTypes" ) )
+        else if ( contextStr == TQString::tqfromLatin1( "MimeTypes" ) )
             context = KIcon::MimeType;
-        else if ( contextStr == TQString::fromLatin1( "FileSystems" ) )
+        else if ( contextStr == TQString::tqfromLatin1( "FileSystems" ) )
             context = KIcon::FileSystem;
-        else if ( contextStr == TQString::fromLatin1( "Applications" ) )
+        else if ( contextStr == TQString::tqfromLatin1( "Applications" ) )
             context = KIcon::Application;
-        else if ( contextStr == TQString::fromLatin1( "Actions" ) )
+        else if ( contextStr == TQString::tqfromLatin1( "Actions" ) )
             context = KIcon::Action;
-        else if ( contextStr == QString::fromLatin1( "Animations" ) )
+        else if ( contextStr == TQString::tqfromLatin1( "Animations" ) )
             context = KIcon::Animation;
-        else if ( contextStr == QString::fromLatin1( "Categories" ) )
+        else if ( contextStr == TQString::tqfromLatin1( "Categories" ) )
             context = KIcon::Category;
-        else if ( contextStr == QString::fromLatin1( "Emblems" ) )
+        else if ( contextStr == TQString::tqfromLatin1( "Emblems" ) )
             context = KIcon::Emblem;
-        else if ( contextStr == QString::fromLatin1( "Emotes" ) )
+        else if ( contextStr == TQString::tqfromLatin1( "Emotes" ) )
             context = KIcon::Emote;
-        else if ( contextStr == QString::fromLatin1( "International" ) )
+        else if ( contextStr == TQString::tqfromLatin1( "International" ) )
             context = KIcon::International;
-        else if ( contextStr == QString::fromLatin1( "Places" ) )
+        else if ( contextStr == TQString::tqfromLatin1( "Places" ) )
             context = KIcon::Place;
-        else if ( contextStr == QString::fromLatin1( "Status" ) )
+        else if ( contextStr == TQString::tqfromLatin1( "Status" ) )
             context = KIcon::StatusIcon;
 
 	KIconDialog dlg(0, "icon dialog");
