@@ -104,7 +104,7 @@ void GlobalData::read()
   f_onts[Fheadings]=config->readFontEntry("headingsFont",&defFont);
   f_ontNames[Fheadings]=i18n("Headings");
 
-  // geometry...
+  // tqgeometry...
   config->setGroup("Geometry");
   TQSize invalid(-1,-1);
   optSize = config->readSizeEntry("Opt_Size",&invalid);
@@ -425,7 +425,7 @@ void OptionsDialog::ColorListItem::paint( TQPainter *p )
 
   p->drawText( 30+3*2, fm.ascent() + fm.leading()/2, text() );
 
-  p->setPen( Qt::black );
+  p->setPen( TQt::black );
   p->drawRect( 3, 1, 30, h-1 );
   p->fillRect( 4, 2, 28, h-3, mColor );
 }
@@ -449,7 +449,7 @@ int OptionsDialog::ColorListItem::width(const TQListBox *lb ) const
 OptionsDialog::FontListItem::FontListItem( const TQString &name, const TQFont &font )
   : TQListBoxText(name), f_ont(font)
 {
-  fontInfo = TQString("[%1 %2]").arg(f_ont.family()).arg(f_ont.pointSize());
+  fontInfo = TQString("[%1 %2]").tqarg(f_ont.family()).tqarg(f_ont.pointSize());
 }
 
 
@@ -461,7 +461,7 @@ OptionsDialog::FontListItem::~FontListItem()
 void OptionsDialog::FontListItem::setFont(const TQFont &font)
 {
   f_ont = font;
-  fontInfo = TQString("[%1 %2]").arg(f_ont.family()).arg(f_ont.pointSize());
+  fontInfo = TQString("[%1 %2]").tqarg(f_ont.family()).tqarg(f_ont.pointSize());
 }
 
 
@@ -869,7 +869,7 @@ void OptionsDialog::slotColDefaultBtnClicked()
     colorItem->setColor(global->defaultColor(i));
   }
   c_List->triggerUpdate(true);
-  c_List->repaint(true);
+  c_List->tqrepaint(true);
 }
 
 
