@@ -74,7 +74,7 @@ TQFile* SaveHelper::getFile(const TQString &dialogTitle)
   if (url.isLocalFile()) {
     if (TQFileInfo(url.path()).exists() &&
         (KMessageBox::warningContinueCancel(global->topLevel,
-                                            i18n("A file named %1 already exists.\nDo you want to replace it?").arg(url.path()),
+                                            i18n("A file named %1 already exists.\nDo you want to replace it?").tqarg(url.path()),
                                             dialogTitle, i18n("&Replace")) != KMessageBox::Continue)) {
       return 0;
     }
@@ -120,7 +120,7 @@ DictHTMLPart::~DictHTMLPart()
 
 void DictHTMLPart::khtmlMouseReleaseEvent(khtml::MouseReleaseEvent *event)
 {
-  if (event->qmouseEvent()->button()==MidButton)
+  if (event->qmouseEvent()->button()==Qt::MidButton)
     emit(middleButtonClicked());
   else
     KHTMLPart::khtmlMouseReleaseEvent(event);
@@ -140,7 +140,7 @@ QueryView::QueryView(TQWidget *_parent)
   part->setJScriptEnabled(false);
   part->setJavaEnabled(false);
   part->setURLCursor(KCursor::handCursor());
-  setFocusPolicy(TQWidget::NoFocus);
+  setFocusPolicy(TQ_NoFocus);
   connect(part, TQT_SIGNAL(completed()), TQT_SLOT(partCompleted()));
   connect(part, TQT_SIGNAL(middleButtonClicked()), TQT_SLOT(middleButtonClicked()));
   rightBtnMenu = new KPopupMenu(this);
@@ -184,11 +184,11 @@ void QueryView::optionsChanged()
   saveCurrentResultPos();
 
   currentHTMLHeader = TQString("<html><head><style type=\"text/css\">\n");
-  currentHTMLHeader += TQString("body { background-color:%1; color:%2; }\n").arg(global->backgroundColor().name()).arg(global->textColor().name());
-  currentHTMLHeader += TQString("a:link, a:active { color:%1; text-decoration:none; }\n").arg(global->linksColor().name());
-  currentHTMLHeader += TQString("a:visited { color:%1; text-decoration:none; }\n").arg(global->visitedLinksColor().name());
-  currentHTMLHeader += TQString("a:hover { color:%1; text-decoration:underline; }\n").arg(global->linksColor().name());
-  currentHTMLHeader += TQString("p.heading {  margin-left:0mm; margin-top:2mm; margin-bottom:2mm; padding:1mm; background-color:%1; color:%2; font-family:%3; font-size:%4pt; ").arg(global->headingsBackgroundColor().name()).arg(global->headingsTextColor().name()).arg(global->headingsFont().family()).arg(global->headingsFont().pointSize());
+  currentHTMLHeader += TQString("body { background-color:%1; color:%2; }\n").tqarg(global->backgroundColor().name()).tqarg(global->textColor().name());
+  currentHTMLHeader += TQString("a:link, a:active { color:%1; text-decoration:none; }\n").tqarg(global->linksColor().name());
+  currentHTMLHeader += TQString("a:visited { color:%1; text-decoration:none; }\n").tqarg(global->visitedLinksColor().name());
+  currentHTMLHeader += TQString("a:hover { color:%1; text-decoration:underline; }\n").tqarg(global->linksColor().name());
+  currentHTMLHeader += TQString("p.heading {  margin-left:0mm; margin-top:2mm; margin-bottom:2mm; padding:1mm; background-color:%1; color:%2; font-family:%3; font-size:%4pt; ").tqarg(global->headingsBackgroundColor().name()).tqarg(global->headingsTextColor().name()).tqarg(global->headingsFont().family()).tqarg(global->headingsFont().pointSize());
   if (global->headingsFont().italic())
     currentHTMLHeader += TQString("font-style:italic; ");
   if (global->headingsFont().bold())
@@ -196,7 +196,7 @@ void QueryView::optionsChanged()
   currentHTMLHeader += TQString("}\n");
   currentHTMLHeader += TQString("p.definition { margin-left:1.5mm; margin-top:2mm; margin-bottom:2mm;}\n");
   currentHTMLHeader += TQString("table { margin-left:1.5mm; margin-top:2mm; margin-bottom:2mm;}\n");
-  currentHTMLHeader += TQString("pre { font-family:%1; font-size:%2pt; ").arg(global->textFont().family()).arg(global->textFont().pointSize());
+  currentHTMLHeader += TQString("pre { font-family:%1; font-size:%2pt; ").tqarg(global->textFont().family()).tqarg(global->textFont().pointSize());
   if (global->textFont().italic())
     currentHTMLHeader += TQString("font-style:italic; ");
   if (global->textFont().bold())
@@ -233,7 +233,7 @@ void QueryView::saveQuery()
     TQString fName = brw->queryText+".html";
     fName.replace(TQRegExp("[\\s/]"),"_");
     SaveHelper helper(fName,"*.html",global->topLevel);
-    TQFile *file = helper.getFile(TQString::null);
+    TQFile *file = helper.getFile(TQString());
 
     if (file) {
       TQTextStream stream(file);
@@ -276,7 +276,7 @@ void QueryView::selectAll()
 
 void QueryView::copySelection()
 {
-  kapp->clipboard()->setText(part->selectedText());
+  kapp->tqclipboard()->setText(part->selectedText());
 }
 
 
@@ -441,14 +441,14 @@ void QueryView::buildPopupMenu(const TQString &url, const TQPoint &point)
                              this,TQT_SLOT(popupMatchSelect()));
     rightBtnMenu->insertSeparator();
   } else {
-    kapp->clipboard()->setSelectionMode(false);
-    TQString text = kapp->clipboard()->text();
+    kapp->tqclipboard()->setSelectionMode(false);
+    TQString text = kapp->tqclipboard()->text();
     if (text.isEmpty()) {
-      kapp->clipboard()->setSelectionMode(true);
-      text = kapp->clipboard()->text();
+      kapp->tqclipboard()->setSelectionMode(true);
+      text = kapp->tqclipboard()->text();
     }
     if (!text.isEmpty()) {
-      popupSelect = TQApplication::clipboard()->text();
+      popupSelect = TQApplication::tqclipboard()->text();
       rightBtnMenu->insertItem(SmallIcon("define_clip"),
                                i18n("&Define Clipboard Content"),
                                this,TQT_SLOT(popupDefineSelect()));
@@ -467,7 +467,7 @@ void QueryView::buildPopupMenu(const TQString &url, const TQPoint &point)
                                this,TQT_SLOT(browseBack()));
     else
       rightBtnMenu->insertItem(SmallIcon("back"),
-                               i18n("&Back: '%1'").arg(getShortString(browseList.at(browsePos-1)->queryText,25)),
+                               i18n("&Back: '%1'").tqarg(getShortString(browseList.at(browsePos-1)->queryText,25)),
                                this,TQT_SLOT(browseBack()));
   } else {
     ID = rightBtnMenu->insertItem(SmallIcon("back"), i18n("&Back"), this, TQT_SLOT(browseBack()));
@@ -481,7 +481,7 @@ void QueryView::buildPopupMenu(const TQString &url, const TQPoint &point)
                                this,TQT_SLOT(browseForward()));
     else
       rightBtnMenu->insertItem(SmallIcon("forward"),
-                               i18n("&Forward: '%1'").arg(getShortString(browseList.at(browsePos+1)->queryText,25)),
+                               i18n("&Forward: '%1'").tqarg(getShortString(browseList.at(browsePos+1)->queryText,25)),
                                this,TQT_SLOT(browseForward()));
   } else {
     ID = rightBtnMenu->insertItem(SmallIcon("forward"),i18n("&Forward"),this,TQT_SLOT(browseForward()));
@@ -569,7 +569,7 @@ void QueryView::updateBrowseActions()
     if (browseList.at(browsePos-1)->queryText.isEmpty())
       actBack->setText(i18n("&Back: Information"));
     else
-      actBack->setText(i18n("&Back: '%1'").arg(getShortString(browseList.at(browsePos-1)->queryText,25)));
+      actBack->setText(i18n("&Back: '%1'").tqarg(getShortString(browseList.at(browsePos-1)->queryText,25)));
 
     actBack->popupMenu()->clear();
     int i = browsePos-1;
@@ -593,7 +593,7 @@ void QueryView::updateBrowseActions()
     if (browseList.at(browsePos+1)->queryText.isEmpty())
       actForward->setText(i18n("&Forward: Information"));
     else
-      actForward->setText(i18n("&Forward: '%1'").arg(getShortString(browseList.at(browsePos+1)->queryText,25)));
+      actForward->setText(i18n("&Forward: '%1'").tqarg(getShortString(browseList.at(browsePos+1)->queryText,25)));
 
     actForward->popupMenu()->clear();
     int i = browsePos+1;
