@@ -13,13 +13,14 @@
 
 #include <tqframe.h>
 
-class myPopup : public QFrame
+class myPopup : public TQFrame
 {
 Q_OBJECT
+  TQ_OBJECT
 	friend class popupManager;
 	
 	private:
-		myPopup(TQWidget *parent, const TQString &text, const TQString &text2 = TQString::null, const TQString &flagFile = TQString::null);
+		myPopup(TQWidget *parent, const TQString &text, const TQString &text2 = TQString(), const TQString &flagFile = TQString());
 	
 	signals:
 		void deleteMe();
