@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: kget_iface.h 1157648 2010-07-31 19:48:06Z tpearson $
+** $Id: kget_iface.h 1237912 2011-06-22 00:30:31Z tpearson $
 **
 ** Copyright (C) 2002 Carsten Pfeiffer <pfeiffer@kde.org>
 **
@@ -21,9 +21,9 @@ protected:
 k_dcop:
     /**
      * @param src The urls to download
-     * @param destDir The destination direction or TQString::null if unspecified
+     * @param destDir The destination direction or TQString() if unspecified
      */
-    virtual ASYNC addTransfers( const KURL::List& src, const TQString& destDir = TQString::null ) = 0;
+    virtual ASYNC addTransfers( const KURL::List& src, const TQString& destDir = TQString() ) = 0;
     
     virtual bool isDropTargetVisible() const = 0;
     
