@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: kget_linkview.h 1157648 2010-07-31 19:48:06Z tpearson $
+** $Id: kget_linkview.h 1246260 2011-08-10 22:19:39Z tpearson $
 **
 ** Copyright (C) 2002 Carsten Pfeiffer <pfeiffer@kde.org>
 **
@@ -16,7 +16,7 @@
 
 #include "links.h"
 
-class LinkViewItem : public QListViewItem
+class LinkViewItem : public TQListViewItem
 {
 public:
     LinkViewItem( TQListView *parent, const LinkItem * lnk );
@@ -27,6 +27,7 @@ public:
 class KGetLinkView : public KMainWindow
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     KGetLinkView( TQWidget *parent = 0L, const char *name = 0L );
