@@ -24,17 +24,17 @@ LinkItem::LinkItem( DOM::Element link )
     
 
     // somehow getElementsByTagName("#text") doesn't work :(
-    DOM::NodeList children = link.childNodes();
-    for ( uint i = 0; i < children.length(); i++ )
+    DOM::NodeList tqchildren = link.childNodes();
+    for ( uint i = 0; i < tqchildren.length(); i++ )
     {
-        DOM::Node node = children.item( i );
+        DOM::Node node = tqchildren.item( i );
         if ( node.nodeType() == DOM::Node::TEXT_NODE )
             text.append( node.nodeValue().string() );
     }
 
     // force "local file" mimetype determination
     KMimeType::Ptr mt = KMimeType::findByURL( url, 0, true, true);
-    icon = mt->icon( TQString::null, false ); // dummy parameters
+    icon = mt->icon( TQString(), false ); // dummy parameters
     mimeType = mt->comment();
     
     m_valid = true;
