@@ -84,7 +84,7 @@ KGrSLDialog::KGrSLDialog (int action, int requestedLevel, int collnIndex,
 
     if ((action == SL_START) || (action == SL_UPD_GAME)) {
 	dad->	setCaption (i18n("Select Game"));
-	TQLabel * startMsg = new QLabel
+	TQLabel * startMsg = new TQLabel
 	    ("<b>" + i18n("Level 1 of the selected game is:") + "</b>", dad);
 	mainLayout->addWidget (startMsg);
     }
@@ -99,7 +99,7 @@ KGrSLDialog::KGrSLDialog (int action, int requestedLevel, int collnIndex,
 
     // Initial range 1->150, small step 1, big step 10 and default value 1.
     number    = new TQScrollBar (1, 150, 1, 10, 1,
-				  TQScrollBar::Horizontal, dad);
+				  Qt::Horizontal, dad);
     grid->addWidget (number, 1, 1);
 
     TQHBox * numberPair = new TQHBox (dad);
@@ -125,14 +125,14 @@ KGrSLDialog::KGrSLDialog (int action, int requestedLevel, int collnIndex,
     TQHBox * buttons = new TQHBox (this);
     mainLayout->addWidget (buttons);
     buttons->setSpacing (spacing);
-    // Buttons are for Qt-only portability.  NOT COMPILED in KDE environment.
+    // Buttons are for TQt-only portability.  NOT COMPILED in KDE environment.
     HELP      = new TQPushButton (i18n("Help"), buttons);
     OK        = new TQPushButton (i18n("&OK"), buttons);
     CANCEL    = new TQPushButton (i18n("&Cancel"), buttons);
 
     TQPoint p  = parent->mapToGlobal (TQPoint (0,0));
 
-    // Base the geometry of the dialog box on the playing area.
+    // Base the tqgeometry of the dialog box on the playing area.
     int cell = parent->width() / (FIELDWIDTH + 4);
     dad->	move (p.x()+2*cell, p.y()+2*cell);
     dad->	setMinimumSize ((FIELDWIDTH*cell/2), (FIELDHEIGHT-1)*cell);
@@ -357,7 +357,7 @@ void KGrSLDialog::slAboutColln ()
 {
     // User clicked the "About" button ...
     int		n = slCollnIndex;
-    QString	title = i18n("About \"%1\"").arg(collections.at(n)->name);
+    TQString	title = i18n("About \"%1\"").tqarg(collections.at(n)->name);
 
     if (collections.at(n)->about.length() > 0) {
 	// Convert game description to ASCII and UTF-8 codes, then translate it.
@@ -401,10 +401,10 @@ void KGrSLDialog::slPaintLevel ()
     if (n < 0) {
 	return;					// Owner has no collections.
     }
-    QString	filePath = game->getFilePath
+    TQString	filePath = game->getFilePath
 		(collections.at(n)->owner, collections.at(n), number->value());
     thumbNail->setFilePath (filePath, slName);
-    thumbNail->repaint();			// Will call "drawContents (p)".
+    thumbNail->tqrepaint();			// Will call "drawContents (p)".
 }
 
 void KGrSLDialog::slotHelp ()
@@ -530,21 +530,21 @@ KGrNHDialog::KGrNHDialog(const TQString & levelName, const TQString & levelHint,
     TQHBox * buttons = new TQHBox (dad);
     mainLayout->addWidget (buttons);
     buttons->setSpacing (spacing);
-    // Buttons are for Qt-only portability.  NOT COMPILED in KDE environment.
+    // Buttons are for TQt-only portability.  NOT COMPILED in KDE environment.
     TQPushButton *	OK = new TQPushButton (i18n("&OK"), buttons);
     TQPushButton *	CANCEL = new TQPushButton (i18n("&Cancel"), buttons);
 
     dad->		setCaption (i18n("Edit Name & Hint"));
 #endif
 
-    // Base the geometry of the text box on the playing area.
-    QPoint		p = parent->mapToGlobal (TQPoint (0,0));
+    // Base the tqgeometry of the text box on the playing area.
+    TQPoint		p = parent->mapToGlobal (TQPoint (0,0));
     int			c = parent->width() / (FIELDWIDTH + 4);
     dad->		move (p.x()+4*c, p.y()+4*c);
     mle->		setMinimumSize ((FIELDWIDTH*c/2), (FIELDHEIGHT/2)*c);
 
     // Configure the text box.
-    mle->		setAlignment (AlignLeft);
+    mle->		tqsetAlignment (AlignLeft);
 #ifndef QT3
     mle->		setWordWrap (TQMultiLineEdit::WidgetWidth);
     mle->		setFixedVisibleLines (9);
@@ -612,7 +612,7 @@ KGrECDialog::KGrECDialog (int action, int collnIndex,
     prefixL  = new TQLabel (i18n("File name prefix:"), prefixBox);
     ecPrefix = new TQLineEdit (prefixBox);
 
-    ecGrp    = new TQButtonGroup (1, TQButtonGroup::Horizontal, 0, dad);
+    ecGrp    = new TQButtonGroup (1, Qt::Horizontal, 0, dad);
     mainLayout->addWidget (ecGrp);
     ecTradB  = new TQRadioButton (i18n("Traditional rules"), ecGrp);
     ecKGrB   = new TQRadioButton (i18n("KGoldrunner rules"), ecGrp);
@@ -636,13 +636,13 @@ KGrECDialog::KGrECDialog (int action, int collnIndex,
     TQHBox * buttons = new TQHBox (dad);
     mainLayout->addWidget (buttons);
     buttons->setSpacing (spacing);
-    // Buttons are for Qt-only portability.  NOT COMPILED in KDE environment.
+    // Buttons are for TQt-only portability.  NOT COMPILED in KDE environment.
     OK       = new TQPushButton (i18n("&OK"), buttons);
     CANCEL   = new TQPushButton (i18n("&Cancel"), buttons);
 
     TQPoint p = parent->mapToGlobal (TQPoint (0,0));
 
-    // Base the geometry of the dialog box on the playing area.
+    // Base the tqgeometry of the dialog box on the playing area.
     int cell = parent->width() / (FIELDWIDTH + 4);
     dad->	move (p.x()+2*cell, p.y()+2*cell);
     dad->	setMinimumSize ((FIELDWIDTH*cell/2), (FIELDHEIGHT-1)*cell);
@@ -663,13 +663,13 @@ KGrECDialog::KGrECDialog (int action, int collnIndex,
 	    // Collection already has some levels, so cannot change the prefix.
 	    ecPrefix->	setEnabled (FALSE);
 	}
-	QString		s;
+	TQString		s;
 #ifndef KGR_PORTABLE
 	nLevL->		setText (i18n("1 level", "%n levels",
 					collections.at(defaultGame)->nLevels));
 #else
 	nLevL->		setText (i18n("%1 levels")
-				.arg(collections.at(defaultGame)->nLevels));
+				.tqarg(collections.at(defaultGame)->nLevels));
 #endif
 	OKText = i18n("Save Changes");
     }
@@ -694,7 +694,7 @@ KGrECDialog::KGrECDialog (int action, int collnIndex,
     }
 
     // Configure the edit box.
-    mle->		setAlignment (AlignLeft);
+    mle->		tqsetAlignment (AlignLeft);
 #ifndef QT3
     mle->		setWordWrap (TQMultiLineEdit::WidgetWidth);
     mle->		setFixedVisibleLines (8);
@@ -780,9 +780,9 @@ KGrLGDialog::KGrLGDialog (TQFile * savedGames,
 
 			lgList   = new TQListBox (dad);
 #ifdef KGR_PORTABLE
-    QFont		f ("courier", 12);
+    TQFont		f ("courier", 12);
 #else
-    QFont		f = KGlobalSettings::fixedFont();	// KDE version.
+    TQFont		f = KGlobalSettings::fixedFont();	// KDE version.
 #endif
 			f.setFixedPitch (TRUE);
     lgList->		setFont (f);
@@ -795,15 +795,15 @@ KGrLGDialog::KGrLGDialog (TQFile * savedGames,
 #ifdef KGR_PORTABLE
     TQHBox *		buttons  = new TQHBox (dad);
     buttons->		setSpacing (spacing);
-    // Buttons are for Qt-only portability.  NOT COMPILED in KDE environment.
+    // Buttons are for TQt-only portability.  NOT COMPILED in KDE environment.
     TQPushButton *	OK       = new TQPushButton (i18n("&OK"), buttons);
     TQPushButton *	CANCEL   = new TQPushButton (i18n("&Cancel"), buttons);
     mainLayout->	addWidget (buttons);
 
     dad->		setCaption (i18n("Select Saved Game"));
 
-    // Base the geometry of the list box on the playing area.
-    QPoint		p = parent->mapToGlobal (TQPoint (0,0));
+    // Base the tqgeometry of the list box on the playing area.
+    TQPoint		p = parent->mapToGlobal (TQPoint (0,0));
     int			c = parent->width() / (FIELDWIDTH + 4);
     dad->		move (p.x()+2*c, p.y()+2*c);
     lgList->		setMinimumHeight ((FIELDHEIGHT/2)*c);
@@ -816,9 +816,9 @@ KGrLGDialog::KGrLGDialog (TQFile * savedGames,
 
 			lgHighlight  = -1;
 
-    QTextStream		gameText (savedGames);
-    QString		s = "";
-    QString		pr = "";
+    TQTextStream		gameText (savedGames);
+    TQString		s = "";
+    TQString		pr = "";
     int			i;
     int			imax = collections.count();
 
@@ -861,7 +861,7 @@ void KGrLGDialog::lgSelect (int n)
 void KGrMessage::information (TQWidget * parent, const TQString &caption, const TQString &text)
 {
 #ifdef KGR_PORTABLE
-    // Force Qt to do word-wrapping (but it ignores "\n" line-breaks).
+    // Force TQt to do word-wrapping (but it ignores "\n" line-breaks).
     TQMessageBox::information (parent, caption,
 				"<qt>" + text + "</qt>");
 #else
@@ -876,7 +876,7 @@ int KGrMessage::warning (TQWidget * parent, TQString caption, TQString text,
     int ans = 0;
 #ifdef KGR_PORTABLE
     // Display a box with 2 or 3 buttons, depending on if label2 is empty or not.
-    // Force Qt to do word-wrapping (but it ignores "\n" line-breaks).
+    // Force TQt to do word-wrapping (but it ignores "\n" line-breaks).
     ans = TQMessageBox::warning (parent, caption,
 				"<qt>" + text + "</qt>",
 				label0, label1, label2,
@@ -919,7 +919,7 @@ void KGrMessage::wrapped (TQWidget * parent, TQString title, TQString contents)
     TQVBoxLayout * mainLayout = new TQVBoxLayout (mm, margin, spacing);
 
     // Make text background grey not white (i.e. same as widget background).
-    QPalette		pl = mm->palette();
+    TQPalette		pl = mm->palette();
 #ifdef QT3
     pl.setColor (TQColorGroup::Base, mm->paletteBackgroundColor());
 #else
@@ -936,21 +936,21 @@ void KGrMessage::wrapped (TQWidget * parent, TQString title, TQString contents)
 #endif
     mainLayout->addWidget (mle);
 
-    // Button is for Qt-only portability.  NOT COMPILED in KDE environment.
+    // Button is for TQt-only portability.  NOT COMPILED in KDE environment.
     TQPushButton *	OK = new TQPushButton (i18n("&OK"), mm);
-    mainLayout->addWidget (OK, Qt::AlignHCenter);
+    mainLayout->addWidget (OK, TQt::AlignHCenter);
 
     mm->		setCaption (title);
 
-    // Base the geometry of the text box on the playing area.
-    QPoint		p = parent->mapToGlobal (TQPoint (0,0));
+    // Base the tqgeometry of the text box on the playing area.
+    TQPoint		p = parent->mapToGlobal (TQPoint (0,0));
     int			c = parent->width() / (FIELDWIDTH + 4);
     mm->		move (p.x()+4*c, p.y()+4*c);
     mle->		setMinimumSize ((FIELDWIDTH*c/2), (FIELDHEIGHT/2)*c);
     OK->		setMaximumWidth (3*c);
 
     mle->		setFrameStyle (TQFrame::NoFrame);
-    mle->		setAlignment (AlignLeft);
+    mle->		tqsetAlignment (AlignLeft);
     mle->		setReadOnly (TRUE);
     mle->		setText (contents);
 
