@@ -76,7 +76,7 @@ int KGrFigure::gety()
   return absy;
 }
 
-Status KGrFigure::getStatus()
+tqStatus KGrFigure::gettqStatus()
 {
     return status;
 }
@@ -713,7 +713,7 @@ void KGrHero::digRight(){
 #ifdef QT3
 void KGrHero::setEnemyList(TQPtrList<KGrEnemy> *e)
 #else
-void KGrHero::setEnemyList(QList<KGrEnemy> *e)
+void KGrHero::setEnemyList(TQList<KGrEnemy> *e)
 #endif
 {
   enemies = e;
@@ -733,7 +733,7 @@ bool KGrHero::standOnEnemy()
 		(((absx - 16) <  enemy->getx()) &&
 		 ((absx + 16) >  enemy->getx()))) {
                 if (((absy + 12) == enemy->gety()) &&
-                    (enemy->getStatus() != FALLING)) {
+                    (enemy->gettqStatus() != FALLING)) {
                     absy = absy - rely; // Bounce back from overlap, to avoid
                     rely = 0;           // hero-enemy mid-cycle deadlock.
                     walkCounter = 1;
@@ -807,7 +807,7 @@ KGrEnemy :: KGrEnemy (KGrCanvas * view, int x, int y)
   walkCounter = 1;
   captiveCounter = 0;
 
-  searchStatus = HORIZONTAL;
+  searchtqStatus = HORIZONTAL;
 
   birthX=x;
   birthY=y;
@@ -849,7 +849,7 @@ void KGrEnemy::showState(char option)
       case 's': printf (" nuggets %02d status %d walk-ctr %d ",
 			nuggets, status, walkCounter);
 	    printf ("dirn %d search %d capt-ctr %d\n",
-			direction, searchStatus, captiveCounter);
+			direction, searchtqStatus, captiveCounter);
 	    printf ("                     rel (%02d,%02d) abs (%03d,%03d)",
 			relx, rely, absx, absy);
 	    printf (" pix %02d", actualPixmap);
@@ -907,7 +907,7 @@ void KGrEnemy::walkTimeDone ()
       case RIGHT:	walkRight (WALKDELAY, FALLDELAY); break;
       case LEFT:	walkLeft (WALKDELAY, FALLDELAY); break;
       default:		// Switch search direction in KGoldrunner search (only).
-			searchStatus = (searchStatus==VERTIKAL) ?
+			searchtqStatus = (searchtqStatus==VERTIKAL) ?
 					HORIZONTAL : VERTIKAL;
 
                         // In KGoldrunner rules, if a hole opens under an enemy
@@ -942,7 +942,7 @@ void KGrEnemy::walkTimeDone ()
 
     // In KGoldrunner rules, change the search strategy,
     // to avoid enemy-enemy deadlock.
-    searchStatus = (searchStatus==VERTIKAL) ? HORIZONTAL : VERTIKAL;
+    searchtqStatus = (searchtqStatus==VERTIKAL) ? HORIZONTAL : VERTIKAL;
 
     dirn = searchbestway (x, y, herox, heroy);
     if ((dirn != direction) && ((*playfield)[x][y]->whatIam() != USEDHOLE)) {
@@ -1221,7 +1221,7 @@ Direction KGrEnemy::searchbestway(int ew,int eh,int hw,int hh)
   // KGoldrunner search strategy.
   case MEDIUM:
   case HIGH:
-  if(searchStatus==VERTIKAL){
+  if(searchtqStatus==VERTIKAL){
     if (eh > hh)
       return searchupway(ew,eh);
     if (eh < hh)
@@ -1673,7 +1673,7 @@ bool KGrEnemy::willNotFall (int x, int y)
 #ifdef QT3
 void KGrEnemy::setEnemyList(TQPtrList<KGrEnemy> *e)
 #else
-void KGrEnemy::setEnemyList(QList<KGrEnemy> *e)
+void KGrEnemy::setEnemyList(TQList<KGrEnemy> *e)
 #endif
 {
   enemies = e;
