@@ -80,7 +80,7 @@ kgpgOptions::kgpgOptions(TQWidget *parent, const char *name)
 	else
 	{
                 if (TQFile(defaultHomePath+"gpg.conf").exists()) defaultConfigPath="gpg.conf";
-		else defaultConfigPath=TQString::null;
+		else defaultConfigPath=TQString();
 		}
 
 kdDebug(2100)<<"Adding pages"<<endl;
@@ -211,7 +211,7 @@ if (!gpgHome.endsWith("/")) gpgHome.append("/");
 		confFile.close();
 		}
 		}
-		else confPath=TQString::null;
+		else confPath=TQString();
 		}
 		}
 		page4->gpg_conf_path->setText(confPath);
@@ -278,9 +278,9 @@ void kgpgOptions::updateWidgetsDefault()
 	page4->gpg_conf_path->setText(defaultConfigPath);
 	page4->gpg_home_path->setText(defaultHomePath);
 
-	page4->kcfg_PubKeyringUrl->setURL(TQString::null);
+	page4->kcfg_PubKeyringUrl->setURL(TQString());
 	page4->kcfg_PubKeyring->setChecked(false);
-	page4->kcfg_PrivKeyringUrl->setURL(TQString::null);
+	page4->kcfg_PrivKeyringUrl->setURL(TQString());
 	page4->kcfg_PrivKeyring->setChecked(false);
 	page4->kcfg_OnlyAdditional->setChecked(false);
 
@@ -364,7 +364,7 @@ void kgpgOptions::updateSettings()
 	else
 	{
 	if (KgpgInterface::getGpgSetting("keyring", gpgConfigPath)!="") emitReload=true;
-	KgpgInterface::setGpgSetting("keyring",TQString::null, gpgConfigPath);
+	KgpgInterface::setGpgSetting("keyring",TQString(), gpgConfigPath);
 	}
 
 	if (page4->kcfg_PrivKeyring->isChecked())
@@ -375,7 +375,7 @@ void kgpgOptions::updateSettings()
 	else
 	{
 	if (KgpgInterface::getGpgSetting("secret-keyring", gpgConfigPath)!="") emitReload=true;
-	KgpgInterface::setGpgSetting("secret-keyring",TQString::null, gpgConfigPath);
+	KgpgInterface::setGpgSetting("secret-keyring",TQString(), gpgConfigPath);
 	}
 
 	emit changeFont(kfc->font());
@@ -500,7 +500,7 @@ TQString kgpgOptions::namecode(TQString kid)
                 if (TQString(ids[counter].right(8))==kid)
                         return names[counter];
 
-        return TQString::null;
+        return TQString();
 }
 
 
@@ -509,7 +509,7 @@ TQString kgpgOptions::idcode(TQString kname)
         for ( uint counter = 0; counter<names.count(); counter++ )
                 if (names[counter]==kname)
                         return TQString(ids[counter].right(8));
-        return TQString::null;
+        return TQString();
 }
 
 
