@@ -70,14 +70,14 @@ def=isDefault;
 }
 
 
-void UpdateViewItem2::paintCell(TQPainter *p, const TQColorGroup &cg,int column, int width, int alignment)
+void UpdateViewItem2::paintCell(TQPainter *p, const TQColorGroup &cg,int column, int width, int tqalignment)
 {
         if ((def) && (column<2)) {
                 TQFont font(p->font());
                 font.setBold(true);
                 p->setFont(font);
         }
-        KListViewItem::paintCell(p, cg, column, width, alignment);
+        KListViewItem::paintCell(p, cg, column, width, tqalignment);
 }
 
 TQString UpdateViewItem2 :: key(int c,bool ) const
@@ -106,7 +106,7 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
         keySingle=loader->loadIcon("kgpg_key1",KIcon::Small,20);
 	keyGroup=loader->loadIcon("kgpg_key3",KIcon::Small,20);
 
-        if (filemode) setCaption(i18n("Select Public Key for %1").arg(sfile));
+        if (filemode) setCaption(i18n("Select Public Key for %1").tqarg(sfile));
         fmode=filemode;
 
 	TQHButtonGroup *hBar=new TQHButtonGroup(page);
@@ -146,7 +146,7 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
         boutonboxoptions=new TQButtonGroup(5,Qt::Vertical ,page,0);
 
 	KActionCollection *actcol=new KActionCollection(this);
-	(void) new KAction(i18n("&Go to Default Key"),goDefaultKey, this, TQT_SLOT(slotGotoDefaultKey()),actcol,"go_default_key");
+	(void) new KAction(i18n("&Go to Default Key"),goDefaultKey, TQT_TQOBJECT(this), TQT_SLOT(slotGotoDefaultKey()),actcol,"go_default_key");
 
 
         CBarmor=new TQCheckBox(i18n("ASCII armored encryption"),boutonboxoptions);
@@ -176,7 +176,7 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
                         (CBshred,i18n("<b>Shred source file</b>: permanently remove source file. No recovery will be possible"));
 
 		TQString shredWhatsThis = i18n( "<qt><b>Shred source file:</b><br /><p>Checking this option will shred (overwrite several times before erasing) the files you have encrypted. This way, it is almost impossible that the source file is recovered.</p><p><b>But you must be aware that this is not secure</b> on all file systems, and that parts of the file may have been saved in a temporary file or in the spooler of your printer if you previously opened it in an editor or tried to print it. Only works on files (not on folders).</p></qt>");
-		  KActiveLabel *warn= new KActiveLabel( i18n("<a href=\"whatsthis:%1\">Read this before using shredding</a>").arg(shredWhatsThis),parentBox );
+		  KActiveLabel *warn= new KActiveLabel( i18n("<a href=\"whatsthis:%1\">Read this before using shredding</a>").tqarg(shredWhatsThis),parentBox );
 		  shredBox->addWidget(CBshred);
 		  shredBox->addWidget(warn);
         }
@@ -208,7 +208,7 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
 
         char line[200]="\0";
         FILE *fp2;
-        seclist=TQString::null;
+        seclist=TQString();
 
         fp2 = popen("gpg --no-secmem-warning --no-tty --with-colon --list-secret-keys ", "r");
         while ( fgets( line, sizeof(line), fp2))
@@ -329,7 +329,7 @@ void popupPublic::refreshkeys()
 		{
 			if (!TQString(*it).isEmpty())
 			{
-				UpdateViewItem2 *item=new UpdateViewItem2(keysList,TQString(*it),TQString::null,TQString::null,false);
+				UpdateViewItem2 *item=new UpdateViewItem2(keysList,TQString(*it),TQString(),TQString(),false);
 				item->setPixmap(0,keyGroup);
 			}
 		}
@@ -424,14 +424,14 @@ void popupPublic::slotprocread(KProcIO *p)
                 //if (keyname.find("(")!=-1)
                  //       keyname=keyname.section('(',0,0);
         } else {
-                keymail=TQString::null;
+                keymail=TQString();
                 keyname=tst;//.section('(',0,0);
         }
                         if ((!dead) && (!tst.isEmpty())) {
 				bool isDefaultKey=false;
                                 if (id.right(8)==defaultKey) isDefaultKey=true;
                                         UpdateViewItem2 *item=new UpdateViewItem2(keysList,keyname,keymail,id,isDefaultKey);
-					//KListViewItem *sub= new KListViewItem(item,i18n("ID: %1, trust: %2, validity: %3").arg(id).arg(tr).arg(val));
+					//KListViewItem *sub= new KListViewItem(item,i18n("ID: %1, trust: %2, validity: %3").tqarg(id).tqarg(tr).tqarg(val));
                                         //sub->setSelectable(false);
                                         if (seclist.find(tst,0,FALSE)!=-1)
                                                 item->setPixmap(0,keyPair);
