@@ -74,30 +74,30 @@ KHangMan::~KHangMan()
 void KHangMan::setupActions()
 {
     // Game->New
-    KAction *action = new KAction(i18n("&New"), "filenew", CTRL+Key_N , m_view, TQT_SLOT(slotNewGame()), actionCollection(), "file_new");
+    KAction *action = new KAction(i18n("&New"), "filenew", CTRL+Key_N , TQT_TQOBJECT(m_view), TQT_SLOT(slotNewGame()), actionCollection(), "file_new");
     action->setToolTip(i18n( "Play with a new word" ));
 
     // Game->Get Words in New Language
-    new KAction( i18n("&Get Words in New Language..."), "knewstuff", CTRL+Key_G, this, TQT_SLOT( slotDownloadNewStuff() ), actionCollection(), "downloadnewstuff" );
+    new KAction( i18n("&Get Words in New Language..."), "knewstuff", CTRL+Key_G, TQT_TQOBJECT(this), TQT_SLOT( slotDownloadNewStuff() ), actionCollection(), "downloadnewstuff" );
 
-    KStdAction::quit(this, TQT_SLOT(slotQuit()), actionCollection());
+    KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(slotQuit()), actionCollection());
     
     m_levelAction = new KSelectAction(i18n("Le&vel"), 0,  actionCollection(), "combo_level");
     m_levelAction->setToolTip(i18n( "Choose the level" ));
     m_levelAction->setWhatsThis(i18n( "Choose the level of difficulty" ));
-	connect(m_levelAction, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotChangeLevel(int)));
+	connect(m_levelAction, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeLevel(int)));
 
     // Action for selecting language.
     m_languageAction = new KSelectAction(i18n("&Language"), 0, actionCollection(), "languages");
     m_languageAction->setItems(m_languageNames);
     m_languageAction->setCurrentItem(m_languages.findIndex(Prefs::selectedLanguage()));
-    connect(m_languageAction, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotChangeLanguage(int)));
+    connect(m_languageAction, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeLanguage(int)));
     
-    KStdAction::preferences(this, TQT_SLOT(optionsPreferences()), actionCollection());
+    KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(optionsPreferences()), actionCollection());
 
     // Mode. Currently hard coded into Sea and Desert themes.
     TQStringList modes;
-    m_modeAction = new KSelectAction(i18n("L&ook"), 0, this, TQT_SLOT(slotChangeMode()),  actionCollection(), "combo_mode");
+    m_modeAction = new KSelectAction(i18n("L&ook"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotChangeMode()),  actionCollection(), "combo_mode");
     modes += i18n("&Sea Theme");
     modes += i18n("&Desert Theme");
     m_modeAction->setItems(modes);
@@ -228,7 +228,7 @@ void KHangMan::setLanguages()
     for (uint i=0;  i<m_languages.count(); i++) {
         TQString tmp = m_languages[i];
         if (!config->readEntry(tmp))
-            config->writeEntry(tmp, TQDate::currentDate().toString(Qt::ISODate));
+            config->writeEntry(tmp, TQString(TQDate::tqcurrentDate().toString(Qt::ISODate)));
     }
 
     // We look in $KDEDIR/share/locale/all_languages from
@@ -380,7 +380,7 @@ void KHangMan::optionsPreferences()
     Timer *m_timer = new Timer();
     dialog->addPage(m_timer, i18n("Timers"), "clock");
 
-    connect(dialog, TQT_SIGNAL(settingsChanged()), this, TQT_SLOT(updateSettings()));
+    connect(dialog, TQT_SIGNAL(settingsChanged()), TQT_TQOBJECT(this), TQT_SLOT(updateSettings()));
 
     dialog->show();
 }
@@ -420,22 +420,22 @@ void KHangMan::loadLangToolBar()
 
     m_allData.clear();
     if (!m_noSpecialChars) {
-	TQString myString=TQString("khangman/%1.txt").arg(Prefs::selectedLanguage());
+	TQString myString=TQString("khangman/%1.txt").tqarg(Prefs::selectedLanguage());
 	TQFile myFile;
 	myFile.setName(locate("data", myString));
 
 	// Let's look in local KDEHOME dir then
 	if (!myFile.exists()) {
 	    TQString  myString=TQString("khangman/data/%1/%1.txt")
-		.arg(Prefs::selectedLanguage())
-		.arg(Prefs::selectedLanguage());
+		.tqarg(Prefs::selectedLanguage())
+		.tqarg(Prefs::selectedLanguage());
 	    myFile.setName(locate("data",myString));
 	    kdDebug() << myString << endl;
 	}
 
 	if (!myFile.exists()) {
 	    TQString mString=i18n("File $KDEDIR/share/apps/khangman/%1.txt not found;\n"
-				 "check your installation.").arg(Prefs::selectedLanguage());
+				 "check your installation.").tqarg(Prefs::selectedLanguage());
 	    KMessageBox::sorry( this, mString,
 				i18n("Error") );
 	    kapp->quit();
@@ -455,9 +455,9 @@ void KHangMan::loadLangToolBar()
 
 	for (int i=0; i<(int) m_allData.count(); i++)
 	    secondToolbar->insertButton (charIcon(m_allData[i].at(0)), i, 
-					 TQT_SIGNAL( clicked() ), this, 
+					 TQT_SIGNAL( clicked() ), TQT_TQOBJECT(this), 
 					 TQT_SLOT( slotPasteChar()), true,  
-					 i18n("Inserts the character %1").arg(m_allData[i]), i+1 );
+					 i18n("Inserts the character %1").tqarg(m_allData[i]), i+1 );
     }
 
     if (Prefs::showCharToolbar())
@@ -480,7 +480,7 @@ void KHangMan::slotPasteChar()
 TQString KHangMan::charIcon(const TQChar & c)
 {
     ///Create a name and path for the icon
-    TQString s = locateLocal("icon", "char" + TQString::number(c.unicode()) + ".png");
+    TQString s = locateLocal("icon", "char" + TQString::number(c.tqunicode()) + ".png");
 
     TQRect r(4, 4, 120, 120);
 
@@ -492,19 +492,19 @@ TQString KHangMan::charIcon(const TQChar & c)
 
     ///Create the pixmap
     TQPixmap pm(128, 128);
-    pm.fill(Qt::white);
+    pm.fill(TQt::white);
     TQPainter p(&pm);
     p.setFont(font);
-    p.setPen(Qt::black);
-    p.drawText(r, Qt::AlignCenter, (TQString) c);
+    p.setPen(TQt::black);
+    p.drawText(r, TQt::AlignCenter, (TQString) c);
 
     ///Create transparency mask
     TQBitmap bm(128, 128);
-    bm.fill(Qt::color0);
+    bm.fill(TQt::color0);
     TQPainter b(&bm);
     b.setFont(font);
-    b.setPen(Qt::color1);
-    b.drawText(r, Qt::AlignCenter, (TQString) c);
+    b.setPen(TQt::color1);
+    b.drawText(r, TQt::AlignCenter, (TQString) c);
 
     ///Mask the pixmap
     pm.setMask(bm);
