@@ -240,7 +240,7 @@ CFindDialog::CFindDialog( TQWidget *parent, const char *name, bool modal )
   mCheckBackward->setChecked( config.readBoolEntry( "Backwards", false ) );
   mCheckUseNavigator->setChecked( config.readBoolEntry( "UseNavigator", true));
   uint val = config.readUnsignedNumEntry( "Format", 0 );
-  mSelector->setCurrentItem(QMIN(4,val) );
+  mSelector->setCurrentItem(TQMIN(4,val) );
   selectorChanged( mSelector->currentItem() );
   enableButtonOK(!mInput->text().isEmpty());
 }
@@ -365,7 +365,7 @@ CFindNavigatorDialog::CFindNavigatorDialog( TQWidget *parent, const char *name,
 
   mKey = new TQLineEdit( plainPage() );
   mKey->setMinimumWidth( fontMetrics().width("M") * 20 );
-  mKey->setFocusPolicy( TQWidget::NoFocus );
+  mKey->setFocusPolicy( TQ_NoFocus );
   hbox->addWidget( mKey );
 
   topLayout->addSpacing( spacingHint() ); // A little bit extra space
@@ -533,7 +533,7 @@ CReplaceDialog::CReplaceDialog( TQWidget *parent, const char *name, bool modal )
   text = i18n("For&mat (replace):");
   label = new TQLabel( mReplaceSelector, text, plainPage() );
   if( label == 0 ) { return; }
-  label->setFixedHeight( label->sizeHint().height() );
+  label->setFixedHeight( label->tqsizeHint().height() );
 
   vbox->addWidget( label );
   vbox->addWidget( mReplaceSelector );
@@ -549,7 +549,7 @@ CReplaceDialog::CReplaceDialog( TQWidget *parent, const char *name, bool modal )
 
   label = new TQLabel( mReplaceInput, i18n("Rep&lace:"), plainPage() );
   if( label == 0 ) { return; }
-  label->setFixedHeight( label->sizeHint().height() );
+  label->setFixedHeight( label->tqsizeHint().height() );
 
   vbox->addWidget( label );
   vbox->addWidget( mReplaceInput );
@@ -581,10 +581,10 @@ CReplaceDialog::CReplaceDialog( TQWidget *parent, const char *name, bool modal )
   mCheckBackward->setChecked( config.readBoolEntry( "Backwards", false ) );
   mCheckPrompt->setChecked( config.readBoolEntry( "Prompt", true));
   uint val = config.readUnsignedNumEntry( "FindFormat", 0 );
-  mFindSelector->setCurrentItem(QMIN(4,val) );
+  mFindSelector->setCurrentItem(TQMIN(4,val) );
   findSelectorChanged( mFindSelector->currentItem() );
   val = config.readUnsignedNumEntry( "ReplaceFormat", 0 );
-  mReplaceSelector->setCurrentItem(QMIN(4,val) );
+  mReplaceSelector->setCurrentItem(TQMIN(4,val) );
   replaceSelectorChanged( mReplaceSelector->currentItem() );
   enableButtonOK(!mFindInput->text().isEmpty());
 }
@@ -846,7 +846,7 @@ void CFilterDialog::makeOperandLayout( void )
 
   mOperandSelector = new TQComboBox( false, page );
   if( mOperandSelector == 0 ) { return; }
-  mOperandSelector->setFixedHeight( mOperandSelector->sizeHint().height());
+  mOperandSelector->setFixedHeight( mOperandSelector->tqsizeHint().height());
   mOperandSelector->setMinimumWidth( fontMetrics().width("M")*20 );
   mOperandSelector->insertStringList( formatStrings() );
   connect( mOperandSelector, TQT_SIGNAL(activated(int)),
@@ -891,7 +891,7 @@ void CFilterDialog::makeBitSwapLayout( void )
   text = i18n("Swap rule");
   TQLabel *label = new TQLabel( text, page );
   if( label == 0 ) { return; }
-  label->setFixedHeight( label->sizeHint().height() );
+  label->setFixedHeight( label->tqsizeHint().height() );
   vbox->addWidget( label );
 
   mByteWidget = new CByteWidget( page );
@@ -902,7 +902,7 @@ void CFilterDialog::makeBitSwapLayout( void )
 
   text = i18n("&Reset");
   TQPushButton *resetButton = new TQPushButton( text, page );
-  resetButton->setFixedHeight( resetButton->sizeHint().height() );
+  resetButton->setFixedHeight( resetButton->tqsizeHint().height() );
   connect( resetButton, TQT_SIGNAL(clicked()), mByteWidget, TQT_SLOT(reset()) );
 
   hbox->addWidget( resetButton );
@@ -1152,7 +1152,7 @@ CInsertDialog::CInsertDialog( TQWidget *parent, const char *name, bool modal )
   mCheckOnCursor->setChecked( config.readBoolEntry( "InsertOnCursor", false) );
   cursorCheck();
   uint val = config.readUnsignedNumEntry( "Format", 0 );
-  mPatternSelector->setCurrentItem( QMIN(4,val) );
+  mPatternSelector->setCurrentItem( TQMIN(4,val) );
   patternSelectorChanged( mPatternSelector->currentItem() );
 }
 
@@ -1237,7 +1237,7 @@ void centerDialog( TQWidget *widget, TQWidget *centerParent )
   }
 
   TQPoint point = centerParent->mapToGlobal( TQPoint(0,0) );
-  TQRect pos    = centerParent->geometry();
+  TQRect pos    = centerParent->tqgeometry();
 
   widget->setGeometry( point.x() + pos.width()/2  - widget->width()/2,
 		       point.y() + pos.height()/2 - widget->height()/2,
@@ -1253,7 +1253,7 @@ void centerDialogBottom( TQWidget *widget, TQWidget *centerParent )
   }
 
   TQPoint point = centerParent->mapToGlobal( TQPoint(0,0) );
-  TQRect pos    = centerParent->geometry();
+  TQRect pos    = centerParent->tqgeometry();
 
   widget->setGeometry( point.x() + pos.width()/2  - widget->width()/2,
 		       point.y() + pos.height() - widget->height(),
