@@ -213,7 +213,7 @@ CachedCSSStyleSheet::CachedCSSStyleSheet(DocLoader* dl, const DOMString &url, KI
     : CachedObject(url, CSSStyleSheet, _cachePolicy, 0)
 {
     // Set the type we want (probably css or xml)
-    TQString ah = TQString::fromLatin1( accept );
+    TQString ah = TQString::tqfromLatin1( accept );
     if ( !ah.isEmpty() )
         ah += ",";
     ah += "*/*;q=0.1";
@@ -264,7 +264,7 @@ void CachedCSSStyleSheet::data( TQBuffer &buffer, bool eof )
         m_charset = c->name();
     }
     TQString data = c->toUnicode( buffer.buffer().data(), m_size );
-    // workaround Qt bugs
+    // workaround TQt bugs
     m_sheet = static_cast<TQChar>(data[0]) == TQChar::byteOrderMark ? DOMString(data.mid( 1 ) ) : DOMString(data);
     m_loading = false;
 
@@ -327,7 +327,7 @@ CachedScript::CachedScript(DocLoader* dl, const DOMString &url, KIO::CacheContro
     // It's javascript we want.
     // But some websites think their scripts are <some wrong mimetype here>
     // and refuse to serve them if we only accept application/x-javascript.
-    setAccept( TQString::fromLatin1("*/*") );
+    setAccept( TQString::tqfromLatin1("*/*") );
     // load the file
     Cache::loader()->load(dl, this, false);
     m_loading = true;
@@ -380,7 +380,7 @@ void CachedScript::error( int /*err*/, const char* /*text*/ )
 namespace khtml
 {
 
-class ImageSource : public QDataSource
+class ImageSource : public TQDataSource
 {
 public:
     ImageSource(TQByteArray buf)
@@ -397,7 +397,7 @@ public:
 
     void sendTo(TQDataSink* sink, int n)
     {
-        sink->receive((const uchar*)&buffer.at(pos), n);
+        sink->receive((const uchar*)&buffer.tqat(pos), n);
 
         pos += n;
 
@@ -476,7 +476,7 @@ CachedImage::CachedImage(DocLoader* dl, const DOMString &url, KIO::CacheControl
     pixPart = 0;
     bg = 0;
     scaled = 0;
-    bgColor = qRgba( 0, 0, 0, 0xFF );
+    bgColor = tqRgba( 0, 0, 0, 0xFF );
     typeChecked = false;
     isFullyTransparent = false;
     monochrome = false;
@@ -526,7 +526,7 @@ void CachedImage::deref( CachedObjectClient *c )
 
 const TQPixmap &CachedImage::tiled_pixmap(const TQColor& newc, int xWidth, int xHeight)
 {
-    static QRgb bgTransparent = qRgba( 0, 0, 0, 0xFF );
+    static TQRgb bgTransparent = tqRgba( 0, 0, 0, 0xFF );
 
     TQSize s(pixmap_size());
     int w = xWidth;
@@ -618,7 +618,7 @@ const TQPixmap &CachedImage::scaled_pixmap( int xWidth, int xHeight )
 
 //     kdDebug() << "scaling " << r.width() << "," << r.height() << " to " << xWidth << "," << xHeight << endl;
 
-    TQImage image = r.convertToImage().smoothScale(xWidth, xHeight);
+    TQImage image = TQImage(r.convertToImage()).smoothScale(xWidth, xHeight);
 
     scaled = new TQPixmap(xWidth, xHeight, r.depth());
     scaled->convertFromImage(image);
@@ -671,7 +671,7 @@ TQSize CachedImage::pixmap_size() const
 TQRect CachedImage::valid_rect() const
 {
     if (m_wasBlocked) return Cache::blockedPixmap->rect();
-    return (m_hadError ? Cache::brokenPixmap->rect() : m ? m->getValidRect() : ( p ? p->rect() : TQRect()) );
+    return (m_hadError ? Cache::brokenPixmap->rect() : m ? TQRect(m->getValidRect()) : ( p ? TQRect(p->rect()) : TQRect()) );
 }
 
 
@@ -702,15 +702,15 @@ void CachedImage::movieStatus(int status)
     // netscape). We have a problem though where an image is present, and js code creates a new Image object,
     // which uses the same CachedImage, the one in the document is not supposed to be notified
 
-    // just another Qt 2.2.0 bug. we cannot call
+    // just another TQt 2.2.0 bug. we cannot call
     // TQMovie::frameImage if we're after TQMovie::EndOfMovie
     if(status == TQMovie::EndOfFrame)
     {
         const TQImage& im = m->frameImage();
         monochrome = ( ( im.depth() <= 8 ) && ( im.numColors() - int( im.hasAlphaBuffer() ) <= 2 ) );
         for (int i = 0; monochrome && i < im.numColors(); ++i)
-            if (im.colorTable()[i] != qRgb(0xff, 0xff, 0xff) &&
-                im.colorTable()[i] != qRgb(0x00, 0x00, 0x00))
+            if (im.colorTable()[i] != tqRgb(0xff, 0xff, 0xff) &&
+                im.colorTable()[i] != tqRgb(0x00, 0x00, 0x00))
                 monochrome = false;
         if( (im.width() < 5 || im.height() < 5) && im.hasAlphaBuffer()) // only evaluate for small images
         {
@@ -748,7 +748,7 @@ void CachedImage::movieStatus(int status)
             if (p && monochrome && p->depth() > 1)
             {
                 TQPixmap* pix = new TQPixmap;
-                pix->convertFromImage( p->convertToImage().convertDepth( 1 ), MonoOnly|AvoidDither );
+                pix->convertFromImage( TQImage(p->convertToImage()).convertDepth( 1 ), MonoOnly|AvoidDither );
                 if ( p->mask() )
                     pix->setMask( *p->mask() );
                 delete p;
@@ -787,7 +787,7 @@ void CachedImage::setShowAnimations( KHTMLSettings::KAnimationAdvice showAnimati
         delete p;
         p = new TQPixmap(m->framePixmap());
         m->disconnectUpdate( this, TQT_SLOT( movieUpdated( const TQRect &) ));
-        m->disconnectStatus( this, TQT_SLOT( movieStatus( int ) ));
+        m->disconnectqStatus( this, TQT_SLOT( movieStatus( int ) ));
         m->disconnectResize( this, TQT_SLOT( movieResize( const TQSize& ) ) );
         TQTimer::singleShot(0, this, TQT_SLOT( deleteMovie()));
         imgSource = 0;
@@ -816,7 +816,7 @@ void CachedImage::clear()
     delete p;   p = 0;
     delete bg;  bg = 0;
     delete scaled;  scaled = 0;
-    bgColor = qRgba( 0, 0, 0, 0xff );
+    bgColor = tqRgba( 0, 0, 0, 0xff );
     bgSize = TQSize(-1,-1);
     delete pixPart; pixPart = 0;
 
@@ -850,7 +850,7 @@ void CachedImage::data ( TQBuffer &_buffer, bool eof )
             imgSource = new ImageSource( _buffer.buffer());
             m = new TQMovie( imgSource, 8192 );
             m->connectUpdate( this, TQT_SLOT( movieUpdated( const TQRect &) ));
-            m->connectStatus( this, TQT_SLOT( movieStatus(int)));
+            m->connectqStatus( this, TQT_SLOT( movieStatus(int)));
             m->connectResize( this, TQT_SLOT( movieResize( const TQSize& ) ) );
         }
     }
@@ -1167,7 +1167,7 @@ void Loader::servePendingRequests()
             {
                 job->addMetaData( "cross-domain", part->toplevelURL().url() );
                 if (part->widget())
-                    job->setWindow (part->widget()->topLevelWidget());
+                    job->setWindow (part->widget()->tqtopLevelWidget());
             }
         }
 
