@@ -346,7 +346,7 @@ void RenderBox::paintRootBoxDecorations(PaintInfo& paintInfo, int _tx, int _ty)
     }
 
     if( !bgColor.isValid() && canvas()->view())
-        bgColor = canvas()->view()->palette().active().color(TQColorGroup::Base);
+        bgColor = canvas()->view()->tqpalette().active().color(TQColorGroup::Base);
 
     int w = width();
     int h = height();
@@ -490,7 +490,7 @@ void RenderBox::paintBackgroundExtended(TQPainter *p, const TQColor &c, const Ba
     TQColor bgColor = c;
 
     // Paint the color first underneath all images.
-    if (!bgLayer->next() && bgColor.isValid() && qAlpha(bgColor.rgb()) > 0)
+    if (!bgLayer->next() && bgColor.isValid() && tqAlpha(bgColor.rgb()) > 0)
         p->fillRect(_tx, clipy, w, cliph, bgColor);
 
     // no progressive loading of the background image
@@ -622,7 +622,7 @@ void RenderBox::paintBackgroundExtended(TQPainter *p, const TQColor &c, const Ba
             sy+=b.y()-cy;
             cx=b.x();cy=b.y();cw=b.width();ch=b.height();
         }
-        // restrict painting to repaint-clip
+        // restrict painting to tqrepaint-clip
         if (cy < clipy) {
             ch -= (clipy - cy);
             sy += (clipy - cy);
@@ -795,7 +795,7 @@ void RenderBox::position(InlineBox* box, int /*from*/, int /*len*/, bool /*rever
         setPos( box->xPos(), box->yPos() );
 }
 
-void RenderBox::repaint(Priority prior)
+void RenderBox::tqrepaint(Priority prior)
 {
     int ow = style() ? style()->outlineSize() : 0;
     if( isInline() && !isReplaced() )
