@@ -99,25 +99,25 @@ void RenderFormElement::layout()
     setNeedsLayout(false);
 }
 
-Qt::AlignmentFlags RenderFormElement::textAlignment() const
+TQ_Alignment RenderFormElement::textAlignment() const
 {
     switch (style()->textAlign()) {
         case LEFT:
         case KHTML_LEFT:
-            return AlignLeft;
+            return Qt::AlignLeft;
         case RIGHT:
         case KHTML_RIGHT:
-            return AlignRight;
+            return Qt::AlignRight;
         case CENTER:
         case KHTML_CENTER:
-            return AlignHCenter;
+            return Qt::AlignHCenter;
         case JUSTIFY:
             // Just fall into the auto code for justify.
         case TAAUTO:
-            return style()->direction() == RTL ? AlignRight : AlignLeft;
+            return style()->direction() == RTL ? Qt::AlignRight : Qt::AlignLeft;
     }
     assert(false); // Should never be reached.
-    return AlignLeft;
+    return Qt::AlignLeft;
 }
 
 // -------------------------------------------------------------------------
@@ -155,8 +155,8 @@ void RenderCheckBox::calcMinMaxWidth()
     KHTMLAssert( !minMaxKnown() );
 
     TQCheckBox *cb = static_cast<TQCheckBox *>( m_widget );
-    TQSize s( cb->style().pixelMetric( TQStyle::PM_IndicatorWidth ),
-             cb->style().pixelMetric( TQStyle::PM_IndicatorHeight ) );
+    TQSize s( cb->tqstyle().tqpixelMetric( TQStyle::PM_IndicatorWidth ),
+             cb->tqstyle().tqpixelMetric( TQStyle::PM_IndicatorHeight ) );
     setIntrinsicWidth( s.width() );
     setIntrinsicHeight( s.height() );
 
@@ -207,8 +207,8 @@ void RenderRadioButton::calcMinMaxWidth()
     KHTMLAssert( !minMaxKnown() );
 
     TQRadioButton *rb = static_cast<TQRadioButton *>( m_widget );
-    TQSize s( rb->style().pixelMetric( TQStyle::PM_ExclusiveIndicatorWidth ),
-             rb->style().pixelMetric( TQStyle::PM_ExclusiveIndicatorHeight ) );
+    TQSize s( rb->tqstyle().tqpixelMetric( TQStyle::PM_ExclusiveIndicatorWidth ),
+             rb->tqstyle().tqpixelMetric( TQStyle::PM_ExclusiveIndicatorHeight ) );
     setIntrinsicWidth( s.width() );
     setIntrinsicHeight( s.height() );
 
@@ -260,17 +260,17 @@ void RenderSubmitButton::calcMinMaxWidth()
 
     bool empty = raw.isEmpty();
     if ( empty )
-        raw = TQString::fromLatin1("X");
+        raw = TQString::tqfromLatin1("X");
     TQFontMetrics fm = pb->fontMetrics();
     TQSize ts = fm.size( ShowPrefix, raw);
-    TQSize s(pb->style().sizeFromContents( TQStyle::CT_PushButton, pb, ts )
+    TQSize s(pb->tqstyle().tqsizeFromContents( TQStyle::CT_PushButton, pb, ts )
             .expandedTo(TQApplication::globalStrut()));
-    int margin = pb->style().pixelMetric( TQStyle::PM_ButtonMargin, pb) +
-		 pb->style().pixelMetric( TQStyle::PM_DefaultFrameWidth, pb ) * 2;
+    int margin = pb->tqstyle().tqpixelMetric( TQStyle::PM_ButtonMargin, pb) +
+		 pb->tqstyle().tqpixelMetric( TQStyle::PM_DefaultFrameWidth, pb ) * 2;
     int w = ts.width() + margin;
     int h = s.height();
     if (pb->isDefault() || pb->autoDefault()) {
-	int dbw = pb->style().pixelMetric( TQStyle::PM_ButtonDefaultIndicator, pb ) * 2;
+	int dbw = pb->tqstyle().tqpixelMetric( TQStyle::PM_ButtonDefaultIndicator, pb ) * 2;
 	w += dbw;
     }
 
@@ -312,7 +312,7 @@ LineEditWidget::LineEditWidget(DOM::HTMLInputElementImpl* input, KHTMLView* view
 {
     setMouseTracking(true);
     KActionCollection *ac = new KActionCollection(this);
-    m_spellAction = KStdAction::spelling( this, TQT_SLOT( slotCheckSpelling() ), ac );
+    m_spellAction = KStdAction::spelling( TQT_TQOBJECT(this), TQT_SLOT( slotCheckSpelling() ), ac );
 }
 
 LineEditWidget::~LineEditWidget()
@@ -328,7 +328,7 @@ void LineEditWidget::slotCheckSpelling()
     }
 
     delete m_spell;
-    m_spell = new KSpell( this, i18n( "Spell Checking" ), this, TQT_SLOT( slotSpellCheckReady( KSpell *) ), 0, true, true);
+    m_spell = new KSpell( this, i18n( "Spell Checking" ), TQT_TQOBJECT(this), TQT_SLOT( slotSpellCheckReady( KSpell *) ), 0, true, true);
 
     connect( m_spell, TQT_SIGNAL( death() ),this, TQT_SLOT( spellCheckerFinished() ) );
     connect( m_spell, TQT_SIGNAL( misspelling( const TQString &, const TQStringList &, unsigned int ) ),this, TQT_SLOT( spellCheckerMisspelling( const TQString &, const TQStringList &, unsigned int ) ) );
@@ -491,7 +491,7 @@ void RenderLineEdit::setStyle(RenderStyle* _style)
 {
     RenderFormElement::setStyle( _style );
 
-    widget()->setAlignment(textAlignment());
+    widget()->tqsetAlignment(textAlignment());
 }
 
 void RenderLineEdit::highLightWord( unsigned int length, unsigned int pos )
@@ -805,11 +805,11 @@ void RenderFileButton::calcMinMaxWidth()
     int h = fm.lineSpacing();
     int w = fm.width( 'x' ) * (size > 0 ? size+1 : 17); // "some"
     KLineEdit* edit = static_cast<KURLRequester*>( m_widget )->lineEdit();
-    TQSize s = edit->style().sizeFromContents(TQStyle::CT_LineEdit,
+    TQSize s = edit->tqstyle().tqsizeFromContents(TQStyle::CT_LineEdit,
                                              edit,
           TQSize(w + 2 + 2*edit->frameWidth(), kMax(h, 14) + 2 + 2*edit->frameWidth()))
         .expandedTo(TQApplication::globalStrut());
-    TQSize bs = static_cast<KURLRequester*>( m_widget )->minimumSizeHint() - edit->minimumSizeHint();
+    TQSize bs = static_cast<KURLRequester*>( m_widget )->tqminimumSizeHint() - edit->tqminimumSizeHint();
 
     setIntrinsicWidth( s.width() + bs.width() );
     setIntrinsicHeight( kMax(s.height(), bs.height()) );
@@ -890,7 +890,7 @@ bool ComboBoxWidget::event(TQEvent *e)
 	return true;
     if (e->type()==TQEvent::KeyPress)
     {
-	TQKeyEvent *ke = static_cast<TQKeyEvent *>(e);
+	TQKeyEvent *ke = TQT_TQKEYEVENT(e);
 	switch(ke->key())
 	{
 	case Key_Return:
@@ -907,9 +907,9 @@ bool ComboBoxWidget::event(TQEvent *e)
 
 bool ComboBoxWidget::eventFilter(TQObject *dest, TQEvent *e)
 {
-    if (dest==listBox() &&  e->type()==TQEvent::KeyPress)
+    if (TQT_BASE_OBJECT(dest)==TQT_BASE_OBJECT(listBox()) &&  e->type()==TQEvent::KeyPress)
     {
-	TQKeyEvent *ke = static_cast<TQKeyEvent *>(e);
+	TQKeyEvent *ke = TQT_TQKEYEVENT(e);
 	bool forward = false;
 	switch(ke->key())
 	{
@@ -1018,7 +1018,7 @@ void RenderSelect::updateFromElement()
                     DOMString label = optElem->getAttribute(ATTR_LABEL);
                     if (!label.isEmpty())
                         text = label.string();
-                    text = TQString::fromLatin1("    ")+text;
+                    text = TQString::tqfromLatin1("    ")+text;
                 }
 
                 if(m_useListBox) {
@@ -1107,14 +1107,14 @@ void RenderSelect::layout( )
         if(size < 1)
             size = kMin(static_cast<KListBox*>(m_widget)->count(), 10u);
 
-        width += 2*w->frameWidth() + w->verticalScrollBar()->sizeHint().width();
+        width += 2*w->frameWidth() + w->verticalScrollBar()->tqsizeHint().width();
         height = size*height + 2*w->frameWidth();
 
         setIntrinsicWidth( width );
         setIntrinsicHeight( height );
     }
     else {
-        TQSize s(m_widget->sizeHint());
+        TQSize s(m_widget->tqsizeHint());
         setIntrinsicWidth( s.width() );
         setIntrinsicHeight( s.height() );
     }
@@ -1295,9 +1295,9 @@ TextAreaWidget::TextAreaWidget(int wrap, TQWidget* parent)
     setMouseTracking(true);
 
     KActionCollection *ac = new KActionCollection(this);
-    m_findAction = KStdAction::find( this, TQT_SLOT( slotFind() ), ac );
-    m_findNextAction = KStdAction::findNext( this, TQT_SLOT( slotFindNext() ), ac );
-    m_replaceAction = KStdAction::replace( this, TQT_SLOT( slotReplace() ), ac );
+    m_findAction = KStdAction::find( TQT_TQOBJECT(this), TQT_SLOT( slotFind() ), ac );
+    m_findNextAction = KStdAction::findNext( TQT_TQOBJECT(this), TQT_SLOT( slotFindNext() ), ac );
+    m_replaceAction = KStdAction::replace( TQT_TQOBJECT(this), TQT_SLOT( slotReplace() ), ac );
 }
 
 
@@ -1406,7 +1406,7 @@ void TextAreaWidget::slotReplaceNext()
     }
 
     if (!(m_replace->options() & KReplaceDialog::PromptOnReplace)) {
-        viewport()->setUpdatesEnabled(false);
+        viewport()->tqsetUpdatesEnabled(false);
     }
 
     KFind::Result res = KFind::NoMatch;
@@ -1449,7 +1449,7 @@ void TextAreaWidget::slotReplaceNext()
     }
 
     if (!(m_replace->options() & KReplaceDialog::PromptOnReplace)) {
-        viewport()->setUpdatesEnabled(true);
+        viewport()->tqsetUpdatesEnabled(true);
         repaintChanged();
     }
 
@@ -1651,10 +1651,10 @@ void RenderTextArea::calcMinMaxWidth()
     const TQFontMetrics &m = style()->fontMetrics();
     w->setTabStopWidth(8 * m.width(" "));
     TQSize size( kMax(element()->cols(), 1L)*m.width('x') + w->frameWidth() +
-                w->verticalScrollBar()->sizeHint().width(),
+                w->verticalScrollBar()->tqsizeHint().width(),
                 kMax(element()->rows(), 1L)*m.lineSpacing() + w->frameWidth()*4 +
                 (w->wordWrap() == TQTextEdit::NoWrap ?
-                 w->horizontalScrollBar()->sizeHint().height() : 0)
+                 w->horizontalScrollBar()->tqsizeHint().height() : 0)
         );
 
     setIntrinsicWidth( size.width() );
@@ -1670,7 +1670,7 @@ void RenderTextArea::setStyle(RenderStyle* _style)
     RenderFormElement::setStyle(_style);
 
     widget()->blockSignals(true);
-    widget()->setAlignment(textAlignment());
+    widget()->tqsetAlignment(textAlignment());
     widget()->blockSignals(false);
 
     scrollbarsStyled = false;
@@ -1738,13 +1738,13 @@ TQString RenderTextArea::text()
             paragraphText = paragraphText.left(pl); //Snip invented space.
             for (int l = 0; l < pl; ++l) {
                 if (lindex != w->lineOfChar(p, l)) {
-                    paragraphText.insert(l+ll++, TQString::fromLatin1("\n"));
+                    paragraphText.insert(l+ll++, TQString::tqfromLatin1("\n"));
                     lindex = w->lineOfChar(p, l);
                 }
             }
             txt += paragraphText;
             if (p < w->paragraphs() - 1)
-                txt += TQString::fromLatin1("\n");
+                txt += TQString::tqfromLatin1("\n");
         }
     }
     else
