@@ -8,7 +8,7 @@
 /**
  * @internal
  */
-class Dummy : public QObject
+class Dummy : public TQObject
 {
   Q_OBJECT
 public:
