@@ -308,7 +308,7 @@ DocumentImpl::DocumentImpl(DOMImplementationImpl *_implementation, KHTMLView *v)
 
     if ( v ) {
         m_docLoader = new DocLoader(v->part(), this );
-        setPaintDevice( m_view );
+        setPaintDevice( TQT_TQPAINTDEVICE(m_view) );
     }
     else
         m_docLoader = new DocLoader( 0, this );
@@ -337,7 +337,7 @@ DocumentImpl::DocumentImpl(DOMImplementationImpl *_implementation, KHTMLView *v)
     m_namespaceMap = new IdNameMapping(1);
     TQString xhtml(XHTML_NAMESPACE);
     m_namespaceMap->names.insert(emptyNamespace, new DOMStringImpl(""));
-    m_namespaceMap->names.insert(xhtmlNamespace, new DOMStringImpl(xhtml.unicode(), xhtml.length()));
+    m_namespaceMap->names.insert(xhtmlNamespace, new DOMStringImpl(xhtml.tqunicode(), xhtml.length()));
     m_namespaceMap->names[emptyNamespace]->ref();
     m_namespaceMap->names[xhtmlNamespace]->ref();
     m_namespaceMap->count+=2;
@@ -1231,7 +1231,7 @@ void DocumentImpl::attach()
     assert(!attached());
 
     if ( m_view )
-        setPaintDevice( m_view );
+        setPaintDevice( TQT_TQPAINTDEVICE(m_view) );
 
     if (!m_renderArena)
 	m_renderArena.reset(new RenderArena());
@@ -1387,7 +1387,7 @@ void DocumentImpl::write( const TQString &text )
         if (m_view)
             m_view->part()->resetFromScript();
         m_tokenizer->setAutoClose();
-        write(TQString::fromLatin1("<html>"));
+        write(TQString::tqfromLatin1("<html>"));
     }
     m_tokenizer->write(text, false);
 }
