@@ -151,25 +151,25 @@ static TQString readLine( TQFile& file )
 
 static TQColor translatecolor( const TQString& s )
 {
-  if ( s == "R" ) return Qt::red;
-  if ( s == "O" ) return Qt::magenta;
-  if ( s == "Y" ) return Qt::yellow;
-  if ( s == "P" ) return Qt::darkMagenta;
-  if ( s == "V" ) return Qt::darkBlue;
-  if ( s == "Bl" ) return Qt::blue;
-  if ( s == "lBl" ) return Qt::cyan; // TODO: bright blue
-  if ( s == "G" ) return Qt::green;
-  if ( s == "dG" ) return Qt::darkGreen;
+  if ( s == "R" ) return TQt::red;
+  if ( s == "O" ) return TQt::magenta;
+  if ( s == "Y" ) return TQt::yellow;
+  if ( s == "P" ) return TQt::darkMagenta;
+  if ( s == "V" ) return TQt::darkBlue;
+  if ( s == "Bl" ) return TQt::blue;
+  if ( s == "lBl" ) return TQt::cyan; // TODO: bright blue
+  if ( s == "G" ) return TQt::green;
+  if ( s == "dG" ) return TQt::darkGreen;
   if ( s == "Br" ) return TQColor( 165, 42, 42 );
   if ( s == "dBr" ) return TQColor( 128, 128, 0 );
-  if ( s == "lGr" ) return Qt::lightGray;
-  if ( s == "Gr" ) return Qt::gray;
-  if ( s == "dGr" ) return Qt::darkGray;
-  if ( s == "B" ) return Qt::black;
-  if ( s == "W" ) return Qt::white;
+  if ( s == "lGr" ) return TQt::lightGray;
+  if ( s == "Gr" ) return TQt::gray;
+  if ( s == "dGr" ) return TQt::darkGray;
+  if ( s == "B" ) return TQt::black;
+  if ( s == "W" ) return TQt::white;
 
   kdDebug() << k_funcinfo << "unknown color: " << s << endl;
-  return Qt::black;
+  return TQt::black;
 }
 
 bool KigFilterCabri::readObject( TQFile& f, CabriObject& myobj )
@@ -549,7 +549,7 @@ KigDocument* KigFilterCabri::load( const TQString& file )
     else
     {
       notSupported( file, i18n( "This Cabri file contains a \"%1\" object, "
-                                "which Kig does not currently support." ).arg( obj.type ) );
+                                "which Kig does not currently support." ).tqarg( TQString(obj.type) ) );
       return 0;
     }
 
