@@ -213,9 +213,9 @@ double LatexExportImpVisitor::dimRealToCoord( int dim )
 TQString LatexExportImpVisitor::writeStyle( Qt::PenStyle style )
 {
   TQString ret( "linestyle=" );
-  if ( style == Qt::DashLine )
+  if ( style == TQt::DashLine )
     ret += "dashed";
-  else if ( style == Qt::DotLine )
+  else if ( style == TQt::DotLine )
     ret += "dotted,dotsep=2pt";
   else
     ret += "solid";
@@ -228,9 +228,9 @@ void LatexExportImpVisitor::plotGenericCurve( const CurveImp* imp )
   if ( width == -1 ) width = 1;
 
   TQString prefix = TQString( "\\pscurve[linecolor=%1,linewidth=%2,%3]" )
-      .arg( mcurcolorid )
-      .arg( width / 100.0 )
-      .arg( writeStyle( mcurobj->drawer()->style() ) );
+      .tqarg( mcurcolorid )
+      .tqarg( width / 100.0 )
+      .tqarg( writeStyle( mcurobj->drawer()->style() ) );
 
   std::vector< std::vector< Coordinate > > coordlist;
   coordlist.push_back( std::vector< Coordinate >() );
@@ -483,7 +483,7 @@ void LatexExportImpVisitor::visit( const PolygonImp* imp )
 void LatexExporter::run( const KigPart& doc, KigWidget& w )
 {
   KigFileDialog* kfd = new KigFileDialog(
-      TQString::null, i18n( "*.tex|Latex Documents (*.tex)" ),
+      TQString(), i18n( "*.tex|Latex Documents (*.tex)" ),
       i18n( "Export as Latex" ), &w );
   kfd->setOptionCaption( i18n( "Latex Options" ) );
   LatexExporterOptions* opts = new LatexExporterOptions( 0L );
@@ -507,7 +507,7 @@ void LatexExporter::run( const KigPart& doc, KigWidget& w )
   {
     KMessageBox::sorry( &w, i18n( "The file \"%1\" could not be opened. Please "
                                   "check if the file permissions are set correctly." )
-                        .arg( file_name ) );
+                        .tqarg( file_name ) );
     return;
   };
 
