@@ -102,12 +102,12 @@ void StandardConstructorBase::handlePrelim(
   assert ( margsparser.check( os ) != ArgsParser::Invalid );
   std::vector<ObjectCalcer*> args = margsparser.parse( os );
   p.setBrushStyle( Qt::NoBrush );
-  p.setBrushColor( Qt::red );
-  p.setPen( TQPen ( Qt::red,  1) );
+  p.setBrushColor( TQt::red );
+  p.setPen( TQPen ( TQt::red,  1) );
   p.setWidth( -1 ); // -1 means the default width for the object being
                     // drawn..
 
-  ObjectDrawer drawer( Qt::red );
+  ObjectDrawer drawer( TQt::red );
   drawprelim( drawer, p, args, d );
 }
 
@@ -305,7 +305,7 @@ TQString StandardConstructorBase::useText( const ObjectCalcer& o, const std::vec
   transform( sel.begin(), sel.end(), back_inserter( args ), mem_fun( &ObjectCalcer::imp ) );
 
   std::string ret = margsparser.usetext( o.imp(), args );
-  if ( ret.empty() ) return TQString::null;
+  if ( ret.empty() ) return TQString();
   return i18n( ret.c_str() );
 }
 
@@ -318,7 +318,7 @@ TQString StandardConstructorBase::selectStatement(
   transform( sel.begin(), sel.end(), back_inserter( args ), mem_fun( &ObjectCalcer::imp ) );
 
   std::string ret = margsparser.selectStatement( args );
-  if ( ret.empty() ) return TQString::null;
+  if ( ret.empty() ) return TQString();
   return i18n( ret.c_str() );
 }
 
@@ -331,7 +331,7 @@ TQString MergeObjectConstructor::useText( const ObjectCalcer& o, const std::vect
     int w = (*i)->wantArgs( args, d, v );
     if ( w != ArgsParser::Invalid ) return (*i)->useText( o, sel, d, v );
   };
-  return TQString::null;
+  return TQString();
 }
 
 TQString MergeObjectConstructor::selectStatement(
@@ -344,7 +344,7 @@ TQString MergeObjectConstructor::selectStatement(
     int wa = (*i)->wantArgs( args, d, w );
     if ( wa != ArgsParser::Invalid ) return (*i)->selectStatement( sel, d, w );
   };
-  return TQString::null;
+  return TQString();
 }
 
 MacroConstructor::MacroConstructor( const ObjectHierarchy& hier, const TQString& name,
@@ -421,7 +421,7 @@ TQString MacroConstructor::selectStatement(
   transform( sel.begin(), sel.end(), back_inserter( args ),
              mem_fun( &ObjectCalcer::imp ) );
   std::string ret = mparser.selectStatement( args );
-  if ( ret.empty() ) return TQString::null;
+  if ( ret.empty() ) return TQString();
   else return i18n( ret.c_str() );
 }
 
@@ -434,7 +434,7 @@ TQString MacroConstructor::useText( const ObjectCalcer& o, const std::vector<Obj
   transform( sel.begin(), sel.end(), back_inserter( args ),
              mem_fun( &ObjectCalcer::imp ) );
   std::string ret = mparser.usetext( o.imp(), args );
-  if ( ret.empty() ) return TQString::null;
+  if ( ret.empty() ) return TQString();
   else return i18n( ret.c_str() );
 }
 
