@@ -231,7 +231,7 @@ void TextLabelModeBase::mouseMoved( TQMouseEvent* e, KigWidget* w )
       TQString s = d->locationparent->imp()->type()->attachToThisStatement();
       mdoc.emitStatusBarText( s );
 
-      KigPainter p( w->screenInfo(), &w->curPix, mdoc.document() );
+      KigPainter p( w->screenInfo(), TQT_TQPAINTDEVICE(&w->curPix), mdoc.document() );
 
       // set the text next to the arrow cursor
       TQPoint point = e->pos();
@@ -376,7 +376,7 @@ void TextLabelModeBase::updateLinksLabel()
     }
     else
       // otherwise, we show a stub...
-      linktext = i18n( "argument %1" ).arg( count + 1 );
+      linktext = i18n( "argument %1" ).tqarg( count + 1 );
 
     d->wiz->myCustomWidget1->addLink( linktext, buf );
     // set pos and prevpos to the next char after the last match, so
@@ -406,7 +406,7 @@ void TextLabelModeBase::linkClicked( int i )
   d->mwawd = ReallySelectingArgs;
   d->mwaaws = i;
 
-  mdoc.emitStatusBarText( i18n( "Selecting argument %1" ).arg( i + 1 ) );
+  mdoc.emitStatusBarText( i18n( "Selecting argument %1" ).tqarg( i + 1 ) );
 }
 
 void TextLabelModeBase::redrawScreen( KigWidget* w )
