@@ -198,12 +198,12 @@ NormalModePopupObjects::NormalModePopupObjects( KigPart& part,
   else if ( single )
   {
     if ( !objs[0]->name().isNull() )
-      title = TQString::fromLatin1( "%1 %2" ).arg( objs[0]->imp()->type()->translatedName() ).arg( objs[0]->name() );
+      title = TQString::tqfromLatin1( "%1 %2" ).tqarg( objs[0]->imp()->type()->translatedName() ).tqarg( objs[0]->name() );
     else
       title = objs[0]->imp()->type()->translatedName();
   }
   else
-    title = i18n( "%1 Objects" ).arg( objs.size() );
+    title = i18n( "%1 Objects" ).tqarg( objs.size() );
   insertTitle( title, 1 );
 
   if ( !empty )
@@ -281,22 +281,22 @@ NormalModePopupObjects::NormalModePopupObjects( KigPart& part,
       i18n( "Set Co&lor" ),
       i18n( "Set &Pen Width" ),
       i18n( "Set St&yle" ),
-      TQString::null,
+      TQString(),
       i18n( "Set Coordinate S&ystem" )
     };
   static const TQString menuicons[NumberOfMenus] =
     {
       "centralsymmetry",
       "test",
-      TQString::null,
+      TQString(),
       "launch",
       "kig_text",
       "color_fill",
 //      "colorize",
       "sizer",
       "paintbrush",
-      TQString::null,
-      TQString::null
+      TQString(),
+      TQString()
     };
   int index = 1;
   for ( int i = 0; i < NumberOfMenus; ++i )
@@ -360,14 +360,14 @@ NormalModePopupObjects::~NormalModePopupObjects()
 
 static const TQColor* colors[] =
 {
-  &Qt::blue,
-  &Qt::black,
-  &Qt::gray,
-  &Qt::red,
-  &Qt::green,
-  &Qt::cyan,
-  &Qt::yellow,
-  &Qt::darkRed
+  &TQt::blue,
+  &TQt::black,
+  &TQt::gray,
+  &TQt::red,
+  &TQt::green,
+  &TQt::cyan,
+  &TQt::yellow,
+  &TQt::darkRed
 };
 static const int numberofcolors = sizeof( colors ) / sizeof( TQColor* );
 
@@ -424,14 +424,14 @@ void BuiltinObjectActionsProvider::fillUpMenu( NormalModePopupObjects& popup, in
         point = false;
       if ( (*i)->drawer()->color() != color ) samecolor = false;
     };
-    if ( ! samecolor ) color = Qt::blue;
+    if ( ! samecolor ) color = TQt::blue;
     TQPixmap p( point ? 20 : 50, 20 );
     for ( int i = 1; i < 8; ++i )
     {
       p.fill( popup.eraseColor() );
       TQPainter ptr( &p );
       ptr.setPen( TQPen( color, 1 ) );
-      ptr.setBrush( TQBrush( color, Qt::SolidPattern ) );
+      ptr.setBrush( TQBrush( color, TQt::SolidPattern ) );
       if ( point )
       {
         int size = 2*i;
@@ -463,14 +463,14 @@ void BuiltinObjectActionsProvider::fillUpMenu( NormalModePopupObjects& popup, in
       if ( (*i)->drawer()->color() != color ) samecolor = false;
     };
     bool point = ( npoints > nothers );
-    if ( ! samecolor ) color = Qt::blue;
+    if ( ! samecolor ) color = TQt::blue;
     if ( point )
       for ( int i = 0; i < 5; ++i )
       {
         TQPixmap p( 20, 20 );
         p.fill( popup.eraseColor() );
         ScreenInfo si( Rect( -1, -1, 2, 2 ), p.rect() );
-        KigPainter ptr( si, &p, popup.part().document(), false );
+        KigPainter ptr( si, TQT_TQPAINTDEVICE(&p), popup.part().document(), false );
         PointImp pt( Coordinate( 0, 0 ) );
         ObjectDrawer d( color, -1, true, Qt::SolidLine, i );
         d.draw( pt, ptr, false );
@@ -484,7 +484,7 @@ void BuiltinObjectActionsProvider::fillUpMenu( NormalModePopupObjects& popup, in
         TQPixmap p( 50, 20 );
         p.fill( popup.eraseColor() );
         ScreenInfo si( Rect( -2.5, -1, 5, 2 ), p.rect() );
-        KigPainter ptr( si, &p, popup.part().document(), false );
+        KigPainter ptr( si, TQT_TQPAINTDEVICE(&p), popup.part().document(), false );
         LineImp line( Coordinate( -1, 0 ), Coordinate( 1, 0 ) );
         Qt::PenStyle ps = penstyles[i];
         ObjectDrawer d( color, -1, true, ps, 1 );
@@ -518,7 +518,7 @@ static void addNameLabel( ObjectCalcer* object, ObjectCalcer* namecalcer, const
        object->imp()->inherits( CurveImp::stype() ) )
     attachto = object;
   ObjectHolder* label = ObjectFactory::instance()->attachedLabel(
-      TQString::fromLatin1( "%1" ), attachto, loc, namelabelneedsframe, args, doc.document() );
+      TQString::tqfromLatin1( "%1" ), attachto, loc, namelabelneedsframe, args, doc.document() );
   doc.addObject( label );
 }
 
@@ -924,7 +924,7 @@ bool PropertiesActionsProvider::executeAction(
 //  ///////    Coordinate c = Coordinate::invalidCoord();
     Coordinate c = w.fromScreen( popup.plc() );
     ObjectHolder* label = ObjectFactory::instance()->attachedLabel(
-      TQString::fromLatin1( "%1" ), parent->calcer(), c,
+      TQString::tqfromLatin1( "%1" ), parent->calcer(), c,
       false, args, doc.document() );
     doc.addObject( label );
   }
@@ -1182,7 +1182,7 @@ ObjectChooserPopup::ObjectChooserPopup( const TQPoint& p, KigWidget& view,
   for ( uint i = 0; i < mobjs.size(); i++ )
   {
     insertItem( !mobjs[i]->name().isEmpty()
-                ? TQString::fromLatin1( "%1 %2" ).arg( mobjs[i]->imp()->type()->translatedName() ).arg( mobjs[i]->name() )
+                ? TQString::tqfromLatin1( "%1 %2" ).tqarg( mobjs[i]->imp()->type()->translatedName() ).tqarg( mobjs[i]->name() )
                 : mobjs[i]->imp()->type()->translatedName(),
                 i );
   }
