@@ -319,7 +319,7 @@ void Area::drawHighlighting(TQPainter & p)
 {
 	if (Area::highlightArea && !isMoving() && _highlightedPixmap)
 	{
-  	p.setRasterOp(Qt::CopyROP);
+  	p.setRasterOp(TQt::CopyROP);
   	
   	TQPoint point = TQPoint(rect().x(),rect().y());
     if (point.x()<0)
@@ -336,10 +336,10 @@ void Area::drawAlt(TQPainter & p)
 {
   double x,y;
 
-  double scalex = p.worldMatrix().m11();
-//  double scaley = p.worldMatrix().m12();
+  double scalex = p.tqworldMatrix().m11();
+//  double scaley = p.tqworldMatrix().m12();
 
-  TQWMatrix oldMatrix = p.worldMatrix();
+  TQWMatrix oldMatrix = p.tqworldMatrix();
 
   p.setWorldMatrix(TQWMatrix(1,oldMatrix.m12(), oldMatrix.m21(), 1, oldMatrix.dx(), oldMatrix.dy() ));
 
@@ -356,12 +356,12 @@ void Area::drawAlt(TQPainter & p)
 
   if (highlightArea)
   {
-    p.setRasterOp(Qt::CopyROP);
-    p.setPen(Qt::black);
+    p.setRasterOp(TQt::CopyROP);
+    p.setPen(TQt::black);
   }
   else
   {
-    p.setRasterOp(Qt::XorROP);
+    p.setRasterOp(TQt::XorROP);
   	p.setPen(TQPen(TQColor("white"),1));
 	}
 
@@ -379,10 +379,10 @@ void Area::draw(TQPainter & p)
   {
 		int i=0;
 
-    double scalex = p.worldMatrix().m11();
-//    double scaley = p.worldMatrix().m12();
+    double scalex = p.tqworldMatrix().m11();
+//    double scaley = p.tqworldMatrix().m12();
 
-    TQWMatrix oldMatrix = p.worldMatrix();
+    TQWMatrix oldMatrix = p.tqworldMatrix();
 
     p.setWorldMatrix(TQWMatrix(1,oldMatrix.m12(), oldMatrix.m21(), 1, oldMatrix.dx(), oldMatrix.dy() ));
 
@@ -392,15 +392,15 @@ void Area::draw(TQPainter & p)
 			if (i==currentHighlighted) {
 				TQRect r2(0,0,15,15);
 				r2.moveCenter(r->center()*scalex);
-				p.setRasterOp(Qt::CopyROP);
+				p.setRasterOp(TQt::CopyROP);
 				p.setPen(TQPen(TQColor("lightgreen"),2));
 				p.drawEllipse(r2);
-				p.setRasterOp(Qt::XorROP);
+				p.setRasterOp(TQt::XorROP);
 				p.setPen(TQPen(TQColor("white"),1));
 			}
 
 			// Draw the selection point
-			p.setRasterOp(Qt::XorROP);
+			p.setRasterOp(TQt::XorROP);
 
 			TQRect r3(*r);
       int d = 1;
@@ -415,7 +415,7 @@ void Area::draw(TQPainter & p)
 
 			r3.setSize(r3.size()+TQSize(2,2));
 //+			r3.moveBy(-1,-1);	
-			p.setRasterOp(Qt::CopyROP);
+			p.setRasterOp(TQt::CopyROP);
 			p.setPen(TQPen(TQColor("lightgreen"),1));
 			p.setBrush(TQColor("lightgreen"));
 			p.drawPie(r3,0,5760);
@@ -435,7 +435,7 @@ void Area::draw(TQPainter & p)
   {
      drawAlt(p);
    }
-  p.setRasterOp(Qt::XorROP);
+  p.setRasterOp(TQt::XorROP);
 	
 }
 
@@ -584,9 +584,9 @@ void Area::setHighlightedPixmap( TQImage & im, TQBitmap & mask )
   {
     for (int x=0; x < size.width(); x++)
     {
-      r = qRed(image.pixel(x,y));
-      g = qGreen(image.pixel(x,y));
-      b = qBlue(image.pixel(x,y));
+      r = tqRed(image.pixel(x,y));
+      g = tqGreen(image.pixel(x,y));
+      b = tqBlue(image.pixel(x,y));
       r = (r *123 / 255)+132;
       g = (g *123 / 255)+132;
       b = (b *123 / 255)+132;
@@ -639,15 +639,15 @@ void RectArea::draw(TQPainter & p)
 {
 
   drawHighlighting(p);
-//  p.setRasterOp(Qt::CopyROP);
-//  p.setRasterOp(Qt:: OrROP);
+//  p.setRasterOp(TQt::CopyROP);
+//  p.setRasterOp(TQt:: OrROP);
 //  TQBrush b(TQBrush::SolidPattern);
 //  TQBrush b(TQBrush::Dense4Pattern);
 //  TQBrush b(TQBrush::BDiagPattern);
 //	b.setColor(TQColor(32,32,32));
 //	p.fillRect(rect(), b);
 	
-	p.setRasterOp(Qt::XorROP);
+	p.setRasterOp(TQt::XorROP);
 	p.setPen(TQPen(TQColor("white"),1));
   TQRect r(rect());
   r.setWidth(r.width()+1);
@@ -661,12 +661,12 @@ TQBitmap RectArea::getMask() const
 {
 	TQBitmap mask(rect().width(),rect().height());
 	
-	mask.fill(Qt::color0);
+	mask.fill(TQt::color0);
 	TQPainter p(&mask);
-	p.setBackgroundColor(Qt::color0);
-	p.setPen(Qt::color1);
-	p.setBrush(Qt::color1);
-	mask.fill(Qt::color1);
+	p.setBackgroundColor(TQt::color0);
+	p.setPen(TQt::color1);
+	p.setBrush(TQt::color1);
+	mask.fill(TQt::color1);
 	p.end();
 	
 	return mask;
@@ -675,10 +675,10 @@ TQBitmap RectArea::getMask() const
 TQString RectArea::coordsToString() const
 {
 	TQString retStr=TQString("%1,%2,%3,%4")
-					.arg(rect().left())
-					.arg(rect().top())
-					.arg(rect().right())
-					.arg(rect().bottom());
+					.tqarg(rect().left())
+					.tqarg(rect().top())
+					.tqarg(rect().right())
+					.tqarg(rect().bottom());
 
 	return retStr;					
 }
@@ -747,7 +747,7 @@ bool RectArea::setCoords(const TQString & s)
 TQString RectArea::getHTMLCode() const {
 	TQString retStr;
 	retStr+="<area ";
-	retStr+="shape=\"rect\" ";
+	retStr+="tqshape=\"rect\" ";
 	
 	retStr+=getHTMLAttributes();
 	
@@ -791,7 +791,7 @@ void CircleArea::draw(TQPainter & p)
   drawHighlighting(p);
 
 /*
-  p.setRasterOp(Qt::CopyROP);
+  p.setRasterOp(TQt::CopyROP);
 	TQBrush bold = p.brush();
 	TQBrush b(TQBrush::Dense5Pattern);
 	b.setColor(TQColor("green"));
@@ -802,7 +802,7 @@ void CircleArea::draw(TQPainter & p)
 	p.drawChord(r,0,5760);
 	p.setBrush(bold);
 */	
-  p.setRasterOp(Qt::XorROP);
+  p.setRasterOp(TQt::XorROP);
   p.setPen(TQPen(TQColor("white"),1));
 
   TQRect r(_rect);
@@ -817,11 +817,11 @@ TQBitmap CircleArea::getMask() const
 {
 	TQBitmap mask(_rect.width(),_rect.height());
 	
-	mask.fill(Qt::color0);
+	mask.fill(TQt::color0);
 	TQPainter p(&mask);
-	p.setBackgroundColor(Qt::color0);
-	p.setPen(Qt::color1);
-	p.setBrush(Qt::color1);
+	p.setBackgroundColor(TQt::color0);
+	p.setPen(TQt::color1);
+	p.setBrush(TQt::color1);
 	p.drawPie(TQRect(0,0,_rect.width(),_rect.height()),0,5760);
 	p.flush();
 	p.end();
@@ -834,9 +834,9 @@ TQBitmap CircleArea::getMask() const
 TQString CircleArea::coordsToString() const
 {
 	TQString retStr=TQString("%1,%2,%3")
-					.arg(_rect.center().x())
-					.arg(_rect.center().y())
-					.arg(_rect.width()/2);
+					.tqarg(_rect.center().x())
+					.tqarg(_rect.center().y())
+					.tqarg(_rect.width()/2);
 	
 	return retStr;
 }
@@ -949,7 +949,7 @@ bool CircleArea::setCoords(const TQString & s)
 TQString CircleArea::getHTMLCode() const {
 	TQString retStr;
 	retStr+="<area ";
-	retStr+="shape=\"circle\" ";
+	retStr+="tqshape=\"circle\" ";
 	
 	retStr+=getHTMLAttributes();
 	
@@ -985,16 +985,16 @@ void PolyArea::draw(TQPainter & p)
 {
   drawHighlighting(p);
 	
-	p.setRasterOp(Qt::XorROP);
+	p.setRasterOp(TQt::XorROP);
 	p.setPen(TQPen(TQColor("white"),1));
  	if (_coords->count()==0) return;
 
 
 
  	if (_finished)
-    p.drawPolygon ( *_coords,false,0,_coords->count());
+    p.tqdrawPolygon ( *_coords,false,0,_coords->count());
   else
-    p.drawPolyline ( *_coords,0,_coords->count());
+    p.tqdrawPolyline ( *_coords,0,_coords->count());
 
 /*
  	p.moveTo(_coords->point(0));
@@ -1011,16 +1011,16 @@ TQBitmap PolyArea::getMask() const
 {
 	TQBitmap mask(_rect.width(),_rect.height());
 	
-	mask.fill(Qt::color0);
+	mask.fill(TQt::color0);
 	TQPainter p(&mask);
-	p.setBackgroundColor(Qt::color0);
-	p.setPen(Qt::color1);
-	p.setBrush(Qt::color1);
+	p.setBackgroundColor(TQt::color0);
+	p.setPen(TQt::color1);
+	p.setBrush(TQt::color1);
  	p.setClipping(true);
  	TQRegion r(*_coords);
  	r.translate(-_rect.left(),-_rect.top());
  	p.setClipRegion(r);
- 	p.fillRect(TQRect(0,0,_rect.width(),_rect.height()),Qt::color1);
+ 	p.fillRect(TQRect(0,0,_rect.width(),_rect.height()),TQt::color1);
  	p.flush();
 	p.end();
 	
@@ -1033,8 +1033,8 @@ TQString PolyArea::coordsToString() const
  	
  	for (uint i=0;i<_coords->count();i++) {
  		retStr.append(TQString("%1,%2,")
- 			.arg(_coords->point(i).x())
- 			.arg(_coords->point(i).y()));
+ 			.tqarg(_coords->point(i).x())
+ 			.tqarg(_coords->point(i).y()));
  	}
  	
  	retStr.remove(retStr.length()-1,1);
@@ -1224,7 +1224,7 @@ bool PolyArea::setCoords(const TQString & s)
 TQString PolyArea::getHTMLCode() const {
 	TQString retStr;
 	retStr+="<area ";
-	retStr+="shape=\"poly\" ";
+	retStr+="tqshape=\"poly\" ";
 
 	retStr+=getHTMLAttributes();
 		
@@ -1283,7 +1283,7 @@ void DefaultArea::draw(TQPainter &)
 TQString DefaultArea::getHTMLCode() const {
 	TQString retStr;
 	retStr+="<area ";
-	retStr+="shape=\"default\" ";
+	retStr+="tqshape=\"default\" ";
 
 	retStr+=getHTMLAttributes();
 		
@@ -1302,7 +1302,7 @@ AreaSelection::AreaSelection()
 {
 	_areas = new AreaList();
 	_name = "Selection";
-	invalidate();
+	tqinvalidate();
 }
 
 AreaSelection::~AreaSelection() {
@@ -1352,7 +1352,7 @@ void AreaSelection::add(Area *a)
   	}
   }
 
-	invalidate();
+	tqinvalidate();
 }
 
 void AreaSelection::remove(Area *a)
@@ -1362,7 +1362,7 @@ void AreaSelection::remove(Area *a)
 		
 	a->setSelected( false );	
 	_areas->remove( a );
-	invalidate();
+	tqinvalidate();
 }
 
 void AreaSelection::reset()
@@ -1375,7 +1375,7 @@ void AreaSelection::reset()
   }
  	
  	_areas->clear();
-	invalidate();
+	tqinvalidate();
 }
 
 bool AreaSelection::contains(const TQPoint & p) const
@@ -1423,7 +1423,7 @@ void AreaSelection::moveSelectionPoint(TQRect* selectionPoint, const TQPoint & p
 		
 	_areas->getFirst()->moveSelectionPoint(selectionPoint,p);		
 
-	invalidate();
+	tqinvalidate();
 }
 
 
@@ -1436,7 +1436,7 @@ void AreaSelection::moveBy(int dx, int dy)
 
 	Area::moveBy( dx, dy );  	
 
-	invalidate();
+	tqinvalidate();
 }
 
 TQString AreaSelection::typeString() const
@@ -1474,7 +1474,7 @@ void AreaSelection::updateSelectionPoints()
 		it.current()->updateSelectionPoints();
   }
 
- 	invalidate();
+ 	tqinvalidate();
 
 }
 
@@ -1525,7 +1525,7 @@ void AreaSelection::setArea(const Area & copy)
 		setAreaSelection(*selection);
 	else {	
     Area::setArea(copy);
-  	invalidate();
+  	tqinvalidate();
   }
 }
 
@@ -1541,14 +1541,14 @@ void AreaSelection::setAreaSelection(const AreaSelection & copy)
    	it.current()->setArea(*it2.current());
 
   Area::setArea(copy);
-	invalidate();
+	tqinvalidate();
 }
 
 void AreaSelection::setAreaList( const AreaList & areas )
 {
 	delete _areas;
 	_areas = new AreaList(areas);
-	invalidate();
+	tqinvalidate();
 }
 
 void AreaSelection::setRect(const TQRect & r)
@@ -1558,7 +1558,7 @@ void AreaSelection::setRect(const TQRect & r)
 		_areas->getFirst()->setRect(r);
 	}
 
-	invalidate();
+	tqinvalidate();
 	_rect=rect();
 	updateSelectionPoints();
 }
@@ -1586,7 +1586,7 @@ int AreaSelection::addCoord(const TQPoint & p)
 	if ( _areas->count()==1 )
 	{
 		return _areas->getFirst()->addCoord(p);
-		invalidate();
+		tqinvalidate();
 	}
 
   return 0;	
@@ -1597,7 +1597,7 @@ void AreaSelection::insertCoord(int pos, const TQPoint & p)
 	if ( _areas->count()==1 )
 	{
 		_areas->getFirst()->insertCoord(pos, p);
-		invalidate();
+		tqinvalidate();
 	}	
 }
 
@@ -1606,7 +1606,7 @@ void AreaSelection::removeCoord(int pos)
 	if ( _areas->count()==1 )
 	{
 		_areas->getFirst()->removeCoord(pos);
-		invalidate();
+		tqinvalidate();
 	}	
 }
 
@@ -1617,7 +1617,7 @@ bool AreaSelection::removeSelectionPoint(TQRect * r)
 	if ( _areas->count()==1 )
 	{
 		result = _areas->getFirst()->removeSelectionPoint(r);
-		invalidate();
+		tqinvalidate();
 	}	
 	
 	return result;
@@ -1639,7 +1639,7 @@ void AreaSelection::moveCoord(int pos,const TQPoint & p)
 	if ( _areas->count()==1 )
 	{
 		_areas->getFirst()->moveCoord(pos,p);
-		invalidate();
+		tqinvalidate();
 	}	
 }
 
@@ -1648,7 +1648,7 @@ void AreaSelection::highlightSelectionPoint(int i)
 	if ( _areas->count()==1 )
 	{
 		_areas->getFirst()->highlightSelectionPoint(i);
-		invalidate();
+		tqinvalidate();
 	}	
 }
 
