@@ -4,7 +4,7 @@
  *           (c) 1999 Mario Weilguni <mweilguni@sime.com>
  *           (c) 2001 Lubos Lunak <l.lunak@kde.org>
  *
- * $Id: kinit.cpp 1157647 2010-07-31 19:46:43Z tpearson $
+ * $Id: kinit.cpp 1246075 2011-08-10 06:08:18Z tpearson $
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -645,7 +645,7 @@ static pid_t launch(int argc, const char *_name, const char *args,
            {
               const char * ltdlError = lt_dlerror();
               fprintf(stderr, "Could not find kdemain: %s\n", ltdlError != 0 ? ltdlError : "(null)" );
-              TQString errorMsg = i18n("Could not find 'kdemain' in '%1'.\n%2").arg(libpath)
+              TQString errorMsg = i18n("Could not find 'kdemain' in '%1'.\n%2").arg(TQString(libpath))
                  .arg(ltdlError ? TQFile::decodeName(ltdlError) : i18n("Unknown error"));
               exitWithErrorMsg(errorMsg);
            }
@@ -1520,7 +1520,7 @@ static void kdeinit_library_path()
    if((i = display.findRev('.')) > display.findRev(':') && i >= 0)
      display.truncate(i);
 
-   TQCString socketName = TQFile::encodeName(locateLocal("socket", TQString("kdeinit-%1").arg(display), s_instance));
+   TQCString socketName = TQFile::encodeName(locateLocal("socket", TQString("kdeinit-%1").arg(TQString(display)), s_instance));
    if (socketName.length() >= MAX_SOCK_FILE)
    {
      fprintf(stderr, "kdeinit: Aborting. Socket name will be too long:\n");
@@ -1530,7 +1530,7 @@ static void kdeinit_library_path()
    strcpy(sock_file_old, socketName.data());
 
    display.replace(":","_");
-   socketName = TQFile::encodeName(locateLocal("socket", TQString("kdeinit_%1").arg(display), s_instance));
+   socketName = TQFile::encodeName(locateLocal("socket", TQString("kdeinit_%1").arg(TQString(display)), s_instance));
    if (socketName.length() >= MAX_SOCK_FILE)
    {
      fprintf(stderr, "kdeinit: Aborting. Socket name will be too long:\n");
