@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: kfdtest.h 1157647 2010-07-31 19:46:43Z tpearson $
+** $Id: kfdtest.h 1214149 2011-01-13 08:32:36Z tpearson $
 **
 ** Copyright (C) 2003 Carsten Pfeiffer <pfeiffer@kde.org>
 **
@@ -10,7 +10,7 @@
 
 #include <tqobject.h>
 
-class KFDTest : public QObject
+class KFDTest : public TQObject
 {
     Q_OBJECT
 
