@@ -17,7 +17,7 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-// $Id: kfileitem.cpp 1175771 2010-09-15 21:18:13Z tpearson $
+// $Id: kfileitem.cpp 1246075 2011-08-10 06:08:18Z tpearson $
 
 #include <sys/time.h>
 #include <pwd.h>
@@ -1041,7 +1041,7 @@ TQString KFileItem::parsePermissions(mode_t perm) const
     if (hasExtendedACL())
         p[10]='+';
 
-    return TQString::fromLatin1(p);
+    return TQString::tqfromLatin1(p);
 }
 
 // check if we need to cache this
