@@ -17,7 +17,7 @@
  *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  *  Boston, MA 02110-1301, USA.
  *
- *  $Id: kfilemetainfo.cpp 1157647 2010-07-31 19:46:43Z tpearson $
+ *  $Id: kfilemetainfo.cpp 1246075 2011-08-10 06:08:18Z tpearson $
  */
 
 #include <assert.h>
@@ -38,12 +38,12 @@
 #include "kfilemetainfo.h"
 
 // shared data of a KFileMetaInfoItem
-class KFileMetaInfoItem::Data : public QShared
+class KFileMetaInfoItem::Data : public TQShared
 {
 public:
     Data( const KFileMimeTypeInfo::ItemInfo* mti, const TQString& _key,
           const TQVariant& _value )
-        : QShared(),
+        : TQShared(),
           mimeTypeInfo( mti ),
           key( _key ),
           value( _value ),
@@ -270,11 +270,11 @@ void KFileMetaInfoItem::deref()
 ///////////////////////////////////////////////////////////////////
 
 // shared data of a KFileMetaInfo
-class KFileMetaInfo::Data : public QShared
+class KFileMetaInfo::Data : public TQShared
 {
 public:
     Data(const KURL& _url, uint _what)
-        : QShared(),
+        : TQShared(),
           url(_url),
           what(_what),
           mimeTypeInfo( 0L )
@@ -937,7 +937,7 @@ KFilePlugin* KFileMetaInfoProvider::loadPlugin( const TQString& mimeType, const
         query = "(not exist [X-KDE-Protocol])";
         queryMimeType = mimeType;
     } else {
-        query = TQString::fromLatin1( "[X-KDE-Protocol] == '%1'" ).arg(protocol);
+        query = TQString::tqfromLatin1( "[X-KDE-Protocol] == '%1'" ).arg(protocol);
         // querying for a protocol: we have no mimetype, so we need to use KFilePlugin as one
         queryMimeType = "KFilePlugin";
         // hopefully using KFilePlugin as genericMimeType too isn't a problem
@@ -951,7 +951,7 @@ KFilePlugin* KFileMetaInfoProvider::loadPlugin( const TQString& mimeType, const
         return 0;
 
     KFilePlugin* plugin = KParts::ComponentFactory::createInstanceFromService<KFilePlugin>
-                          ( service, this, mimeType.local8Bit() );
+                          ( service, TQT_TQOBJECT(this), mimeType.local8Bit() );
     if (!plugin)
         kdWarning(7033) << "error loading the plugin from " << service->desktopEntryPath() << endl;
 
@@ -1144,11 +1144,11 @@ TQStringList KFileMetaInfoProvider::supportedMimeTypes() const
 
 
 // shared data of a KFileMetaInfoGroup
-class KFileMetaInfoGroup::Data : public QShared
+class KFileMetaInfoGroup::Data : public TQShared
 {
 public:
     Data(const TQString& _name)
-        : QShared(),
+        : TQShared(),
           name(_name),
           mimeTypeInfo(0L),
           dirty( false ),
