@@ -84,12 +84,12 @@ KServiceGroup::KServiceGroup( const TQString &configFile, const TQString & _relp
   TQStringList tmpList;
   if (config.hasKey("OnlyShowIn"))
   {
-     if (!config.readListEntry("OnlyShowIn", ';').contains("KDE"))
+     if ((!config.readListEntry("OnlyShowIn", ';').contains("TDE")) && (!config.readListEntry("OnlyShowIn", ';').contains("KDE")))
         d->m_bNoDisplay = true;
   }
   if (config.hasKey("NotShowIn"))
   {
-     if (config.readListEntry("NotShowIn", ';').contains("KDE"))
+     if ((config.readListEntry("NotShowIn", ';').contains("TDE")) || (config.readListEntry("NotShowIn", ';').contains("KDE")))
         d->m_bNoDisplay = true;
   }
 
@@ -229,11 +229,11 @@ bool KServiceGroup::SuSEshortMenu() const
 void KServiceGroup::load( TQDataStream& s )
 {
   TQStringList groupList;
-  Q_INT8 noDisplay;
-  Q_INT8 _showEmptyMenu;
-  Q_INT8 inlineHeader;
-  Q_INT8 _inlineAlias;
-  Q_INT8 _allowInline;
+  TQ_INT8 noDisplay;
+  TQ_INT8 _showEmptyMenu;
+  TQ_INT8 inlineHeader;
+  TQ_INT8 _inlineAlias;
+  TQ_INT8 _allowInline;
   s >> m_strCaption >> m_strIcon >>
       m_strComment >> groupList >> m_strBaseGroupName >> m_childCount >>
       noDisplay >> d->suppressGenericNames >> d->directoryEntryPath >>
@@ -302,11 +302,11 @@ void KServiceGroup::save( TQDataStream& s )
 
   (void) childCount();
 
-  Q_INT8 noDisplay = d->m_bNoDisplay ? 1 : 0;
-  Q_INT8 _showEmptyMenu = d->m_bShowEmptyMenu ? 1 : 0;
-  Q_INT8 inlineHeader = d->m_bShowInlineHeader ? 1 : 0;
-  Q_INT8 _inlineAlias = d->m_bInlineAlias ? 1 : 0;
-  Q_INT8 _allowInline = d->m_bAllowInline ? 1 : 0;
+  TQ_INT8 noDisplay = d->m_bNoDisplay ? 1 : 0;
+  TQ_INT8 _showEmptyMenu = d->m_bShowEmptyMenu ? 1 : 0;
+  TQ_INT8 inlineHeader = d->m_bShowInlineHeader ? 1 : 0;
+  TQ_INT8 _inlineAlias = d->m_bInlineAlias ? 1 : 0;
+  TQ_INT8 _allowInline = d->m_bAllowInline ? 1 : 0;
   s << m_strCaption << m_strIcon <<
       m_strComment << groupList << m_strBaseGroupName << m_childCount <<
       noDisplay << d->suppressGenericNames << d->directoryEntryPath <<
@@ -707,7 +707,7 @@ KServiceGroup::childGroup(const TQString &parent)
    return KServiceGroupFactory::self()->findGroupByDesktopPath("#parent#"+parent, true);
 }
 
-QString
+TQString
 KServiceGroup::directoryEntryPath() const
 {
    return d->directoryEntryPath;
