@@ -346,7 +346,7 @@ bool Scheduler::startJobScheduled(ProtocolInfo *protInfo)
        // Prevent starvation. We skip the first entry in the queue at most
        // 2 times in a row. The
        protInfo->skipCount = 0;
-       job = protInfo->joblist.at(0);
+       job = protInfo->joblist.tqat(0);
        slave = findIdleSlave(protInfo, job, dummy );
     }
     else
@@ -356,7 +356,7 @@ bool Scheduler::startJobScheduled(ProtocolInfo *protInfo)
        Slave *firstSlave = 0;
        for(uint i = 0; (i < protInfo->joblist.count()) && (i < 10); i++)
        {
-          job = protInfo->joblist.at(i);
+          job = protInfo->joblist.tqat(i);
           slave = findIdleSlave(protInfo, job, exact);
           if (!firstSlave)
           {
@@ -504,7 +504,7 @@ Slave *Scheduler::findIdleSlave(ProtocolInfo *, SimpleJob *job, bool &exact)
           if ( bCanReuse )
           {
             KIO::MetaData outgoing = tJob->outgoingMetaData();
-            TQString resume = (!outgoing.contains("resume")) ? TQString::null : outgoing["resume"];
+            TQString resume = (!outgoing.contains("resume")) ? TQString() : outgoing["resume"];
             kdDebug(7006) << "Resume metadata is '" << resume << "'" << endl;
             bCanReuse = (resume.isEmpty() || resume == "0");
           }
@@ -865,7 +865,7 @@ Scheduler::_registerWindow(TQWidget *wid)
    if (!wid)
       return;
 
-   TQObject *obj = static_cast<TQObject *>(wid);
+   TQObject *obj = TQT_TQOBJECT(wid);
    if (!m_windowList.contains(obj))
    {
       // We must store the window Id because by the time
@@ -873,7 +873,7 @@ Scheduler::_registerWindow(TQWidget *wid)
       // access TQWidget::winId() (already destructed)
       WId windowId = wid->winId();
       m_windowList.insert(obj, windowId);
-      connect(wid, TQT_SIGNAL(destroyed(TQObject *)),
+      connect(TQT_TQOBJECT(wid), TQT_SIGNAL(destroyed(TQObject *)),
               this, TQT_SLOT(slotUnregisterWindow(TQObject*)));
       TQByteArray params;
       TQDataStream stream(params, IO_WriteOnly);
