@@ -59,7 +59,7 @@ extern "C"
 using namespace KIO;
 using namespace KCDDB;
 
-#define QFL1(x) TQString::fromLatin1(x)
+#define TQFL1(x) TQString::tqfromLatin1(x)
 #define DEFAULT_CD_DEVICE "/dev/cdrom"
 #define CDDB_INFORMATION "CDDB Information"
 
@@ -251,9 +251,9 @@ struct cdrom_drive * AudioCDProtocol::initRequest(const KURL & url)
 			// circumstances, so build a representation from
 			// the unit number and SCSI device name.
 			//
-			TQString devname = TQString::fromLatin1( "/dev/%1%2" )
-				.arg( drive->dev->given_dev_name )
-				.arg( drive->dev->given_unit_number ) ;
+			TQString devname = TQString::tqfromLatin1( "/dev/%1%2" )
+				.tqarg( drive->dev->given_dev_name )
+				.tqarg( drive->dev->given_unit_number ) ;
 			kdDebug(7117) << "  Using derived name " << devname << endl;
 			d->cd.setDevice( devname );
 		}
@@ -399,7 +399,7 @@ void AudioCDProtocol::get(const KURL & url)
 
 	if( d->fname.contains(i18n(CDDB_INFORMATION))){
 		uint choice = 1;
-		if(d->fname != TQString("%1.txt").arg(i18n(CDDB_INFORMATION))){
+		if(d->fname != TQString("%1.txt").tqarg(i18n(CDDB_INFORMATION))){
 			choice= d->fname.section('_',1,1).section('.',0,0).toInt();
 		}
 		uint count = 1;
@@ -465,7 +465,7 @@ void AudioCDProtocol::get(const KURL & url)
 
 	unsigned long size = encoder->size(time_secs);
 	totalSize(size);
-	emit mimeType(QFL1(encoder->mimeType()));
+	emit mimeType(TQFL1(encoder->mimeType()));
 
 	// Read data (track/disk) from the cd
 	paranoiaRead(drive, firstSector, lastSector, encoder, url.fileName(), size);
@@ -504,7 +504,7 @@ void AudioCDProtocol::stat(const KURL & url)
 
 	UDSAtom atom;
 	atom.m_uds = KIO::UDS_NAME;
-	atom.m_str = url.fileName().replace('/', QFL1("%2F"));
+	atom.m_str = url.fileName().replace('/', TQFL1("%2F"));
 	kdDebug(7117) << k_funcinfo << atom.m_str << endl;
 	entry.append(atom);
 
@@ -610,15 +610,15 @@ void AudioCDProtocol::listDir(const KURL & url)
 		for ( it = d->cddbList.begin(); it != d->cddbList.end(); ++it ){
 			(*it).toString();
 			if(count == 1)
-				app_file(entry, TQString("%1.txt").arg(i18n(CDDB_INFORMATION)), ((*it).toString().length())+1);
+				app_file(entry, TQString("%1.txt").tqarg(i18n(CDDB_INFORMATION)), ((*it).toString().length())+1);
 			else
-				app_file(entry, TQString("%1_%2.txt").arg(i18n(CDDB_INFORMATION)).arg(count), ((*it).toString().length())+1);
+				app_file(entry, TQString("%1_%2.txt").tqarg(i18n(CDDB_INFORMATION)).tqarg(count), ((*it).toString().length())+1);
 			count++;
 			listEntry(entry, false);
 		}
 		// Error
 		if( count == 1 ) {
-			app_file(entry, TQString("%1: %2.txt").arg(i18n(CDDB_INFORMATION)).arg(CDDB::resultToString(d->cddbResult)), ((*it).toString().length())+1);
+			app_file(entry, TQString("%1: %2.txt").tqarg(i18n(CDDB_INFORMATION)).tqarg(CDDB::resultToString(d->cddbResult)), ((*it).toString().length())+1);
 			count++;
 			listEntry(entry, false);
 		}
@@ -838,7 +838,7 @@ void AudioCDProtocol::paranoiaRead(
 		if (0 == buf) {
 			kdDebug(7117) << "Unrecoverable error in paranoia_read" << endl;
 			ok = false;
-			error( ERR_SLAVE_DEFINED, i18n( "Error reading audio data for %1 from the CD" ).arg( fileName ) );
+			error( ERR_SLAVE_DEFINED, i18n( "Error reading audio data for %1 from the CD" ).tqarg( fileName ) );
 			break;
 		}
 
@@ -848,7 +848,7 @@ void AudioCDProtocol::paranoiaRead(
 		if(encoderProcessed == -1){
 			kdDebug(7117) << "Encoder processing error, stopping." << endl;
 			ok = false;
-			TQString errMsg = i18n( "Couldn't read %1: encoding failed" ).arg( fileName );
+			TQString errMsg = i18n( "Couldn't read %1: encoding failed" ).tqarg( fileName );
 			TQString details = encoder->lastErrorMessage();
 			if ( !details.isEmpty() )
 			    errMsg += "\n" + details;
@@ -926,7 +926,7 @@ void AudioCDProtocol::paranoiaRead(
 		processedSize(processed);
 	}
 	else if ( ok ) // i.e. no error message already emitted
-		error( ERR_SLAVE_DEFINED, i18n( "Couldn't read %1: encoding failed" ).arg( fileName ) );
+		error( ERR_SLAVE_DEFINED, i18n( "Couldn't read %1: encoding failed" ).tqarg( fileName ) );
 
 	paranoia_free(paranoia);
 	paranoia = 0;
@@ -960,17 +960,17 @@ void AudioCDProtocol::parseURLArgs(const KURL & url)
 		TQString attribute(token.left(equalsPos));
 		TQString value(token.mid(equalsPos + 1));
 
-		if (attribute == QFL1("device"))
+		if (attribute == TQFL1("device"))
 			d->device = value;
-		else if (attribute == QFL1("paranoia_level"))
+		else if (attribute == TQFL1("paranoia_level"))
 			d->paranoiaLevel = value.toInt();
-		else if (attribute == QFL1("fileNameTemplate"))
+		else if (attribute == TQFL1("fileNameTemplate"))
 			d->fileNameTemplate = value;
-		else if (attribute == QFL1("albumNameTemplate"))
+		else if (attribute == TQFL1("albumNameTemplate"))
 			d->albumTemplate = value;
-		else if (attribute == QFL1("cddbChoice"))
+		else if (attribute == TQFL1("cddbChoice"))
 			d->cddbUserChoice = value.toInt();
-		else if (attribute == QFL1("niceLevel")){
+		else if (attribute == TQFL1("niceLevel")){
 			int niceLevel = value.toInt();
 			if(setpriority(PRIO_PROCESS, getpid(), niceLevel) != 0)
 				kdDebug(7117) << "Setting nice level to (" << niceLevel << ") failed." << endl;
@@ -984,12 +984,12 @@ void AudioCDProtocol::parseURLArgs(const KURL & url)
  */
 void AudioCDProtocol::loadSettings()
 {
-	KConfig *config = new KConfig(QFL1("kcmaudiocdrc"), true /*readonly*/, false /*no kdeglobals*/);
+	KConfig *config = new KConfig(TQFL1("kcmaudiocdrc"), true /*readonly*/, false /*no kdeglobals*/);
 
-	config->setGroup(QFL1("CDDA"));
+	config->setGroup(TQFL1("CDDA"));
 
-	if (!config->readBoolEntry(QFL1("autosearch"),true)) {
-		d->device = config->readEntry(QFL1("device"),QFL1(DEFAULT_CD_DEVICE));
+	if (!config->readBoolEntry(TQFL1("autosearch"),true)) {
+		d->device = config->readEntry(TQFL1("device"),TQFL1(DEFAULT_CD_DEVICE));
 	}
 
 	d->paranoiaLevel = 1; // enable paranoia error correction, but allow skipping
@@ -1058,7 +1058,7 @@ void AudioCDProtocol::generateTemplateTitles()
 	{
 		for (unsigned int i = 0; i < d->tracks; i++){
 			TQString n;
-			d->templateTitles.append( i18n("Track %1").arg(n.sprintf("%02d", i + 1)));
+			d->templateTitles.append( i18n("Track %1").tqarg(n.sprintf("%02d", i + 1)));
 		}
 		return;
 	}
@@ -1076,11 +1076,11 @@ void AudioCDProtocol::generateTemplateTitles()
 		macros["title"] = (info.trackInfoList[i].title);
 		TQString n;
 		macros["number"] = n.sprintf("%02d", i + 1);
-		//macros["number"] = TQString("%1").arg(i+1, 2, 10);
+		//macros["number"] = TQString("%1").tqarg(i+1, 2, 10);
 		macros["genre"] = info.genre;
 		macros["year"] = TQString::number(info.year);
 
-		TQString title = KMacroExpander::expandMacros(d->fileNameTemplate, macros, '%').replace('/', QFL1("%2F"));
+		TQString title = KMacroExpander::expandMacros(d->fileNameTemplate, macros, '%').replace('/', TQFL1("%2F"));
 		title.replace( TQRegExp(d->rsearch), d->rreplace );
 		d->templateTitles.append(title);
 	}
@@ -1090,7 +1090,7 @@ void AudioCDProtocol::generateTemplateTitles()
 	macros["albumtitle"] = info.title;
 	macros["genre"] = info.genre;
 	macros["year"] = TQString::number(info.year);
-	d->templateAlbumName = KMacroExpander::expandMacros(d->albumTemplate, macros, '%').replace('/', QFL1("%2F"));
+	d->templateAlbumName = KMacroExpander::expandMacros(d->albumTemplate, macros, '%').replace('/', TQFL1("%2F"));
 	d->templateAlbumName.replace( TQRegExp(d->rsearch), d->rreplace );
 }
 
