@@ -78,10 +78,10 @@ TrashProtocol::TrashProtocol( const TQCString& protocol, const TQCString &pool,
 {
     struct passwd *user = getpwuid( getuid() );
     if ( user )
-        m_userName = TQString::fromLatin1(user->pw_name);
+        m_userName = TQString::tqfromLatin1(user->pw_name);
     struct group *grp = getgrgid( getgid() );
     if ( grp )
-        m_groupName = TQString::fromLatin1(grp->gr_name);
+        m_groupName = TQString::tqfromLatin1(grp->gr_name);
 }
 
 TrashProtocol::~TrashProtocol()
@@ -540,7 +540,7 @@ void TrashProtocol::get( const KURL& url )
              this, TQT_SLOT( slotMimetype( KIO::Job*, const TQString& ) ) );
     connect( job, TQT_SIGNAL( result(KIO::Job *) ),
              this, TQT_SLOT( jobFinished(KIO::Job *) ) );
-    qApp->eventLoop()->enterLoop();
+    tqApp->eventLoop()->enterLoop();
 }
 
 void TrashProtocol::slotData( KIO::Job*, const TQByteArray&arr )
@@ -559,7 +559,7 @@ void TrashProtocol::jobFinished( KIO::Job* job )
         error( job->error(), job->errorText() );
     else
         finished();
-    qApp->eventLoop()->exitLoop();
+    tqApp->eventLoop()->exitLoop();
 }
 
 #if 0
