@@ -149,10 +149,10 @@ const TQCString& kio_sieveResponse::getExtra() const
 }
 
 /* ---------------------------------------------------------------------------------- */
-void kio_sieveResponse::setQuantity(const uint& newQty)
+void kio_sieveResponse::setQuantity(const uint& newTQty)
 {
-	rType = QUANTITY;
-	quantity = newQty;
+	rType = TQUANTITY;
+	quantity = newTQty;
 }
 
 /* ---------------------------------------------------------------------------------- */
@@ -307,8 +307,8 @@ void kio_sieveProtocol::changeCheck( const KURL &url )
 		TQStringList::iterator it;
 
 		for ( it = q.begin(); it != q.end(); ++it ) {
-			if ( ( (*it).section('=',0,0) ).lower() == "x-mech" ) {
-				auth = ( (*it).section('=',1) ).upper();
+			if ( TQString( (*it).section('=',0,0) ).lower() == "x-mech" ) {
+				auth = TQString( (*it).section('=',1) ).upper();
 				break;
 			}
 		}
@@ -340,7 +340,7 @@ bool kio_sieveProtocol::connect(bool useTLSIfAvailable)
 
 	if (isConnectionValid()) return true;
 
-	infoMessage(i18n("Connecting to %1...").arg( m_sServer));
+	infoMessage(i18n("Connecting to %1...").tqarg( m_sServer));
 
 	if (m_connMode == CONNECTION_ORIENTED && m_shouldBeConnected) {
 		error(ERR_CONNECTION_BROKEN, i18n("The connection to the server was lost."));
@@ -453,7 +453,7 @@ void kio_sieveProtocol::disconnect(bool forcibly)
 /* ---------------------------------------------------------------------------------- */
 /*void kio_sieveProtocol::slave_status()
 {
-	slaveStatus(isConnectionValid() ? m_sServer : "", isConnectionValid());
+	slavetqStatus(isConnectionValid() ? m_sServer : "", isConnectionValid());
 
 	finished();
 }*/
@@ -626,7 +626,7 @@ void kio_sieveProtocol::put(const KURL& url, int /*permissions*/, bool /*overwri
 			error(ERR_UNSUPPORTED_PROTOCOL, i18n("A protocol error occurred "
 						"while trying to negotiate script uploading.\n"
 						"The server responded:\n%1")
-							.arg(r.getAction().right(r.getAction().length() - 3)));
+							.tqarg(r.getAction().right(r.getAction().length() - 3)));
 			return;
 		}
 	}*/
@@ -661,7 +661,7 @@ void kio_sieveProtocol::put(const KURL& url, int /*permissions*/, bool /*overwri
 			// send the extra message off for re-processing
 			receiveData(false, &extra);
 
-			if (r.getType() == kio_sieveResponse::QUANTITY) {
+			if (r.getType() == kio_sieveResponse::TQUANTITY) {
 				// length of the error message
 				uint len = r.getQuantity();
 
@@ -672,7 +672,7 @@ void kio_sieveProtocol::put(const KURL& url, int /*permissions*/, bool /*overwri
 				error(ERR_INTERNAL_SERVER,
 						i18n("The script did not upload successfully.\n"
 							"This is probably due to errors in the script.\n"
-							"The server responded:\n%1").arg(errmsg));
+							"The server responded:\n%1").tqarg(TQString(errmsg)));
 
 				// clear the rest of the incoming data
 				receiveData();
@@ -680,7 +680,7 @@ void kio_sieveProtocol::put(const KURL& url, int /*permissions*/, bool /*overwri
 				error(ERR_INTERNAL_SERVER,
 						i18n("The script did not upload successfully.\n"
 							"This is probably due to errors in the script.\n"
-							"The server responded:\n%1").arg(r.getKey()));
+							"The server responded:\n%1").tqarg(TQString(r.getKey())));
 			} else
 				error(ERR_INTERNAL_SERVER,
 					i18n("The script did not upload successfully.\n"
@@ -736,7 +736,7 @@ void kio_sieveProtocol::get(const KURL& url)
 	if (!sendData("GETSCRIPT \"" + filename.utf8() + "\""))
 		return;
 
-	if (receiveData() && r.getType() == kio_sieveResponse::QUANTITY) {
+	if (receiveData() && r.getType() == kio_sieveResponse::TQUANTITY) {
 		// determine script size
 		ssize_t total_len = r.getQuantity();
 		totalSize( total_len );
@@ -1016,7 +1016,7 @@ bool kio_sieveProtocol::saslInteract( void *in, AuthInfo &ai )
   return true;
 }
 
-#define SASLERROR  error(ERR_COULD_NOT_AUTHENTICATE, i18n("An error occurred during authentication: %1").arg( \
+#define SASLERROR  error(ERR_COULD_NOT_AUTHENTICATE, i18n("An error occurred during authentication: %1").tqarg( \
       TQString::fromUtf8( sasl_errdetail( conn ) )));
 
 bool kio_sieveProtocol::authenticate()
@@ -1082,13 +1082,13 @@ bool kio_sieveProtocol::authenticate()
 
 	ksDebug() << "Preferred authentication method is " << mechusing << "." << endl;
 
-  TQString firstCommand = "AUTHENTICATE \"" + TQString::fromLatin1( mechusing ) + "\"";
+  TQString firstCommand = "AUTHENTICATE \"" + TQString::tqfromLatin1( mechusing ) + "\"";
   tmp.setRawData( out, outlen );
   KCodecs::base64Encode( tmp, challenge );
   tmp.resetRawData( out, outlen );
   if ( !challenge.isEmpty() ) {
     firstCommand += " \"";
-    firstCommand += TQString::fromLatin1( challenge.data(), challenge.size() );
+    firstCommand += TQString::tqfromLatin1( challenge.data(), challenge.size() );
     firstCommand += "\"";
   }
 
@@ -1105,11 +1105,11 @@ bool kio_sieveProtocol::authenticate()
 
 		ksDebug() << "Challenge len  " << r.getQuantity() << endl;
 
-		if (r.getType() != kio_sieveResponse::QUANTITY) {
+		if (r.getType() != kio_sieveResponse::TQUANTITY) {
       sasl_dispose( &conn );
 			error(ERR_SLAVE_DEFINED,
 					i18n("A protocol error occurred during authentication.\n"
-							"Choose a different authentication method to %1.").arg(mechusing));
+							"Choose a different authentication method to %1.").tqarg(mechusing));
 			return false;
 		}
 
@@ -1121,7 +1121,7 @@ bool kio_sieveProtocol::authenticate()
       sasl_dispose( &conn );
 			error(ERR_UNSUPPORTED_PROTOCOL,
 					i18n("A protocol error occurred during authentication.\n"
-							"Choose a different authentication method to %1.").arg(mechusing));
+							"Choose a different authentication method to %1.").tqarg(mechusing));
 			return false;
 		}
 
@@ -1168,7 +1168,7 @@ bool kio_sieveProtocol::authenticate()
 		return true;
 	} else {
 		// Authentication failed.
-		error(ERR_COULD_NOT_AUTHENTICATE, i18n("Authentication failed.\nMost likely the password is wrong.\nThe server responded:\n%1").arg( r.getAction() ) );
+		error(ERR_COULD_NOT_AUTHENTICATE, i18n("Authentication failed.\nMost likely the password is wrong.\nThe server responded:\n%1").tqarg( TQString(r.getAction()) ) );
 		return false;
 	}
 }
@@ -1222,7 +1222,7 @@ bool kio_sieveProtocol::receiveData(bool waitForData, TQCString *reparse)
 		buffer[SIEVE_DEFAULT_RECIEVE_BUFFER-1] = '\0';
 
 		// strip LF/CR
-		interpret = TQCString(buffer).left(qstrlen(buffer) - 2);
+		interpret = TQCString(buffer).left(tqstrlen(buffer) - 2);
 
 	} else {
 		interpret = reparse->copy();
