@@ -25,9 +25,10 @@
 
 #include <tqwidget.h>
 
-class AboutPage : public QWidget
+class AboutPage : public TQWidget
 {
   Q_OBJECT
+  TQ_OBJECT
 
   public:
     AboutPage( TQWidget *parent );
