@@ -1,11 +1,11 @@
 /*
  * portable.cpp
  *
- * $Id: portable.cpp 1157653 2010-07-31 19:52:55Z tpearson $
+ * $Id: portable.cpp 1249829 2011-08-27 21:38:57Z tpearson $
  *
  * Copyright (c) 1999 Paul Campbell <paul@taniwha.com>
  *
- * Requires the Qt widget libraries, available at no cost at
+ * Requires the TQt widget libraries, available at no cost at
  * http://www.troll.no/
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -199,7 +199,7 @@ pmu_read(apm_info *ap)
 	int timerem = 0;
 	int maxcharge = 0;
 	for (int i = 0; i < bcnt; i++) {
-		TQFile bf(TQString("/proc/pmu/battery_%1").arg(i));
+		TQFile bf(TQString("/proc/pmu/battery_%1").tqarg(i));
 		if (!bf.exists() || !bf.open(IO_ReadOnly))
 			continue;
 
@@ -961,16 +961,16 @@ TQLabel *laptop_portable::how_to_do_suspend_resume(TQWidget *parent)
  		TQLabel* note = new KRichTextLabel(i18n("\nIf you make /usr/bin/apm setuid then you will also "
 						"be able to choose 'suspend' and 'standby' in the above "
 						"dialog - check out the help button below to find out "
-						"how to do this").replace("\n", TQString::null), parent);
+						"how to do this").replace("\n", TQString()), parent);
 		return(note);
 	}
 	if (::has_acpi()) {
                 // TODO: remove linefeed from string, can't do it right now coz we have a string freeze
- 		TQLabel* note = new KRichTextLabel(i18n("\nYou may need to enable ACPI suspend/resume in the ACPI panel").replace("\n", TQString::null), parent);
+ 		TQLabel* note = new KRichTextLabel(i18n("\nYou may need to enable ACPI suspend/resume in the ACPI panel").replace("\n", TQString()), parent);
 		return(note);
 	}
         // TODO: remove linefeed from string, can't do it right now coz we have a string freeze
- 	TQLabel* note = new KRichTextLabel(i18n("\nYour system does not support suspend/standby").replace("\n", TQString::null), parent);
+ 	TQLabel* note = new KRichTextLabel(i18n("\nYour system does not support suspend/standby").replace("\n", TQString()), parent);
 	return(note);
 }
 
@@ -1226,7 +1226,7 @@ laptop_portable::get_battery_status(int &num_batteries, TQStringList &names, TQS
 		for(unsigned int i = 0; i < acpi_batteries.count(); ++i) {
 			acpi_battery_info& bat = acpi_batteries[i];
 			names.append(bat.name);
-			values.append(TQString("%1").arg(bat.percentage));
+			values.append(TQString("%1").tqarg(bat.percentage));
 			state.append(bat.present ? "yes" : "no");
 		}
 		return;
@@ -1330,11 +1330,11 @@ TQString laptop_portable::cpu_frequency() {
 					continue;
 				if (ll.first().stripWhiteSpace() 
 						== "cpu MHz") {
-					rc = i18n("%1 MHz (%2)").arg(ll.last().stripWhiteSpace()).arg(rc);
+					rc = i18n("%1 MHz (%2)").tqarg(ll.last().stripWhiteSpace()).tqarg(rc);
 					break;
 				} else if (ll.first().stripWhiteSpace()
 						== "clock") {
-					rc = TQString("%1 (%2)").arg(ll.last().stripWhiteSpace()).arg(rc);
+					rc = TQString("%1 (%2)").tqarg(ll.last().stripWhiteSpace()).tqarg(rc);
 					break;
 				}
 			}
@@ -1581,7 +1581,7 @@ get_acpi_list(char p, int *map, const char *dev, TQStringList &list, int &index,
 							TQString l;
 							f.readLine(l, 500);
 							if (l.contains("active limit", false)) {
-								TQRegExp rx(TQString("%1(\\d+)").arg(p));
+								TQRegExp rx(TQString("%1(\\d+)").tqarg(p));
 								if (rx.search(l) >= 0) {
 									bool ok;
 									int min = rx.cap(1).toInt(&ok);
@@ -1706,7 +1706,7 @@ static int get_cpufreq_24_state(TQStringList &states, int &current, const TQStri
 		f.close();
 		cpufreq_minmax_frequency[i] = buffer;
 		unsigned int val = buffer.toUInt() / 1000;
-		states.append(i18n("%1 MHz").arg(val));
+		states.append(i18n("%1 MHz").tqarg(val));
 		if(buffer.stripWhiteSpace() == cur)
 			current = i;
 	}
@@ -2267,7 +2267,7 @@ laptop_portable::apm_set_mask(bool , bool )
 //	adds extra widgets to the battery panel
 //
 void
-laptop_portable::extra_config(TQWidget * /*parent*/, KConfig * /*config*/, TQVBoxLayout * /*layout*/)
+laptop_portable::extra_config(TQWidget * /*parent*/, KConfig * /*config*/, TQVBoxLayout * /*tqlayout*/)
 {
 	// INSERT HERE
 }
@@ -2945,7 +2945,7 @@ int laptop_portable::has_apm(int)
 //	adds extra widgets to the battery panel
 //
 void
-laptop_portable::extra_config(TQWidget *parent, KConfig *config, TQVBoxLayout *layout)
+laptop_portable::extra_config(TQWidget *parent, KConfig *config, TQVBoxLayout *tqlayout)
 {
 	// INSERT HERE
 }
