@@ -51,7 +51,7 @@ LinesBoard::LinesBoard( BallPainter * abPainter, TQWidget* parent, const char* n
 
   bPainter = abPainter;
 
-  setFocusPolicy( NoFocus );
+  setFocusPolicy( TQ_NoFocus );
   setBackgroundColor( gray );
 
   setMouseTracking( FALSE );
@@ -163,7 +163,7 @@ void LinesBoard::placeBall(  )
 
 /*id LinesBoard::doAfterBalls() {
   erase5Balls();
-  repaint(FALSE);
+  tqrepaint(FALSE);
 }
 */
 /*
@@ -215,7 +215,7 @@ void LinesBoard::paintEvent( TQPaintEvent* )
     {
        paint->end();
 
-       KPixmapEffect::fade(*pixmap, 0.5, Qt::black);
+       KPixmapEffect::fade(*pixmap, 0.5, TQt::black);
 
        TQPainter p(this);
        p.drawPixmap(0,0, *pixmap);
@@ -225,9 +225,9 @@ void LinesBoard::paintEvent( TQPaintEvent* )
        gameover_font.setPointSize(48);
        gameover_font.setBold(true);
        p.setFont(gameover_font);
-       p.setPen(Qt::white);
+       p.setPen(TQt::white);
        TQString gameover_text = i18n("Game Over");
-       p.drawText(0, 0, width(), height(), AlignCenter|Qt::WordBreak, gameover_text);
+       p.drawText(0, 0, width(), height(), AlignCenter|TQt::WordBreak, gameover_text);
     }
     else
     {
@@ -239,7 +239,7 @@ void LinesBoard::paintEvent( TQPaintEvent* )
         r.setY(focusY*CELLSIZE+2);
         r.setWidth(CELLSIZE-4);
         r.setHeight(CELLSIZE-4);
-        paint->setPen(TQPen(Qt::DotLine));
+        paint->setPen(TQPen(TQt::DotLine));
         paint->drawRect(r);
       }
     }
@@ -306,7 +306,7 @@ void LinesBoard::moveFocus(int dx, int dy)
     focusX = (focusX + dx + NUMCELLSW) % NUMCELLSW;
     focusY = (focusY + dy + NUMCELLSH) % NUMCELLSH;
   }
-  repaint(FALSE);
+  tqrepaint(FALSE);
 } 
 
 void LinesBoard::moveLeft()
@@ -401,7 +401,7 @@ int LinesBoard::AnimEnd( )
   else if ( oldanim == ANIM_BURN )
   {
     emit eraseLine( deleteAnimatedBalls() );
-    repaint(FALSE);
+    tqrepaint(FALSE);
     if ( nextBallToPlace < BALLSDROP )
     {
       placeBall();
@@ -455,7 +455,7 @@ void LinesBoard::AnimNext() {
       if ( (direction > 0 && animstep == animmax) || ( direction < 0 && animstep == 0))
         direction = -direction;
       animstep += direction;
-      repaint(FALSE);
+      tqrepaint(FALSE);
     } else {
       if ( animstep >= animmax )
         AnimEnd();
@@ -466,7 +466,7 @@ void LinesBoard::AnimNext() {
             moveBall(way[animstep].x,way[animstep].y,way[animstep+1].x,way[animstep+1].y);
           animstep++;
           animdelaycount = animdelaystart;
-          repaint( FALSE );
+          tqrepaint( FALSE );
         }
       }
     }
@@ -698,7 +698,7 @@ void LinesBoard::undo()
   AnimEnd();
   restoreUndo();
   restoreRandomState();
-  repaint( FALSE );
+  tqrepaint( FALSE );
 }
 
 void LinesBoard::showDemoText(const TQString &text)
@@ -711,13 +711,13 @@ void LinesBoard::showDemoText(const TQString &text)
      demoLabel->setAutoMask( FALSE );
      demoLabel->setFrameStyle( TQFrame::Plain | TQFrame::Box );
      demoLabel->setLineWidth( 1 );
-     demoLabel->setAlignment( AlignHCenter | AlignTop );
+     demoLabel->tqsetAlignment( AlignHCenter | AlignTop );
      demoLabel->setPalette(TQToolTip::palette());
      demoLabel->polish();
   }
   demoLabel->setText(text);
   demoLabel->adjustSize();
-  TQSize s = demoLabel->sizeHint();
+  TQSize s = demoLabel->tqsizeHint();
   TQPoint p = TQPoint(x() + (width()-s.width())/2, y() + (height()-s.height())/2);
   demoLabel->move(mapToGlobal(p));
   demoLabel->show();
@@ -744,7 +744,7 @@ void LinesBoard::demoClick(int x, int y)
      kapp->enter_loop();
   }
   TQCursor::setPos(dest);
-  TQMouseEvent ev(TQEvent::MouseButtonPress, lDest, dest, LeftButton, LeftButton);
+  TQMouseEvent ev(TQEvent::MouseButtonPress, lDest, dest, Qt::LeftButton, Qt::LeftButton);
   mousePressEvent(&ev);
 }
 
