@@ -151,13 +151,13 @@ void SessionWidget::newSearchManager()
 
     search_manager_ = new SearchManager(KLSConfig::maxConnectionsNumber(),
                                         KLSConfig::timeOut(),
-                                        this, "search_manager");
+                                        TQT_TQOBJECT(this), "search_manager");
     Q_ASSERT(search_manager_);
 
-    connect(search_manager_, TQT_SIGNAL(signalRootChecked(const LinkStatus *, LinkChecker *)),
-            this, TQT_SLOT(slotRootChecked(const LinkStatus *, LinkChecker *)));
-    connect(search_manager_, TQT_SIGNAL(signalLinkChecked(const LinkStatus *, LinkChecker *)),
-            this, TQT_SLOT(slotLinkChecked(const LinkStatus *, LinkChecker *)));
+    connect(search_manager_, TQT_SIGNAL(signalRootChecked(const LinktqStatus *, LinkChecker *)),
+            this, TQT_SLOT(slotRootChecked(const LinktqStatus *, LinkChecker *)));
+    connect(search_manager_, TQT_SIGNAL(signalLinkChecked(const LinktqStatus *, LinkChecker *)),
+            this, TQT_SLOT(slotLinkChecked(const LinktqStatus *, LinkChecker *)));
     connect(search_manager_, TQT_SIGNAL(signalSearchFinished()),
             this, TQT_SLOT(slotSearchFinished()));
     connect(search_manager_, TQT_SIGNAL(signalSearchPaused()),
@@ -321,7 +321,7 @@ void SessionWidget::slotCheck()
 
 void SessionWidget::keyPressEvent ( TQKeyEvent* e )
 {
-    if( e->key() == Qt::Key_Return &&
+    if( e->key() == TQt::Key_Return &&
         ( combobox_url->hasFocus() ||
               //lineedit_domain->hasFocus() ||
               //checkbox_depth->hasFocus()  ||
@@ -338,7 +338,7 @@ void SessionWidget::keyPressEvent ( TQKeyEvent* e )
         }
     }
 
-    else if(e->key() == Qt::Key_F6)
+    else if(e->key() == TQt::Key_F6)
     {
         combobox_url->lineEdit()->selectAll();
     }
@@ -356,7 +356,7 @@ bool SessionWidget::validFields()
         return true;
 }
 
-void SessionWidget::slotRootChecked(LinkStatus const* linkstatus, LinkChecker * anal)
+void SessionWidget::slotRootChecked(LinktqStatus const* linkstatus, LinkChecker * anal)
 {
     slotSetTimeElapsed();
     emit signalUpdateTabLabel(search_manager_->linkStatusRoot(), this);
@@ -368,7 +368,7 @@ void SessionWidget::slotRootChecked(LinkStatus const* linkstatus, LinkChecker *
 
     //table_linkstatus->insertResult(linkstatus);
     TreeViewItem* tree_view_item = new TreeViewItem(tree_view, tree_view->lastItem(), linkstatus);
-    LinkStatus* ls = const_cast<LinkStatus*> (linkstatus);
+    LinktqStatus* ls = const_cast<LinktqStatus*> (linkstatus);
     ls->setTreeViewItem(tree_view_item);
 
     if(linkstatus->isRedirection() && linkstatus->redirection())
@@ -378,7 +378,7 @@ void SessionWidget::slotRootChecked(LinkStatus const* linkstatus, LinkChecker *
     ActionManager::getInstance()->action("file_export_html")->setEnabled(!isEmpty());
 }
 
-void SessionWidget::slotLinkChecked(LinkStatus const* linkstatus, LinkChecker * anal)
+void SessionWidget::slotLinkChecked(LinktqStatus const* linkstatus, LinkChecker * anal)
 {
     slotSetTimeElapsed();
 
@@ -416,7 +416,7 @@ void SessionWidget::slotLinkChecked(LinkStatus const* linkstatus, LinkChecker *
             tree_view_item->setVisible(match);
         }
         
-        LinkStatus* ls = const_cast<LinkStatus*> (linkstatus);
+        LinktqStatus* ls = const_cast<LinktqStatus*> (linkstatus);
         ls->setTreeViewItem(tree_view_item);
 
         if(linkstatus->isRedirection() && linkstatus->redirection())
@@ -503,10 +503,10 @@ void SessionWidget::showBottomStatusLabel(TQListViewItem* item)
     TreeViewItem* _item = tree_view->myItem(item);
     if(_item)
     {
-        TQString status = _item->linkStatus()->statusText();
+        TQString status = _item->linktqStatus()->statusText();
         textlabel_status->setText(status);
 
-        if(textlabel_status->sizeHint().width() > textlabel_status->maximumWidth())
+        if(textlabel_status->tqsizeHint().width() > textlabel_status->maximumWidth())
             TQToolTip::add(textlabel_status, status);
         else
             TQToolTip::remove(textlabel_status);
@@ -683,7 +683,7 @@ void SessionWidget::slotApplyFilter(LinkMatcher link_matcher)
 
 void SessionWidget::slotExportAsHTML( )
 {
-    KURL url = KFileDialog::getSaveURL(TQString::null,"text/html", 0, i18n("Export Results as HTML"));
+    KURL url = KFileDialog::getSaveURL(TQString(),"text/html", 0, i18n("Export Results as HTML"));
 
     if(url.isEmpty())
         return;
