@@ -18,11 +18,11 @@
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
+    the TQt library by Trolltech AS, Norway (or with modified versions
+    of TQt that use the same license as TQt), and distribute linked
     combinations including the two.  You must obey the GNU General
     Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
+    TQt.  If you modify this file, you may extend this exception to
     your version of the file, but you are not obligated to do so.  If
     you do not wish to do so, delete this exception statement from
     your version.
@@ -157,8 +157,8 @@ void ActionScheduler::setSourceFolder( KMFolder *srcFolder )
 {
   srcFolder->open("actionschedsrc");
   if (mSrcFolder) {
-    disconnect( mSrcFolder, TQT_SIGNAL(msgAdded(KMFolder*, Q_UINT32)),
-		this, TQT_SLOT(msgAdded(KMFolder*, Q_UINT32)) );
+    disconnect( mSrcFolder, TQT_SIGNAL(msgAdded(KMFolder*, TQ_UINT32)),
+		this, TQT_SLOT(msgAdded(KMFolder*, TQ_UINT32)) );
     disconnect( mSrcFolder, TQT_SIGNAL(closed()),
                 this, TQT_SLOT(folderClosedOrExpunged()) );
     disconnect( mSrcFolder, TQT_SIGNAL(expunged(KMFolder*)),
@@ -170,8 +170,8 @@ void ActionScheduler::setSourceFolder( KMFolder *srcFolder )
   for (i = 0; i < mSrcFolder->count(); ++i)
     enqueue( mSrcFolder->getMsgBase( i )->getMsgSerNum() );
   if (mSrcFolder) {
-    connect( mSrcFolder, TQT_SIGNAL(msgAdded(KMFolder*, Q_UINT32)),
-	     this, TQT_SLOT(msgAdded(KMFolder*, Q_UINT32)) );
+    connect( mSrcFolder, TQT_SIGNAL(msgAdded(KMFolder*, TQ_UINT32)),
+	     this, TQT_SLOT(msgAdded(KMFolder*, TQ_UINT32)) );
     connect( mSrcFolder, TQT_SIGNAL(closed()),
              this, TQT_SLOT(folderClosedOrExpunged()) );
     connect( mSrcFolder, TQT_SIGNAL(expunged(KMFolder*)),
@@ -230,9 +230,9 @@ void ActionScheduler::tempCloseFolders()
   mOpenFolders.clear();
 }
 
-void ActionScheduler::execFilters(const TQValueList<Q_UINT32> serNums)
+void ActionScheduler::execFilters(const TQValueList<TQ_UINT32> serNums)
 {
-  TQValueListConstIterator<Q_UINT32> it;
+  TQValueListConstIterator<TQ_UINT32> it;
   for (it = serNums.begin(); it != serNums.end(); ++it)
     execFilters( *it );
 }
@@ -250,7 +250,7 @@ void ActionScheduler::execFilters(KMMsgBase* msgBase)
   execFilters( msgBase->getMsgSerNum() );
 }
 
-void ActionScheduler::execFilters(Q_UINT32 serNum)
+void ActionScheduler::execFilters(TQ_UINT32 serNum)
 {
   if (mResult != ResultOk) {
       if ((mResult != ResultCriticalError) &&
@@ -279,7 +279,7 @@ void ActionScheduler::execFilters(Q_UINT32 serNum)
   }
 }
 
-KMMsgBase *ActionScheduler::messageBase(Q_UINT32 serNum)
+KMMsgBase *ActionScheduler::messageBase(TQ_UINT32 serNum)
 {
   int idx = -1;
   KMFolder *folder = 0;
@@ -299,7 +299,7 @@ KMMsgBase *ActionScheduler::messageBase(Q_UINT32 serNum)
   return msg;
 }
 
-KMMessage *ActionScheduler::message(Q_UINT32 serNum)
+KMMessage *ActionScheduler::message(TQ_UINT32 serNum)
 {
   int idx = -1;
   KMFolder *folder = 0;
@@ -380,7 +380,7 @@ void ActionScheduler::finish()
 
 void ActionScheduler::fetchMessage()
 {
-  TQValueListIterator<Q_UINT32> mFetchMessageIt = mFetchSerNums.begin();
+  TQValueListIterator<TQ_UINT32> mFetchMessageIt = mFetchSerNums.begin();
   while (mFetchMessageIt != mFetchSerNums.end()) {
     if (!MessageProperty::transferInProgress(*mFetchMessageIt))
       break;
@@ -454,7 +454,7 @@ void ActionScheduler::messageFetched( KMMessage *msg )
     serNumS.setNum( msg->getMsgSerNum() );
     KMMessage *newMsg = new KMMessage;
     newMsg->fromString(msg->asString());
-    newMsg->setStatus(msg->status());
+    newMsg->setqStatus(msg->status());
     newMsg->setComplete(msg->isComplete());
     newMsg->setHeaderField( "X-KMail-Filtered", serNumS );
     mSrcFolder->addMsg( newMsg );
@@ -466,13 +466,13 @@ void ActionScheduler::messageFetched( KMMessage *msg )
   return;
 }
 
-void ActionScheduler::msgAdded( KMFolder*, Q_UINT32 serNum )
+void ActionScheduler::msgAdded( KMFolder*, TQ_UINT32 serNum )
 {
   if (!mIgnore)
     enqueue( serNum );
 }
 
-void ActionScheduler::enqueue(Q_UINT32 serNum)
+void ActionScheduler::enqueue(TQ_UINT32 serNum)
 {
   if (mResult != ResultOk)
     return; // An error has already occurred don't even try to process this msg
@@ -625,7 +625,7 @@ void ActionScheduler::actionMessage(KMFilterAction::ReturnCode res)
     if (msg) {
       if ( FilterLog::instance()->isLogging() ) {
         TQString logText( i18n( "<b>Applying filter action:</b> %1" )
-                        .arg( mFilterAction->displayString() ) );
+                        .tqarg( mFilterAction->displayString() ) );
         FilterLog::instance()->add( logText, FilterLog::appliedAction );
       }
       KMFilterAction *action = mFilterAction;
@@ -786,19 +786,19 @@ TQString ActionScheduler::debug()
     TQValueList<ActionScheduler*>::iterator it;
     int i = 1;
     for ( it = schedulerList->begin(); it != schedulerList->end(); ++it ) {
-	res.append( TQString( "ActionScheduler #%1.\n" ).arg( i ) );
+	res.append( TQString( "ActionScheduler #%1.\n" ).tqarg( i ) );
 	if ((*it)->mAccount && kmkernel->find( (*it)->mAccountId )) {
 	    res.append( TQString( "Account %1, Name %2.\n" )
-			.arg( (*it)->mAccountId )
-			.arg( kmkernel->acctMgr()->find( (*it)->mAccountId )->name() ) );
+			.tqarg( (*it)->mAccountId )
+			.tqarg( kmkernel->acctMgr()->find( (*it)->mAccountId )->name() ) );
 	}
-	res.append( TQString( "mExecuting %1, " ).arg( (*it)->mExecuting ? "true" : "false" ) );
-	res.append( TQString( "mExecutingLock %1, " ).arg( (*it)->mExecutingLock ? "true" : "false" ) );
-	res.append( TQString( "mFetchExecuting %1.\n" ).arg( (*it)->mFetchExecuting ? "true" : "false" ) );
-	res.append( TQString( "mOriginalSerNum %1.\n" ).arg( (*it)->mOriginalSerNum ) );
-	res.append( TQString( "mMessageIt %1.\n" ).arg( ((*it)->mMessageIt != 0) ? *(*it)->mMessageIt : 0 ) );
-	res.append( TQString( "mSerNums count %1, " ).arg( (*it)->mSerNums.count() ) );
-	res.append( TQString( "mFetchSerNums count %1.\n" ).arg( (*it)->mFetchSerNums.count() ) );
+	res.append( TQString( "mExecuting %1, " ).tqarg( (*it)->mExecuting ? "true" : "false" ) );
+	res.append( TQString( "mExecutingLock %1, " ).tqarg( (*it)->mExecutingLock ? "true" : "false" ) );
+	res.append( TQString( "mFetchExecuting %1.\n" ).tqarg( (*it)->mFetchExecuting ? "true" : "false" ) );
+	res.append( TQString( "mOriginalSerNum %1.\n" ).tqarg( (*it)->mOriginalSerNum ) );
+	res.append( TQString( "mMessageIt %1.\n" ).tqarg( ((*it)->mMessageIt != 0) ? *(*it)->mMessageIt : 0 ) );
+	res.append( TQString( "mSerNums count %1, " ).tqarg( (*it)->mSerNums.count() ) );
+	res.append( TQString( "mFetchSerNums count %1.\n" ).tqarg( (*it)->mFetchSerNums.count() ) );
 	res.append( TQString( "mResult " ) );
 	if ((*it)->mResult == ResultOk)
 	    res.append( TQString( "ResultOk.\n" ) );
