@@ -17,11 +17,11 @@
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
+    the TQt library by Trolltech AS, Norway (or with modified versions
+    of TQt that use the same license as TQt), and distribute linked
     combinations including the two.  You must obey the GNU General
     Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
+    TQt.  If you modify this file, you may extend this exception to
     your version of the file, but you are not obligated to do so.  If
     you do not wish to do so, delete this exception statement from
     your version.
@@ -495,7 +495,7 @@ void AntiSpamWizard::checkToolAvailability()
   bool found = false;
   for ( TQValueListIterator<SpamToolConfig> it = mToolList.begin();
         it != mToolList.end(); ++it ) {
-    TQString text( i18n("Scanning for %1...").arg( (*it).getId() ) );
+    TQString text( i18n("Scanning for %1...").tqarg( (*it).getId() ) );
     mInfoPage->setScanProgressText( text );
     if ( (*it).isSpamTool() && (*it).isServerBased() ) {
       // check the configured account for pattern in <server>
@@ -517,7 +517,7 @@ void AntiSpamWizard::checkToolAvailability()
     }
     else {
       // check the availability of the application
-      KApplication::kApplication()->processEvents( 200 );
+      KApplication::kApplication()->tqprocessEvents( 200 );
       if ( !checkForProgram( (*it).getExecutable() ) ) {
         mInfoPage->addAvailableTool( (*it).getVisibleName() );
         found = true;
@@ -702,7 +702,7 @@ void AntiSpamWizard::ConfigReader::readAndMergeConfig()
   int registeredTools = general.readNumEntry( "tools", 0 );
   for (int i = 1; i <= registeredTools; i++)
   {
-    KConfigGroup toolConfig( mConfig, groupName.arg( i ) );
+    KConfigGroup toolConfig( mConfig, groupName.tqarg( i ) );
     if( !toolConfig.readBoolEntry( "HeadersOnly", false ) )
       mToolList.append( readToolConfig( toolConfig ) );
   }
@@ -714,7 +714,7 @@ void AntiSpamWizard::ConfigReader::readAndMergeConfig()
   int user_registeredTools = user_general.readNumEntry( "tools", 0 );
   for (int i = 1; i <= user_registeredTools; i++)
   {
-    KConfigGroup toolConfig( mConfig, groupName.arg( i ) );
+    KConfigGroup toolConfig( mConfig, groupName.tqarg( i ) );
     if( !toolConfig.readBoolEntry( "HeadersOnly", false ) )
       mergeToolConfig( readToolConfig( toolConfig ) );
   }
@@ -855,7 +855,7 @@ ASWizInfoPage::ASWizInfoPage( AntiSpamWizard::WizardMode mode,
                               TQWidget * parent, const char * name )
   : ASWizPage( parent, name )
 {
-  TQBoxLayout * layout = new TQVBoxLayout( mLayout );
+  TQBoxLayout * tqlayout = new TQVBoxLayout( mLayout );
 
   mIntroText = new TQLabel( this );
   mIntroText->setText(
@@ -879,26 +879,26 @@ ASWizInfoPage::ASWizInfoPage( AntiSpamWizard::WizardMode mode,
       "deleting the filter rules created by the wizard to get "
       "back to the former behavior."
       ) );
-  layout->addWidget( mIntroText );
+  tqlayout->addWidget( mIntroText );
 
   mScanProgressText = new TQLabel( this );
   mScanProgressText->setText( "" ) ;
-  layout->addWidget( mScanProgressText );
+  tqlayout->addWidget( mScanProgressText );
 
   mToolsList = new KListBox( this );
   mToolsList->hide();
   mToolsList->setSelectionMode( TQListBox::Multi );
   mToolsList->setRowMode( TQListBox::FixedNumber );
   mToolsList->setRowMode( 10 );
-  layout->addWidget( mToolsList );
+  tqlayout->addWidget( mToolsList );
   connect( mToolsList, TQT_SIGNAL(selectionChanged()),
            this, TQT_SLOT(processSelectionChange(void)) );
 
   mSelectionHint = new TQLabel( this );
   mSelectionHint->setText( "" );
-  layout->addWidget( mSelectionHint );
+  tqlayout->addWidget( mSelectionHint );
 
-  layout->addStretch();
+  tqlayout->addStretch();
 }
 
 
@@ -940,18 +940,18 @@ ASWizSpamRulesPage::ASWizSpamRulesPage( TQWidget * parent, const char * name,
                                         KMFolderTree * mainFolderTree )
   : ASWizPage( parent, name )
 {
-  TQVBoxLayout *layout = new TQVBoxLayout( mLayout );
+  TQVBoxLayout *tqlayout = new TQVBoxLayout( mLayout );
 
   mMarkRules = new TQCheckBox( i18n("&Mark detected spam messages as read"), this );
   TQWhatsThis::add( mMarkRules,
       i18n( "Mark messages which have been classified as spam as read.") );
-  layout->addWidget( mMarkRules);
+  tqlayout->addWidget( mMarkRules);
 
   mMoveSpamRules = new TQCheckBox( i18n("Move &known spam to:"), this );
   TQWhatsThis::add( mMoveSpamRules,
       i18n( "The default folder for spam messages is the trash folder, "
             "but you may change that in the folder view below.") );
-  layout->addWidget( mMoveSpamRules );
+  tqlayout->addWidget( mMoveSpamRules );
 
   mFolderReqForSpamFolder = new FolderRequester( this, mainFolderTree );
   mFolderReqForSpamFolder->setFolder( "trash" );
@@ -959,7 +959,7 @@ ASWizSpamRulesPage::ASWizSpamRulesPage( TQWidget * parent, const char * name,
   mFolderReqForSpamFolder->setShowOutbox( false );
   mFolderReqForSpamFolder->setShowImapFolders( false );
 
-  TQHBoxLayout *hLayout1 = new TQHBoxLayout( layout );
+  TQHBoxLayout *hLayout1 = new TQHBoxLayout( tqlayout );
   hLayout1->addSpacing( KDialog::spacingHint() * 3 );
   hLayout1->addWidget( mFolderReqForSpamFolder );
 
@@ -969,7 +969,7 @@ ASWizSpamRulesPage::ASWizSpamRulesPage( TQWidget * parent, const char * name,
             "in the folder view below.<p>"
             "Not all tools support a classification as unsure. If you haven't "
             "selected a capable tool, you can't select a folder as well.") );
-  layout->addWidget( mMoveUnsureRules );
+  tqlayout->addWidget( mMoveUnsureRules );
 
   mFolderReqForUnsureFolder = new FolderRequester( this, mainFolderTree );
   mFolderReqForUnsureFolder->setFolder( "inbox" );
@@ -977,11 +977,11 @@ ASWizSpamRulesPage::ASWizSpamRulesPage( TQWidget * parent, const char * name,
   mFolderReqForUnsureFolder->setShowOutbox( false );
   mFolderReqForUnsureFolder->setShowImapFolders( false );
 
-  TQHBoxLayout *hLayout2 = new TQHBoxLayout( layout );
+  TQHBoxLayout *hLayout2 = new TQHBoxLayout( tqlayout );
   hLayout2->addSpacing( KDialog::spacingHint() * 3 );
   hLayout2->addWidget( mFolderReqForUnsureFolder );
 
-  layout->addStretch();
+  tqlayout->addStretch();
 
   connect( mMarkRules, TQT_SIGNAL(clicked()),
             this, TQT_SLOT(processSelectionChange(void)) );
@@ -1138,11 +1138,11 @@ void ASWizVirusRulesPage::processSelectionChange()
 ASWizSummaryPage::ASWizSummaryPage( TQWidget * parent, const char * name )
   : ASWizPage( parent, name )
 {
-  TQBoxLayout * layout = new TQVBoxLayout( mLayout );
+  TQBoxLayout * tqlayout = new TQVBoxLayout( mLayout );
 
   mSummaryText = new TQLabel( this );
-  layout->addWidget( mSummaryText );
-  layout->addStretch();
+  tqlayout->addWidget( mSummaryText );
+  tqlayout->addStretch();
 }
 
 
