@@ -20,11 +20,11 @@
  *
  *  In addition, as a special exception, the copyright holders give
  *  permission to link the code of this program with any edition of
- *  the Qt library by Trolltech AS, Norway (or with modified versions
- *  of Qt that use the same license as Qt), and distribute linked
+ *  the TQt library by Trolltech AS, Norway (or with modified versions
+ *  of TQt that use the same license as TQt), and distribute linked
  *  combinations including the two.  You must obey the GNU General
  *  Public License in all respects for all of the code used other than
- *  Qt.  If you modify this file, you may extend this exception to
+ *  TQt.  If you modify this file, you may extend this exception to
  *  your version of the file, but you are not obligated to do so.  If
  *  you do not wish to do so, delete this exception statement from
  *  your version.
@@ -70,7 +70,7 @@ CachedImapJob::CachedImapJob( const TQValueList<MsgForDownload>& msgs,
 // Put messages
 CachedImapJob::CachedImapJob( const TQPtrList<KMMessage>& msgs, JobType type,
                               KMFolderCachedImap* folder )
-  : FolderJob( msgs, TQString::null, type, folder?folder->folder():0 ), mFolder( folder ),
+  : FolderJob( msgs, TQString(), type, folder?folder->folder():0 ), mFolder( folder ),
     mTotalBytes( msgs.count() ), // we abuse it as "total number of messages"
     mMsg( 0 ), mParentFolder( 0 )
 {
@@ -78,7 +78,7 @@ CachedImapJob::CachedImapJob( const TQPtrList<KMMessage>& msgs, JobType type,
 
 CachedImapJob::CachedImapJob( const TQValueList<unsigned long>& msgs,
 			      JobType type, KMFolderCachedImap* folder )
-  : FolderJob( TQPtrList<KMMessage>(), TQString::null, type, folder?folder->folder():0 ),
+  : FolderJob( TQPtrList<KMMessage>(), TQString(), type, folder?folder->folder():0 ),
     mFolder( folder ), mSerNumMsgList( msgs ), mTotalBytes( msgs.count() ), mMsg( 0 ),
     mParentFolder ( 0 )
 {
@@ -234,7 +234,7 @@ void CachedImapJob::slotDeleteNextMessages( KIO::Job* job )
 
   KURL url = mAccount->getUrl();
   url.setPath( mFolder->imapPath() +
-               TQString::fromLatin1(";UID=%1").arg(uids) );
+               TQString::tqfromLatin1(";UID=%1").tqarg(uids) );
 
   KIO::SimpleJob *simpleJob = KIO::file_delete( url, false );
   KIO::Scheduler::assignJobToSlave( mAccount->slave(), simpleJob );
@@ -248,7 +248,7 @@ void CachedImapJob::expungeFolder()
 {
   KURL url = mAccount->getUrl();
   // Special URL that means EXPUNGE
-  url.setPath( mFolder->imapPath() + TQString::fromLatin1(";UID=*") );
+  url.setPath( mFolder->imapPath() + TQString::tqfromLatin1(";UID=*") );
 
   KIO::SimpleJob *job = KIO::file_delete( url, false );
   KIO::Scheduler::assignJobToSlave( mAccount->slave(), job );
@@ -311,7 +311,7 @@ void CachedImapJob::slotGetNextMessage(KIO::Job * job)
       mFolder->addMsgInternal( mMsg, true, &index );
 
       if ( kmkernel->iCalIface().isResourceFolder( mFolder->folder() ) ) {
-        mFolder->setStatus( index, KMMsgStatusRead, false );
+        mFolder->setqStatus( index, KMMsgStatusRead, false );
       }
 
       emit messageRetrieved( mMsg );
@@ -339,9 +339,9 @@ void CachedImapJob::slotGetNextMessage(KIO::Job * job)
   mMsg->setUID(mfd.uid);
   mMsg->setMsgSizeServer(mfd.size);
   if( mfd.flags > 0 )
-    KMFolderImap::flagsToStatus(mMsg, mfd.flags, true, GlobalSettings::allowLocalFlags() ? mFolder->permanentFlags() : INT_MAX);
+    KMFolderImap::flagsTotqStatus(mMsg, mfd.flags, true, GlobalSettings::allowLocalFlags() ? mFolder->permanentFlags() : INT_MAX);
   KURL url = mAccount->getUrl();
-  url.setPath(mFolder->imapPath() + TQString(";UID=%1;SECTION=BODY.PEEK[]").arg(mfd.uid));
+  url.setPath(mFolder->imapPath() + TQString(";UID=%1;SECTION=BODY.PEEK[]").tqarg(mfd.uid));
 
   ImapAccountBase::jobData jd( url.url(), mFolder->folder() );
   jd.cancellable = true;
@@ -408,10 +408,10 @@ void CachedImapJob::slotPutNextMessage()
   unsigned int i = 0;
   for( char *ch = cstr.data(); *ch; ch++ ) {
     if ( *ch == '\n' ) {
-      mData.at(i) = '\r';
+      mData.tqat(i) = '\r';
       i++;
     }
-    mData.at(i) = *ch; i++;
+    mData.tqat(i) = *ch; i++;
   }
   jd.data = mData;
   jd.msgList.append( mMsg );
@@ -539,7 +539,7 @@ void CachedImapJob::slotAddNextSubfolder( KIO::Job * job )
 
     if ( job->error() && !silentUpload ) {
       TQString myError = "<p><b>" + i18n("Error while uploading folder")
-        + "</b></p><p>" + i18n("Could not make the folder <b>%1</b> on the server.").arg((*it).items[0])
+        + "</b></p><p>" + i18n("Could not make the folder <b>%1</b> on the server.").tqarg((*it).items[0])
         + "</p><p>" + i18n("This could be because you do not have permission to do this, or because the folder is already present on the server; the error message from the server communication is here:") + "</p>";
       mAccount->handleJobError( job, myError );
     }
@@ -597,8 +597,8 @@ void CachedImapJob::slotAddNextSubfolder( KIO::Job * job )
     TQDataStream stream( packedArgs, IO_WriteOnly );
 
     const TQString command = TQString( "X-CREATE-SPECIAL" );
-    const TQString argument = TQString( "%1 %2" ).arg( Scalix::Utils::contentsTypeToScalixId( folder->contentsType() ) )
-                                               .arg( path );
+    const TQString argument = TQString( "%1 %2" ).tqarg( Scalix::Utils::contentsTypeToScalixId( folder->contentsType() ) )
+                                               .tqarg( path );
 
     stream << (int) 'X' << 'N' << command << argument;
 
@@ -626,7 +626,7 @@ void CachedImapJob::slotDeleteNextFolder( KIO::Job *job )
     mAccount->removeDeletedFolder( (*it).path );
 
     if( job->error() ) {
-      mAccount->handleJobError( job, i18n( "Error while deleting folder %1 on the server: " ).arg( (*it).path ) + '\n' );
+      mAccount->handleJobError( job, i18n( "Error while deleting folder %1 on the server: " ).tqarg( (*it).path ) + '\n' );
       delete this;
       return;
     }
@@ -679,7 +679,7 @@ void CachedImapJob::slotCheckUidValidityResult(KIO::Job * job)
 
   if( job->error() ) {
     mErrorCode = job->error();
-    mAccount->handleJobError( job, i18n( "Error while reading folder %1 on the server: " ).arg( (*it).parent->label() ) + '\n' );
+    mAccount->handleJobError( job, i18n( "Error while reading folder %1 on the server: " ).tqarg( (*it).parent->label() ) + '\n' );
     delete this;
     return;
   }
@@ -813,7 +813,7 @@ void CachedImapJob::slotSubscribtionChange1Failed( const TQString &errorMessage
                                "from the folder list after the next sync since it is unsubscribed on the server.\n"
                                "You can try to manually subscribe to the folder yourself.\n\n"
                                "%2" )
-      .arg( mFolder->label() ).arg( errorMessage ) );
+      .tqarg( mFolder->label() ).tqarg( errorMessage ) );
   delete this;
 }
 
@@ -854,7 +854,7 @@ void CachedImapJob::slotRenameFolderResult( KIO::Job *job )
 
   if( job->error() ) {
     revertLabelChange();
-    const TQString errorMessage = i18n( "Error while trying to rename folder %1" ).arg( mFolder->label() );
+    const TQString errorMessage = i18n( "Error while trying to rename folder %1" ).tqarg( mFolder->label() );
     mAccount->handleJobError( job, errorMessage );
     delete this;
   } else {
