@@ -22,11 +22,11 @@
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
+    the TQt library by Trolltech AS, Norway (or with modified versions
+    of TQt that use the same license as TQt), and distribute linked
     combinations including the two.  You must obey the GNU General
     Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
+    TQt.  If you modify this file, you may extend this exception to
     your version of the file, but you are not obligated to do so.  If
     you do not wish to do so, delete this exception statement from
     your version.
@@ -174,7 +174,7 @@ void FolderStorage::markNewAsUnread()
     if (!(msgBase = getMsgBase(i))) continue;
     if (msgBase->isNew())
     {
-      msgBase->setStatus(KMMsgStatusUnread);
+      msgBase->setqStatus(KMMsgStatusUnread);
       msgBase->setDirty(true);
     }
   }
@@ -197,7 +197,7 @@ void FolderStorage::markUnreadAsRead()
   if (serNums.empty())
     return;
 
-  KMCommand *command = new KMSetStatusCommand( KMMsgStatusRead, serNums );
+  KMCommand *command = new KMSeStatusCommand( KMMsgStatusRead, serNums );
   command->start();
 }
 
@@ -283,7 +283,7 @@ void FolderStorage::slotEmitChangedTimer()
 //-----------------------------------------------------------------------------
 void FolderStorage::emitMsgAddedSignals(int idx)
 {
-  Q_UINT32 serNum = KMMsgDict::instance()->getMsgSerNum( folder() , idx );
+  TQ_UINT32 serNum = KMMsgDict::instance()->getMsgSerNum( folder() , idx );
   if (!mQuiet) {
     emit msgAdded(idx);
   } else {
@@ -388,7 +388,7 @@ void FolderStorage::removeMsg(int idx, bool)
 
   KMMsgBase* mb = getMsgBase(idx);
 
-  Q_UINT32 serNum = KMMsgDict::instance()->getMsgSerNum( folder(), idx );
+  TQ_UINT32 serNum = KMMsgDict::instance()->getMsgSerNum( folder(), idx );
   if (serNum != 0)
     emit msgRemoved( folder(), serNum );
   mb = takeIndexEntry( idx );
@@ -430,7 +430,7 @@ KMMessage* FolderStorage::take(int idx)
   mb = getMsgBase(idx);
   if (!mb) return 0;
   if (!mb->isMessage()) readMsg(idx);
-  Q_UINT32 serNum = KMMsgDict::instance()->getMsgSerNum( folder(), idx );
+  TQ_UINT32 serNum = KMMsgDict::instance()->getMsgSerNum( folder(), idx );
   emit msgRemoved( folder(), serNum );
 
   msg = (KMMessage*)takeIndexEntry(idx);
@@ -503,7 +503,7 @@ KMMessage* FolderStorage::getMsg(int idx)
         kdDebug(5006) << "Error: " << location() <<
           " Index file is inconsistent with folder file. This should never happen." << endl;
 
-        // We can't recreate the index at this point, since that would invalidate the current
+        // We can't recreate the index at this point, since that would tqinvalidate the current
         // message list and delete KMMsgBase or KMMessage objects that are in use.
         // Do it later in KMFolderIndex::readIndexHeader() instead.
         mCompactable = false; // Don't compact
@@ -844,7 +844,7 @@ int FolderStorage::countUnread()
   return (unread > 0) ? unread : 0;
 }
 
-Q_INT64 FolderStorage::folderSize() const
+TQ_INT64 FolderStorage::folderSize() const
 {
     if ( mSize != -1 ) {
         return mSize;
@@ -861,18 +861,18 @@ bool FolderStorage::isCloseToQuota() const
 }
 
 //-----------------------------------------------------------------------------
-void FolderStorage::msgStatusChanged(const KMMsgStatus oldStatus,
-  const KMMsgStatus newStatus, int idx)
+void FolderStorage::msgStatusChanged(const KMMsgtqStatus oldtqStatus,
+  const KMMsgtqStatus newtqStatus, int idx)
 {
   int oldUnread = 0;
   int newUnread = 0;
 
-  if (((oldStatus & KMMsgStatusUnread || oldStatus & KMMsgStatusNew) &&
-      !(oldStatus & KMMsgStatusIgnored)) ||
+  if (((oldtqStatus & KMMsgStatusUnread || oldtqStatus & KMMsgStatusNew) &&
+      !(oldtqStatus & KMMsgStatusIgnored)) ||
       (folder() == kmkernel->outboxFolder()))
     oldUnread = 1;
-  if (((newStatus & KMMsgStatusUnread || newStatus & KMMsgStatusNew) &&
-      !(newStatus & KMMsgStatusIgnored)) ||
+  if (((newtqStatus & KMMsgStatusUnread || newtqStatus & KMMsgStatusNew) &&
+      !(newtqStatus & KMMsgStatusIgnored)) ||
       (folder() == kmkernel->outboxFolder()))
     newUnread = 1;
   int deltaUnread = newUnread - oldUnread;
@@ -889,7 +889,7 @@ void FolderStorage::msgStatusChanged(const KMMsgStatus oldStatus,
       }
       mChanged = true;
     }
-    Q_UINT32 serNum = KMMsgDict::instance()->getMsgSerNum(folder(), idx);
+    TQ_UINT32 serNum = KMMsgDict::instance()->getMsgSerNum(folder(), idx);
     emit msgChanged( folder(), serNum, deltaUnread );
   }
 }
@@ -1040,24 +1040,24 @@ void FolderStorage::setRDict( KMMsgDictREntry *rentry ) const
 }
 
 //-----------------------------------------------------------------------------
-void FolderStorage::setStatus(int idx, KMMsgStatus status, bool toggle)
+void FolderStorage::setqStatus(int idx, KMMsgtqStatus status, bool toggle)
 {
   KMMsgBase *msg = getMsgBase(idx);
   if ( msg ) {
     if (toggle)
-      msg->toggleStatus(status, idx);
+      msg->toggletqStatus(status, idx);
     else
-      msg->setStatus(status, idx);
+      msg->setqStatus(status, idx);
   }
 }
 
 
 //-----------------------------------------------------------------------------
-void FolderStorage::setStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle)
+void FolderStorage::setqStatus(TQValueList<int>& ids, KMMsgtqStatus status, bool toggle)
 {
   for ( TQValueList<int>::Iterator it = ids.begin(); it != ids.end(); ++it )
   {
-    FolderStorage::setStatus(*it, status, toggle);
+    FolderStorage::setqStatus(*it, status, toggle);
   }
 }
 
@@ -1135,11 +1135,11 @@ void FolderStorage::slotProcessNextSearchBatch()
 {
   if ( !mSearchPattern )
     return;
-  TQValueList<Q_UINT32> matchingSerNums;
-  const int end = QMIN( mCurrentSearchedMsg + 15, count() );
+  TQValueList<TQ_UINT32> matchingSerNums;
+  const int end = TQMIN( mCurrentSearchedMsg + 15, count() );
   for ( int i = mCurrentSearchedMsg; i < end; ++i )
   {
-    Q_UINT32 serNum = KMMsgDict::instance()->getMsgSerNum( folder(), i );
+    TQ_UINT32 serNum = KMMsgDict::instance()->getMsgSerNum( folder(), i );
     if ( mSearchPattern->matches( serNum ) )
       matchingSerNums.append( serNum );
   }
@@ -1151,7 +1151,7 @@ void FolderStorage::slotProcessNextSearchBatch()
 }
 
 //-----------------------------------------------------------------------------
-void FolderStorage::search( const KMSearchPattern* pattern, Q_UINT32 serNum )
+void FolderStorage::search( const KMSearchPattern* pattern, TQ_UINT32 serNum )
 {
   bool matches = pattern && pattern->matches( serNum );
 
