@@ -16,11 +16,11 @@
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of this program with any edition of
- * the Qt library by Trolltech AS, Norway (or with modified versions
- * of Qt that use the same license as Qt), and distribute linked
+ * the TQt library by Trolltech AS, Norway (or with modified versions
+ * of TQt that use the same license as TQt), and distribute linked
  * combinations including the two.  You must obey the GNU General
  * Public License in all respects for all of the code used other than
- * Qt.  If you modify this file, you may extend this exception to
+ * TQt.  If you modify this file, you may extend this exception to
  * your version of the file, but you are not obligated to do so.  If
  * you do not wish to do so, delete this exception statement from
  * your version.
@@ -60,15 +60,15 @@ const char* const folderIndexDisabledKey = "fulltextIndexDisabled";
 
 #ifdef HAVE_INDEXLIB
 static
-TQValueList<int> vectorToQValueList( const std::vector<Q_UINT32>& input ) {
+TQValueList<int> vectorToTQValueList( const std::vector<TQ_UINT32>& input ) {
 	TQValueList<int> res;
 	std::copy( input.begin(), input.end(), std::back_inserter( res ) );
 	return res;
 }
 
 static
-std::vector<Q_UINT32> QValueListToVector( const TQValueList<int>& input ) {
-	std::vector<Q_UINT32> res;
+std::vector<TQ_UINT32> TQValueListToVector( const TQValueList<int>& input ) {
+	std::vector<TQ_UINT32> res;
 	// res.assign( input.begin(), input.end() ) doesn't work for some reason
 	for ( TQValueList<int>::const_iterator first = input.begin(), past = input.end(); first != past; ++first ) {
 		res.push_back( *first );
@@ -91,10 +91,10 @@ KMMsgIndex::KMMsgIndex( TQObject* parent ):
 	mSlowDown( false ) {
 	kdDebug( 5006 ) << "KMMsgIndex::KMMsgIndex()" << endl;
 
-	connect( kmkernel->folderMgr(), TQT_SIGNAL( msgRemoved( KMFolder*, Q_UINT32 ) ), TQT_SLOT( slotRemoveMessage( Q_UINT32 ) ) );
-	connect( kmkernel->folderMgr(), TQT_SIGNAL( msgAdded( KMFolder*, Q_UINT32 ) ), TQT_SLOT( slotAddMessage( Q_UINT32 ) ) );
-	connect( kmkernel->dimapFolderMgr(), TQT_SIGNAL( msgRemoved( KMFolder*, Q_UINT32 ) ), TQT_SLOT( slotRemoveMessage( Q_UINT32 ) ) );
-	connect( kmkernel->dimapFolderMgr(), TQT_SIGNAL( msgAdded( KMFolder*, Q_UINT32 ) ), TQT_SLOT( slotAddMessage( Q_UINT32 ) ) );
+	connect( kmkernel->folderMgr(), TQT_SIGNAL( msgRemoved( KMFolder*, TQ_UINT32 ) ), TQT_SLOT( slotRemoveMessage( TQ_UINT32 ) ) );
+	connect( kmkernel->folderMgr(), TQT_SIGNAL( msgAdded( KMFolder*, TQ_UINT32 ) ), TQT_SLOT( slotAddMessage( TQ_UINT32 ) ) );
+	connect( kmkernel->dimapFolderMgr(), TQT_SIGNAL( msgRemoved( KMFolder*, TQ_UINT32 ) ), TQT_SLOT( slotRemoveMessage( TQ_UINT32 ) ) );
+	connect( kmkernel->dimapFolderMgr(), TQT_SIGNAL( msgAdded( KMFolder*, TQ_UINT32 ) ), TQT_SLOT( slotAddMessage( TQ_UINT32 ) ) );
 
 	connect( mTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( act() ) );
 	//connect( mSyncTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( syncIndex() ) );
@@ -123,8 +123,8 @@ KMMsgIndex::KMMsgIndex( TQObject* parent ):
 			TQTimer::singleShot( 8000, this, TQT_SLOT( continueCreation() ) );
 			mState = s_creating;
 		} else {
-			mPendingMsgs = QValueListToVector( cfg.readIntListEntry( "pending" ) );
-			mRemovedMsgs = QValueListToVector( cfg.readIntListEntry( "removed" ) );
+			mPendingMsgs = TQValueListToVector( cfg.readIntListEntry( "pending" ) );
+			mRemovedMsgs = TQValueListToVector( cfg.readIntListEntry( "removed" ) );
 		}
 	}
 	mIndex = 0;
@@ -143,10 +143,10 @@ KMMsgIndex::~KMMsgIndex() {
 	TQValueList<int> pendingMsg;
 	if ( mState == s_processing ) {
 		Q_ASSERT( mAddedMsgs.empty() );
-		pendingMsg = vectorToQValueList( mPendingMsgs );
+		pendingMsg = vectorToTQValueList( mPendingMsgs );
 	}
 	cfg.writeEntry( "pending", pendingMsg );
-	cfg.writeEntry( "removed", vectorToQValueList( mRemovedMsgs ) );
+	cfg.writeEntry( "removed", vectorToTQValueList( mRemovedMsgs ) );
 	delete mIndex;
 #endif
 }
@@ -272,7 +272,7 @@ void KMMsgIndex::maintenance() {
 #endif
 }
 
-int KMMsgIndex::addMessage( Q_UINT32 serNum ) {
+int KMMsgIndex::addMessage( TQ_UINT32 serNum ) {
 	kdDebug( 5006 ) << "KMMsgIndex::addMessage( " << serNum << " )" << endl;
 	if ( mState == s_error ) return 0;
 #ifdef HAVE_INDEXLIB
@@ -407,7 +407,7 @@ bool KMMsgIndex::startQuery( KMSearch* s ) {
 	connect( search, TQT_SIGNAL( finished( bool ) ), s, TQT_SIGNAL( finished( bool ) ) );
 	connect( search, TQT_SIGNAL( finished( bool ) ), s, TQT_SLOT( indexFinished() ) );
 	connect( search, TQT_SIGNAL( destroyed( TQObject* ) ), TQT_SLOT( removeSearch( TQObject* ) ) );
-	connect( search, TQT_SIGNAL( found( Q_UINT32 ) ), s, TQT_SIGNAL( found( Q_UINT32 ) ) );
+	connect( search, TQT_SIGNAL( found( TQ_UINT32 ) ), s, TQT_SIGNAL( found( TQ_UINT32 ) ) );
 	mSearches.push_back( search );
 	return true;
 }
@@ -449,13 +449,13 @@ bool KMMsgIndex::stopQuery( KMSearch* s ) {
 	return false;
 }
 
-std::vector<Q_UINT32> KMMsgIndex::simpleSearch( TQString s, bool* ok ) const {
+std::vector<TQ_UINT32> KMMsgIndex::simpleSearch( TQString s, bool* ok ) const {
 	kdDebug( 5006 ) << "KMMsgIndex::simpleSearch( -" << s.latin1() << "- )" << endl;
 	if ( mState == s_error || mState == s_disabled ) {
 		if ( ok ) *ok = false;
-		return std::vector<Q_UINT32>();
+		return std::vector<TQ_UINT32>();
 	}
-	std::vector<Q_UINT32> res;
+	std::vector<TQ_UINT32> res;
 #ifdef HAVE_INDEXLIB
 	assert( mIndex );
 	std::vector<unsigned> residx = mIndex->search( s.latin1() )->list();
@@ -482,7 +482,7 @@ bool KMMsgIndex::canHandleQuery( const KMSearchPattern* pat ) const {
 	return false;
 }
 
-void KMMsgIndex::slotAddMessage( Q_UINT32 serNum ) {
+void KMMsgIndex::slotAddMessage( TQ_UINT32 serNum ) {
 	kdDebug( 5006 ) << "KMMsgIndex::slotAddMessage( . , " << serNum << " )" << endl;
 	if ( mState == s_error || mState == s_disabled ) return;
 
@@ -493,7 +493,7 @@ void KMMsgIndex::slotAddMessage( Q_UINT32 serNum ) {
 	scheduleAction();
 }
 
-void KMMsgIndex::slotRemoveMessage( Q_UINT32 serNum ) {
+void KMMsgIndex::slotRemoveMessage( TQ_UINT32 serNum ) {
 	kdDebug( 5006 ) << "KMMsgIndex::slotRemoveMessage( . , " << serNum << " )" << endl;
 	if ( mState == s_error || mState == s_disabled ) return;
 
@@ -509,7 +509,7 @@ void KMMsgIndex::scheduleAction() {
 #endif
 }
 
-void KMMsgIndex::removeMessage( Q_UINT32 serNum ) {
+void KMMsgIndex::removeMessage( TQ_UINT32 serNum ) {
 	kdDebug( 5006 ) << "KMMsgIndex::removeMessage( " << serNum << " )" << endl;
 	if ( mState == s_error || mState == s_disabled ) return;
 
@@ -550,7 +550,7 @@ void KMMsgIndex::Search::act() {
 			TQString terms;
 			for ( KMSearchRule* rule = pat->first(); rule; rule = pat->next() ) {
 				Q_ASSERT( rule->function() == KMSearchRule::FuncContains );
-				terms += TQString::fromLatin1( " %1 " ).arg( rule->contents() );
+				terms += TQString::tqfromLatin1( " %1 " ).tqarg( rule->contents() );
 			}
 
 			mValues = kmkernel->msgIndex()->simpleSearch( terms, 0  );
