@@ -10,12 +10,12 @@
  * As soon as it gets out of scope, it will restore the original
  * cursor.
  */
-class KCursorSaver : public Qt
+class KCursorSaver : public TQt
 {
 public:
-    /// constructor taking TQCursor shapes
-    KCursorSaver(Qt::CursorShape shape) {
-        TQApplication::setOverrideCursor( TQCursor(shape) );
+    /// constructor taking TQCursor tqshapes
+    KCursorSaver(TQt::tqCursorShape tqshape) {
+        TQApplication::setOverrideCursor( TQCursor(tqshape) );
         inited = true;
     }
 
