@@ -24,11 +24,11 @@
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
+    the TQt library by Trolltech AS, Norway (or with modified versions
+    of TQt that use the same license as TQt), and distribute linked
     combinations including the two.  You must obey the GNU General
     Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
+    TQt.  If you modify this file, you may extend this exception to
     your version of the file, but you are not obligated to do so.  If
     you do not wish to do so, delete this exception statement from
     your version.
@@ -308,7 +308,7 @@ static std::vector<GpgME::Key> trustedOrConfirmed( const std::vector<GpgME::Key>
              "for encryption.")
       : i18n("One or more of the OpenPGP encryption keys or S/MIME "
              "certificates for recipient \"%1\" is not fully trusted "
-             "for encryption.").arg(address) ;
+             "for encryption.").tqarg(address) ;
 
   if ( !fishies.empty() ) {
     // certificates can't have marginal trust
@@ -651,7 +651,7 @@ Kpgp::Result Kleo::KeyResolver::checkKeyNearExpiry( const GpgME::Key & key, cons
                      "<p>expired less than a day ago.</p>",
                      "<p>The OpenPGP key for</p><p align=center><b>%1</b> (KeyID 0x%2)</p>"
                      "<p>expired %n days ago.</p>",
-                     daysSinceExpiry ) ).arg( TQString::fromUtf8( key.userID(0).id() ),
+                     daysSinceExpiry ) ).tqarg( TQString::fromUtf8( key.userID(0).id() ),
 					 key.shortKeyID() )
           : ( ca
               ? ( key.isRoot()
@@ -698,7 +698,7 @@ Kpgp::Result Kleo::KeyResolver::checkKeyNearExpiry( const GpgME::Key & key, cons
                              "<p>The intermediate CA certificate</p><p align=center><b>%3</b></p>"
                              "<p>for S/MIME certificate</p><p align=center><b>%1</b> (serial number %2)</p>"
                              "<p>expired %n days ago.</p>",
-                             daysSinceExpiry ) ) ).arg( Kleo::DN( orig.userID(0).id() ).prettyDN(),
+                             daysSinceExpiry ) ) ).tqarg( Kleo::DN( orig.userID(0).id() ).prettyDN(),
                                                        orig.issuerSerial(),
                                                        Kleo::DN( key.userID(0).id() ).prettyDN() )
               : ( mine ? sign
@@ -716,7 +716,7 @@ Kpgp::Result Kleo::KeyResolver::checkKeyNearExpiry( const GpgME::Key & key, cons
                          "<p>expired less than a day ago.</p>",
                          "<p>The S/MIME certificate for</p><p align=center><b>%1</b> (serial number %2)</p>"
                          "<p>expired %n days ago.</p>",
-                         daysSinceExpiry ) ).arg( Kleo::DN( key.userID(0).id() ).prettyDN(),
+                         daysSinceExpiry ) ).tqarg( Kleo::DN( key.userID(0).id() ).prettyDN(),
                                                  key.issuerSerial() ) );
       d->alreadyWarnedFingerprints.insert( subkey.fingerprint() );
       if ( KMessageBox::warningContinueCancel( 0, msg,
@@ -759,7 +759,7 @@ Kpgp::Result Kleo::KeyResolver::checkKeyNearExpiry( const GpgME::Key & key, cons
 		 "<p>expires in less than a day.</p>",
 		 "<p>The OpenPGP key for</p><p align=center><b>%1</b> (KeyID 0x%2)</p>"
 		 "<p>expires in less than %n days.</p>",
-		 daysTillExpiry ) ).arg( TQString::fromUtf8( key.userID(0).id() ),
+		 daysTillExpiry ) ).tqarg( TQString::fromUtf8( key.userID(0).id() ),
 					 key.shortKeyID() )
       : ( ca
 	  ? ( key.isRoot()
@@ -806,7 +806,7 @@ Kpgp::Result Kleo::KeyResolver::checkKeyNearExpiry( const GpgME::Key & key, cons
 			 "<p>The intermediate CA certificate</p><p align=center><b>%3</b></p>"
 			 "<p>for S/MIME certificate</p><p align=center><b>%1</b> (serial number %2)</p>"
 			 "<p>expires in less than %n days.</p>",
-			 daysTillExpiry ) ) ).arg( Kleo::DN( orig.userID(0).id() ).prettyDN(),
+			 daysTillExpiry ) ) ).tqarg( Kleo::DN( orig.userID(0).id() ).prettyDN(),
 						   orig.issuerSerial(),
 						   Kleo::DN( key.userID(0).id() ).prettyDN() )
 	  : ( mine ? sign
@@ -824,7 +824,7 @@ Kpgp::Result Kleo::KeyResolver::checkKeyNearExpiry( const GpgME::Key & key, cons
 		     "<p>expires in less than a day.</p>",
 		     "<p>The S/MIME certificate for</p><p align=center><b>%1</b> (serial number %2)</p>"
 		     "<p>expires in less than %n days.</p>",
-		     daysTillExpiry ) ).arg( Kleo::DN( key.userID(0).id() ).prettyDN(),
+		     daysTillExpiry ) ).tqarg( Kleo::DN( key.userID(0).id() ).prettyDN(),
 					     key.issuerSerial() ) );
     d->alreadyWarnedFingerprints.insert( subkey.fingerprint() );
     if ( KMessageBox::warningContinueCancel( 0, msg,
@@ -1379,7 +1379,7 @@ void Kleo::KeyResolver::collapseAllSplitInfos() {
     SplitInfo & si = v.front();
     for ( std::vector<SplitInfo>::const_iterator it = v.begin() + 1; it != v.end() ; ++it ) {
       si.keys.insert( si.keys.end(), it->keys.begin(), it->keys.end() );
-      qCopy( it->recipients.begin(), it->recipients.end(), std::back_inserter( si.recipients ) );
+      tqCopy( it->recipients.begin(), it->recipients.end(), std::back_inserter( si.recipients ) );
     }
     v.resize( 1 );
   }
@@ -1422,7 +1422,7 @@ void Kleo::KeyResolver::dump() const {
 	std::cerr << kit->shortKeyID() << " ";
       std::cerr << std::endl
 		<< "  SplitInfo #" << i << " recipients: "
-		<< sit->recipients.join(", ").utf8() << std::endl;
+		<< sit->recipients.join(", ").utf8().data() << std::endl;
     }
   }
 #endif
@@ -1628,7 +1628,7 @@ std::vector<GpgME::Key> Kleo::KeyResolver::getEncryptionKeys( const TQString & p
               "There is a problem with the "
               "encryption certificate(s) for \"%1\".\n\n"
               "Please re-select the certificate(s) which should "
-              "be used for this recipient.").arg(person),
+              "be used for this recipient.").tqarg(person),
             keys );
       }
       bool canceled = false;
@@ -1680,13 +1680,13 @@ std::vector<GpgME::Key> Kleo::KeyResolver::getEncryptionKeys( const TQString & p
               "Select the certificate(s) which should "
               "be used for this recipient. If there is no suitable certificate in the list "
               "you can also search for external certificates by clicking the button: search for external certificates.</qt>")
-             .arg( TQStyleSheet::escape(person) )
+             .tqarg( TQStyleSheet::escape(person) )
           : i18n("if in your language something like "
               "'certificate(s)' isn't possible please "
               "use the plural in the translation",
               "More than one certificate matches \"%1\".\n\n"
               "Select the certificate(s) which should "
-              "be used for this recipient.").arg( TQStyleSheet::escape(person) ),
+              "be used for this recipient.").tqarg( TQStyleSheet::escape(person) ),
           matchingKeys ), address, canceled );
   // we can ignore 'canceled' here, since trustedOrConfirmed() returns
   // an empty vector when canceled == true, and we'd just do the same
@@ -1797,7 +1797,7 @@ void Kleo::KeyResolver::saveContactPreference( const TQString& email, const Cont
   KABC::Addressee addr;
   if ( res.isEmpty() ) {
      bool ok = true;
-     TQString fullName = KInputDialog::getText( i18n( "Name Selection" ), i18n( "Which name shall the contact '%1' have in your addressbook?" ).arg( email ), TQString::null, &ok );
+     TQString fullName = KInputDialog::getText( i18n( "Name Selection" ), i18n( "Which name shall the contact '%1' have in your addressbook?" ).tqarg( email ), TQString(), &ok );
     if ( ok ) {
       addr.setNameFromString( fullName );
       addr.insertEmail( email, true );
