@@ -19,11 +19,11 @@
  *
  *  In addition, as a special exception, the copyright holders give
  *  permission to link the code of this program with any edition of
- *  the Qt library by Trolltech AS, Norway (or with modified versions
- *  of Qt that use the same license as Qt), and distribute linked
+ *  the TQt library by Trolltech AS, Norway (or with modified versions
+ *  of TQt that use the same license as TQt), and distribute linked
  *  combinations including the two.  You must obey the GNU General
  *  Public License in all respects for all of the code used other than
- *  Qt.  If you modify this file, you may extend this exception to
+ *  TQt.  If you modify this file, you may extend this exception to
  *  your version of the file, but you are not obligated to do so.  If
  *  you do not wish to do so, delete this exception statement from
  *  your version.
@@ -186,7 +186,7 @@ void KMAcctCachedImap::slotCheckQueuedFolders()
     mMailCheckFolders.append( mFoldersQueuedForChecking.front() );
     mFoldersQueuedForChecking.pop_front();
     if ( mFoldersQueuedForChecking.isEmpty() )
-      disconnect( this, TQT_SIGNAL( finishedCheck( bool, CheckStatus ) ),
+      disconnect( this, TQT_SIGNAL( finishedCheck( bool, ChecktqStatus ) ),
                   this, TQT_SLOT( slotCheckQueuedFolders() ) );
 
     kmkernel->acctMgr()->singleCheckMail(this, true);
@@ -243,7 +243,7 @@ void KMAcctCachedImap::processNewMail( KMFolderCachedImap* folder,
   mMailCheckProgressItem = KPIM::ProgressManager::createProgressItem(
     "MailCheck" + TQString::number( id() ),
     TQStyleSheet::escape( folder->label() ), // will be changed immediately in serverSync anyway
-    TQString::null,
+    TQString(),
     true, // can be cancelled
     useSSL() || useTLS() );
   connect( mMailCheckProgressItem, TQT_SIGNAL( progressItemCanceled( KPIM::ProgressItem* ) ),
@@ -318,7 +318,7 @@ void KMAcctCachedImap::readConfig( /*const*/ KConfig/*Base*/ & config ) {
   TQStringList::const_iterator it = oldPaths.begin();
   TQStringList::const_iterator nameit = newNames.begin();
   for( ; it != oldPaths.end() && nameit != newNames.end(); ++it, ++nameit ) {
-    addRenamedFolder( *it, TQString::null, *nameit );
+    addRenamedFolder( *it, TQString(), *nameit );
   }
   mGroupwareType = (GroupwareType)config.readNumEntry( "groupwareType", GroupwareKolab );
 }
@@ -351,7 +351,7 @@ void KMAcctCachedImap::invalidateIMAPFolders( KMFolderCachedImap* folder )
   TQStringList strList;
   TQValueList<TQGuardedPtr<KMFolder> > folderList;
   kmkernel->dimapFolderMgr()->createFolderList( &strList, &folderList,
-                                                folder->folder()->child(), TQString::null,
+                                                folder->folder()->child(), TQString(),
                                                 false );
   TQValueList<TQGuardedPtr<KMFolder> >::Iterator it;
   mCountLastUnread = 0;
@@ -447,7 +447,7 @@ void KMAcctCachedImap::slotProgressItemCanceled( ProgressItem* )
   killAllJobs( abortConnection );
   if ( abortConnection ) {
     // If we were trying to connect, tell kmfoldercachedimap so that it moves on
-    emit connectionResult( KIO::ERR_USER_CANCELED, TQString::null );
+    emit connectionResult( KIO::ERR_USER_CANCELED, TQString() );
   }
 }
 
@@ -462,7 +462,7 @@ TQString KMAcctCachedImap::renamedFolder( const TQString& imapPath ) const
   TQMap<TQString, RenamedFolder>::ConstIterator renit = mRenamedFolders.find( imapPath );
   if ( renit != mRenamedFolders.end() )
     return (*renit).mNewName;
-  return TQString::null;
+  return TQString();
 }
 
 #include "kmacctcachedimap.moc"
