@@ -82,7 +82,7 @@ void KMEdit::keyPressEvent( TQKeyEvent* e )
         int line, col;
         getCursorPosition( &line, &col );
         TQString lineText = text( line );
-        // returns line with additional trailing space (bug in Qt?), cut it off
+        // returns line with additional trailing space (bug in TQt?), cut it off
         lineText.truncate( lineText.length() - 1 );
         // special treatment of quoted lines only if the cursor is neither at
         // the begin nor at the end of the line
@@ -148,7 +148,7 @@ void KMEdit::contentsDropEvent(TQDropEvent *e)
         TQBuffer serNumBuffer(serNums);
         serNumBuffer.open(IO_ReadOnly);
         TQDataStream serNumStream(&serNumBuffer);
-        Q_UINT32 serNum;
+        TQ_UINT32 serNum;
         KMFolder *folder = 0;
         int idx;
         TQPtrList<KMMsgBase> messageList;
@@ -169,7 +169,7 @@ void KMEdit::contentsDropEvent(TQDropEvent *e)
         command->start();
     }
     else if( e->provides("image/png") ) {
-        emit attachPNGImageData(e->encodedData("image/png"));
+        emit attachPNGImageData(e->tqencodedData("image/png"));
     }
     else if( KURLDrag::canDecode( e ) ) {
         KURL::List urlList;
@@ -225,7 +225,7 @@ KMEdit::KMEdit(TQWidget *parent, KMComposeWin* composer,
     mWasModifiedBeforeSpellCheck( false ),
     mHighlighter( 0 ),
     mSpellLineEdit( false ),
-    mPasteMode( QClipboard::Clipboard )
+    mPasteMode( TQClipboard::Clipboard )
 {
   connect( this, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(slotSelectionChanged()) );
   installEventFilter(this);
@@ -241,7 +241,7 @@ KMEdit::KMEdit(TQWidget *parent, KMComposeWin* composer,
 void KMEdit::createSpellers()
 {
   delete mSpeller;
-  mSpeller = new KMSpell( this, TQT_SLOT( spellerReady( KSpell * ) ), mSpellConfig );
+  mSpeller = new KMSpell( TQT_TQOBJECT(this), TQT_SLOT( spellerReady( KSpell * ) ), mSpellConfig );
 }
 
 void KMEdit::initializeAutoSpellChecking()
@@ -251,9 +251,9 @@ void KMEdit::initializeAutoSpellChecking()
   TQColor defaultColor1( 0x00, 0x80, 0x00 ); // defaults from kmreaderwin.cpp
   TQColor defaultColor2( 0x00, 0x70, 0x00 );
   TQColor defaultColor3( 0x00, 0x60, 0x00 );
-  TQColor defaultForeground( kapp->palette().active().text() );
+  TQColor defaultForeground( kapp->tqpalette().active().text() );
 
-  TQColor c = Qt::red;
+  TQColor c = TQt::red;
   KConfigGroup readerConfig( KMKernel::config(), "Reader" );
   TQColor col1;
   if ( !readerConfig.readBoolEntry(  "defaultColors", true ) )
@@ -281,7 +281,7 @@ TQPopupMenu *KMEdit::createPopupMenu( const TQPoint& pos )
   enum { IdUndo, IdRedo, IdSep1, IdCut, IdCopy, IdPaste, IdClear, IdSep2, IdSelectAll };
 
   TQPopupMenu *menu = KEdit::createPopupMenu( pos );
-  if ( !TQApplication::clipboard()->image().isNull() ) {
+  if ( !TQApplication::tqclipboard()->image().isNull() ) {
     int id = menu->idAt(0);
     menu->setItemEnabled( id - IdPaste, true);
   }
@@ -356,7 +356,7 @@ unsigned int KMEdit::lineBreakColumn() const
   unsigned int lineBreakColumn = 0;
   unsigned int numlines = numLines();
   while ( numlines-- ) {
-    lineBreakColumn = QMAX( lineBreakColumn, textLine( numlines ).length() );
+    lineBreakColumn = TQMAX( lineBreakColumn, textLine( numlines ).length() );
   }
   return lineBreakColumn;
 }
@@ -413,7 +413,7 @@ void KMEdit::spellerReady( KSpell *spell )
 
 bool KMEdit::eventFilter(TQObject*o, TQEvent* e)
 {
-  if (o == this)
+  if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this))
     KCursor::autoHideEventFilter(o, e);
 
   if (e->type() == TQEvent::KeyPress)
@@ -454,11 +454,11 @@ bool KMEdit::eventFilter(TQObject*o, TQEvent* e)
               TQT_SLOT(slotExternalEditorDone(KProcess*)));
       if (!mExtEditorProcess->start())
       {
-        KMessageBox::error( topLevelWidget(),
+        KMessageBox::error( tqtopLevelWidget(),
                             i18n("Unable to start external editor.") );
         killExternalEditor();
       } else {
-        mExtEditorTempFileWatcher = new KDirWatch( this, "mExtEditorTempFileWatcher" );
+        mExtEditorTempFileWatcher = new KDirWatch( TQT_TQOBJECT(this), "mExtEditorTempFileWatcher" );
         connect( mExtEditorTempFileWatcher, TQT_SIGNAL(dirty(const TQString&)),
                  TQT_SLOT(slotExternalEditorTempFileChanged(const TQString&)) );
         mExtEditorTempFileWatcher->addFile( mExtEditorTempFile->name() );
@@ -570,7 +570,7 @@ bool KMEdit::eventFilter(TQObject*o, TQEvent* e)
       }
     }
   } else if ( e->type() == TQEvent::FocusIn || e->type() == TQEvent::FocusOut ) {
-    TQFocusEvent *fe = static_cast<TQFocusEvent*>(e);
+    TQFocusEvent *fe = TQT_TQFOCUSEVENT(e);
     if(! (fe->reason() == TQFocusEvent::ActiveWindow || fe->reason() == TQFocusEvent::Popup) )
       emit focusChanged( fe->gotFocus() );
   }
@@ -581,7 +581,7 @@ bool KMEdit::eventFilter(TQObject*o, TQEvent* e)
 
 int KMEdit::autoSpellChecking( bool on )
 {
-  if ( textFormat() == Qt::RichText ) {
+  if ( textFormat() == TQt::RichText ) {
      // syntax highlighter doesn't support extended text properties
      if ( on )
        KMessageBox::sorry(this, i18n("Automatic spellchecking is not possible on text with markup."));
@@ -607,7 +607,7 @@ void KMEdit::slotExternalEditorTempFileChanged( const TQString & fileName ) {
 
   insertLine(TQString::fromLocal8Bit(KPIM::kFileToString( fileName, true, false )), -1);
   setAutoUpdate(true);
-  repaint();
+  tqrepaint();
 }
 
 void KMEdit::slotExternalEditorDone( KProcess * proc ) {
@@ -627,7 +627,7 @@ void KMEdit::killExternalEditor() {
 bool KMEdit::checkExternalEditorFinished() {
   if ( !mExtEditorProcess )
     return true;
-  switch ( KMessageBox::warningYesNoCancel( topLevelWidget(),
+  switch ( KMessageBox::warningYesNoCancel( tqtopLevelWidget(),
            i18n("The external editor is still running.\n"
                 "Abort the external editor or leave it open?"),
            i18n("External Editor"),
@@ -649,7 +649,7 @@ void KMEdit::spellcheck()
   mWasModifiedBeforeSpellCheck = isModified();
   mSpellLineEdit = !mSpellLineEdit;
 //  maybe for later, for now plaintext is given to KSpell
-//  if (textFormat() == Qt::RichText ) {
+//  if (textFormat() == TQt::RichText ) {
 //    kdDebug(5006) << "KMEdit::spellcheck, spellchecking for RichText" << endl;
 //    mKSpellForDialog = new KSpell(this, i18n("Spellcheck - KMail"), this,
 //                    TQT_SLOT(slotSpellcheck2(KSpell*)),0,true,false,KSpell::HTML);
@@ -658,7 +658,7 @@ void KMEdit::spellcheck()
 
     // Don't use mSpellConfig here. Reason is that the spell dialog, KSpellDlg, uses its own
     // spell config, and therefore the two wouldn't be in sync.
-    mKSpellForDialog = new KSpell( this, i18n("Spellcheck - KMail"), this,
+    mKSpellForDialog = new KSpell( TQT_TQWIDGET(this), i18n("Spellcheck - KMail"), TQT_TQOBJECT(this),
                                    TQT_SLOT(slotSpellcheck2(KSpell*))/*, mSpellConfig*/ );
 //  }
 
@@ -679,21 +679,21 @@ void KMEdit::spellcheck()
 void KMEdit::cut()
 {
   KEdit::cut();
-  if ( textFormat() != Qt::RichText && mHighlighter )
+  if ( textFormat() != TQt::RichText && mHighlighter )
     mHighlighter->restartBackgroundSpellCheck();
 }
 
 void KMEdit::clear()
 {
   KEdit::clear();
-  if ( textFormat() != Qt::RichText && mHighlighter )
+  if ( textFormat() != TQt::RichText && mHighlighter )
     mHighlighter->restartBackgroundSpellCheck();
 }
 
 void KMEdit::del()
 {
   KEdit::del();
-  if ( textFormat() != Qt::RichText && mHighlighter )
+  if ( textFormat() != TQt::RichText && mHighlighter )
     mHighlighter->restartBackgroundSpellCheck();
 }
 
@@ -711,15 +711,15 @@ void KMEdit::contentsMouseReleaseEvent( TQMouseEvent * e )
 {
   if( e->button() != Qt::MidButton )
     return KEdit::contentsMouseReleaseEvent( e );
-  mPasteMode = QClipboard::Selection;
+  mPasteMode = TQClipboard::Selection;
   KEdit::contentsMouseReleaseEvent( e );
-  mPasteMode = QClipboard::Clipboard;
+  mPasteMode = TQClipboard::Clipboard;
 }
 
 void KMEdit::contentsMouseDoubleClickEvent( TQMouseEvent *e )
 {
   bool handled = false;
-  if ( e->button() == TQt::LeftButton ) {
+  if ( e->button() == Qt::LeftButton ) {
 
     // Get the cursor position for the place where the user clicked to
     int paragraphPos;
@@ -828,7 +828,7 @@ void KMEdit::slotSpellcheck2(KSpell*)
         kdDebug(5006) << "spelling: new SpellingFilter with prefix=\"" << quotePrefix << "\"" << endl;
         TQTextEdit plaintext;
         plaintext.setText(text());
-        plaintext.setTextFormat(Qt::PlainText);
+        plaintext.setTextFormat(TQt::PlainText);
         mSpellingFilter = new SpellingFilter(plaintext.text(), quotePrefix, SpellingFilter::FilterUrls,
                                              SpellingFilter::FilterEmailAddresses);
 
@@ -880,7 +880,7 @@ void KMEdit::slotSpellDone()
   mComposer->sujectLineWidget()->deselect();
   if (status == KSpell::Error)
   {
-     KMessageBox::sorry( topLevelWidget(),
+     KMessageBox::sorry( tqtopLevelWidget(),
                          i18n("ISpell/Aspell could not be started. Please "
                               "make sure you have ISpell or Aspell properly "
                               "configured and in your PATH.") );
@@ -889,7 +889,7 @@ void KMEdit::slotSpellDone()
   else if (status == KSpell::Crashed)
   {
      spellcheck_stop();
-     KMessageBox::sorry( topLevelWidget(),
+     KMessageBox::sorry( tqtopLevelWidget(),
                          i18n("ISpell/Aspell seems to have crashed.") );
      emit spellcheck_done( KS_CANCEL );
   }
@@ -898,7 +898,7 @@ void KMEdit::slotSpellDone()
       if( mSpellLineEdit )
           spellcheck();
       else if( !mComposer->subjectTextWasSpellChecked() && status == KSpell::FinishedNoMisspellingsEncountered )
-          KMessageBox::information( topLevelWidget(),
+          KMessageBox::information( tqtopLevelWidget(),
                                     i18n("No misspellings encountered.") );
   }
 }
