@@ -185,7 +185,7 @@ const TQString KMFilterActionWithUOID::argsAsString() const
 const TQString KMFilterActionWithUOID::displayString() const
 {
   // FIXME after string freeze:
-  // return i18n("").arg( );
+  // return i18n("").tqarg( );
   return label() + " \"" + TQStyleSheet::escape( argsAsString() ) + "\"";
 }
 
@@ -236,7 +236,7 @@ const TQString KMFilterActionWithString::argsAsString() const
 const TQString KMFilterActionWithString::displayString() const
 {
   // FIXME after string freeze:
-  // return i18n("").arg( );
+  // return i18n("").tqarg( );
   return label() + " \"" + TQStyleSheet::escape( argsAsString() ) + "\"";
 }
 
@@ -464,7 +464,7 @@ TQString KMFilterActionWithCommand::substituteCommandLineArgsFor( KMMessage *aMs
         tf->close();
         delete tf;
         kdDebug(5006) << "KMFilterActionWithCommand: Could not create temp file!" << endl;
-        return TQString::null;
+        return TQString();
       }
       tf->setAutoDelete(true);
       aTempFileList.append( tf );
@@ -483,11 +483,11 @@ TQString KMFilterActionWithCommand::substituteCommandLineArgsFor( KMMessage *aMs
       }
       tf->close();
     }
-    // TQString( "%0 and %1 and %1" ).arg( 0 ).arg( 1 )
+    // TQString( "%0 and %1 and %1" ).tqarg( 0 ).tqarg( 1 )
     // returns "0 and 1 and %1", so we must call .arg as
     // many times as there are %n's, regardless of their multiplicity.
     if ((*it) == -1) result.replace( "%-1", tempFileName );
-    else result = result.arg( tempFileName );
+    else result = result.tqarg( tempFileName );
   }
 
   // And finally, replace the %{foo} with the content of the foo
@@ -495,7 +495,7 @@ TQString KMFilterActionWithCommand::substituteCommandLineArgsFor( KMMessage *aMs
   TQRegExp header_rx( "%\\{([a-z0-9-]+)\\}", false );
   int idx = 0;
   while ( ( idx = header_rx.search( result, idx ) ) != -1 ) {
-    TQString replacement = KProcess::quote( aMsg->headerField( header_rx.cap(1).latin1() ) );
+    TQString replacement = KProcess::quote( aMsg->headerField( TQString(header_rx.cap(1)).latin1() ) );
     result.replace( idx, header_rx.matchedLength(), replacement );
     idx += replacement.length();
   }
@@ -742,13 +742,13 @@ void KMFilterActionIdentity::setParamWidgetValue( TQWidget * paramWidget ) const
 }
 
 //=============================================================================
-// KMFilterActionSetStatus - set status to
+// KMFilterActionSetqStatus - set status to
 // Set the status of messages
 //=============================================================================
-class KMFilterActionSetStatus: public KMFilterActionWithStringList
+class KMFilterActionSetqStatus: public KMFilterActionWithStringList
 {
 public:
-  KMFilterActionSetStatus();
+  KMFilterActionSetqStatus();
   virtual ReturnCode process(KMMessage* msg) const;
   virtual bool requiresBody(KMMsgBase*) const;
 
@@ -762,7 +762,7 @@ public:
 };
 
 
-static const KMMsgStatus stati[] =
+static const KMMsgtqStatus stati[] =
 {
   KMMsgStatusFlag,
   KMMsgStatusRead,
@@ -776,18 +776,18 @@ static const KMMsgStatus stati[] =
   KMMsgStatusSpam,
   KMMsgStatusHam
 };
-static const int StatiCount = sizeof( stati ) / sizeof( KMMsgStatus );
+static const int StatiCount = sizeof( stati ) / sizeof( KMMsgtqStatus );
 
-KMFilterAction* KMFilterActionSetStatus::newAction()
+KMFilterAction* KMFilterActionSetqStatus::newAction()
 {
-  return (new KMFilterActionSetStatus);
+  return (new KMFilterActionSetqStatus);
 }
 
-KMFilterActionSetStatus::KMFilterActionSetStatus()
+KMFilterActionSetqStatus::KMFilterActionSetqStatus()
   : KMFilterActionWithStringList( "set status", i18n("Mark As") )
 {
   // if you change this list, also update
-  // KMFilterActionSetStatus::stati above
+  // KMFilterActionSetqStatus::stati above
   mParameterList.append( "" );
   mParameterList.append( i18n("msg status","Important") );
   mParameterList.append( i18n("msg status","Read") );
@@ -804,22 +804,22 @@ KMFilterActionSetStatus::KMFilterActionSetStatus()
   mParameter = *mParameterList.at(0);
 }
 
-KMFilterAction::ReturnCode KMFilterActionSetStatus::process(KMMessage* msg) const
+KMFilterAction::ReturnCode KMFilterActionSetqStatus::process(KMMessage* msg) const
 {
   int idx = mParameterList.findIndex( mParameter );
   if ( idx < 1 ) return ErrorButGoOn;
 
-  KMMsgStatus status = stati[idx-1] ;
-  msg->setStatus( status );
+  KMMsgtqStatus status = stati[idx-1] ;
+  msg->setqStatus( status );
   return GoOn;
 }
 
-bool KMFilterActionSetStatus::requiresBody(KMMsgBase*) const
+bool KMFilterActionSetqStatus::requiresBody(KMMsgBase*) const
 {
   return false;
 }
 
-void KMFilterActionSetStatus::argsFromString( const TQString argsStr )
+void KMFilterActionSetqStatus::argsFromString( const TQString argsStr )
 {
   if ( argsStr.length() == 1 ) {
     for ( int i = 0 ; i < StatiCount ; i++ )
@@ -831,19 +831,19 @@ void KMFilterActionSetStatus::argsFromString( const TQString argsStr )
   mParameter = *mParameterList.at(0);
 }
 
-const TQString KMFilterActionSetStatus::argsAsString() const
+const TQString KMFilterActionSetqStatus::argsAsString() const
 {
   int idx = mParameterList.findIndex( mParameter );
-  if ( idx < 1 ) return TQString::null;
+  if ( idx < 1 ) return TQString();
 
-  KMMsgStatus status = stati[idx-1];
+  KMMsgtqStatus status = stati[idx-1];
   return KMMsgBase::statusToStr(status);
 }
 
-const TQString KMFilterActionSetStatus::displayString() const
+const TQString KMFilterActionSetqStatus::displayString() const
 {
   // FIXME after string freeze:
-  // return i18n("").arg( );
+  // return i18n("").tqarg( );
   return label() + " \"" + TQStyleSheet::escape( argsAsString() ) + "\"";
 }
 
@@ -930,7 +930,7 @@ void KMFilterActionFakeDisposition::argsFromString( const TQString argsStr )
 const TQString KMFilterActionFakeDisposition::argsAsString() const
 {
   int idx = mParameterList.findIndex( mParameter );
-  if ( idx < 1 ) return TQString::null;
+  if ( idx < 1 ) return TQString();
 
   return TQString( TQChar( idx < 2 ? 'I' : char(mdns[idx-2]) ) );
 }
@@ -938,7 +938,7 @@ const TQString KMFilterActionFakeDisposition::argsAsString() const
 const TQString KMFilterActionFakeDisposition::displayString() const
 {
   // FIXME after string freeze:
-  // return i18n("").arg( );
+  // return i18n("").tqarg( );
   return label() + " \"" + TQStyleSheet::escape( argsAsString() ) + "\"";
 }
 
@@ -1064,7 +1064,7 @@ TQWidget* KMFilterActionAddHeader::createParamWidget( TQWidget* parent ) const
   cb->setInsertionPolicy( TQComboBox::AtBottom );
   hbl->addWidget( cb, 0 /* stretch */ );
   TQLabel *l = new TQLabel( i18n("With value:"), w );
-  l->setFixedWidth( l->sizeHint().width() );
+  l->setFixedWidth( l->tqsizeHint().width() );
   hbl->addWidget( l, 0 );
   TQLineEdit *le = new KLineEdit( w, "ledit" );
   hbl->addWidget( le, 1 );
@@ -1123,7 +1123,7 @@ const TQString KMFilterActionAddHeader::argsAsString() const
 const TQString KMFilterActionAddHeader::displayString() const
 {
   // FIXME after string freeze:
-  // return i18n("").arg( );
+  // return i18n("").tqarg( );
   return label() + " \"" + TQStyleSheet::escape( argsAsString() ) + "\"";
 }
 
@@ -1214,14 +1214,14 @@ TQWidget* KMFilterActionRewriteHeader::createParamWidget( TQWidget* parent ) con
   hbl->addWidget( cb, 0 /* stretch */ );
 
   TQLabel *l = new TQLabel( i18n("Replace:"), w );
-  l->setFixedWidth( l->sizeHint().width() );
+  l->setFixedWidth( l->tqsizeHint().width() );
   hbl->addWidget( l, 0 );
 
   RegExpLineEdit *rele = new RegExpLineEdit( w, "search" );
   hbl->addWidget( rele, 1 );
 
   l = new TQLabel( i18n("With:"), w );
-  l->setFixedWidth( l->sizeHint().width() );
+  l->setFixedWidth( l->tqsizeHint().width() );
   hbl->addWidget( l, 0 );
 
   TQLineEdit *le = new KLineEdit( w, "replace" );
@@ -1299,7 +1299,7 @@ const TQString KMFilterActionRewriteHeader::argsAsString() const
 const TQString KMFilterActionRewriteHeader::displayString() const
 {
   // FIXME after string freeze:
-  // return i18n("").arg( );
+  // return i18n("").tqarg( );
   return label() + " \"" + TQStyleSheet::escape( argsAsString() ) + "\"";
 }
 
@@ -1540,7 +1540,7 @@ void KMFilterActionForward::applyParamWidgetValue( TQWidget* paramWidget )
 
   if ( templateCombo->currentItem() == 0 ) {
     // Default template, so don't use a custom one
-    mTemplate = TQString::null;
+    mTemplate = TQString();
   }
   else {
     mTemplate = templateCombo->currentText();
@@ -1573,7 +1573,7 @@ void KMFilterActionForward::setParamWidgetValue( TQWidget* paramWidget ) const
       templateCombo->setCurrentItem( templateIndex );
     }
     else {
-      mTemplate = TQString::null;
+      mTemplate = TQString();
     }
   }
 }
@@ -1617,9 +1617,9 @@ const TQString KMFilterActionForward::argsAsString() const
 const TQString KMFilterActionForward::displayString() const
 {
   if ( mTemplate.isEmpty() )
-    return i18n( "Forward to %1 with default template " ).arg( mParameter );
+    return i18n( "Forward to %1 with default template " ).tqarg( mParameter );
   else
-    return i18n( "Forward to %1 with template %2" ).arg( mParameter, mTemplate );
+    return i18n( "Forward to %1 with template %2" ).tqarg( mParameter, mTemplate );
 }
 
 //=============================================================================
@@ -1732,7 +1732,7 @@ class PipeJob : public KPIM::ThreadWeaver::Job
         if (! fgets( buffer, len, p ) ) break;
         int oldsize = ba.size();
         ba.resize( oldsize + strlen(buffer) );
-        qmemmove( ba.begin() + oldsize, buffer, strlen(buffer) );
+        tqmemmove( ba.begin() + oldsize, buffer, strlen(buffer) );
       }
       pclose(p);
       if ( !ba.isEmpty() ) {
@@ -1744,10 +1744,10 @@ class PipeJob : public KPIM::ThreadWeaver::Job
         if ( !origSerNum.isEmpty() )
           mMsg->setHeaderField( "X-KMail-Filtered", origSerNum );
         if ( filterFolder && handler ) {
-          bool oldStatus = handler->ignoreChanges( true );
+          bool oldtqStatus = handler->ignoreChanges( true );
           filterFolder->take( filterFolder->find( mMsg ) );
           filterFolder->addMsg( mMsg );
-          handler->ignoreChanges( oldStatus );
+          handler->ignoreChanges( oldtqStatus );
         } else {
           kdDebug(5006) << "Warning: Cannot refresh the message from the external filter." << endl;
         }
@@ -1878,7 +1878,7 @@ const TQString KMFilterActionWithTest::argsAsString() const
 const TQString KMFilterActionWithTest::displayString() const
 {
   // FIXME after string freeze:
-  // return i18n("").arg( );
+  // return i18n("").tqarg( );
   return label() + " \"" + TQStyleSheet::escape( argsAsString() ) + "\"";
 }
 
@@ -1898,7 +1898,7 @@ KMFilterAction::ReturnCode KMFilterActionExecSound::process(KMMessage*) const
   if ( mParameter.isEmpty() )
     return ErrorButGoOn;
   TQString play = mParameter;
-  TQString file = TQString::fromLatin1("file:");
+  TQString file = TQString::tqfromLatin1("file:");
   if (mParameter.startsWith(file))
     play = mParameter.mid(file.length());
   KAudioPlayer::play(TQFile::encodeName(play));
@@ -1955,7 +1955,7 @@ const TQString KMFilterActionWithUrl::argsAsString() const
 const TQString KMFilterActionWithUrl::displayString() const
 {
   // FIXME after string freeze:
-  // return i18n("").arg( );
+  // return i18n("").tqarg( );
   return label() + " \"" + TQStyleSheet::escape( argsAsString() ) + "\"";
 }
 
@@ -1970,7 +1970,7 @@ void KMFilterActionDict::init(void)
   insert( KMFilterActionMove::newAction );
   insert( KMFilterActionCopy::newAction );
   insert( KMFilterActionIdentity::newAction );
-  insert( KMFilterActionSetStatus::newAction );
+  insert( KMFilterActionSetqStatus::newAction );
   insert( KMFilterActionFakeDisposition::newAction );
   insert( KMFilterActionTransport::newAction );
   insert( KMFilterActionReplyTo::newAction );
