@@ -190,8 +190,8 @@ public:
   virtual void argsFromString(const TQString) {};
 
   /** Return extra arguments as string. Must not contain newlines. We
-      return TQString::null, because we have no parameter. */
-  virtual const TQString argsAsString() const { return TQString::null; }
+      return TQString(), because we have no parameter. */
+  virtual const TQString argsAsString() const { return TQString(); }
 
   /** Returns a translated string describing this filter for visualization
       purposes, e.g. in the filter log. */
@@ -493,7 +493,7 @@ public:
 
 
 /** Abstract base class for KMail's filter actions that need a command
-    line as parameter, e.g. 'forward to'. Can create a QLineEdit
+    line as parameter, e.g. 'forward to'. Can create a TQLineEdit
     (are there better widgets in the depths of the kdelibs?) as
     parameter widget. A subclass of this must provide at least
     implementations for the following methods:
