@@ -32,7 +32,7 @@ using KMail::FilterImporterExporter;
 #include <klistview.h>
 #include <kpushbutton.h>
 
-// other Qt headers:
+// other TQt headers:
 #include <tqlayout.h>
 #include <tqlabel.h>
 #include <tqcombobox.h>
@@ -173,23 +173,23 @@ KMFilterDlg::KMFilterDlg(TQWidget* parent, const char* name, bool popFilter, boo
   hbl->setStretchFactor( vbl, 2 );
 
   mPatternEdit = new KMSearchPatternEdit( i18n("Filter Criteria"), bPopFilter ? w : page1 , "spe", bPopFilter);
-  vbl->addWidget( mPatternEdit, 0, Qt::AlignTop );
+  vbl->addWidget( mPatternEdit, 0, TQt::AlignTop );
 
   if(bPopFilter){
     mActionGroup = new KMPopFilterActionWidget( i18n("Filter Action"), w );
-    vbl->addWidget( mActionGroup, 0, Qt::AlignTop );
+    vbl->addWidget( mActionGroup, 0, TQt::AlignTop );
 
     mGlobalsBox = new TQVGroupBox(i18n("Global Options"), w);
     mShowLaterBtn = new TQCheckBox(i18n("Always &show matched 'Download Later' messages in confirmation dialog"), mGlobalsBox);
     TQWhatsThis::add( mShowLaterBtn, i18n(_wt_filterdlg_showLater) );
-    vbl->addWidget( mGlobalsBox, 0, Qt::AlignTop );
+    vbl->addWidget( mGlobalsBox, 0, TQt::AlignTop );
   }
   else {
-    TQGroupBox *agb = new TQGroupBox( 1 /*column*/, Vertical, i18n("Filter Actions"), page1 );
+    TQGroupBox *agb = new TQGroupBox( 1 /*column*/, Qt::Vertical, i18n("Filter Actions"), page1 );
     mActionLister = new KMFilterActionWidgetLister( agb );
-    vbl->addWidget( agb, 0, Qt::AlignTop );
+    vbl->addWidget( agb, 0, TQt::AlignTop );
 
-    mAdvOptsGroup = new TQGroupBox ( 1 /*columns*/, Vertical,
+    mAdvOptsGroup = new TQGroupBox ( 1 /*columns*/, Qt::Vertical,
 				    i18n("Advanced Options"), page2);
     {
       TQWidget *adv_w = new TQWidget( mAdvOptsGroup );
@@ -234,7 +234,7 @@ KMFilterDlg::KMFilterDlg(TQWidget* parent, const char* name, bool popFilter, boo
       mConfigureShortcut = new TQCheckBox( i18n("Add this filter to the Apply Filter menu"), adv_w );
       gl->addMultiCellWidget( mConfigureShortcut, 7, 7, 0, 1 );
       TQLabel *keyButtonLabel = new TQLabel( i18n( "Shortcut:" ), adv_w );
-      keyButtonLabel->setAlignment( AlignVCenter | AlignRight );
+      keyButtonLabel->tqsetAlignment( AlignVCenter | AlignRight );
       gl->addMultiCellWidget( keyButtonLabel, 7, 7, 2, 2 );
       mKeyButton = new KKeyButton( adv_w, "FilterShortcutSelector" );
       gl->addMultiCellWidget( mKeyButton, 7, 7, 3, 3 );
@@ -257,7 +257,7 @@ KMFilterDlg::KMFilterDlg(TQWidget* parent, const char* name, bool popFilter, boo
 
       gl->addMultiCellWidget( hbox, 9, 9, 0, 3 );
     }
-    vbl2->addWidget( mAdvOptsGroup, 0, Qt::AlignTop );
+    vbl2->addWidget( mAdvOptsGroup, 0, TQt::AlignTop );
   }
   // spacer:
   vbl->addStretch( 1 );
@@ -339,11 +339,11 @@ KMFilterDlg::KMFilterDlg(TQWidget* parent, const char* name, bool popFilter, boo
   connect( this, TQT_SIGNAL(finished()),
 	   this, TQT_SLOT(slotFinished()) );
 
-  KConfigGroup geometry( KMKernel::config(), "Geometry");
+  KConfigGroup tqgeometry( KMKernel::config(), "Geometry");
   const char * configKey
     = bPopFilter ? "popFilterDialogSize" : "filterDialogSize";
-  if ( geometry.hasKey( configKey ) )
-    resize( geometry.readSizeEntry( configKey ) );
+  if ( tqgeometry.hasKey( configKey ) )
+    resize( tqgeometry.readSizeEntry( configKey ) );
   else
     adjustSize();
 
@@ -356,8 +356,8 @@ void KMFilterDlg::slotFinished() {
 }
 
 void KMFilterDlg::slotSaveSize() {
-  KConfigGroup geometry( KMKernel::config(), "Geometry" );
-  geometry.writeEntry( bPopFilter ? "popFilterDialogSize" : "filterDialogSize", size() );
+  KConfigGroup tqgeometry( KMKernel::config(), "Geometry" );
+  tqgeometry.writeEntry( bPopFilter ? "popFilterDialogSize" : "filterDialogSize", size() );
 }
 
 /** Set action of popFilter */
@@ -558,7 +558,7 @@ void KMFilterDlg::slotUpdateAccountList()
     TQCheckListItem *listItem =
       new TQCheckListItem( mAccountList, top, a->name(), TQCheckListItem::CheckBox );
     listItem->setText( 1, a->type() );
-    listItem->setText( 2, TQString( "%1" ).arg( a->id() ) );
+    listItem->setText( 2, TQString( "%1" ).tqarg( a->id() ) );
     if ( mFilter )
       listItem->setOn( mFilter->applyOnAccount( a->id() ) );
     top = listItem;
@@ -578,7 +578,7 @@ void KMFilterDlg::slotUpdateAccountList()
 //=============================================================================
 
 KMFilterListBox::KMFilterListBox( const TQString & title, TQWidget *parent, const char* name, bool popFilter )
-  : TQGroupBox( 1, Horizontal, title, parent, name ),
+  : TQGroupBox( 1, Qt::Horizontal, title, parent, name ),
     bPopFilter(popFilter)
 {
   mFilterList.setAutoDelete( true );
@@ -592,22 +592,22 @@ KMFilterListBox::KMFilterListBox( const TQString & title, TQWidget *parent, cons
   //----------- the first row of buttons
   TQHBox *hb = new TQHBox(this);
   hb->setSpacing(4);
-  mBtnTop = new KPushButton( TQString::null, hb );
+  mBtnTop = new KPushButton( TQString(), hb );
   mBtnTop->setAutoRepeat( true );
   mBtnTop->setIconSet( BarIconSet( "top", KIcon::SizeSmall ) );
-  mBtnTop->setMinimumSize( mBtnTop->sizeHint() * 1.2 );
-  mBtnUp = new KPushButton( TQString::null, hb );
+  mBtnTop->setMinimumSize( mBtnTop->tqsizeHint() * 1.2 );
+  mBtnUp = new KPushButton( TQString(), hb );
   mBtnUp->setAutoRepeat( true );
   mBtnUp->setIconSet( BarIconSet( "up", KIcon::SizeSmall ) );
-  mBtnUp->setMinimumSize( mBtnUp->sizeHint() * 1.2 );
-  mBtnDown = new KPushButton( TQString::null, hb );
+  mBtnUp->setMinimumSize( mBtnUp->tqsizeHint() * 1.2 );
+  mBtnDown = new KPushButton( TQString(), hb );
   mBtnDown->setAutoRepeat( true );
   mBtnDown->setIconSet( BarIconSet( "down", KIcon::SizeSmall ) );
-  mBtnDown->setMinimumSize( mBtnDown->sizeHint() * 1.2 );
-  mBtnBot = new KPushButton( TQString::null, hb );
+  mBtnDown->setMinimumSize( mBtnDown->tqsizeHint() * 1.2 );
+  mBtnBot = new KPushButton( TQString(), hb );
   mBtnBot->setAutoRepeat( true );
   mBtnBot->setIconSet( BarIconSet( "bottom", KIcon::SizeSmall ) );
-  mBtnBot->setMinimumSize( mBtnBot->sizeHint() * 1.2 );
+  mBtnBot->setMinimumSize( mBtnBot->tqsizeHint() * 1.2 );
   TQToolTip::add( mBtnTop, i18n("Top") );
   TQToolTip::add( mBtnUp, i18n("Up") );
   TQToolTip::add( mBtnDown, i18n("Down") );
@@ -620,15 +620,15 @@ KMFilterListBox::KMFilterListBox( const TQString & title, TQWidget *parent, cons
   //----------- the second row of buttons
   hb = new TQHBox(this);
   hb->setSpacing(4);
-  mBtnNew = new TQPushButton( TQString::null, hb );
+  mBtnNew = new TQPushButton( TQString(), hb );
   mBtnNew->setPixmap( BarIcon( "filenew", KIcon::SizeSmall ) );
-  mBtnNew->setMinimumSize( mBtnNew->sizeHint() * 1.2 );
-  mBtnCopy = new TQPushButton( TQString::null, hb );
+  mBtnNew->setMinimumSize( mBtnNew->tqsizeHint() * 1.2 );
+  mBtnCopy = new TQPushButton( TQString(), hb );
   mBtnCopy->setIconSet( BarIconSet( "editcopy", KIcon::SizeSmall ) );
-  mBtnCopy->setMinimumSize( mBtnCopy->sizeHint() * 1.2 );
-  mBtnDelete = new TQPushButton( TQString::null, hb );
+  mBtnCopy->setMinimumSize( mBtnCopy->tqsizeHint() * 1.2 );
+  mBtnDelete = new TQPushButton( TQString(), hb );
   mBtnDelete->setIconSet( BarIconSet( "editdelete", KIcon::SizeSmall ) );
-  mBtnDelete->setMinimumSize( mBtnDelete->sizeHint() * 1.2 );
+  mBtnDelete->setMinimumSize( mBtnDelete->tqsizeHint() * 1.2 );
   mBtnRename = new TQPushButton( i18n("Rename..."), hb );
   TQToolTip::add( mBtnNew, i18n("New") );
   TQToolTip::add( mBtnCopy, i18n("Copy") );
@@ -682,7 +682,7 @@ void KMFilterListBox::createFilter( const TQCString & field,
 
   KMFilter *newFilter = new KMFilter(0, bPopFilter);
   newFilter->pattern()->append( newRule );
-  newFilter->pattern()->setName( TQString("<%1>:%2").arg( field ).arg( value) );
+  newFilter->pattern()->setName( TQString("<%1>:%2").tqarg( TQString(field) ).tqarg( TQString(value) ) );
 
   KMFilterActionDesc *desc = (*kmkernel->filterActionDict())["transfer"];
   if ( desc )
@@ -712,7 +712,7 @@ void KMFilterListBox::slotUpdateFilterName()
   if ( mFilterList.at(mIdxSelItem)->isAutoNaming() ) {
     // auto-naming of patterns
     if ( !p->isEmpty() && p->first() && !p->first()->field().stripWhiteSpace().isEmpty() )
-      shouldBeName = TQString( "<%1>: %2" ).arg( p->first()->field() ).arg( p->first()->contents() );
+      shouldBeName = TQString( "<%1>: %2" ).tqarg( TQString(p->first()->field()) ).tqarg( TQString(p->first()->contents()) );
     else
       shouldBeName = "<" + i18n("unnamed") + ">";
     p->setName( shouldBeName );
@@ -757,7 +757,7 @@ void KMFilterListBox::slotApplyFilterChanges()
 		       "IMAP account. Such filters will only be applied "
 		       "when manually filtering and when filtering "
 		       "incoming online IMAP mail.");
-    KMessageBox::information( this, str, TQString::null,
+    KMessageBox::information( this, str, TQString(),
 			      "filterDlgOnlineImapCheck" );
   }
 }
@@ -786,7 +786,7 @@ TQValueList<KMFilter*> KMFilterListBox::filtersForSaving() const
         TQString msg = i18n("The following filters have not been saved because they "
                    "were invalid (e.g. containing no actions or no search "
                    "rules).");
-        KMessageBox::informationList( 0, msg, emptyFilters, TQString::null,
+        KMessageBox::informationList( 0, msg, emptyFilters, TQString(),
                       "ShowInvalidFilterWarning" );
       }
       return filters;
@@ -946,9 +946,9 @@ void KMFilterListBox::slotRename()
     (
      i18n("Rename Filter"),
      i18n("Rename filter \"%1\" to:\n(leave the field empty for automatic naming)")
-        .arg( filter->pattern()->name() ) /*label*/,
+        .tqarg( filter->pattern()->name() ) /*label*/,
      filter->pattern()->name() /* initial value */,
-     &okPressed, topLevelWidget(), 0, validator
+     &okPressed, tqtopLevelWidget(), 0, validator
      );
   delete validator;
 
@@ -1140,13 +1140,13 @@ KMFilterActionWidget::KMFilterActionWidget( TQWidget *parent, const char* name )
 
   // don't show scroll bars.
   mComboBox->setSizeLimit( mComboBox->count() );
-  // layout management:
-  // o the combo box is not to be made larger than it's sizeHint(),
+  // tqlayout management:
+  // o the combo box is not to be made larger than it's tqsizeHint(),
   //   the parameter widget should grow instead.
   // o the whole widget takes all space horizontally, but is fixed vertically.
   mComboBox->adjustSize();
-  mComboBox->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
-  setSizePolicy( TQSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Fixed ) );
+  mComboBox->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
+  tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Fixed ) );
   updateGeometry();
 
   // redirect focus to the filter action combo box
@@ -1162,7 +1162,7 @@ void KMFilterActionWidget::setAction( const KMFilterAction* aAction )
   int i=0;
   bool found =  false ;
   int count = mComboBox->count() - 1 ; // last entry is the empty one
-  TQString label = ( aAction ) ? aAction->label() : TQString::null ;
+  TQString label = ( aAction ) ? aAction->label() : TQString() ;
 
   // find the index of typeOf(aAction) in mComboBox
   // and clear the other widgets on the way.
