@@ -53,14 +53,14 @@ namespace KMail {
 }
 using KMail::AttachmentStrategy;
 
-typedef TQValueList<Q_UINT32> SerNumList;
+typedef TQValueList<TQ_UINT32> SerNumList;
 
 /** Mail folder.
  * (description will be here).
  *
  * @section Accounts
  *   The accounts (of KMail) that are fed into the folder are
- *   represented as the children of the folder. They are only stored here
+ *   represented as the tqchildren of the folder. They are only stored here
  *   during runtime to have a reference for which accounts point to a
  *   specific folder.
  */
@@ -68,6 +68,7 @@ typedef TQValueList<Q_UINT32> SerNumList;
 class KMFolder: public KMFolderNode
 {
   Q_OBJECT
+  TQ_OBJECT
   friend class ::KMFolderJob;
 public:
 
@@ -168,10 +169,10 @@ public:
   /** Specify, that the folder can't contain mails. */
   void setNoContent(bool aNoContent);
 
-  /** Returns, if the folder can't have children */
+  /** Returns, if the folder can't have tqchildren */
   bool noChildren() const;
 
-  /** Specify, that the folder can't have children */
+  /** Specify, that the folder can't have tqchildren */
   void setNoChildren(bool aNoChildren);
 
   /** Read message at given index. Indexing starts at zero */
@@ -196,7 +197,7 @@ public:
    * for each derived KMFolder).
    */
   FolderJob* createJob( KMMessage *msg, FolderJob::JobType jt = FolderJob::tGetMessage,
-                        KMFolder *folder = 0, TQString partSpecifier = TQString::null,
+                        KMFolder *folder = 0, TQString partSpecifier = TQString(),
                         const AttachmentStrategy *as = 0 ) const;
   FolderJob* createJob( TQPtrList<KMMessage>& msgList, const TQString& sets,
                         FolderJob::JobType jt = FolderJob::tGetMessage,
@@ -272,10 +273,10 @@ public:
       contained by this folder */
   int countUnreadRecursive();
 
-  /** Called by KMMsgBase::setStatus when status of a message has changed
+  /** Called by KMMsgBase::setqStatus when status of a message has changed
       required to keep the number unread messages variable current. */
-  void msgStatusChanged( const KMMsgStatus oldStatus,
-                         const KMMsgStatus newStatus,
+  void msgStatusChanged( const KMMsgtqStatus oldtqStatus,
+                         const KMMsgtqStatus newtqStatus,
                          int idx);
 
   /** Open folder for access.
@@ -489,10 +490,10 @@ public:
   int writeIndex( bool createEmptyIndex = false );
 
   /** Set the status of the message at index @p idx to @p status. */
-  void setStatus(int idx, KMMsgStatus status, bool toggle=false);
+  void setqStatus(int idx, KMMsgtqStatus status, bool toggle=false);
 
   /** Set the status of the message(s) in the TQValueList @p ids to @p status. */
-  void setStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle=false);
+  void setqStatus(TQValueList<int>& ids, KMMsgtqStatus status, bool toggle=false);
 
   /** Icon related methods */
   bool useCustomIcons() const { return mUseCustomIcons; }
@@ -573,7 +574,7 @@ signals:
   void shortcutChanged( KMFolder * );
 
   /** Emitted before a message is removed from the folder. */
-  void msgRemoved(KMFolder*, Q_UINT32 sernum);
+  void msgRemoved(KMFolder*, TQ_UINT32 sernum);
 
   /** Emitted after a message is removed from the folder. */
   void msgRemoved( int idx, TQString msgIdMD5 );
@@ -581,10 +582,10 @@ signals:
 
   /** Emitted when a message is added from the folder. */
   void msgAdded(int idx);
-  void msgAdded(KMFolder*, Q_UINT32 sernum);
+  void msgAdded(KMFolder*, TQ_UINT32 sernum);
 
   /** Emitted, when the status of a message is changed */
-  void msgChanged(KMFolder*, Q_UINT32 sernum, int delta);
+  void msgChanged(KMFolder*, TQ_UINT32 sernum, int delta);
 
   /** Emitted when a field of the header of a specific message changed. */
   void msgHeaderChanged(KMFolder*, int);
@@ -639,7 +640,7 @@ private:
   bool mExportsSernums :1;
   bool mMoveInProgress :1;
 
-  /** nationalized label or TQString::null (then name() should be used) */
+  /** nationalized label or TQString() (then name() should be used) */
   TQString mLabel;
   TQString mSystemLabel;
 
