@@ -19,11 +19,11 @@
  *
  *  In addition, as a special exception, the copyright holders give
  *  permission to link the code of this program with any edition of
- *  the Qt library by Trolltech AS, Norway (or with modified versions
- *  of Qt that use the same license as Qt), and distribute linked
+ *  the TQt library by Trolltech AS, Norway (or with modified versions
+ *  of TQt that use the same license as TQt), and distribute linked
  *  combinations including the two.  You must obey the GNU General
  *  Public License in all respects for all of the code used other than
- *  Qt.  If you modify this file, you may extend this exception to
+ *  TQt.  If you modify this file, you may extend this exception to
  *  your version of the file, but you are not obligated to do so.  If
  *  you do not wish to do so, delete this exception statement from
  *  your version.
@@ -66,6 +66,7 @@ using KMail::AttachmentStrategy;
 class DImapTroubleShootDialog : public KDialogBase
 {
   Q_OBJECT
+  TQ_OBJECT
 public:
   enum SelectedOperation {
     None = -1,
@@ -92,6 +93,7 @@ private:
 class KMFolderCachedImap : public KMFolderMaildir
 {
   Q_OBJECT
+  TQ_OBJECT
 
 public:
   static TQString cacheLocation() {
@@ -283,8 +285,8 @@ public:
   void setACLList( const ACLList& arr );
 
   // Reimplemented so the mStatusChangedLocally bool can be set
-  virtual void setStatus( int id, KMMsgStatus status, bool toggle );
-  virtual void setStatus( TQValueList<int>& ids, KMMsgStatus status, bool toggle );
+  virtual void setqStatus( int id, KMMsgtqStatus status, bool toggle );
+  virtual void setqStatus( TQValueList<int>& ids, KMMsgtqStatus status, bool toggle );
 
   TQString annotationFolderType() const { return mAnnotationFolderType; }
 
@@ -403,7 +405,7 @@ protected:
   virtual void timerEvent( TQTimerEvent* );
 
   /* update progress status */
-  void newState( int progress, const TQString& syncStatus );
+  void newState( int progress, const TQString& synctqStatus );
 
   /** See if there is a better parent then this folder */
   KMFolderCachedImap* findParent( const TQString& path, const TQString& name );
@@ -472,8 +474,8 @@ private:
 
   /**
    * Sync the next subfolder in the list of subfolders (mSubfoldersForSync).
-   * When finished, this will switch either to the state SYNC_STATE_GET_SUBFOLDER_QUOTA or
-   * to SYNC_STATE_GET_QUOTA.
+   * When finished, this will switch either to the state SYNC_STATE_GET_SUBFOLDER_TQUOTA or
+   * to SYNC_STATE_GET_TQUOTA.
    */
   void syncNextSubFolder( bool secondSync );
 
@@ -503,13 +505,13 @@ private:
     SYNC_STATE_SET_ANNOTATIONS,
     SYNC_STATE_GET_ACLS,
     SYNC_STATE_SET_ACLS,
-    SYNC_STATE_GET_QUOTA,
+    SYNC_STATE_GET_TQUOTA,
     SYNC_STATE_FIND_SUBFOLDERS,
     SYNC_STATE_SYNC_SUBFOLDERS,
     SYNC_STATE_CHECK_UIDVALIDITY,
     SYNC_STATE_RENAME_FOLDER,
     SYNC_STATE_CLOSE,
-    SYNC_STATE_GET_SUBFOLDER_QUOTA
+    SYNC_STATE_GET_SUBFOLDER_TQUOTA
   } mSyncState;
 
   int mProgress;
@@ -588,7 +590,7 @@ private:
   bool mSharedSeenFlagsChanged;
 
  /**
-  * UIDs added by setStatus. Indicates that the client has changed
+  * UIDs added by setqStatus. Indicates that the client has changed
   * the status of those mails. The mail flags for changed mails will be
   * uploaded to the server, overwriting the server's notion of the status
   * of the mails in this folder.
