@@ -20,11 +20,11 @@
  *
  *  In addition, as a special exception, the copyright holders give
  *  permission to link the code of this program with any edition of
- *  the Qt library by Trolltech AS, Norway (or with modified versions
- *  of Qt that use the same license as Qt), and distribute linked
+ *  the TQt library by Trolltech AS, Norway (or with modified versions
+ *  of TQt that use the same license as TQt), and distribute linked
  *  combinations including the two.  You must obey the GNU General
  *  Public License in all respects for all of the code used other than
- *  Qt.  If you modify this file, you may extend this exception to
+ *  TQt.  If you modify this file, you may extend this exception to
  *  your version of the file, but you are not obligated to do so.  If
  *  you do not wish to do so, delete this exception statement from
  *  your version.
@@ -100,7 +100,7 @@ KMFolderDialog::KMFolderDialog(KMFolder *aFolder, KMFolderDir *aFolderDir,
 
   TQStringList folderNames;
   TQValueList<TQGuardedPtr<KMFolder> > folders;
-  // get all folders but search and folders that can not have children
+  // get all folders but search and folders that can not have tqchildren
   aParent->createFolderList(&folderNames, &folders, true, true,
                             true, false, true, false);
 
@@ -185,7 +185,7 @@ void KMFolderDialog::slotOk()
 
   mDelayedSavingTabs = 0; // number of tabs which need delayed saving
   for ( unsigned int i = 0 ; i < mTabs.count() ; ++i ) {
-    FolderDiaTab::AcceptStatus s = mTabs[i]->accept();
+    FolderDiaTab::AcceptqStatus s = mTabs[i]->accept();
     if ( s == FolderDiaTab::Canceled ) {
       slotCancelAccept();
       return;
@@ -234,14 +234,14 @@ void KMFolderDialog::setFolder( KMFolder* folder )
   mFolder = folder;
 }
 
-static void addLine( TQWidget *parent, TQVBoxLayout* layout )
+static void addLine( TQWidget *parent, TQVBoxLayout* tqlayout )
 {
    TQFrame *line = new TQFrame( parent, "line" );
    line->setGeometry( TQRect( 80, 150, 250, 20 ) );
    line->setFrameShape( TQFrame::HLine );
    line->setFrameShadow( TQFrame::Sunken );
    line->setFrameShape( TQFrame::HLine );
-   layout->addWidget( line );
+   tqlayout->addWidget( line );
 }
 
 //----------------------------------------------------------------------------
@@ -331,7 +331,7 @@ KMail::FolderDiaGeneralTab::FolderDiaGeneralTab( KMFolderDialog* dlg,
     mNameEdit->setText( mDlg->folder() ? mDlg->folder()->label() : i18n("unnamed") );
     if (!aName.isEmpty())
             mNameEdit->setText(aName);
-    mNameEdit->setMinimumSize(mNameEdit->sizeHint());
+    mNameEdit->setMinimumSize(mNameEdit->tqsizeHint());
     // prevent renaming of IMAP inbox
     if ( mDlg->folder() && mDlg->folder()->isSystemFolder() ) {
       TQString imapPath;
@@ -449,7 +449,7 @@ KMail::FolderDiaGeneralTab::FolderDiaGeneralTab( KMFolderDialog* dlg,
 
   addLine( this, topLayout );
 
-  // use grid layout for the following combobox settings
+  // use grid tqlayout for the following combobox settings
   TQGridLayout *gl = new TQGridLayout( topLayout, 3, 2, KDialog::spacingHint() );
   gl->setColStretch( 1, 100 ); // make the second column use all available space
   int row = -1;
