@@ -245,7 +245,7 @@ void KMFolderImap::remove()
   jd.progressItem = ProgressManager::createProgressItem(
                       "ImapFolderRemove" + ProgressManager::getUniqueID(),
                       i18n("Removing folder"),
-                      i18n( "URL: %1" ).arg( TQStyleSheet::escape( folder()->prettyURL() ) ),
+                      i18n( "URL: %1" ).tqarg( TQStyleSheet::escape( folder()->prettyURL() ) ),
                       false,
                       account()->useSSL() || account()->useTLS() );
   account()->insertJob(job, jd);
@@ -322,7 +322,7 @@ int KMFolderImap::rename( const TQString& newName, KMFolderDir *aParent )
 void KMFolderImap::addMsgQuiet(KMMessage* aMsg)
 {
   KMFolder *aFolder = aMsg->parent();
-  Q_UINT32 serNum = 0;
+  TQ_UINT32 serNum = 0;
   aMsg->setTransferInProgress( false );
   if (aFolder) {
     serNum = aMsg->getMsgSerNum();
@@ -480,7 +480,7 @@ int KMFolderImap::addMsg(TQPtrList<KMMessage>& msgList, TQValueList<int>& aIndex
       if ( !msg->transferInProgress() )
         msg->setTransferInProgress( true );
     }
-    imapJob = new ImapJob( msgList, TQString::null, ImapJob::tPutMessage, this );
+    imapJob = new ImapJob( msgList, TQString(), ImapJob::tPutMessage, this );
     if ( !mAddMessageProgressItem && msgList.count() > 1 )
     {
       // use a parent progress if we have more than 1 message
@@ -488,7 +488,7 @@ int KMFolderImap::addMsg(TQPtrList<KMMessage>& msgList, TQValueList<int>& aIndex
       mAddMessageProgressItem = ProgressManager::createProgressItem(
           "Uploading"+ProgressManager::getUniqueID(),
           i18n("Uploading message data"),
-          i18n("Destination folder: %1").arg( TQStyleSheet::escape( folder()->prettyURL() ) ),
+          i18n("Destination folder: %1").tqarg( TQStyleSheet::escape( folder()->prettyURL() ) ),
           true,
           account()->useSSL() || account()->useTLS() );
       mAddMessageProgressItem->setTotalItems( msgList.count() );
@@ -849,7 +849,7 @@ void KMFolderImap::slotListResult( const TQStringList& subfolderNames,
       // update progress
       account()->listDirProgressItem()->incCompletedItems();
       account()->listDirProgressItem()->updateProgress();
-      account()->listDirProgressItem()->setStatus( folder()->prettyURL() + i18n(" completed") );
+      account()->listDirProgressItem()->setqStatus( folder()->prettyURL() + i18n(" completed") );
 
       f->initializeFrom( this, subfolderPaths[i], subfolderMimeTypes[i] );
       f->setChildrenState( subfolderAttributes[i] );
@@ -905,7 +905,7 @@ void KMFolderImap::initInbox()
   }
   if ( f ) {
     f->initializeFrom( this, "/INBOX/", "message/directory" );
-    f->setChildrenState( TQString::null );
+    f->setChildrenState( TQString() );
   }
   // so we have an INBOX
   account()->setHasInbox( true );
@@ -1003,11 +1003,11 @@ bool KMFolderImap::mailCheckInProgress() const
 //-----------------------------------------------------------------------------
 void KMFolderImap::setChildrenState( TQString attributes )
 {
-  // update children state
-  if ( attributes.find( "haschildren", 0, false ) != -1 )
+  // update tqchildren state
+  if ( attributes.find( "hastqchildren", 0, false ) != -1 )
   {
     setHasChildren( FolderStorage::HasChildren );
-  } else if ( attributes.find( "hasnochildren", 0, false ) != -1 ||
+  } else if ( attributes.find( "hasnotqchildren", 0, false ) != -1 ||
               attributes.find( "noinferiors", 0, false ) != -1 )
   {
     setHasChildren( FolderStorage::HasNoChildren );
@@ -1073,7 +1073,7 @@ void KMFolderImap::checkValidity()
     mMailCheckProgressItem->setProgress(0);
   }
   if ( account()->mailCheckProgressItem() ) {
-    account()->mailCheckProgressItem()->setStatus( folder()->prettyURL() );
+    account()->mailCheckProgressItem()->setqStatus( folder()->prettyURL() );
   }
   ImapAccountBase::jobData jd( url.url() );
   KIO::SimpleJob *job = KIO::get(url, false, false);
@@ -1231,7 +1231,7 @@ void KMFolderImap::reallyGetFolder(const TQString &startUid)
   if (startUid.isEmpty())
   {
     if ( mMailCheckProgressItem )
-      mMailCheckProgressItem->setStatus( i18n("Retrieving message status") );
+      mMailCheckProgressItem->setqStatus( i18n("Retrieving message status") );
     url.setPath(imapPath() + ";SECTION=UID FLAGS");
     KIO::SimpleJob *job = KIO::listDir(url, false);
     KIO::Scheduler::assignJobToSlave(account()->slave(), job);
@@ -1246,7 +1246,7 @@ void KMFolderImap::reallyGetFolder(const TQString &startUid)
   } else {
     mContentState = imapDownloadInProgress;
     if ( mMailCheckProgressItem )
-      mMailCheckProgressItem->setStatus( i18n("Retrieving messages") );
+      mMailCheckProgressItem->setqStatus( i18n("Retrieving messages") );
     url.setPath(imapPath() + ";UID=" + startUid
       + ":*;SECTION=ENVELOPE");
     KIO::SimpleJob *newJob = KIO::get(url, false, false);
@@ -1271,7 +1271,7 @@ void KMFolderImap::slotListFolderResult(KIO::Job * job)
   if (job->error())
   {
     account()->handleJobError( job,
-         i18n("Error while listing the contents of the folder %1.").arg( label() ) );
+         i18n("Error while listing the contents of the folder %1.").tqarg( label() ) );
     account()->removeJob(it);
     finishMailCheck( "listfolder", imapNoInformation );
     return;
@@ -1309,9 +1309,9 @@ void KMFolderImap::slotListFolderResult(KIO::Job * job)
           int supportedFlags = mUploadAllFlags ? 31 : mPermanentFlags;
           if ( mReadOnly )
             supportedFlags = INT_MAX;
-          flagsToStatus( msgBase, serverFlags, false, supportedFlags );
+          flagsTotqStatus( msgBase, serverFlags, false, supportedFlags );
         } else
-          seenFlagToStatus( msgBase, serverFlags, false );
+          seenFlagTotqStatus( msgBase, serverFlags, false );
         idx++;
         uid = (*it).items.remove(uid);
         if ( msgBase->getMsgSerNum() > 0 ) {
@@ -1327,7 +1327,7 @@ void KMFolderImap::slotListFolderResult(KIO::Job * job)
   // strip the flags from the list of uids, so it can be reused
   for (uid = (*it).items.begin(); uid != (*it).items.end(); ++uid)
     (*uid).truncate((*uid).find(","));
-  ImapAccountBase::jobData jd( TQString::null, (*it).parent );
+  ImapAccountBase::jobData jd( TQString(), (*it).parent );
   jd.total = (*it).items.count();
   if (jd.total == 0)
   {
@@ -1341,7 +1341,7 @@ void KMFolderImap::slotListFolderResult(KIO::Job * job)
     mMailCheckProgressItem->setCompletedItems( 0 );
     mMailCheckProgressItem->setTotalItems( jd.total );
     mMailCheckProgressItem->setProgress( 0 );
-    mMailCheckProgressItem->setStatus( i18n("Retrieving messages") );
+    mMailCheckProgressItem->setqStatus( i18n("Retrieving messages") );
   }
 
   TQStringList sets;
@@ -1421,7 +1421,7 @@ void KMFolderImap::slotListFolderEntries(KIO::Job * job,
 //X }
 
 //-----------------------------------------------------------------------------
-void KMFolderImap::flagsToStatus(KMMsgBase *msg, int flags, bool newMsg, int supportedFlags )
+void KMFolderImap::flagsTotqStatus(KMMsgBase *msg, int flags, bool newMsg, int supportedFlags )
 {
   if ( !msg ) return;
 
@@ -1440,45 +1440,45 @@ void KMFolderImap::flagsToStatus(KMMsgBase *msg, int flags, bool newMsg, int sup
   };
   static const int numFlags = sizeof imapFlagMap / sizeof *imapFlagMap;
 
-  const KMMsgStatus oldStatus = msg->status();
+  const KMMsgtqStatus oldtqStatus = msg->status();
   for ( int i = 0; i < numFlags; ++i ) {
     if ( ( (supportedFlags & imapFlagMap[i].imapFlag) == 0 && (supportedFlags & 64) == 0 )
          && !imapFlagMap[i].standardFlag ) {
       continue;
     }
-    if ( ((flags & imapFlagMap[i].imapFlag) > 0) != ((oldStatus & imapFlagMap[i].kmFlag) > 0) ) {
-      msg->toggleStatus( imapFlagMap[i].kmFlag );
+    if ( ((flags & imapFlagMap[i].imapFlag) > 0) != ((oldtqStatus & imapFlagMap[i].kmFlag) > 0) ) {
+      msg->toggletqStatus( imapFlagMap[i].kmFlag );
     }
   }
 
-  seenFlagToStatus( msg, flags, newMsg );
+  seenFlagTotqStatus( msg, flags, newMsg );
 }
 
-void KMFolderImap::seenFlagToStatus(KMMsgBase * msg, int flags, bool newMsg)
+void KMFolderImap::seenFlagTotqStatus(KMMsgBase * msg, int flags, bool newMsg)
 {
   if ( !msg ) return;
 
-  const KMMsgStatus oldStatus = msg->status();
-  if ( (flags & 1) && (oldStatus & KMMsgStatusOld) == 0 )
-    msg->setStatus( KMMsgStatusOld );
+  const KMMsgtqStatus oldtqStatus = msg->status();
+  if ( (flags & 1) && (oldtqStatus & KMMsgStatusOld) == 0 )
+    msg->setqStatus( KMMsgStatusOld );
 
   // In case the message does not have the seen flag set, override our local
   // notion that it is read. Otherwise the count of unread messages and the
   // number of messages which actually show up as read can go out of sync.
-  if ( msg->isOfUnknownStatus() || (!(flags&1) && !(oldStatus&(KMMsgStatusNew|KMMsgStatusUnread)) ) ) {
+  if ( msg->isOfUnknowntqStatus() || (!(flags&1) && !(oldtqStatus&(KMMsgStatusNew|KMMsgStatusUnread)) ) ) {
     if (newMsg) {
-      if ( (oldStatus & KMMsgStatusNew) == 0 )
-        msg->setStatus( KMMsgStatusNew );
+      if ( (oldtqStatus & KMMsgStatusNew) == 0 )
+        msg->setqStatus( KMMsgStatusNew );
     } else {
-      if ( (oldStatus & KMMsgStatusUnread) == 0 )
-        msg->setStatus( KMMsgStatusUnread );
+      if ( (oldtqStatus & KMMsgStatusUnread) == 0 )
+        msg->setqStatus( KMMsgStatusUnread );
     }
   }
 }
 
 
 //-----------------------------------------------------------------------------
-TQString KMFolderImap::statusToFlags(KMMsgStatus status, int supportedFlags)
+TQString KMFolderImap::statusToFlags(KMMsgtqStatus status, int supportedFlags)
 {
   TQString flags;
   if (status & KMMsgStatusDeleted)
@@ -1546,7 +1546,7 @@ void KMFolderImap::slotGetMessagesData(KIO::Job * job, const TQByteArray & data)
         kdDebug(5006) << "KMFolderImap::slotGetMessagesData - server has less messages (" <<
           exists << ") then folder (" << count() << "), so reload" << endl;
         open("getMessage");
-        reallyGetFolder( TQString::null );
+        reallyGetFolder( TQString() );
         (*it).cdata.remove(0, pos);
         return;
       } else if ( ok ) {
@@ -1596,14 +1596,14 @@ void KMFolderImap::slotGetMessagesData(KIO::Job * job, const TQByteArray & data)
         }
         // Transfer the status, if it is cached.
         if ( md ) {
-          msg->setStatus( md->status() );
+          msg->setqStatus( md->status() );
         } else if ( !account()->hasCapability("uidplus") ) {
           // see if we have cached the msgIdMD5 and get the status +
           // serial number from there
           TQString id = msg->msgIdMD5();
           if ( mMetaDataMap.find( id ) ) {
             md =  mMetaDataMap[id];
-            msg->setStatus( md->status() );
+            msg->setqStatus( md->status() );
             if ( md->serNum() != 0 && serNum == 0 ) {
               msg->setMsgSerNum( md->serNum() );
             }
@@ -1613,7 +1613,7 @@ void KMFolderImap::slotGetMessagesData(KIO::Job * job, const TQByteArray & data)
         }
         KMFolderMbox::addMsg(msg, 0);
         // Merge with the flags from the server.
-        flagsToStatus((KMMsgBase*)msg, flags, true, mUploadAllFlags ? 31 : mPermanentFlags);
+        flagsTotqStatus((KMMsgBase*)msg, flags, true, mUploadAllFlags ? 31 : mPermanentFlags);
         // set the correct size
         msg->setMsgSizeServer( msg->headerField("X-Length").toUInt() );
         msg->setUID(uid);
@@ -1667,7 +1667,7 @@ KMFolderImap::doCreateJob( KMMessage *msg, FolderJob::JobType jt,
   } else {
     // download complete message or part (attachment)
     if ( partSpecifier == "STRUCTURE" ) // hide from outside
-      partSpecifier = TQString::null;
+      partSpecifier = TQString();
 
     ImapJob *job = new ImapJob( msg, jt, kmfi, partSpecifier );
     job->setParentFolder( this );
@@ -1880,15 +1880,15 @@ void KMFolderImap::deleteMessage(const TQPtrList<KMMessage>& msgList)
 }
 
 //-----------------------------------------------------------------------------
-void KMFolderImap::setStatus(int idx, KMMsgStatus status, bool toggle)
+void KMFolderImap::setqStatus(int idx, KMMsgtqStatus status, bool toggle)
 {
   TQValueList<int> ids; ids.append(idx);
-  setStatus(ids, status, toggle);
+  setqStatus(ids, status, toggle);
 }
 
-void KMFolderImap::setStatus(TQValueList<int>& _ids, KMMsgStatus status, bool toggle)
+void KMFolderImap::setqStatus(TQValueList<int>& _ids, KMMsgtqStatus status, bool toggle)
 {
-  FolderStorage::setStatus(_ids, status, toggle);
+  FolderStorage::setqStatus(_ids, status, toggle);
   TQValueList<int> ids;
   if ( mUploadAllFlags ) {
     kdDebug(5006) << k_funcinfo << "Migrating all flags to the server" << endl;
@@ -1929,14 +1929,14 @@ void KMFolderImap::setStatus(TQValueList<int>& _ids, KMMsgStatus status, bool to
       TQStringList sets = KMFolderImap::makeSets( seenUids, true );
       for( TQStringList::Iterator it = sets.begin(); it != sets.end(); ++it ) {
         TQString imappath = imapPath() + ";UID=" + ( *it );
-        account()->setImapSeenStatus( folder(), imappath, true );
+        account()->setImapSeentqStatus( folder(), imappath, true );
       }
     }
     if ( !unseenUids.isEmpty() ) {
       TQStringList sets = KMFolderImap::makeSets( unseenUids, true );
       for( TQStringList::Iterator it = sets.begin(); it != sets.end(); ++it ) {
         TQString imappath = imapPath() + ";UID=" + ( *it );
-        account()->setImapSeenStatus( folder(), imappath, false );
+        account()->setImapSeentqStatus( folder(), imappath, false );
       }
     }
     return;
@@ -1960,7 +1960,7 @@ void KMFolderImap::setStatus(TQValueList<int>& _ids, KMMsgStatus status, bool to
      // Send off a status setting job for each set.
      for (  TQStringList::Iterator slit = sets.begin(); slit != sets.end(); ++slit ) {
        TQString imappath = imapPath() + ";UID=" + ( *slit );
-       account()->setImapStatus(folder(), imappath, flags);
+       account()->setImaptqStatus(folder(), imappath, flags);
      }
   }
   if ( mContentState == imapListingInProgress ) {
@@ -1970,7 +1970,7 @@ void KMFolderImap::setStatus(TQValueList<int>& _ids, KMMsgStatus status, bool to
     kdDebug(5006) << "Set status during folder listing, restarting listing." << endl;
     disconnect(this, TQT_SLOT(slotListFolderResult(KIO::Job *)));
     quiet( false );
-    reallyGetFolder( TQString::null );
+    reallyGetFolder( TQString() );
   }
 }
 
@@ -2185,7 +2185,7 @@ TQValueList<ulong> KMFolderImap::splitSets(const TQString uids)
   TQValueList<ulong> uidlist;
 
   // ex: 1205,1204,1203,1202,1236:1238
-  TQString buffer = TQString::null;
+  TQString buffer = TQString();
   int setstart = -1;
   // iterate over the uids
   for (uint i = 0; i < uids.length(); i++)
@@ -2284,7 +2284,7 @@ void KMFolderImap::setSubfolderState( imapState state )
   mSubfolderState = state;
   if ( state == imapNoInformation && folder()->child() )
   {
-    // pass through to children
+    // pass through to tqchildren
     KMFolderNode* node;
     TQPtrListIterator<KMFolderNode> it( *folder()->child() );
     for ( ; (node = it.current()); )
@@ -2345,18 +2345,18 @@ void KMFolderImap::search( const KMSearchPattern* pattern )
   if ( !pattern || pattern->isEmpty() )
   {
     // not much to do here
-    TQValueList<Q_UINT32> serNums;
+    TQValueList<TQ_UINT32> serNums;
     emit searchResult( folder(), serNums, pattern, true );
     return;
   }
   SearchJob* job = new SearchJob( this, account(), pattern );
-  connect( job, TQT_SIGNAL( searchDone( TQValueList<Q_UINT32>, const KMSearchPattern*, bool ) ),
-           this, TQT_SLOT( slotSearchDone( TQValueList<Q_UINT32>, const KMSearchPattern*, bool ) ) );
+  connect( job, TQT_SIGNAL( searchDone( TQValueList<TQ_UINT32>, const KMSearchPattern*, bool ) ),
+           this, TQT_SLOT( slotSearchDone( TQValueList<TQ_UINT32>, const KMSearchPattern*, bool ) ) );
   job->start();
 }
 
 //-----------------------------------------------------------------------------
-void KMFolderImap::slotSearchDone( TQValueList<Q_UINT32> serNums,
+void KMFolderImap::slotSearchDone( TQValueList<TQ_UINT32> serNums,
                                    const KMSearchPattern* pattern,
                                    bool complete )
 {
@@ -2364,7 +2364,7 @@ void KMFolderImap::slotSearchDone( TQValueList<Q_UINT32> serNums,
 }
 
 //-----------------------------------------------------------------------------
-void KMFolderImap::search( const KMSearchPattern* pattern, Q_UINT32 serNum )
+void KMFolderImap::search( const KMSearchPattern* pattern, TQ_UINT32 serNum )
 {
   if ( !pattern || pattern->isEmpty() )
   {
@@ -2373,13 +2373,13 @@ void KMFolderImap::search( const KMSearchPattern* pattern, Q_UINT32 serNum )
     return;
   }
   SearchJob* job = new SearchJob( this, account(), pattern, serNum );
-  connect( job, TQT_SIGNAL( searchDone( Q_UINT32, const KMSearchPattern*, bool ) ),
-           this, TQT_SLOT( slotSearchDone( Q_UINT32, const KMSearchPattern*, bool ) ) );
+  connect( job, TQT_SIGNAL( searchDone( TQ_UINT32, const KMSearchPattern*, bool ) ),
+           this, TQT_SLOT( slotSearchDone( TQ_UINT32, const KMSearchPattern*, bool ) ) );
   job->start();
 }
 
 //-----------------------------------------------------------------------------
-void KMFolderImap::slotSearchDone( Q_UINT32 serNum, const KMSearchPattern* pattern,
+void KMFolderImap::slotSearchDone( TQ_UINT32 serNum, const KMSearchPattern* pattern,
                                    bool matches )
 {
   emit searchDone( folder(), serNum, pattern, matches );
