@@ -61,16 +61,16 @@ using KPIM::ProgressItem;
 class KMMsgMetaData
 {
 public:
-  KMMsgMetaData(KMMsgStatus aStatus)
-    :mStatus(aStatus), mSerNum(0) {}
-  KMMsgMetaData(KMMsgStatus aStatus, Q_UINT32 aSerNum)
-    :mStatus(aStatus), mSerNum(aSerNum) {}
+  KMMsgMetaData(KMMsgtqStatus atqStatus)
+    :mtqStatus(atqStatus), mSerNum(0) {}
+  KMMsgMetaData(KMMsgtqStatus atqStatus, TQ_UINT32 aSerNum)
+    :mtqStatus(atqStatus), mSerNum(aSerNum) {}
   ~KMMsgMetaData() {};
-  KMMsgStatus status() const { return mStatus; }
-  Q_UINT32 serNum() const { return mSerNum; }
+  KMMsgtqStatus status() const { return mtqStatus; }
+  TQ_UINT32 serNum() const { return mSerNum; }
 private:
-  KMMsgStatus mStatus;
-  Q_UINT32 mSerNum;
+  KMMsgtqStatus mtqStatus;
+  TQ_UINT32 mSerNum;
 };
 
 
@@ -78,6 +78,7 @@ private:
 class KMFolderImap : public KMFolderMbox
 {
   Q_OBJECT
+  TQ_OBJECT
   friend class ::KMail::ImapJob;
 public:
 
@@ -171,7 +172,7 @@ public:
    * by default
    */
   void createFolder(const TQString &name,
-      const TQString& imapPath = TQString::null, bool askUser = true);
+      const TQString& imapPath = TQString(), bool askUser = true);
 
   /**
    * Delete a message
@@ -183,12 +184,12 @@ public:
    * Change the status of the message indicated by @p index
    * Overloaded function for the following one
    */
-  virtual void setStatus(int idx, KMMsgStatus status, bool toggle);
+  virtual void setqStatus(int idx, KMMsgtqStatus status, bool toggle);
 
   /**
    * Change the status of several messages indicated by @p ids
    */
-  virtual void setStatus(TQValueList<int>& _ids, KMMsgStatus status, bool toggle);
+  virtual void setqStatus(TQValueList<int>& _ids, KMMsgtqStatus status, bool toggle);
 
   /** generates sets of uids */
   static TQStringList makeSets( TQValueList<ulong>&, bool sort = true);
@@ -240,7 +241,7 @@ public:
   /**
    * Convert message status to a list of IMAP flags
    */
-  static TQString statusToFlags(KMMsgStatus status, int supportedFalgs);
+  static TQString statusToFlags(KMMsgtqStatus status, int supportedFalgs);
 
   /**
    * Return the filename of the folder (reimplemented from KFolder)
@@ -289,7 +290,7 @@ public:
   /**
    * Mark the folder as already removed from the server
    * If set to true the folder will only be deleted locally
-   * This will recursively be applied to all children
+   * This will recursively be applied to all tqchildren
    */
   void setAlreadyRemoved(bool removed);
 
@@ -314,7 +315,7 @@ public:
     * is signaled with searchDone()
     */
   virtual void search( const KMSearchPattern* );
-  virtual void search( const KMSearchPattern*, Q_UINT32 serNum );
+  virtual void search( const KMSearchPattern*, TQ_UINT32 serNum );
 
   /** Returns true if this folder can be moved */
   virtual bool isMoveable() const;
@@ -379,13 +380,13 @@ public slots:
    * Convert IMAP flags to a message status
    * @param newMsg specifies whether unseen messages are new or unread
    */
-  static void flagsToStatus(KMMsgBase *msg, int flags, bool newMsg = TRUE, int supportedFalgs = 31 );
+  static void flagsTotqStatus(KMMsgBase *msg, int flags, bool newMsg = TRUE, int supportedFalgs = 31 );
 
   /**
    * Convert IMAP seen flag to a message status.
    * @param newMsg specifies whether unseen messages are new or unread
    */
-  static void seenFlagToStatus( KMMsgBase *msg, int flags, bool newMsg = true );
+  static void seenFlagTotqStatus( KMMsgBase *msg, int flags, bool newMsg = true );
 
   /**
    * Connected to the result signal of the copy/move job
@@ -395,14 +396,14 @@ public slots:
   /**
    * Called from the SearchJob when the folder is done or messages where found
    */
-  void slotSearchDone( TQValueList<Q_UINT32> serNums,
+  void slotSearchDone( TQValueList<TQ_UINT32> serNums,
                        const KMSearchPattern* pattern,
                        bool complete );
 
   /**
    * Called from the SearchJob when the message was searched
    */
-  void slotSearchDone( Q_UINT32 serNum, const KMSearchPattern* pattern, bool matches );
+  void slotSearchDone( TQ_UINT32 serNum, const KMSearchPattern* pattern, bool matches );
 
   /**
    * Connected to ListJob::receivedFolders
@@ -456,7 +457,7 @@ protected slots:
   /**
    * Get the folder now (internal)
    */
-  void reallyGetFolder(const TQString &startUid = TQString::null);
+  void reallyGetFolder(const TQString &startUid = TQString());
 
   /**
    * For listing the contents of a folder
