@@ -87,11 +87,11 @@ int KMFolderMaildir::canAccess()
     KCursorSaver idle(KBusyPtr::idle());
     if ( nRetVal == ENOENT )
       KMessageBox::sorry(0, i18n("Error opening %1; this folder is missing.")
-                         .arg(sBadFolderName));
+                         .tqarg(sBadFolderName));
     else
       KMessageBox::sorry(0, i18n("Error opening %1; either this is not a valid "
                                  "maildir folder, or you do not have sufficient access permissions.")
-                         .arg(sBadFolderName));
+                         .tqarg(sBadFolderName));
     return nRetVal;
   }
 
@@ -117,12 +117,12 @@ int KMFolderMaildir::open(const char *)
 
   if (!folder()->path().isEmpty())
   {
-    if (KMFolderIndex::IndexOk != indexStatus()) // test if contents file has changed
+    if (KMFolderIndex::IndexOk != indextqStatus()) // test if contents file has changed
     {
       TQString str;
       mIndexStream = 0;
       str = i18n("Folder `%1' changed; recreating index.")
-		  .arg(name());
+		  .tqarg(name());
       emit statusMsg(str);
     } else {
       mIndexStream = fopen(TQFile::encodeName(indexLocation()), "r+"); // index file
@@ -279,7 +279,7 @@ int KMFolderMaildir::compact( unsigned int startIndex, int nbMessages, const TQS
   TQString subdirCur(location() + "/cur/");
 
   unsigned int stopIndex = nbMessages == -1 ? mMsgList.count() :
-                           QMIN( mMsgList.count(), startIndex + nbMessages );
+                           TQMIN( mMsgList.count(), startIndex + nbMessages );
   //kdDebug(5006) << "KMFolderMaildir: compacting from " << startIndex << " to " << stopIndex << endl;
   for(unsigned int idx = startIndex; idx < stopIndex; ++idx) {
     KMMsgInfo* mi = (KMMsgInfo*)mMsgList.at(idx);
@@ -310,7 +310,7 @@ int KMFolderMaildir::compact( unsigned int startIndex, int nbMessages, const TQS
     // we can't have any New messages at this point
     if (mi->isNew())
     {
-      mi->setStatus(KMMsgStatusUnread);
+      mi->setqStatus(KMMsgStatusUnread);
       setDirty( true );
     }
 #endif
@@ -385,7 +385,7 @@ if( fileD0.open( IO_WriteOnly ) ) {
     msgParent->getMsg( idx );
   }
 
-  aMsg->setStatusFields();
+  aMsg->seStatusFields();
   if (aMsg->headerField("Content-Type").isEmpty())  // This might be added by
     aMsg->removeHeaderField("Content-Type");        // the line above
 
@@ -506,7 +506,7 @@ if( fileD0.open( IO_WriteOnly ) ) {
       error |= appendToFolderIdsFile( idx );
 
     if (error) {
-      kdDebug(5006) << "Error: Could not add message to folder (No space left on device?)" << endl;
+      kdDebug(5006) << "Error: Could not add message to folder (No space left on tqdevice?)" << endl;
       if (ftell(mIndexStream) > revert) {
 	kdDebug(5006) << "Undoing changes" << endl;
 	truncate( TQFile::encodeName(indexLocation()), revert );
@@ -519,7 +519,7 @@ if( fileD0.open( IO_WriteOnly ) ) {
       if (busy) kmkernel->kbp()->idle();
       KMessageBox::sorry(0,
         i18n("Unable to add message to folder.\n"
-	     "(No space left on device or insufficient quota?)\n"
+	     "(No space left on tqdevice or insufficient quota?)\n"
 	     "Free space and sufficient quota are required to continue safely."));
       if (busy) kmkernel->kbp()->busy();
       */
@@ -583,7 +583,7 @@ DwString KMFolderMaildir::getDwString(int idx)
 }
 
 
-void KMFolderMaildir::readFileHeaderIntern(const TQString& dir, const TQString& file, KMMsgStatus status)
+void KMFolderMaildir::readFileHeaderIntern(const TQString& dir, const TQString& file, KMMsgtqStatus status)
 {
   // we keep our current directory to restore it later
   char path_buffer[PATH_MAX];
@@ -605,7 +605,7 @@ void KMFolderMaildir::readFileHeaderIntern(const TQString& dir, const TQString&
   // open the file and get a pointer to it
   TQFile f(file);
   if ( f.open( IO_ReadOnly ) == false ) {
-    kdWarning(5006) << "The file '" << TQFile::encodeName(dir) << "/" << file
+    kdWarning(5006) << "The file '" << TQString(TQFile::encodeName(dir)) << "/" << file
                     << "' could not be opened for reading the message. "
                        "Please check ownership and permissions."
                     << endl;
@@ -729,7 +729,7 @@ void KMFolderMaildir::readFileHeaderIntern(const TQString& dir, const TQString&
 
       dateStr = dateStr.stripWhiteSpace();
       if (!dateStr.isEmpty())
-        mi->setDate(dateStr);
+        mi->setDate(dateStr.data());
       if ( !uidStr.isEmpty() )
          mi->setUID( uidStr.toULong() );
       mi->setDirty(false);
@@ -864,8 +864,8 @@ int KMFolderMaildir::createIndexFromContents()
   curDir.setFilter(TQDir::Files);
 
   // then, we look for all the 'cur' files
-  const QFileInfoList *list = curDir.entryInfoList();
-  QFileInfoListIterator it(*list);
+  const TQFileInfoList *list = curDir.entryInfoList();
+  TQFileInfoListIterator it(*list);
   TQFileInfo *fi;
 
   while ((fi = it.current()))
@@ -903,7 +903,7 @@ int KMFolderMaildir::createIndexFromContents()
   return 0;
 }
 
-KMFolderIndex::IndexStatus KMFolderMaildir::indexStatus()
+KMFolderIndex::IndextqStatus KMFolderMaildir::indextqStatus()
 {
   if ( !mCompactable )
     return KMFolderIndex::IndexCorrupt;
@@ -989,8 +989,8 @@ static bool removeDirAndContentsRecursively( const TQString & path )
   d.setPath( path );
   d.setFilter( TQDir::Files | TQDir::Dirs | TQDir::Hidden | TQDir::NoSymLinks );
 
-  const QFileInfoList *list = d.entryInfoList();
-  QFileInfoListIterator it( *list );
+  const TQFileInfoList *list = d.entryInfoList();
+  TQFileInfoListIterator it( *list );
   TQFileInfo *fi;
 
   while ( (fi = it.current()) != 0 ) {
@@ -1033,7 +1033,7 @@ static KStaticDeleter<TQRegExp> suffix_regex_sd;
 //-----------------------------------------------------------------------------
 // static
 TQString KMFolderMaildir::constructValidFileName( const TQString & filename,
-                                                 KMMsgStatus status )
+                                                 KMMsgtqStatus status )
 {
   TQString aFileName( filename );
 
@@ -1075,7 +1075,7 @@ TQString KMFolderMaildir::moveInternal(const TQString& oldLoc, const TQString& n
 }
 
 //-----------------------------------------------------------------------------
-TQString KMFolderMaildir::moveInternal(const TQString& oldLoc, const TQString& newLoc, TQString& aFileName, KMMsgStatus status)
+TQString KMFolderMaildir::moveInternal(const TQString& oldLoc, const TQString& newLoc, TQString& aFileName, KMMsgtqStatus status)
 {
   TQString dest(newLoc);
   // make sure that our destination filename doesn't already exist
@@ -1090,23 +1090,23 @@ TQString KMFolderMaildir::moveInternal(const TQString& oldLoc, const TQString& n
 
   TQDir d;
   if (d.rename(oldLoc, dest) == false)
-    return TQString::null;
+    return TQString();
   else
     return dest;
 }
 
 //-----------------------------------------------------------------------------
-void KMFolderMaildir::msgStatusChanged(const KMMsgStatus oldStatus,
-  const KMMsgStatus newStatus, int idx)
+void KMFolderMaildir::msgStatusChanged(const KMMsgtqStatus oldtqStatus,
+  const KMMsgtqStatus newtqStatus, int idx)
 {
   // if the status of any message changes, then we need to compact
   needsCompact = true;
 
-  KMFolderIndex::msgStatusChanged(oldStatus, newStatus, idx);
+  KMFolderIndex::msgStatusChanged(oldtqStatus, newtqStatus, idx);
 }
 
 /*virtual*/
-Q_INT64 KMFolderMaildir::doFolderSize() const
+TQ_INT64 KMFolderMaildir::doFolderSize() const
 {
   if ( mCurrentlyCheckingFolderSize )
   {
@@ -1123,7 +1123,7 @@ Q_INT64 KMFolderMaildir::doFolderSize() const
   item = new KFileItem( S_IFDIR, -1, location() + "/tmp" );
   list.append( item );
   s_DirSizeJobQueue.append(
-    qMakePair( TQGuardedPtr<const KMFolderMaildir>( this ), list ) );
+    tqMakePair( TQGuardedPtr<const KMFolderMaildir>( this ), list ) );
 
   // if there's only one entry in the queue then we can start
   // a dirSizeJob right away
