@@ -109,7 +109,7 @@ int KMFolderMbox::open(const char *owner)
   if (!mStream)
   {
     KNotifyClient::event( 0, "warning",
-    i18n("Cannot open file \"%1\":\n%2").arg(location()).arg(strerror(errno)));
+    i18n("Cannot open file \"%1\":\n%2").tqarg(location()).tqarg(strerror(errno)));
     kdDebug(5006) << "Cannot open folder `" << location() << "': " << strerror(errno) << endl;
     mOpenCount = 0;
     return errno;
@@ -119,7 +119,7 @@ int KMFolderMbox::open(const char *owner)
 
   if (!folder()->path().isEmpty())
   {
-     KMFolderIndex::IndexStatus index_status = indexStatus();
+     KMFolderIndex::IndextqStatus index_status = indextqStatus();
      // test if index file exists and is up-to-date
      if (KMFolderIndex::IndexOk != index_status)
      {
@@ -137,8 +137,8 @@ int KMFolderMbox::open(const char *owner)
                            "of KMail</a> for "
                            "information about how to prevent this "
                            "problem from happening again.</p></qt>")
-                      .arg("help:/kmail/faq.html#faq-index-regeneration")
-                      .arg(name());
+                      .tqarg("help:/kmail/faq.html#faq-index-regeneration")
+                      .tqarg(name());
         // When KMail is starting up we have to show a non-blocking message
         // box so that the initialization can continue. We don't show a
         // queued message box when KMail isn't starting up because queued
@@ -164,7 +164,7 @@ int KMFolderMbox::open(const char *owner)
        TQString str;
        mIndexStream = 0;
        str = i18n("Folder `%1' changed. Recreating index.")
-             .arg(name());
+             .tqarg(name());
        emit statusMsg(str);
      } else {
        mIndexStream = fopen(TQFile::encodeName(indexLocation()), "r+"); // index file
@@ -262,7 +262,7 @@ void KMFolderMbox::reallyDoClose(const char* owner)
   Q_UNUSED( owner );
   if (mAutoCreateIndex)
   {
-      if (KMFolderIndex::IndexOk != indexStatus()) {
+      if (KMFolderIndex::IndexOk != indextqStatus()) {
           kdDebug(5006) << "Critical error: " << location() <<
               " has been modified by an external application while KMail was running." << endl;
           //      exit(1); backed out due to broken nfs
@@ -297,7 +297,7 @@ void KMFolderMbox::sync()
   if (mOpenCount > 0)
     if (!mStream || fsync(fileno(mStream)) ||
         !mIndexStream || fsync(fileno(mIndexStream))) {
-    kmkernel->emergencyExit( i18n("Could not sync index file <b>%1</b>: %2").arg( indexLocation() ).arg(errno ? TQString::fromLocal8Bit(strerror(errno)) : i18n("Internal error. Please copy down the details and report a bug.")));
+    kmkernel->emergencyExit( i18n("Could not sync index file <b>%1</b>: %2").tqarg( indexLocation() ).tqarg(errno ? TQString::fromLocal8Bit(strerror(errno)) : i18n("Internal error. Please copy down the details and report a bug.")));
     }
 }
 
@@ -521,7 +521,7 @@ int KMFolderMbox::unlock()
 
 
 //-----------------------------------------------------------------------------
-KMFolderIndex::IndexStatus KMFolderMbox::indexStatus()
+KMFolderIndex::IndextqStatus KMFolderMbox::indextqStatus()
 {
   if ( !mCompactable )
     return KMFolderIndex::IndexCorrupt;
@@ -555,8 +555,8 @@ int KMFolderMbox::createIndexFromContents()
   KMMsgInfo* mi;
   TQString msgStr;
   TQRegExp regexp(MSG_SEPERATOR_REGEX);
-  int i, num, numStatus;
-  short needStatus;
+  int i, num, numtqStatus;
+  short needtqStatus;
 
   assert(mStream != 0);
   rewind(mStream);
@@ -564,7 +564,7 @@ int KMFolderMbox::createIndexFromContents()
   mMsgList.clear();
 
   num     = -1;
-  numStatus= 11;
+  numtqStatus= 11;
   off_t offs = 0;
   size_t size = 0;
   dateStr = "";
@@ -578,7 +578,7 @@ int KMFolderMbox::createIndexFromContents()
   replyToAuxIdStr = "";
   referencesStr = "";
   msgIdStr = "";
-  needStatus = 3;
+  needtqStatus = 3;
   size_t sizeServer = 0;
   ulong uid = 0;
 
@@ -597,11 +597,11 @@ int KMFolderMbox::createIndexFromContents()
 
       if (num >= 0)
       {
-        if (numStatus <= 0)
+        if (numtqStatus <= 0)
         {
           msgStr = i18n("Creating index file: one message done", "Creating index file: %n messages done", num);
           emit statusMsg(msgStr);
-          numStatus = 10;
+          numtqStatus = 10;
         }
 
         if (size > 0)
@@ -682,14 +682,14 @@ int KMFolderMbox::createIndexFromContents()
                     replyToIdStr, replyToAuxIdStr, msgIdStr,
                     KMMsgEncryptionStateUnknown, KMMsgSignatureStateUnknown,
                     KMMsgMDNStateUnknown, charset, offs, size, sizeServer, uid );
-          mi->setStatus(status, xstatus);
-          mi->setDate( dateStr.stripWhiteSpace() );
+          mi->setqStatus(status, xstatus);
+          mi->setDate( dateStr.stripWhiteSpace().data() );
           mi->setDirty(false);
           mMsgList.append(mi, mExportsSernums );
 
           *status = '\0';
           *xstatus = '\0';
-          needStatus = 3;
+          needtqStatus = 3;
           xmarkStr = "";
           replyToIdStr = "";
           replyToAuxIdStr = "";
@@ -701,12 +701,12 @@ int KMFolderMbox::createIndexFromContents()
           sizeServer = 0;
           uid = 0;
         }
-        else num--,numStatus++;
+        else num--,numtqStatus++;
       }
 
       offs = ftell(mStream);
       num++;
-      numStatus--;
+      numtqStatus--;
       inHeader = true;
       continue;
     }
@@ -727,19 +727,19 @@ int KMFolderMbox::createIndexFromContents()
     /* -sanders Make all messages read when auto-recreating index */
     /* Reverted, as it breaks reading the sent mail status, for example.
        -till */
-    if ((needStatus & 1) && strncasecmp(line, "Status:", 7) == 0)
+    if ((needtqStatus & 1) && strncasecmp(line, "Status:", 7) == 0)
     {
       for(i=0; i<4 && line[i+8] > ' '; i++)
         status[i] = line[i+8];
       status[i] = '\0';
-      needStatus &= ~1;
+      needtqStatus &= ~1;
     }
-    else if ((needStatus & 2) && strncasecmp(line, "X-Status:", 9)==0)
+    else if ((needtqStatus & 2) && strncasecmp(line, "X-Status:", 9)==0)
     {
       for(i=0; i<4 && line[i+10] > ' '; i++)
         xstatus[i] = line[i+10];
       xstatus[i] = '\0';
-      needStatus &= ~2;
+      needtqStatus &= ~2;
     }
     else if (strncasecmp(line,"X-KMail-Mark:",13)==0)
         xmarkStr = TQCString(line+13);
@@ -852,7 +852,7 @@ static size_t unescapeFrom( char* str, size_t strLen ) {
       *d++ = *s++;  // == '>'
       while ( s < e && *s == '>' )
         *d++ = *s++;
-      if ( qstrncmp( s, "From ", STRDIM("From ") ) == 0 )
+      if ( tqstrncmp( s, "From ", STRDIM("From ") ) == 0 )
         --d;
     }
     *d++ = *s++; // yes, s might be e here, but e is not the end :-)
@@ -887,7 +887,7 @@ TQByteArray KMFolderMbox::escapeFrom( const DwString & str ) {
     case '>':
       break;
     case 'F':
-      if ( onlyAnglesAfterLF && qstrncmp( s+1, "rom ", STRDIM("rom ") ) == 0 )
+      if ( onlyAnglesAfterLF && tqstrncmp( s+1, "rom ", STRDIM("rom ") ) == 0 )
         *d++ = '>';
       // fall through
     default:
@@ -979,7 +979,7 @@ if( fileD0.open( IO_WriteOnly ) ) {
     fileD0.close();  // If data is 0 we just create a zero length file.
 }
 */
-    aMsg->setStatusFields();
+    aMsg->seStatusFields();
 /*
 TQFile fileD1( "testdat_xx-kmfoldermbox-1" );
 if( fileD1.open( IO_WriteOnly ) ) {
@@ -1047,7 +1047,7 @@ if( fileD1.open( IO_WriteOnly ) ) {
     if (busy) kmkernel->kbp()->idle();
     KMessageBox::sorry(0,
           i18n("Unable to add message to folder.\n"
-               "(No space left on device or insufficient quota?)\n"
+               "(No space left on tqdevice or insufficient quota?)\n"
                "Free space and sufficient quota are required to continue safely."));
     if (busy) kmkernel->kbp()->busy();
     kmkernel->kbp()->idle();
@@ -1118,7 +1118,7 @@ if( fileD1.open( IO_WriteOnly ) ) {
       error |= appendToFolderIdsFile( idx );
 
     if (error) {
-      kdWarning(5006) << "Error: Could not add message to folder (No space left on device?)" << endl;
+      kdWarning(5006) << "Error: Could not add message to folder (No space left on tqdevice?)" << endl;
       if (ftell(mIndexStream) > revert) {
         kdWarning(5006) << "Undoing changes" << endl;
         truncate( TQFile::encodeName(indexLocation()), revert );
@@ -1126,14 +1126,14 @@ if( fileD1.open( IO_WriteOnly ) ) {
       if ( errno )
         kmkernel->emergencyExit( i18n("Could not add message to folder:") + TQString::fromLocal8Bit(strerror(errno)));
       else
-        kmkernel->emergencyExit( i18n("Could not add message to folder (No space left on device?)") );
+        kmkernel->emergencyExit( i18n("Could not add message to folder (No space left on tqdevice?)") );
 
       /* This code may not be 100% reliable
       bool busy = kmkernel->kbp()->isBusy();
       if (busy) kmkernel->kbp()->idle();
       KMessageBox::sorry(0,
         i18n("Unable to add message to folder.\n"
-             "(No space left on device or insufficient quota?)\n"
+             "(No space left on tqdevice or insufficient quota?)\n"
              "Free space and sufficient quota are required to continue safely."));
       if (busy) kmkernel->kbp()->busy();
       */
@@ -1155,7 +1155,7 @@ int KMFolderMbox::compact( unsigned int startIndex, int nbMessages, FILE* tmpfil
   int rc = 0;
   TQCString mtext;
   unsigned int stopIndex = nbMessages == -1 ? mMsgList.count() :
-                           QMIN( mMsgList.count(), startIndex + nbMessages );
+                           TQMIN( mMsgList.count(), startIndex + nbMessages );
   //kdDebug(5006) << "KMFolderMbox: compacting from " << startIndex << " to " << stopIndex << endl;
   for(unsigned int idx = startIndex; idx < stopIndex; ++idx) {
     KMMsgInfo* mi = (KMMsgInfo*)mMsgList.at(idx);
@@ -1237,10 +1237,10 @@ int KMFolderMbox::compact( bool silent )
   // Note that job autodeletes itself.
 
   // If this is the current folder, the changed signal will ultimately call
-  // KMHeaders::setFolderInfoStatus which will override the message, so save/restore it
+  // KMHeaders::setFolderInfotqStatus which will override the message, so save/restore it
   TQString statusMsg = BroadcastStatus::instance()->statusMsg();
   emit changed();
-  BroadcastStatus::instance()->setStatusMsg( statusMsg );
+  BroadcastStatus::instance()->seStatusMsg( statusMsg );
   return rc;
 }
 
@@ -1276,10 +1276,10 @@ int KMFolderMbox::expungeContents()
 
 //-----------------------------------------------------------------------------
 /*virtual*/
-Q_INT64 KMFolderMbox::doFolderSize() const
+TQ_INT64 KMFolderMbox::doFolderSize() const
 {
   TQFileInfo info( location() );
-  return (Q_INT64)(info.size());
+  return (TQ_INT64)(info.size());
 }
 
 //-----------------------------------------------------------------------------
