@@ -267,14 +267,14 @@ void KMFolderTreeItem::slotIconsChanged()
   else
     setPixmap( 0, normalIcon( iconSize() ) );
   emit iconChanged( this );
-  repaint();
+  tqrepaint();
 }
 
 void KMFolderTreeItem::slotNameChanged()
 {
   setText( 0, mFolder->label() );
   emit nameChanged( this );
-  repaint();
+  tqrepaint();
 }
 
 void KMFolderTreeItem::slotNoContentChanged()
@@ -495,7 +495,7 @@ void KMFolderTree::readConfig (void)
       setFont(KGlobalSettings::generalFont());
   }
 
-  // restore the layout
+  // restore the tqlayout
   restoreLayout(conf, "Geometry");
 }
 
@@ -510,7 +510,7 @@ void KMFolderTree::writeConfig()
       writeIsListViewItemOpen(fti);
   }
 
-  // save the current layout
+  // save the current tqlayout
   saveLayout(KMKernel::config(), "Geometry");
 }
 
@@ -556,7 +556,7 @@ void KMFolderTree::reload(bool openFolders)
 
   int top = contentsY();
   mLastItem = 0;
-  // invalidate selected drop item
+  // tqinvalidate selected drop item
   oldSelected = 0;
   // remember last
   KMFolder* last = currentFolder();
@@ -627,9 +627,9 @@ void KMFolderTree::reload(bool openFolders)
              this, TQT_SLOT(slotSyncStateChanged()) );
 
     // we want to be noticed of changes to update the unread/total columns
-    disconnect(fti->folder(), TQT_SIGNAL(msgAdded(KMFolder*,Q_UINT32)),
+    disconnect(fti->folder(), TQT_SIGNAL(msgAdded(KMFolder*,TQ_UINT32)),
         this,TQT_SLOT(slotUpdateCountsDelayed(KMFolder*)));
-    connect(fti->folder(), TQT_SIGNAL(msgAdded(KMFolder*,Q_UINT32)),
+    connect(fti->folder(), TQT_SIGNAL(msgAdded(KMFolder*,TQ_UINT32)),
         this,TQT_SLOT(slotUpdateCountsDelayed(KMFolder*)));
     //}
 
@@ -737,13 +737,13 @@ void KMFolderTree::addDirectory( KMFolderDir *fdir, KMFolderTreeItem* parent )
     } else {
       // hide local inbox if unused
       if ( kmkernel->inboxFolder() == folder && hideLocalInbox() ) {
-        connect( kmkernel->inboxFolder(), TQT_SIGNAL(msgAdded(KMFolder*,Q_UINT32)), TQT_SLOT(slotUnhideLocalInbox()) );
+        connect( kmkernel->inboxFolder(), TQT_SIGNAL(msgAdded(KMFolder*,TQ_UINT32)), TQT_SLOT(slotUnhideLocalInbox()) );
         continue;
       }
 
       // create new child
       fti = new KMFolderTreeItem( parent, folder->label(), folder );
-      // set folders explicitely to exandable when they have children
+      // set folders explicitely to exandable when they have tqchildren
       // this way we can do a listing for IMAP folders when the user expands them
       // even when the child folders are not created yet
       if ( folder->storage()->hasChildren() == FolderStorage::HasChildren ) {
@@ -800,7 +800,7 @@ void KMFolderTree::delayedUpdate()
         continue;
 
       if ( fti->needsRepaint() ) {
-        fti->repaint();
+        fti->tqrepaint();
         fti->setNeedsRepaint( false );
       }
     }
@@ -918,7 +918,7 @@ bool KMFolderTree::checkUnreadFolder (KMFolderTreeItem* fti, bool confirm)
       //  parameter (kept in the config file for kmail)
       if ( KMessageBox::questionYesNo( this,
             i18n( "<qt>Go to the next unread message in folder <b>%1</b>?</qt>" )
-            .arg( fti->folder()->label() ),
+            .tqarg( fti->folder()->label() ),
             i18n( "Go to Next Unread Message" ),
             i18n("Go To"), i18n("Do Not Go To"), // defaults
             "AskNextFolder",
@@ -1115,13 +1115,13 @@ void KMFolderTree::slotContextMenuRequested( TQListViewItem *lvi,
 
     // copy folder
     TQPopupMenu *copyMenu = new TQPopupMenu( folderMenu );
-    folderToPopupMenu( CopyFolder, this, &mMenuToFolder, copyMenu );
+    folderToPopupMenu( CopyFolder, TQT_TQOBJECT(this), &mMenuToFolder, copyMenu );
     folderMenu->insertItem( i18n("&Copy Folder To"), copyMenu );
 
     if ( fti->folder()->isMoveable() && fti->folder()->canDeleteMessages() )
     {
       TQPopupMenu *moveMenu = new TQPopupMenu( folderMenu );
-      folderToPopupMenu( MoveFolder, this, &mMenuToFolder, moveMenu );
+      folderToPopupMenu( MoveFolder, TQT_TQOBJECT(this), &mMenuToFolder, moveMenu );
       folderMenu->insertItem( i18n("&Move Folder To"), moveMenu );
     }
 
@@ -1280,7 +1280,7 @@ void KMFolderTree::addChildFolder( KMFolder *folder, TQWidget * parent )
       const TQString message = i18n( "<qt>Cannot create folder under <b>%1</b> because of insufficient "
                                     "permissions on the server. If you think you should be able to create "
                                     "subfolders here, ask your administrator to grant you rights to do so."
-                                    "</qt> " ).arg(aFolder->label());
+                                    "</qt> " ).tqarg(aFolder->label());
       KMessageBox::error( this, message );
       return;
     }
@@ -1419,7 +1419,7 @@ void KMFolderTree::openFolder()
     autoopen_timer.stop();
     if ( dropItem && !dropItem->isOpen() ) {
         dropItem->setOpen( true );
-        dropItem->repaint();
+        dropItem->tqrepaint();
     }
 }
 
@@ -1467,7 +1467,7 @@ void KMFolderTree::contentsDragMoveEvent( TQDragMoveEvent *e )
         }
 
         if ( dragAccepted ) {
-            e->accept( itemRect(i) );
+            e->accept( tqitemRect(i) );
 
             switch ( e->action() ) {
                 case TQDropEvent::Copy:
@@ -1753,10 +1753,10 @@ void KMFolderTree::slotToggleSizeColumn()
 bool KMFolderTree::eventFilter( TQObject *o, TQEvent *e )
 {
   if ( e->type() == TQEvent::MouseButtonPress &&
-      static_cast<TQMouseEvent*>(e)->button() == RightButton &&
-      o->isA("TQHeader") )
+      TQT_TQMOUSEEVENT(e)->button() == Qt::RightButton &&
+      o->isA(TQHEADER_OBJECT_NAME_STRING) )
   {
-    mPopup->popup( static_cast<TQMouseEvent*>(e)->globalPos() );
+    mPopup->popup( TQT_TQMOUSEEVENT(e)->globalPos() );
     return true;
   }
   return KFolderTree::eventFilter(o, e);
@@ -1987,7 +1987,7 @@ void KMFolderTree::moveOrCopyFolder( TQValueList<TQGuardedPtr<KMFolder> > source
 
     if ( parent->hasNamedFolder( sourceFolderName ) || sourceFolderNames.contains( sourceFolderName ) ) {
       KMessageBox::error( this, i18n("<qt>Cannot move or copy folder <b>%1</b> here because a folder with the same name already exists.</qt>")
-          .arg( sourceFolderName ) );
+          .tqarg( sourceFolderName ) );
       setDragEnabled( true );
       return;
     }
@@ -1998,7 +1998,7 @@ void KMFolderTree::moveOrCopyFolder( TQValueList<TQGuardedPtr<KMFolder> > source
     while ( f ) {
       if ( f->moveInProgress() ) {
         KMessageBox::error( this, i18n("<qt>Cannot move or copy folder <b>%1</b> because it is not completely copied itself.</qt>")
-            .arg( sourceFolderName ) );
+            .tqarg( sourceFolderName ) );
         setDragEnabled( true );
         return;
       }
@@ -2176,7 +2176,7 @@ void KMFolderTree::slotAddToFavorites()
 
 void KMFolderTree::slotUnhideLocalInbox()
 {
-  disconnect( kmkernel->inboxFolder(), TQT_SIGNAL(msgAdded(KMFolder*,Q_UINT32)),
+  disconnect( kmkernel->inboxFolder(), TQT_SIGNAL(msgAdded(KMFolder*,TQ_UINT32)),
               this, TQT_SLOT(slotUnhideLocalInbox()) );
   reload();
 }
