@@ -150,21 +150,21 @@ public:
   }
 
   /** Mark the message as deleted */
-  void del() { setStatus(KMMsgStatusDeleted); }
+  void del() { setqStatus(KMMsgStatusDeleted); }
 
   /** Undelete the message. Same as touch */
-  void undel() { setStatus(KMMsgStatusOld); }
+  void undel() { setqStatus(KMMsgStatusOld); }
 
   /** Touch the message - mark it as read */
-  void touch() { setStatus(KMMsgStatusOld); }
+  void touch() { setqStatus(KMMsgStatusOld); }
 
   /** Create a new message that is a reply to this message, filling all
       required header fields with the proper values. The returned message
       is not stored in any folder. Marks this message as replied. */
   KMMessage* createReply( KMail::ReplyStrategy replyStrategy = KMail::ReplySmart,
-                          TQString selection=TQString::null, bool noQuote = false,
+                          TQString selection=TQString(), bool noQuote = false,
                           bool allowDecryption = true,
-                          const TQString &tmpl = TQString::null );
+                          const TQString &tmpl = TQString() );
 
   /** Create a new message that is a redirect to this message, filling all
     required header fields with the proper values. The returned message
@@ -181,7 +181,7 @@ public:
   /** Create a new message that is a forward of this message, filling all
     required header fields with the proper values. The returned message
     is not stored in any folder. Marks this message as forwarded. */
-  KMMessage* createForward( const TQString &tmpl = TQString::null );
+  KMMessage* createForward( const TQString &tmpl = TQString() );
 
   /** Create a new message that is a delivery receipt of this message,
       filling required header fileds with the proper values. The
@@ -210,9 +210,9 @@ public:
   void sanitizeHeaders( const TQStringList& whiteList = TQStringList() );
 
   /** Parse the string and create this message from it. */
-  void fromDwString(const DwString& str, bool setStatus=false);
-  void fromString(const TQCString& str, bool setStatus=false);
-  void fromByteArray(const TQByteArray & ba, bool setStatus=false);
+  void fromDwString(const DwString& str, bool setqStatus=false);
+  void fromString(const TQCString& str, bool setqStatus=false);
+  void fromByteArray(const TQByteArray & ba, bool setqStatus=false);
 
   /** Return the entire message contents in the DwString. This function
       is *fast* even for large message since it does *not* involve a
@@ -243,7 +243,7 @@ public:
   TQCString headerAsSendableString() const;
 
   /**
-   * Remove all private header fields: *Status: and X-KMail-*
+   * Remove all private header fields: *tqStatus: and X-KMail-*
    **/
   void removePrivateHeaderFields();
 
@@ -545,7 +545,7 @@ public:
    */
   void setBodyFromUnicode( const TQString & str, DwEntity *entity = 0 );
 
-  /** Returns the body part decoded to unicode.
+  /** Returns the body part decoded to tqunicode.
    **/
   TQString bodyToUnicode(const TQTextCodec* codec=0) const;
 
@@ -669,7 +669,7 @@ public:
 
   /** Set "Status" and "X-Status" fields of the message from the
    * internal message status. */
-  void setStatusFields();
+  void seStatusFields();
 
   /** Generates the Message-Id. It uses either the Message-Id suffix
    * defined by the user or the given email address as suffix. The address
@@ -679,7 +679,7 @@ public:
 
   /** Convert '<' into "&lt;" resp. '>' into "&gt;" in order to
     * prevent their interpretation by KHTML.
-    * Does *not* use the Qt replace function but runs a very fast C code
+    * Does *not* use the TQt replace function but runs a very fast C code
     * the same way as lf2crlf() does.
    */
   static TQCString html2source( const TQCString & src );
@@ -717,7 +717,7 @@ public:
    * only the name part and not the given emailAddr.
    */
   static TQString emailAddrAsAnchor(const TQString& emailAddr,
-          bool stripped=true, const TQString& cssStyle = TQString::null, bool link = true);
+          bool stripped=true, const TQString& cssStyle = TQString(), bool link = true);
 
   /** Strips an address from an address list. This is for example used
       when replying to all.
@@ -746,7 +746,7 @@ public:
   static TQString guessEmailAddressFromLoginName( const TQString& userName );
 
   /**
-   *  Given argument msg add quoting characters and relayout for max width maxLength
+   *  Given argument msg add quoting characters and retqlayout for max width maxLength
    *  @param msg the string which it to be quoted
    *  @param maxLineLength reformat text to be this amount of columns at maximum, adding
    *    linefeeds at word boundaries to make it fit.
@@ -822,11 +822,11 @@ public:
   ulong UID() const;
   void setUID(ulong uid);
 
-  /** Status of the message. */
-  KMMsgStatus status() const { return mStatus; }
+  /** tqStatus of the message. */
+  KMMsgtqStatus status() const { return mtqStatus; }
   /** Set status and mark dirty. */
-  void setStatus(const KMMsgStatus status, int idx = -1);
-  void setStatus(const char* s1, const char* s2=0) { KMMsgBase::setStatus(s1, s2); }
+  void setqStatus(const KMMsgtqStatus status, int idx = -1);
+  void setqStatus(const char* s1, const char* s2=0) { KMMsgBase::setqStatus(s1, s2); }
 
   /** Set encryption status of the message. */
   void setEncryptionState(const KMMsgEncryptionState, int idx = -1);
@@ -844,11 +844,11 @@ public:
 
   KMMsgMDNSentState mdnSentState() const { return mMDNSentState; }
 
-  /** Links this message to @p aMsg, setting link type to @p aStatus. */
-  void link(const KMMessage *aMsg, KMMsgStatus aStatus);
+  /** Links this message to @p aMsg, setting link type to @p atqStatus. */
+  void link(const KMMessage *aMsg, KMMsgtqStatus atqStatus);
   /** Returns the information for the Nth link into @p retMsg
-   * and @p retStatus. */
-  void getLink(int n, ulong *retMsgSerNum, KMMsgStatus *retStatus) const;
+   * and @p retqStatus. */
+  void getLink(int n, ulong *retMsgSerNum, KMMsgtqStatus *retqStatus) const;
 
   /** Convert wildcards into normal string */
   TQString formatString(const TQString&) const;
@@ -900,7 +900,7 @@ public:
     get converted to plain text when allowDecryption is true. */
   TQString asQuotedString( const TQString & headerStr,
           const TQString & indentStr,
-          const TQString & selection=TQString::null,
+          const TQString & selection=TQString(),
           bool aStripSignature=true,
           bool allowDecryption=true) const;
 
