@@ -72,7 +72,7 @@ using KMail::MessageProperty;
 //-----------------------------------------------------------------------------
 KMMsgBase::KMMsgBase(KMFolder* aParentFolder)
   : mParent( aParentFolder ), mIndexOffset( 0 ),
-    mIndexLength( 0 ), mDirty( false ), mEnableUndo( false ), mStatus( KMMsgStatusUnknown )
+    mIndexLength( 0 ), mDirty( false ), mEnableUndo( false ), mtqStatus( KMMsgStatusUnknown )
 {
 }
 
@@ -121,145 +121,145 @@ bool KMMsgBase::isMessage(void) const
   return false;
 }
 //-----------------------------------------------------------------------------
-void KMMsgBase::toggleStatus(const KMMsgStatus aStatus, int idx)
+void KMMsgBase::toggletqStatus(const KMMsgtqStatus atqStatus, int idx)
 {
   mDirty = true;
-  KMMsgStatus oldStatus = status();
-  if ( status() & aStatus ) {
-    mStatus &= ~aStatus;
+  KMMsgtqStatus oldtqStatus = status();
+  if ( status() & atqStatus ) {
+    mtqStatus &= ~atqStatus;
   } else {
-    mStatus |= aStatus;
+    mtqStatus |= atqStatus;
     // Ignored and Watched are toggleable, yet mutually exclusive.
     // That is an arbitrary restriction on my part. HAR HAR HAR :) -till
-    if (aStatus == KMMsgStatusWatched)
-      mStatus &= ~KMMsgStatusIgnored;
-    if (aStatus == KMMsgStatusIgnored)
-      mStatus &= ~KMMsgStatusWatched;
-    if (aStatus == KMMsgStatusSpam)
-      mStatus &= ~KMMsgStatusHam;
-    if (aStatus == KMMsgStatusHam)
-      mStatus &= ~KMMsgStatusSpam;
+    if (atqStatus == KMMsgStatusWatched)
+      mtqStatus &= ~KMMsgStatusIgnored;
+    if (atqStatus == KMMsgStatusIgnored)
+      mtqStatus &= ~KMMsgStatusWatched;
+    if (atqStatus == KMMsgStatusSpam)
+      mtqStatus &= ~KMMsgStatusHam;
+    if (atqStatus == KMMsgStatusHam)
+      mtqStatus &= ~KMMsgStatusSpam;
   }
   if (storage()) {
      if (idx < 0)
        idx = storage()->find( this );
-     storage()->msgStatusChanged( oldStatus, status(), idx );
+     storage()->msgStatusChanged( oldtqStatus, status(), idx );
      storage()->headerOfMsgChanged(this, idx);
   }
 
 }
 
 //-----------------------------------------------------------------------------
-void KMMsgBase::setStatus(const KMMsgStatus aStatus, int idx)
+void KMMsgBase::setqStatus(const KMMsgtqStatus atqStatus, int idx)
 {
   mDirty = true;
-  KMMsgStatus oldStatus = status();
-  switch (aStatus) {
+  KMMsgtqStatus oldtqStatus = status();
+  switch (atqStatus) {
     case KMMsgStatusRead:
       // Unset unread and new, set read
-      mStatus &= ~KMMsgStatusUnread;
-      mStatus &= ~KMMsgStatusNew;
-      mStatus |= KMMsgStatusRead;
+      mtqStatus &= ~KMMsgStatusUnread;
+      mtqStatus &= ~KMMsgStatusNew;
+      mtqStatus |= KMMsgStatusRead;
       break;
 
     case KMMsgStatusUnread:
       // unread overrides read
-      mStatus &= ~KMMsgStatusOld;
-      mStatus &= ~KMMsgStatusRead;
-      mStatus &= ~KMMsgStatusNew;
-      mStatus |= KMMsgStatusUnread;
+      mtqStatus &= ~KMMsgStatusOld;
+      mtqStatus &= ~KMMsgStatusRead;
+      mtqStatus &= ~KMMsgStatusNew;
+      mtqStatus |= KMMsgStatusUnread;
       break;
 
     case KMMsgStatusOld:
       // old can't be new or unread
-      mStatus &= ~KMMsgStatusNew;
-      mStatus &= ~KMMsgStatusUnread;
-      mStatus |= KMMsgStatusOld;
+      mtqStatus &= ~KMMsgStatusNew;
+      mtqStatus &= ~KMMsgStatusUnread;
+      mtqStatus |= KMMsgStatusOld;
       break;
 
     case KMMsgStatusNew:
       // new overrides old and read
-      mStatus &= ~KMMsgStatusOld;
-      mStatus &= ~KMMsgStatusRead;
-      mStatus &= ~KMMsgStatusUnread;
-      mStatus |= KMMsgStatusNew;
+      mtqStatus &= ~KMMsgStatusOld;
+      mtqStatus &= ~KMMsgStatusRead;
+      mtqStatus &= ~KMMsgStatusUnread;
+      mtqStatus |= KMMsgStatusNew;
       break;
 
     case KMMsgStatusDeleted:
-      mStatus |= KMMsgStatusDeleted;
+      mtqStatus |= KMMsgStatusDeleted;
       break;
 
     case KMMsgStatusReplied:
-      mStatus |= KMMsgStatusReplied;
+      mtqStatus |= KMMsgStatusReplied;
       break;
 
     case KMMsgStatusForwarded:
-      mStatus |= KMMsgStatusForwarded;
+      mtqStatus |= KMMsgStatusForwarded;
       break;
 
     case KMMsgStatusQueued:
-      mStatus |= KMMsgStatusQueued;
+      mtqStatus |= KMMsgStatusQueued;
       break;
 
     case KMMsgStatusTodo:
-      mStatus |= KMMsgStatusTodo;
+      mtqStatus |= KMMsgStatusTodo;
       break;
 
     case KMMsgStatusSent:
-      mStatus &= ~KMMsgStatusQueued;
-      mStatus &= ~KMMsgStatusUnread;
-      mStatus &= ~KMMsgStatusNew;
-      mStatus |= KMMsgStatusSent;
+      mtqStatus &= ~KMMsgStatusQueued;
+      mtqStatus &= ~KMMsgStatusUnread;
+      mtqStatus &= ~KMMsgStatusNew;
+      mtqStatus |= KMMsgStatusSent;
       break;
 
     case KMMsgStatusFlag:
-      mStatus |= KMMsgStatusFlag;
+      mtqStatus |= KMMsgStatusFlag;
       break;
 
     // Watched and ignored are mutually exclusive
     case KMMsgStatusWatched:
-      mStatus &= ~KMMsgStatusIgnored;
-      mStatus |= KMMsgStatusWatched;
+      mtqStatus &= ~KMMsgStatusIgnored;
+      mtqStatus |= KMMsgStatusWatched;
       break;
 
     case KMMsgStatusIgnored:
-      mStatus &= ~KMMsgStatusWatched;
-      mStatus |= KMMsgStatusIgnored;
+      mtqStatus &= ~KMMsgStatusWatched;
+      mtqStatus |= KMMsgStatusIgnored;
       break;
     // as are ham and spam
     case KMMsgStatusSpam:
-      mStatus &= ~KMMsgStatusHam;
-      mStatus |= KMMsgStatusSpam;
+      mtqStatus &= ~KMMsgStatusHam;
+      mtqStatus |= KMMsgStatusSpam;
       break;
     case KMMsgStatusHam:
-      mStatus &= ~KMMsgStatusSpam;
-      mStatus |= KMMsgStatusHam;
+      mtqStatus &= ~KMMsgStatusSpam;
+      mtqStatus |= KMMsgStatusHam;
       break;
     case KMMsgStatusHasAttach:
-      mStatus &= ~KMMsgStatusHasNoAttach;
-      mStatus |= KMMsgStatusHasAttach;
+      mtqStatus &= ~KMMsgStatusHasNoAttach;
+      mtqStatus |= KMMsgStatusHasAttach;
       break;
     case KMMsgStatusHasNoAttach:
-      mStatus &= ~KMMsgStatusHasAttach;
-      mStatus |= KMMsgStatusHasNoAttach;
+      mtqStatus &= ~KMMsgStatusHasAttach;
+      mtqStatus |= KMMsgStatusHasNoAttach;
       break;
     case KMMsgStatusHasInvitation:
-      mStatus &= ~KMMsgStatusHasNoInvitation;
-      mStatus |= KMMsgStatusHasInvitation;
+      mtqStatus &= ~KMMsgStatusHasNoInvitation;
+      mtqStatus |= KMMsgStatusHasInvitation;
       break;
     case KMMsgStatusHasNoInvitation:
-      mStatus &= ~KMMsgStatusHasInvitation;
-      mStatus |= KMMsgStatusHasNoInvitation;
+      mtqStatus &= ~KMMsgStatusHasInvitation;
+      mtqStatus |= KMMsgStatusHasNoInvitation;
       break;
     default:
-      mStatus = aStatus;
+      mtqStatus = atqStatus;
       break;
   }
 
-  if ( oldStatus != mStatus && storage() ) {
+  if ( oldtqStatus != mtqStatus && storage() ) {
     if (idx < 0)
       idx = storage()->find( this );
-    storage()->msgStatusChanged( oldStatus, status(), idx );
+    storage()->msgStatusChanged( oldtqStatus, status(), idx );
     storage()->headerOfMsgChanged( this, idx );
   }
 }
@@ -267,40 +267,40 @@ void KMMsgBase::setStatus(const KMMsgStatus aStatus, int idx)
 
 
 //-----------------------------------------------------------------------------
-void KMMsgBase::setStatus(const char* aStatusStr, const char* aXStatusStr)
+void KMMsgBase::setqStatus(const char* aStatusStr, const char* aXStatusStr)
 {
   // first try to find status from "X-Status" field if given
   if (aXStatusStr) {
-    if (strchr(aXStatusStr, 'N')) setStatus(KMMsgStatusNew);
-    if (strchr(aXStatusStr, 'U')) setStatus(KMMsgStatusUnread);
-    if (strchr(aXStatusStr, 'O')) setStatus(KMMsgStatusOld);
-    if (strchr(aXStatusStr, 'R')) setStatus(KMMsgStatusRead);
-    if (strchr(aXStatusStr, 'D')) setStatus(KMMsgStatusDeleted);
-    if (strchr(aXStatusStr, 'A')) setStatus(KMMsgStatusReplied);
-    if (strchr(aXStatusStr, 'F')) setStatus(KMMsgStatusForwarded);
-    if (strchr(aXStatusStr, 'Q')) setStatus(KMMsgStatusQueued);
-    if (strchr(aXStatusStr, 'K')) setStatus(KMMsgStatusTodo);
-    if (strchr(aXStatusStr, 'S')) setStatus(KMMsgStatusSent);
-    if (strchr(aXStatusStr, 'G')) setStatus(KMMsgStatusFlag);
-    if (strchr(aXStatusStr, 'P')) setStatus(KMMsgStatusSpam);
-    if (strchr(aXStatusStr, 'H')) setStatus(KMMsgStatusHam);
-    if (strchr(aXStatusStr, 'T')) setStatus(KMMsgStatusHasAttach);
-    if (strchr(aXStatusStr, 'C')) setStatus(KMMsgStatusHasNoAttach);
+    if (strchr(aXStatusStr, 'N')) setqStatus(KMMsgStatusNew);
+    if (strchr(aXStatusStr, 'U')) setqStatus(KMMsgStatusUnread);
+    if (strchr(aXStatusStr, 'O')) setqStatus(KMMsgStatusOld);
+    if (strchr(aXStatusStr, 'R')) setqStatus(KMMsgStatusRead);
+    if (strchr(aXStatusStr, 'D')) setqStatus(KMMsgStatusDeleted);
+    if (strchr(aXStatusStr, 'A')) setqStatus(KMMsgStatusReplied);
+    if (strchr(aXStatusStr, 'F')) setqStatus(KMMsgStatusForwarded);
+    if (strchr(aXStatusStr, 'Q')) setqStatus(KMMsgStatusQueued);
+    if (strchr(aXStatusStr, 'K')) setqStatus(KMMsgStatusTodo);
+    if (strchr(aXStatusStr, 'S')) setqStatus(KMMsgStatusSent);
+    if (strchr(aXStatusStr, 'G')) setqStatus(KMMsgStatusFlag);
+    if (strchr(aXStatusStr, 'P')) setqStatus(KMMsgStatusSpam);
+    if (strchr(aXStatusStr, 'H')) setqStatus(KMMsgStatusHam);
+    if (strchr(aXStatusStr, 'T')) setqStatus(KMMsgStatusHasAttach);
+    if (strchr(aXStatusStr, 'C')) setqStatus(KMMsgStatusHasNoAttach);
   }
 
   // Merge the contents of the "Status" field
   if (aStatusStr) {
     if ((aStatusStr[0]== 'R' && aStatusStr[1]== 'O') ||
         (aStatusStr[0]== 'O' && aStatusStr[1]== 'R')) {
-      setStatus( KMMsgStatusOld );
-      setStatus( KMMsgStatusRead );
+      setqStatus( KMMsgStatusOld );
+      setqStatus( KMMsgStatusRead );
     }
     else if (aStatusStr[0] == 'R')
-      setStatus(KMMsgStatusRead);
+      setqStatus(KMMsgStatusRead);
     else if (aStatusStr[0] == 'D')
-      setStatus(KMMsgStatusDeleted);
+      setqStatus(KMMsgStatusDeleted);
     else
-      setStatus(KMMsgStatusNew);
+      setqStatus(KMMsgStatusNew);
   }
 }
 
@@ -363,117 +363,117 @@ void KMMsgBase::setSignatureStateChar( TQChar status, int idx )
 //-----------------------------------------------------------------------------
 bool KMMsgBase::isUnread(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st & KMMsgStatusUnread && !(st & KMMsgStatusIgnored));
 }
 
 //-----------------------------------------------------------------------------
 bool KMMsgBase::isNew(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st & KMMsgStatusNew && !(st & KMMsgStatusIgnored));
 }
 
 //-----------------------------------------------------------------------------
-bool KMMsgBase::isOfUnknownStatus(void) const
+bool KMMsgBase::isOfUnknowntqStatus(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st == KMMsgStatusUnknown);
 }
 
 //-----------------------------------------------------------------------------
 bool KMMsgBase::isOld(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st & KMMsgStatusOld);
 }
 
 //-----------------------------------------------------------------------------
 bool KMMsgBase::isRead(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st & KMMsgStatusRead || st & KMMsgStatusIgnored);
 }
 
 //-----------------------------------------------------------------------------
 bool KMMsgBase::isDeleted(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st & KMMsgStatusDeleted);
 }
 
 //-----------------------------------------------------------------------------
 bool KMMsgBase::isReplied(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st & KMMsgStatusReplied);
 }
 
 //-----------------------------------------------------------------------------
 bool KMMsgBase::isForwarded(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st & KMMsgStatusForwarded);
 }
 
 //-----------------------------------------------------------------------------
 bool KMMsgBase::isQueued(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st & KMMsgStatusQueued);
 }
 
 //-----------------------------------------------------------------------------
 bool KMMsgBase::isTodo(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st & KMMsgStatusTodo);
 }
 
 //-----------------------------------------------------------------------------
 bool KMMsgBase::isSent(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st & KMMsgStatusSent);
 }
 
 //-----------------------------------------------------------------------------
 bool KMMsgBase::isImportant(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st & KMMsgStatusFlag);
 }
 
 //-----------------------------------------------------------------------------
 bool KMMsgBase::isWatched(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st & KMMsgStatusWatched);
 }
 
 //-----------------------------------------------------------------------------
 bool KMMsgBase::isIgnored(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st & KMMsgStatusIgnored);
 }
 
 //-----------------------------------------------------------------------------
 bool KMMsgBase::isSpam(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st & KMMsgStatusSpam);
 }
 
 //-----------------------------------------------------------------------------
 bool KMMsgBase::isHam(void) const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   return (st & KMMsgStatusHam);
 }
 
 //-----------------------------------------------------------------------------
-TQCString KMMsgBase::statusToStr(const KMMsgStatus status)
+TQCString KMMsgBase::statusToStr(const KMMsgtqStatus status)
 {
   TQCString sstr;
   if (status & KMMsgStatusNew) sstr += 'N';
@@ -587,8 +587,8 @@ TQCString KMMsgBase::toUsAscii(const TQString& _str, bool *ok)
   TQString result = _str;
   int len = result.length();
   for (int i = 0; i < len; i++)
-    if (result.at(i).unicode() >= 128) {
-      result.at(i) = '?';
+    if (result.tqat(i).tqunicode() >= 128) {
+      result.tqat(i) = '?';
       all_ok = false;
     }
   if (ok)
@@ -658,12 +658,12 @@ namespace {
 TQString KMMsgBase::decodeRFC2047String(const TQCString& aStr, TQCString prefCharset)
 {
   if ( aStr.isEmpty() )
-    return TQString::null;
+    return TQString();
 
   const TQCString str = unfold( aStr );
 
   if ( str.isEmpty() )
-    return TQString::null;
+    return TQString();
 
   if ( str.find( "=?" ) < 0 ) {
     if ( !prefCharset.isEmpty() &&
@@ -800,7 +800,7 @@ TQCString KMMsgBase::encodeRFC2047String(const TQString& _str,
   unsigned int nonAscii = 0;
   unsigned int strLength(_str.length());
   for (unsigned int i = 0; i < strLength; i++)
-    if (_str.at(i).unicode() >= 128) nonAscii++;
+    if (_str.tqat(i).tqunicode() >= 128) nonAscii++;
   bool useBase64 = (nonAscii * 6 > strLength);
 
   unsigned int start, stop, p, pos = 0, encLength;
@@ -813,17 +813,17 @@ TQCString KMMsgBase::encodeRFC2047String(const TQString& _str,
     start = pos; p = pos;
     while (p < strLength)
     {
-      if (!breakLine && (_str.at(p) == ' ' || dontQuote.find(_str.at(p)) != -1))
+      if (!breakLine && (_str.tqat(p) == ' ' || dontQuote.find(_str.tqat(p)) != -1))
         start = p + 1;
-      if (_str.at(p).unicode() >= 128 || _str.at(p).unicode() < 32)
+      if (_str.tqat(p).tqunicode() >= 128 || _str.tqat(p).tqunicode() < 32)
         break;
       p++;
     }
     if (breakLine || p < strLength)
     {
-      while (dontQuote.find(_str.at(start)) != -1) start++;
+      while (dontQuote.find(_str.tqat(start)) != -1) start++;
       stop = start;
-      while (stop < strLength && dontQuote.find(_str.at(stop)) == -1)
+      while (stop < strLength && dontQuote.find(_str.tqat(stop)) == -1)
         stop++;
       result += _str.mid(pos, start - pos).latin1();
       encLength = encodeRFC2047Quoted(codec->fromUnicode(_str.
@@ -843,7 +843,7 @@ TQCString KMMsgBase::encodeRFC2047String(const TQString& _str,
         stop = start + dif;
       }
       p = stop;
-      while (p > start && _str.at(p) != ' ') p--;
+      while (p > start && _str.tqat(p) != ' ') p--;
       if (p > start) stop = p;
       if (result.right(3) == "?= ") start--;
       if (result.right(5) == "?=\n  ") {
@@ -956,13 +956,13 @@ TQString KMMsgBase::decodeRFC2231String(const TQCString& _str)
   p = 0;
   while (p < (int)st.length())
   {
-    if (st.at(p) == 37)
+    if (st.tqat(p) == 37)
     {
-      ch = st.at(p+1) - 48;
+      ch = st.tqat(p+1) - 48;
       if (ch > 16) ch -= 7;
-      ch2 = st.at(p+2) - 48;
+      ch2 = st.tqat(p+2) - 48;
       if (ch2 > 16) ch2 -= 7;
-      st.at(p) = ch * 16 + ch2;
+      st.tqat(p) = ch * 16 + ch2;
       st.remove( p+1, 2 );
     }
     p++;
@@ -1037,7 +1037,7 @@ TQCString KMMsgBase::autoDetectCharset(const TQCString &_encoding, const TQStrin
     TQStringList charsets = encodingList;
     if (!_encoding.isEmpty())
     {
-       TQString currentCharset = TQString::fromLatin1(_encoding);
+       TQString currentCharset = TQString::tqfromLatin1(_encoding);
        charsets.remove(currentCharset);
        charsets.prepend(currentCharset);
     }
@@ -1093,7 +1093,7 @@ unsigned long KMMsgBase::getMsgSerNum() const
 //-----------------------------------------------------------------------------
 KMMsgAttachmentState KMMsgBase::attachmentState() const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   if (st & KMMsgStatusHasAttach)
     return KMMsgHasAttachment;
   else if (st & KMMsgStatusHasNoAttach)
@@ -1105,7 +1105,7 @@ KMMsgAttachmentState KMMsgBase::attachmentState() const
 
 KMMsgInvitationState KMMsgBase::invitationState() const
 {
-  KMMsgStatus st = status();
+  KMMsgtqStatus st = status();
   if (st & KMMsgStatusHasInvitation)
     return KMMsgHasInvitation;
   else if (st & KMMsgStatusHasNoInvitation)
@@ -1119,9 +1119,9 @@ static void swapEndian(TQString &str)
 {
   uint len = str.length();
   str = TQDeepCopy<TQString>(str);
-  TQChar *unicode = const_cast<TQChar*>( str.unicode() );
+  TQChar *tqunicode = const_cast<TQChar*>( str.tqunicode() );
   for (uint i = 0; i < len; i++)
-    unicode[i] = kmail_swap_16(unicode[i].unicode());
+    tqunicode[i] = kmail_swap_16(tqunicode[i].tqunicode());
 }
 
 //-----------------------------------------------------------------------------
@@ -1171,9 +1171,9 @@ retry:
   }
 
   MsgPartType type;
-  Q_UINT16 l;
+  TQ_UINT16 l;
   while(g_chunk_offset < mIndexLength) {
-    Q_UINT32 tmp;
+    TQ_UINT32 tmp;
     copy_from_stream(tmp);
     copy_from_stream(l);
     if (swapByteOrder)
@@ -1193,7 +1193,7 @@ retry:
     }
     if(type == t) {
         // This works because the TQString constructor does a memcpy.
-        // Otherwise we would need to be concerned about the alignment.
+        // Otherwise we would need to be concerned about the tqalignment.
 	if(l)
 	    ret = TQString((TQChar *)(g_chunk + g_chunk_offset), l/2);
 	break;
@@ -1204,9 +1204,9 @@ retry:
       g_chunk_length = 0;
       g_chunk = 0;
   }
-  // Normally we need to swap the byte order because the QStrings are written
-  // in the style of Qt2 (MSB -> network ordered).
-  // QStrings in Qt3 expect host ordering.
+  // Normally we need to swap the byte order because the TQStrings are written
+  // in the style of TQt2 (MSB -> network ordered).
+  // TQStrings in TQt3 expect host ordering.
   // On e.g. Intel host ordering is LSB, on e.g. Sparc it is MSB.
 
 #ifndef WORDS_BIGENDIAN
@@ -1248,9 +1248,9 @@ retry:
   }
 
   MsgPartType type;
-  Q_UINT16 l;
+  TQ_UINT16 l;
   while (g_chunk_offset < mIndexLength) {
-    Q_UINT32 tmp;
+    TQ_UINT32 tmp;
     copy_from_stream(tmp);
     copy_from_stream(l);
     if (swapByteOrder)
@@ -1285,7 +1285,7 @@ retry:
       else if (sizeOfLong == 4)
       {
          // Long is stored as 4 bytes in index file, sizeof(long) = 8
-         Q_UINT32 ret_32;
+         TQ_UINT32 ret_32;
          copy_from_stream(ret_32);
          if (swapByteOrder)
             ret_32 = kmail_swap_32(ret_32);
@@ -1294,8 +1294,8 @@ retry:
       else if (sizeOfLong == 8)
       {
          // Long is stored as 8 bytes in index file, sizeof(long) = 4
-         Q_UINT32 ret_1;
-         Q_UINT32 ret_2;
+         TQ_UINT32 ret_1;
+         TQ_UINT32 ret_2;
          copy_from_stream(ret_1);
          copy_from_stream(ret_2);
          if (!swapByteOrder)
@@ -1347,8 +1347,8 @@ retry:
 	int len2 = (len > 256) ? 256 : len; \
 	if(csize < (length + (len2 + sizeof(short) + sizeof(MsgPartType)))) \
     	   ret = (uchar *)realloc(ret, csize += len2+sizeof(short)+sizeof(MsgPartType)); \
-        Q_UINT32 t = (Q_UINT32) type; memcpy(ret+length, &t, sizeof(t)); \
-        Q_UINT16 l = len2; memcpy(ret+length+sizeof(t), &l, sizeof(l)); \
+        TQ_UINT32 t = (TQ_UINT32) type; memcpy(ret+length, &t, sizeof(t)); \
+        TQ_UINT16 l = len2; memcpy(ret+length+sizeof(t), &l, sizeof(l)); \
         if (network_order) \
            memcpy_networkorder(ret+length+sizeof(t)+sizeof(l), x, len2); \
         else \
@@ -1371,23 +1371,23 @@ const uchar *KMMsgBase::asIndexString(int &length) const
 
   //these is at the beginning because it is queried quite often
   tmp_str = msgIdMD5().stripWhiteSpace();
-  STORE_DATA_LEN(MsgIdMD5Part, tmp_str.unicode(), tmp_str.length() * 2, true);
-  tmp = mLegacyStatus;
+  STORE_DATA_LEN(MsgIdMD5Part, tmp_str.tqunicode(), tmp_str.length() * 2, true);
+  tmp = mLegacytqStatus;
   STORE_DATA(MsgLegacyStatusPart, tmp);
 
   //these are completely arbitrary order
   tmp_str = fromStrip().stripWhiteSpace();
-  STORE_DATA_LEN(MsgFromStripPart, tmp_str.unicode(), tmp_str.length() * 2, true);
+  STORE_DATA_LEN(MsgFromStripPart, tmp_str.tqunicode(), tmp_str.length() * 2, true);
   tmp_str = subject().stripWhiteSpace();
-  STORE_DATA_LEN(MsgSubjectPart, tmp_str.unicode(), tmp_str.length() * 2, true);
+  STORE_DATA_LEN(MsgSubjectPart, tmp_str.tqunicode(), tmp_str.length() * 2, true);
   tmp_str = toStrip().stripWhiteSpace();
-  STORE_DATA_LEN(MsgToStripPart, tmp_str.unicode(), tmp_str.length() * 2, true);
+  STORE_DATA_LEN(MsgToStripPart, tmp_str.tqunicode(), tmp_str.length() * 2, true);
   tmp_str = replyToIdMD5().stripWhiteSpace();
-  STORE_DATA_LEN(MsgReplyToIdMD5Part, tmp_str.unicode(), tmp_str.length() * 2, true);
+  STORE_DATA_LEN(MsgReplyToIdMD5Part, tmp_str.tqunicode(), tmp_str.length() * 2, true);
   tmp_str = xmark().stripWhiteSpace();
-  STORE_DATA_LEN(MsgXMarkPart, tmp_str.unicode(), tmp_str.length() * 2, true);
+  STORE_DATA_LEN(MsgXMarkPart, tmp_str.tqunicode(), tmp_str.length() * 2, true);
   tmp_str = fileName().stripWhiteSpace();
-  STORE_DATA_LEN(MsgFilePart, tmp_str.unicode(), tmp_str.length() * 2, true);
+  STORE_DATA_LEN(MsgFilePart, tmp_str.tqunicode(), tmp_str.length() * 2, true);
   tmp = msgSize();
   STORE_DATA(MsgSizePart, tmp);
   tmp = folderOffset();
@@ -1400,10 +1400,10 @@ const uchar *KMMsgBase::asIndexString(int &length) const
   STORE_DATA(MsgMDNSentPart, tmp);
 
   tmp_str = replyToAuxIdMD5().stripWhiteSpace();
-  STORE_DATA_LEN(MsgReplyToAuxIdMD5Part, tmp_str.unicode(), tmp_str.length() * 2, true);
+  STORE_DATA_LEN(MsgReplyToAuxIdMD5Part, tmp_str.tqunicode(), tmp_str.length() * 2, true);
 
   tmp_str = strippedSubjectMD5().stripWhiteSpace();
-  STORE_DATA_LEN(MsgStrippedSubjectMD5Part, tmp_str.unicode(), tmp_str.length() * 2, true);
+  STORE_DATA_LEN(MsgStrippedSubjectMD5Part, tmp_str.tqunicode(), tmp_str.length() * 2, true);
 
   tmp = status();
   STORE_DATA(MsgStatusPart, tmp);
@@ -1414,10 +1414,10 @@ const uchar *KMMsgBase::asIndexString(int &length) const
   STORE_DATA(MsgUIDPart, tmp);
 
   tmp_str = from();
-  STORE_DATA_LEN( MsgFromPart, tmp_str.unicode(), tmp_str.length() * 2, true );
+  STORE_DATA_LEN( MsgFromPart, tmp_str.tqunicode(), tmp_str.length() * 2, true );
 
   tmp_str = to();
-  STORE_DATA_LEN( MsgToPart, tmp_str.unicode(), tmp_str.length() * 2, true );
+  STORE_DATA_LEN( MsgToPart, tmp_str.tqunicode(), tmp_str.length() * 2, true );
 
   return ret;
 }
@@ -1462,7 +1462,7 @@ void KMMsgBase::readConfig()
 TQString KMMsgBase::stripOffPrefixes( const TQString& str )
 {
   return replacePrefixes( str, sReplySubjPrefixes + sForwardSubjPrefixes,
-                          true, TQString::null ).stripWhiteSpace();
+                          true, TQString() ).stripWhiteSpace();
 }
 
 //-----------------------------------------------------------------------------
@@ -1476,8 +1476,8 @@ TQString KMMsgBase::replacePrefixes( const TQString& str,
   // construct a big regexp that
   // 1. is anchored to the beginning of str (sans whitespace)
   // 2. matches at least one of the part regexps in prefixRegExps
-  TQString bigRegExp = TQString::fromLatin1("^(?:\\s+|(?:%1))+\\s*")
-                      .arg( prefixRegExps.join(")|(?:") );
+  TQString bigRegExp = TQString::tqfromLatin1("^(?:\\s+|(?:%1))+\\s*")
+                      .tqarg( prefixRegExps.join(")|(?:") );
   TQRegExp rx( bigRegExp, false /*case insens.*/ );
   if ( !rx.isValid() ) {
     kdWarning(5006) << "KMMessage::replacePrefixes(): bigRegExp = \""
@@ -1503,7 +1503,7 @@ TQString KMMsgBase::replacePrefixes( const TQString& str,
 TQString KMMsgBase::cleanSubject() const
 {
   return cleanSubject( sReplySubjPrefixes + sForwardSubjPrefixes,
-		       true, TQString::null ).stripWhiteSpace();
+		       true, TQString() ).stripWhiteSpace();
 }
 
 //-----------------------------------------------------------------------------
