@@ -348,29 +348,29 @@ void KMReaderMainWin::setupAccel()
   //                             this, TQT_SLOT( slotSaveMsg() ),
   //                             actionCollection(), "file_save_as" );
 
-  mSaveAsAction = KStdAction::saveAs( mReaderWin, TQT_SLOT( slotSaveMsg() ),
+  mSaveAsAction = KStdAction::saveAs( TQT_TQOBJECT(mReaderWin), TQT_SLOT( slotSaveMsg() ),
 				      actionCollection() );
   mSaveAsAction->setShortcut( KStdAccel::shortcut( KStdAccel::Save ) );
-  mPrintAction = KStdAction::print( this, TQT_SLOT( slotPrintMsg() ),
+  mPrintAction = KStdAction::print( TQT_TQOBJECT(this), TQT_SLOT( slotPrintMsg() ),
                                     actionCollection() );
 
-  KAction *closeAction = KStdAction::close( this, TQT_SLOT( close() ), actionCollection() );
+  KAction *closeAction = KStdAction::close( TQT_TQOBJECT(this), TQT_SLOT( close() ), actionCollection() );
   KShortcut closeShortcut = closeAction->shortcut();
   closeShortcut.append( KKey(Key_Escape));
   closeAction->setShortcut(closeShortcut);
 
   //----- Edit Menu
-  KStdAction::copy( this, TQT_SLOT( slotCopy() ), actionCollection() );
-  KStdAction::selectAll( this, TQT_SLOT( slotMarkAll() ), actionCollection() );
-  KStdAction::find( this, TQT_SLOT(slotFind()), actionCollection() );
-  KStdAction::findNext( this, TQT_SLOT( slotFindNext() ), actionCollection() );
+  KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT( slotCopy() ), actionCollection() );
+  KStdAction::selectAll( TQT_TQOBJECT(this), TQT_SLOT( slotMarkAll() ), actionCollection() );
+  KStdAction::find( TQT_TQOBJECT(this), TQT_SLOT(slotFind()), actionCollection() );
+  KStdAction::findNext( TQT_TQOBJECT(this), TQT_SLOT( slotFindNext() ), actionCollection() );
   mTrashAction = new KAction( KGuiItem( i18n( "&Move to Trash" ), "edittrash",
                               i18n( "Move message to trashcan" ) ),
-                              Key_Delete, this, TQT_SLOT( slotTrashMsg() ),
+                              Key_Delete, TQT_TQOBJECT(this), TQT_SLOT( slotTrashMsg() ),
                               actionCollection(), "move_to_trash" );
 
   //----- View Menu
-  mViewSourceAction = new KAction( i18n("&View Source"), Key_V, this,
+  mViewSourceAction = new KAction( i18n("&View Source"), Key_V, TQT_TQOBJECT(this),
                                    TQT_SLOT(slotShowMsgSrc()), actionCollection(),
                                    "view_source" );
 
@@ -379,25 +379,25 @@ void KMReaderMainWin::setupAccel()
 					"mail_forward", actionCollection(),
 					"message_forward" );
       mForwardInlineAction = new KAction( i18n("&Inline..."),
-                                      "mail_forward", SHIFT+Key_F, this,
+                                      "mail_forward", SHIFT+Key_F, TQT_TQOBJECT(this),
                                       TQT_SLOT(slotForwardInlineMsg()),
                                       actionCollection(),
                                       "message_forward_inline" );
 
       mForwardAttachedAction = new KAction( i18n("Message->Forward->","As &Attachment..."),
-                                        "mail_forward", Key_F, this,
+                                        "mail_forward", Key_F, TQT_TQOBJECT(this),
                                         TQT_SLOT(slotForwardAttachedMsg()),
                                         actionCollection(),
                                         "message_forward_as_attachment" );
 
       mForwardDigestAction = new KAction( i18n("Message->Forward->","As Di&gest..."),
-                                      "mail_forward", 0, this,
+                                      "mail_forward", 0, TQT_TQOBJECT(this),
                                       TQT_SLOT(slotForwardDigestMsg()),
                                       actionCollection(),
                                       "message_forward_as_digest" );
 
       mRedirectAction = new KAction( i18n("Message->Forward->","&Redirect..."),
-                                 "mail_forward", Key_E, this,
+                                 "mail_forward", Key_E, TQT_TQOBJECT(this),
                                  TQT_SLOT(slotRedirectMsg()),
                                  actionCollection(),
                                  "message_forward_redirect" );
@@ -435,7 +435,7 @@ void KMReaderMainWin::setupAccel()
 	  mReaderWin, TQT_SLOT(slotUrlClicked()));
 
   setStandardToolBarMenuEnabled(true);
-  KStdAction::configureToolbars(this, TQT_SLOT(slotEditToolbars()), actionCollection());
+  KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT(slotEditToolbars()), actionCollection());
 }
 
 
@@ -503,7 +503,7 @@ void KMReaderMainWin::slotMsgPopup(KMMessage &aMsg, const KURL &aUrl, const TQPo
     TQPopupMenu* copyMenu = new TQPopupMenu(menu);
     KMMainWidget* mainwin = kmkernel->getKMMainWidget();
     if ( mainwin )
-      mainwin->folderTree()->folderToPopupMenu( KMFolderTree::CopyMessage, this,
+      mainwin->folderTree()->folderToPopupMenu( KMFolderTree::CopyMessage, TQT_TQOBJECT(this),
           &mMenuToFolder, copyMenu );
     menu->insertItem( i18n("&Copy To" ), copyMenu );
     menu->insertSeparator();
