@@ -75,6 +75,7 @@ namespace KParts {
 
 class KMReaderWin: public TQWidget, public KMail::Interface::Observer {
   Q_OBJECT
+  TQ_OBJECT
 
   friend void KMMimePartTree::itemClicked( TQListViewItem* item );
   friend void KMMimePartTree::itemRightClicked( TQListViewItem* item, const TQPoint & );
@@ -369,7 +370,7 @@ public slots:
   /** Refresh the reader window */
   void updateReaderWin();
 
-  /** HTML Widget scrollbar and layout handling. */
+  /** HTML Widget scrollbar and tqlayout handling. */
   void slotScrollUp();
   void slotScrollDown();
   void slotScrollPrior();
@@ -420,7 +421,7 @@ public slots:
   void slotMessageArrived( KMMessage *msg );
   /** start IM Chat with addressee */
   void slotIMChat();
-  void contactStatusChanged( const TQString &uid);
+  void contacStatusChanged( const TQString &uid);
 
   void slotLevelQuote( int l );
   void slotTouchMessage();
@@ -493,7 +494,7 @@ protected:
   TQString writeMsgHeader(KMMessage* aMsg, partNode *vCardNode = 0, bool topLevel=false );
 
   /** Writes the given message part to a temporary file and returns the
-      name of this file or TQString::null if writing failed.
+      name of this file or TQString() if writing failed.
   */
   TQString writeMessagePartToTempFile( KMMessagePart* msgPart, int partNumber );
 
