@@ -18,8 +18,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #include "recipientseditor.h"
@@ -288,7 +288,7 @@ void RecipientLine::keyPressEvent( TQKeyEvent *ev )
 
 int RecipientLine::setComboWidth( int w )
 {
-  w = QMAX( w, mCombo->sizeHint().width() );
+  w = TQMAX( w, mCombo->tqsizeHint().width() );
   mCombo->setFixedWidth( w );
   mCombo->updateGeometry();
   parentWidget()->updateGeometry();
@@ -331,7 +331,7 @@ RecipientsView::RecipientsView( TQWidget *parent )
 
   addLine();
   setResizePolicy( TQScrollView::Manual );
-  setSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding );
+  tqsetSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding );
 
   viewport()->setPaletteBackgroundColor( paletteBackgroundColor() );
 }
@@ -400,7 +400,7 @@ RecipientLine *RecipientsView::addLine()
 
   mFirstColumnWidth = line->setComboWidth( mFirstColumnWidth );
 
-  mLineHeight = line->minimumSizeHint().height();
+  mLineHeight = line->tqminimumSizeHint().height();
 
   line->resize( viewport()->width(), mLineHeight );
 
@@ -536,7 +536,7 @@ void RecipientsView::resizeView()
 //    setFixedHeight( mLineHeight * mLines.count() );
   }
 
-  parentWidget()->layout()->activate();
+  parentWidget()->tqlayout()->activate();
   emit sizeHintChanged();
   TQTimer::singleShot( 0, this, TQT_SLOT(moveCompletionPopup()) );
 }
@@ -555,12 +555,12 @@ void RecipientsView::viewportResizeEvent ( TQResizeEvent *ev )
   ensureVisible( 0, mLines.count() * mLineHeight );
 }
 
-TQSize RecipientsView::sizeHint() const
+TQSize RecipientsView::tqsizeHint() const
 {
   return TQSize( 200, mLineHeight * mLines.count() );
 }
 
-TQSize RecipientsView::minimumSizeHint() const
+TQSize RecipientsView::tqminimumSizeHint() const
 {
   int height;
   uint numLines = 5;
@@ -742,9 +742,9 @@ void RecipientsToolTip::maybeTip( const TQPoint & p )
 
   text.append( "</qt>" );
 
-  TQRect geometry( p + TQPoint( 2, 2 ), TQPoint( 400, 100 ) );
+  TQRect tqgeometry( p + TQPoint( 2, 2 ), TQPoint( 400, 100 ) );
 
-  tip( TQRect( p.x() - 20, p.y() - 20, 40, 40 ), text, geometry );
+  tip( TQRect( p.x() - 20, p.y() - 20, 40, 40 ), text, tqgeometry );
 }
 
 
@@ -757,7 +757,7 @@ SideWidget::SideWidget( RecipientsView *view, TQWidget *parent )
   topLayout->addStretch( 1 );
 
   mTotalLabel = new TQLabel( this );
-  mTotalLabel->setAlignment( AlignCenter );
+  mTotalLabel->tqsetAlignment( AlignCenter );
   topLayout->addWidget( mTotalLabel );
   mTotalLabel->hide();
 
@@ -915,8 +915,8 @@ void RecipientsEditor::setRecipientString( const TQString &str,
     if ( count++ > GlobalSettings::self()->maximumRecipients() ) {
       KMessageBox::sorry( this,
         i18n("Truncating recipients list to %1 of %2 entries.")
-        .arg( GlobalSettings::self()->maximumRecipients() )
-        .arg( r.count() ) );
+        .tqarg( GlobalSettings::self()->maximumRecipients() )
+        .tqarg( r.count() ) );
       break;
     }
     addRecipient( *it, type );
