@@ -103,7 +103,7 @@ void RecipientItem::setAddressee( const KABC::Addressee &a,
 
   TQImage img = a.photo().data();
   if ( !img.isNull() )
-    mIcon = img.smoothScale( 20, 20, TQImage::ScaleMin );
+    mIcon = img.smoothScale( 20, 20, TQ_ScaleMin );
   else
     mIcon = KGlobal::iconLoader()->loadIcon( "personal", KIcon::Small );
 
@@ -241,7 +241,7 @@ void RecipientsListToolTip::maybeTip( const TQPoint & pos )
   RecipientViewItem *i = static_cast<RecipientViewItem *>( item );
 
   if( item ) {
-    r = mListView->itemRect( item );
+    r = mListView->tqitemRect( item );
     TQString tipText( i->recipientItem()->tooltip() );
     if ( !tipText.isEmpty() ) {
       tip( r, tipText );
@@ -347,7 +347,7 @@ RecipientsPicker::RecipientsPicker( TQWidget *parent )
 #endif
     ,mLdapSearchDialog( 0 )
 {
-//  KWin::setType( winId(), NET::Dock );
+//  KWin::setType( winId(), NET::TQt::Dock );
 
   setCaption( i18n("Select Recipient") );
 
@@ -783,7 +783,7 @@ void RecipientsPicker::pick( Recipient::Type type )
              "recipients is %1. Please adapt the selection.",
              "You selected %n recipients. The maximum supported number of "
              "recipients is %1. Please adapt the selection.", count)
-      .arg( GlobalSettings::self()->maximumRecipients() ) );
+      .tqarg( GlobalSettings::self()->maximumRecipients() ) );
     return;
   }
 
@@ -838,7 +838,7 @@ void RecipientsPicker::setFocusList()
 
 void RecipientsPicker::resetSearch()
 {
-  mSearchLine->setText( TQString::null );
+  mSearchLine->setText( TQString() );
 }
 
 void RecipientsPicker::slotSearchLDAP()
