@@ -188,8 +188,8 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
   if ( list )
       object = list->first();
   delete list;
-  if (!searchFolder && object && ::qt_cast<TQComboBox*>(object))
-      static_cast<TQComboBox*>(object)->setCurrentText("Subject");
+  if (!searchFolder && object && ::tqqt_cast<TQComboBox*>(object))
+      static_cast<TQComboBox*>(TQT_TQWIDGET(object))->setCurrentText("Subject");
 
   vbl->addWidget( mPatternEdit );
 
@@ -199,7 +199,7 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
   connect( mChkbxSpecificFolders, TQT_SIGNAL(toggled(bool)),
            mChkSubFolders, TQT_SLOT(setEnabled(bool)) );
   connect( mChkbxAllFolders, TQT_SIGNAL(toggled(bool)),
-           this, TQT_SLOT(setEnabledSearchButton(bool)) );
+           TQT_TQOBJECT(this), TQT_SLOT(setEnabledSearchButton(bool)) );
 
   mLbxMatches = new MatchListView(searchWidget, this, "Find Messages");
 
@@ -237,13 +237,13 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
   mLbxMatches->setDragEnabled( true );
 
   connect( mLbxMatches, TQT_SIGNAL(clicked(TQListViewItem *)),
-           this, TQT_SLOT(slotShowMsg(TQListViewItem *)) );
+           TQT_TQOBJECT(this), TQT_SLOT(slotShowMsg(TQListViewItem *)) );
   connect( mLbxMatches, TQT_SIGNAL(doubleClicked(TQListViewItem *)),
-           this, TQT_SLOT(slotViewMsg(TQListViewItem *)) );
+           TQT_TQOBJECT(this), TQT_SLOT(slotViewMsg(TQListViewItem *)) );
   connect( mLbxMatches, TQT_SIGNAL(currentChanged(TQListViewItem *)),
-           this, TQT_SLOT(slotCurrentChanged(TQListViewItem *)) );
+           TQT_TQOBJECT(this), TQT_SLOT(slotCurrentChanged(TQListViewItem *)) );
   connect( mLbxMatches, TQT_SIGNAL(contextMenuRequested(TQListViewItem *,const TQPoint &,int)),
-           this, TQT_SLOT(slotContextMenuRequested(TQListViewItem *,const TQPoint &,int)) );
+           TQT_TQOBJECT(this), TQT_SLOT(slotContextMenuRequested(TQListViewItem *,const TQPoint &,int)) );
   vbl->addWidget( mLbxMatches );
 
   TQHBoxLayout *hbl2 = new TQHBoxLayout( vbl, spacingHint(), "kmfs_hbl2" );
@@ -261,21 +261,21 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
   mSearchFolderOpenBtn->setEnabled(false);
   hbl2->addWidget(mSearchFolderOpenBtn);
   connect( mSearchFolderEdt, TQT_SIGNAL( textChanged( const TQString &)),
-           this, TQT_SLOT( scheduleRename( const TQString & )));
+           TQT_TQOBJECT(this), TQT_SLOT( scheduleRename( const TQString & )));
   connect( &mRenameTimer, TQT_SIGNAL( timeout() ),
-           this, TQT_SLOT( renameSearchFolder() ));
+           TQT_TQOBJECT(this), TQT_SLOT( renameSearchFolder() ));
   connect( mSearchFolderOpenBtn, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( openSearchFolder() ));
+           TQT_TQOBJECT(this), TQT_SLOT( openSearchFolder() ));
   mSearchResultOpenBtn = new TQPushButton(i18n("Open &Message"), searchWidget);
   mSearchResultOpenBtn->setEnabled(false);
   hbl2->addWidget(mSearchResultOpenBtn);
   connect( mSearchResultOpenBtn, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotViewSelectedMsg() ));
+           TQT_TQOBJECT(this), TQT_SLOT( slotViewSelectedMsg() ));
   mStatusBar = new KStatusBar(searchWidget);
   mStatusBar->insertFixedItem(i18n("AMiddleLengthText..."), 0, true);
   mStatusBar->changeItem(i18n("Ready."), 0);
   mStatusBar->setItemAlignment(0, AlignLeft | AlignVCenter);
-  mStatusBar->insertItem(TQString::null, 1, 1, true);
+  mStatusBar->insertItem(TQString(), 1, 1, true);
   mStatusBar->setItemAlignment(1, AlignLeft | AlignVCenter);
   vbl->addWidget(mStatusBar);
 
@@ -286,7 +286,7 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
     resize(mainWidth, mainHeight);
 
   setMainWidget(searchWidget);
-  setButtonBoxOrientation(TQWidget::Vertical);
+  setButtonBoxOrientation(Qt::Vertical);
 
   mBtnSearch = actionButton(KDialogBase::User1);
   mBtnStop = actionButton(KDialogBase::User2);
@@ -294,12 +294,12 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
 
   connect(this, TQT_SIGNAL(user1Clicked()), TQT_SLOT(slotSearch()));
   connect(this, TQT_SIGNAL(user2Clicked()), TQT_SLOT(slotStop()));
-  connect(this, TQT_SIGNAL(finished()), this, TQT_SLOT(deleteLater()));
+  connect(this, TQT_SIGNAL(finished()), TQT_TQOBJECT(this), TQT_SLOT(deleteLater()));
 
   // give focus to the value field of the first search rule
   object = mPatternEdit->child( "regExpLineEdit" );
   if ( object && object->isWidgetType() ) {
-      static_cast<TQWidget*>(object)->setFocus();
+      TQT_TQWIDGET(object)->setFocus();
       //kdDebug(5006) << "SearchWindow: focus has been given to widget "
       //              << object->name() << endl;
   }
@@ -309,13 +309,13 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
   //set up actions
   KActionCollection *ac = actionCollection();
   ac->setWidget( this );
-  mReplyAction = new KAction( i18n("&Reply..."), "mail_reply", 0, this,
+  mReplyAction = new KAction( i18n("&Reply..."), "mail_reply", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotReplyToMsg()), ac, "search_reply" );
   mReplyAllAction = new KAction( i18n("Reply to &All..."), "mail_replyall",
-                                 0, this, TQT_SLOT(slotReplyAllToMsg()),
+                                 0, TQT_TQOBJECT(this), TQT_SLOT(slotReplyAllToMsg()),
                                  ac, "search_reply_all" );
   mReplyListAction = new KAction( i18n("Reply to Mailing-&List..."),
-                                  "mail_replylist", 0, this,
+                                  "mail_replylist", 0, TQT_TQOBJECT(this),
                                   TQT_SLOT(slotReplyListToMsg()), ac,
                                   "search_reply_list" );
   mForwardActionMenu = new KActionMenu( i18n("Message->","&Forward"),
@@ -324,11 +324,11 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
   connect( mForwardActionMenu, TQT_SIGNAL(activated()), this,
            TQT_SLOT(slotForwardInlineMsg()) );
   mForwardAttachedAction = new KAction( i18n("Message->Forward->","As &Attachment..."),
-                                        "mail_forward", 0, this,
+                                        "mail_forward", 0, TQT_TQOBJECT(this),
                                         TQT_SLOT(slotForwardAttachedMsg()), ac,
                                         "search_message_forward_as_attachment" );
   mForwardInlineAction = new KAction( i18n("&Inline..."),
-                                      "mail_forward", 0, this,
+                                      "mail_forward", 0, TQT_TQOBJECT(this),
                                       TQT_SLOT(slotForwardInlineMsg()), ac,
                                       "search_message_forward_inline" );
   if ( GlobalSettings::self()->forwardingInlineByDefault() ) {
@@ -340,32 +340,32 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
   }
 
   mForwardDigestAction = new KAction( i18n("Message->Forward->","As Di&gest..."),
-                                      "mail_forward", 0, this,
+                                      "mail_forward", 0, TQT_TQOBJECT(this),
                                       TQT_SLOT(slotForwardDigestMsg()), ac,
                                       "search_message_forward_as_digest" );
   mForwardActionMenu->insert( mForwardDigestAction );
   mRedirectAction = new KAction( i18n("Message->Forward->","&Redirect..."),
-                                      "mail_forward", 0, this,
+                                      "mail_forward", 0, TQT_TQOBJECT(this),
                                       TQT_SLOT(slotRedirectMsg()), ac,
                                       "search_message_forward_redirect" );
   mForwardActionMenu->insert( mRedirectAction );
-  mSaveAsAction = KStdAction::saveAs( this, TQT_SLOT(slotSaveMsg()), ac, "search_file_save_as" );
+  mSaveAsAction = KStdAction::saveAs( TQT_TQOBJECT(this), TQT_SLOT(slotSaveMsg()), ac, "search_file_save_as" );
   mSaveAtchAction = new KAction( i18n("Save Attachments..."), "attach", 0,
-                                 this, TQT_SLOT(slotSaveAttachments()), ac, "search_save_attachments" );
+                                 TQT_TQOBJECT(this), TQT_SLOT(slotSaveAttachments()), ac, "search_save_attachments" );
 
-  mPrintAction = KStdAction::print( this, TQT_SLOT(slotPrintMsg()), ac, "search_print" );
-  mClearAction = new KAction( i18n("Clear Selection"), 0, 0, this,
+  mPrintAction = KStdAction::print( TQT_TQOBJECT(this), TQT_SLOT(slotPrintMsg()), ac, "search_print" );
+  mClearAction = new KAction( i18n("Clear Selection"), 0, 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotClearSelection()), ac, "search_clear_selection" );
 
-  mCopyAction = KStdAction::copy( this, TQT_SLOT(slotCopyMsgs()), ac, "search_copy_messages" );
-  mCutAction = KStdAction::cut( this, TQT_SLOT(slotCutMsgs()), ac, "search_cut_messages" );
+  mCopyAction = KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT(slotCopyMsgs()), ac, "search_copy_messages" );
+  mCutAction = KStdAction::cut( TQT_TQOBJECT(this), TQT_SLOT(slotCutMsgs()), ac, "search_cut_messages" );
 
-  connect(mTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(updStatus()));
+  connect(mTimer, TQT_SIGNAL(timeout()), TQT_TQOBJECT(this), TQT_SLOT(updtqStatus()));
   connect(kmkernel->searchFolderMgr(), TQT_SIGNAL(folderInvalidated(KMFolder*)),
-          this, TQT_SLOT(folderInvalidated(KMFolder*)));
+          TQT_TQOBJECT(this), TQT_SLOT(folderInvalidated(KMFolder*)));
 
   connect(mCbxFolders, TQT_SIGNAL(folderChanged(KMFolder*)),
-          this, TQT_SLOT(slotFolderActivated()));
+          TQT_TQOBJECT(this), TQT_SLOT(slotFolderActivated()));
 
 }
 
@@ -400,7 +400,7 @@ void SearchWindow::setEnabledSearchButton(bool)
 }
 
 //-----------------------------------------------------------------------------
-void SearchWindow::updStatus(void)
+void SearchWindow::updtqStatus(void)
 {
     TQString genMsg, detailMsg, procMsg;
     int numMatches = 0, numProcessed = 0;
@@ -418,17 +418,17 @@ void SearchWindow::updStatus(void)
         if(!mStopped) {
             genMsg = i18n("Done.");
             detailMsg = i18n("%n match in %1", "%n matches in %1",
-                             numMatches).arg(procMsg);
+                             numMatches).tqarg(procMsg);
         } else {
             genMsg = i18n("Search canceled.");
             detailMsg = i18n("%n match so far in %1", "%n matches so far in %1",
-                             numMatches).arg(procMsg);
+                             numMatches).tqarg(procMsg);
         }
     } else {
         procMsg = i18n("%n message", "%n messages", numProcessed);
         genMsg = i18n("%n match", "%n matches", numMatches);
         detailMsg = i18n("Searching in %1. %2 searched so far")
-                    .arg(folderName).arg(procMsg);
+                    .tqarg(folderName).tqarg(procMsg);
     }
 
     mStatusBar->changeItem(genMsg, 0);
@@ -466,7 +466,7 @@ void SearchWindow::activateFolder(KMFolder *curFolder)
 //-----------------------------------------------------------------------------
 void SearchWindow::slotSearch()
 {
-    mLastFocus = focusWidget();
+    mLastFocus = tqfocusWidget();
     mBtnSearch->setFocus();     // set focus so we don't miss key event
 
     mStopped = false;
@@ -497,7 +497,7 @@ void SearchWindow::slotSearch()
       while ((folder = mgr->find(fullName))) {
         if (folder->storage()->inherits("KMFolderSearch"))
           break;
-        fullName = TQString("%1 %2").arg(baseName).arg(++count);
+        fullName = TQString("%1 %2").tqarg(baseName).tqarg(++count);
       }
 
       if (!folder)
@@ -508,17 +508,17 @@ void SearchWindow::slotSearch()
     }
     mFolder->stopSearch();
     disconnect(mFolder, TQT_SIGNAL(msgAdded(int)),
-            this, TQT_SLOT(slotAddMsg(int)));
-    disconnect(mFolder, TQT_SIGNAL(msgRemoved(KMFolder*, Q_UINT32)),
-            this, TQT_SLOT(slotRemoveMsg(KMFolder*, Q_UINT32)));
+            TQT_TQOBJECT(this), TQT_SLOT(slotAddMsg(int)));
+    disconnect(mFolder, TQT_SIGNAL(msgRemoved(KMFolder*, TQ_UINT32)),
+            TQT_TQOBJECT(this), TQT_SLOT(slotRemoveMsg(KMFolder*, TQ_UINT32)));
     connect(mFolder, TQT_SIGNAL(msgAdded(int)),
-            this, TQT_SLOT(slotAddMsg(int)));
-    connect(mFolder, TQT_SIGNAL(msgRemoved(KMFolder*, Q_UINT32)),
-            this, TQT_SLOT(slotRemoveMsg(KMFolder*, Q_UINT32)));
+            TQT_TQOBJECT(this), TQT_SLOT(slotAddMsg(int)));
+    connect(mFolder, TQT_SIGNAL(msgRemoved(KMFolder*, TQ_UINT32)),
+            TQT_TQOBJECT(this), TQT_SLOT(slotRemoveMsg(KMFolder*, TQ_UINT32)));
     mSearchFolderEdt->setEnabled(false);
     KMSearch *search = new KMSearch();
     connect(search, TQT_SIGNAL(finished(bool)),
-            this, TQT_SLOT(searchDone()));
+            TQT_TQOBJECT(this), TQT_SLOT(searchDone()));
     if (mChkbxAllFolders->isChecked()) {
         search->setRecursive(true);
     } else {
@@ -541,9 +541,9 @@ void SearchWindow::slotSearch()
 void SearchWindow::searchDone()
 {
     mTimer->stop();
-    updStatus();
+    updtqStatus();
 
-    TQTimer::singleShot(0, this, TQT_SLOT(enableGUI()));
+    TQTimer::singleShot(0, TQT_TQOBJECT(this), TQT_SLOT(enableGUI()));
     if(mLastFocus)
         mLastFocus->setFocus();
     if (mCloseRequested)
@@ -584,7 +584,7 @@ void SearchWindow::slotAddMsg(int idx)
         mFolder->unGetMsg(idx);
 }
 
-void SearchWindow::slotRemoveMsg(KMFolder *, Q_UINT32 serNum)
+void SearchWindow::slotRemoveMsg(KMFolder *, TQ_UINT32 serNum)
 {
     if (!mFolder)
         return;
@@ -623,7 +623,7 @@ void SearchWindow::closeEvent(TQCloseEvent *e)
       //Cancel search in progress by setting the search folder search to
       //the null search
       mFolder->setSearch(new KMSearch());
-      TQTimer::singleShot(0, this, TQT_SLOT(slotClose()));
+      TQTimer::singleShot(0, TQT_TQOBJECT(this), TQT_SLOT(slotClose()));
     } else {
       KDialogBase::closeEvent(e);
     }
@@ -677,7 +677,7 @@ void SearchWindow::folderInvalidated(KMFolder *folder)
         mLbxMatches->clear();
         if (mFolder->search())
             connect(mFolder->search(), TQT_SIGNAL(finished(bool)),
-                    this, TQT_SLOT(searchDone()));
+                    TQT_TQOBJECT(this), TQT_SLOT(searchDone()));
         mTimer->start(200);
         enableGUI();
     }
@@ -840,10 +840,10 @@ void SearchWindow::slotContextMenuRequested( TQListViewItem *lvi, const TQPoint
     mMenuToFolder.clear();
     TQPopupMenu *msgMoveMenu = new TQPopupMenu(menu);
     mKMMainWidget->folderTree()->folderToPopupMenu( KMFolderTree::MoveMessage,
-        this, &mMenuToFolder, msgMoveMenu );
+        TQT_TQOBJECT(this), &mMenuToFolder, msgMoveMenu );
     TQPopupMenu *msgCopyMenu = new TQPopupMenu(menu);
     mKMMainWidget->folderTree()->folderToPopupMenu( KMFolderTree::CopyMessage,
-        this, &mMenuToFolder, msgCopyMenu );
+        TQT_TQOBJECT(this), &mMenuToFolder, msgCopyMenu );
 
     // show most used actions
     mReplyAction->plug(menu);
@@ -948,13 +948,13 @@ void SearchWindow::slotPrintMsg()
 
 void SearchWindow::slotCopyMsgs()
 {
-  TQValueList<Q_UINT32> list = MessageCopyHelper::serNumListFromMsgList( selectedMessages() );
+  TQValueList<TQ_UINT32> list = MessageCopyHelper::serNumListFromMsgList( selectedMessages() );
   mKMMainWidget->headers()->setCopiedMessages( list, false );
 }
 
 void SearchWindow::slotCutMsgs()
 {
-  TQValueList<Q_UINT32> list = MessageCopyHelper::serNumListFromMsgList( selectedMessages() );
+  TQValueList<TQ_UINT32> list = MessageCopyHelper::serNumListFromMsgList( selectedMessages() );
   mKMMainWidget->headers()->setCopiedMessages( list, true );
 }
 
