@@ -261,7 +261,7 @@ void TemplateParser::processWithTemplate( const TQString &tmpl )
         } else if ( mDebug ) {
           KMessageBox::error( 0,
                               i18n( "Cannot insert content from file %1: %2" ).
-                              arg( path ).arg( file.errorString() ) );
+                              tqarg( path ).tqarg( file.errorString() ) );
         }
 
       } else if ( cmd.startsWith( "SYSTEM=" ) ) {
@@ -294,12 +294,12 @@ void TemplateParser::processWithTemplate( const TQString &tmpl )
         } else if ( mDebug ) {
           KMessageBox::error( 0,
                               i18n( "Cannot insert content from file %1: %2").
-                              arg( path ).arg(file.errorString() ));
+                              tqarg( path ).tqarg(file.errorString() ));
         }
 
       } else if ( cmd.startsWith( "QUOTEPIPE=" ) ) {
         // pipe message body throw command and insert it as quotation
-        kdDebug() << "Command: QUOTEPIPE=" << endl;
+        kdDebug() << "Command: TQUOTEPIPE=" << endl;
         TQString q;
         int len = parseQuotes( "QUOTEPIPE=", cmd, q );
         i += len;
@@ -312,7 +312,7 @@ void TemplateParser::processWithTemplate( const TQString &tmpl )
         }
 
       } else if ( cmd.startsWith( "QUOTE" ) ) {
-        kdDebug() << "Command: QUOTE" << endl;
+        kdDebug() << "Command: TQUOTE" << endl;
         i += strlen( "QUOTE" );
         if ( mOrigMsg ) {
           TQString quote = mOrigMsg->asQuotedString( "", mQuoteString, messageText( true ),
@@ -321,7 +321,7 @@ void TemplateParser::processWithTemplate( const TQString &tmpl )
         }
 
       } else if ( cmd.startsWith( "QHEADERS" ) ) {
-        kdDebug() << "Command: QHEADERS" << endl;
+        kdDebug() << "Command: TQHEADERS" << endl;
         i += strlen( "QHEADERS" );
         if ( mOrigMsg ) {
           TQString quote = mOrigMsg->asQuotedString( "", mQuoteString,
@@ -396,7 +396,7 @@ void TemplateParser::processWithTemplate( const TQString &tmpl )
         kdDebug() << "Command: OTEXTSIZE" << endl;
         i += strlen( "OTEXTSIZE" );
         if ( mOrigMsg ) {
-          TQString str = TQString( "%1" ).arg( mOrigMsg->body().length() );
+          TQString str = TQString( "%1" ).tqarg( mOrigMsg->body().length() );
           body.append( str );
         }
 
@@ -693,7 +693,7 @@ void TemplateParser::processWithTemplate( const TQString &tmpl )
       } else if ( cmd.startsWith( "DATEEN" ) ) {
         kdDebug() << "Command: DATEEN" << endl;
         i += strlen( "DATEEN" );
-        TQDateTime date = TQDateTime::currentDateTime();
+        TQDateTime date = TQDateTime::tqcurrentDateTime();
         KLocale locale( "C" );
         TQString str = locale.formatDate( date.date(), false );
         body.append( str );
@@ -701,28 +701,28 @@ void TemplateParser::processWithTemplate( const TQString &tmpl )
       } else if ( cmd.startsWith( "DATESHORT" ) ) {
         kdDebug() << "Command: DATESHORT" << endl;
         i += strlen( "DATESHORT" );
-        TQDateTime date = TQDateTime::currentDateTime();
+        TQDateTime date = TQDateTime::tqcurrentDateTime();
         TQString str = KGlobal::locale()->formatDate( date.date(), true );
         body.append( str );
 
       } else if ( cmd.startsWith( "DATE" ) ) {
         kdDebug() << "Command: DATE" << endl;
         i += strlen( "DATE" );
-        TQDateTime date = TQDateTime::currentDateTime();
+        TQDateTime date = TQDateTime::tqcurrentDateTime();
         TQString str = KGlobal::locale()->formatDate( date.date(), false );
         body.append( str );
 
       } else if ( cmd.startsWith( "DOW" ) ) {
         kdDebug() << "Command: DOW" << endl;
         i += strlen( "DOW" );
-        TQDateTime date = TQDateTime::currentDateTime();
+        TQDateTime date = TQDateTime::tqcurrentDateTime();
         TQString str = KGlobal::locale()->calendar()->weekDayName( date.date(), false );
         body.append( str );
 
       } else if ( cmd.startsWith( "TIMELONGEN" ) ) {
         kdDebug() << "Command: TIMELONGEN" << endl;
         i += strlen( "TIMELONGEN" );
-        TQDateTime date = TQDateTime::currentDateTime();
+        TQDateTime date = TQDateTime::tqcurrentDateTime();
         KLocale locale( "C");
         TQString str = locale.formatTime( date.time(), true );
         body.append( str );
@@ -730,14 +730,14 @@ void TemplateParser::processWithTemplate( const TQString &tmpl )
       } else if ( cmd.startsWith( "TIMELONG" ) ) {
         kdDebug() << "Command: TIMELONG" << endl;
         i += strlen( "TIMELONG" );
-        TQDateTime date = TQDateTime::currentDateTime();
+        TQDateTime date = TQDateTime::tqcurrentDateTime();
         TQString str = KGlobal::locale()->formatTime( date.time(), true );
         body.append( str );
 
       } else if ( cmd.startsWith( "TIME" ) ) {
         kdDebug() << "Command: TIME" << endl;
         i += strlen( "TIME" );
-        TQDateTime date = TQDateTime::currentDateTime();
+        TQDateTime date = TQDateTime::tqcurrentDateTime();
         TQString str = KGlobal::locale()->formatTime( date.time(), false );
         body.append( str );
 
@@ -967,7 +967,7 @@ void TemplateParser::addProcessedBodyToMessage( const TQString &body )
             DwParameter *nameParameter = new DwParameter;
             nameParameter->SetAttribute( "name" );
             nameParameter->SetValue( Util::dwString( KMMsgBase::encodeRFC2231StringAutoDetectCharset(
-                       i18n( "Attachment %1" ).arg( attachmentNumber ) ) ) );
+                       i18n( "Attachment %1" ).tqarg( attachmentNumber ) ) ) );
             ct.AddParameter( nameParameter );
           }
         }
@@ -1059,7 +1059,7 @@ TQString TemplateParser::findTemplate()
 
   TQString iid;
   if ( mIdentity ) {
-    iid = TQString("IDENTITY_%1").arg( mIdentity );	// templates ID for that identity
+    iid = TQString("IDENTITY_%1").tqarg( mIdentity );	// templates ID for that identity
   }
   else {
     iid = "IDENTITY_NO_IDENTITY"; // templates ID for no identity
@@ -1148,11 +1148,11 @@ TQString TemplateParser::pipe( const TQString &cmd, const TQString &buf )
             if ( mPipeErr.isEmpty() ) {
               KMessageBox::error( 0,
                                   i18n( "Pipe command exit with status %1: %2").
-                                  arg( mPipeRc ).arg( cmd ) );
+                                  tqarg( mPipeRc ).tqarg( cmd ) );
             } else {
               KMessageBox::detailedError( 0,
                                           i18n( "Pipe command exit with status %1: %2" ).
-                                          arg( mPipeRc ).arg( cmd ), mPipeErr );
+                                          tqarg( mPipeRc ).tqarg( cmd ), mPipeErr );
             }
           }
 
@@ -1163,11 +1163,11 @@ TQString TemplateParser::pipe( const TQString &cmd, const TQString &buf )
             if ( mPipeErr.isEmpty() ) {
               KMessageBox::error( 0,
                                   i18n( "Pipe command killed by signal %1: %2" ).
-                                  arg( -(mPipeRc) ).arg( cmd ) );
+                                  tqarg( -(mPipeRc) ).tqarg( cmd ) );
             } else {
               KMessageBox::detailedError( 0,
                                           i18n( "Pipe command killed by signal %1: %2" ).
-                                          arg( -(mPipeRc) ).arg( cmd ), mPipeErr );
+                                          tqarg( -(mPipeRc) ).tqarg( cmd ), mPipeErr );
             }
           }
         }
@@ -1179,7 +1179,7 @@ TQString TemplateParser::pipe( const TQString &cmd, const TQString &buf )
         if ( mDebug ) {
           KMessageBox::error( 0,
                               i18n( "Pipe command did not finish within %1 seconds: %2" ).
-                              arg( PipeTimeout ).arg( cmd ) );
+                              tqarg( PipeTimeout ).tqarg( cmd ) );
         }
       }
 
@@ -1190,11 +1190,11 @@ TQString TemplateParser::pipe( const TQString &cmd, const TQString &buf )
       if ( mDebug ) {
         if ( mPipeErr.isEmpty() ) {
           KMessageBox::error( 0,
-                              i18n( "Cannot write to process stdin: %1" ).arg( cmd ) );
+                              i18n( "Cannot write to process stdin: %1" ).tqarg( cmd ) );
         } else {
           KMessageBox::detailedError( 0,
                                       i18n( "Cannot write to process stdin: %1" ).
-                                      arg( cmd ), mPipeErr );
+                                      tqarg( cmd ), mPipeErr );
         }
       }
     }
@@ -1202,7 +1202,7 @@ TQString TemplateParser::pipe( const TQString &cmd, const TQString &buf )
   } else if ( mDebug ) {
     KMessageBox::error( 0,
                         i18n( "Cannot start pipe command from template: %1" ).
-                        arg( cmd ) );
+                        tqarg( cmd ) );
   }
 
   return mPipeOut;
