@@ -90,7 +90,7 @@ DockContainer::DockContainer(TQWidget *parent, TQWidget *win, int position, int
 
   m_ws=new TQWidgetStack(this);
 
-  m_ws->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding,TQSizePolicy::Expanding));
+  m_ws->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding,TQSizePolicy::Expanding));
 
   if ( (position==KDockWidget::DockLeft) || (position==KDockWidget::DockTop))
   {
@@ -119,7 +119,7 @@ DockContainer::~DockContainer()
     it = m_map.begin();
     KDockWidget *w=it.key();
       if (m_overlapButtons.contains(w)) {
-        (static_cast<KDockWidgetHeader*>(w->getHeader()->qt_cast("KDockWidgetHeader")))->removeButton(m_overlapButtons[w]);
+        (::tqqt_cast<KDockWidgetHeader*>(w->getHeader()))->removeButton(m_overlapButtons[w]);
         m_overlapButtons.remove(w);
       }
     m_map.remove(w);
@@ -148,8 +148,8 @@ void DockContainer::init()
   // try to restore splitter size
   if ( parentDockWidget() && parentDockWidget()->parent() )
   {
-    KDockSplitter *sp= static_cast<KDockSplitter*>(parentDockWidget()->
-                parent()->qt_cast("KDockSplitter"));
+    KDockSplitter *sp= ::tqqt_cast<KDockSplitter*>(parentDockWidget()->
+                parent());
     if ( sp )
       sp->setSeparatorPosX( m_separatorPos );
   }
@@ -184,12 +184,11 @@ void DockContainer::insertWidget (KDockWidget *dwdg, TQPixmap pixmap, const TQSt
     if (((KDockWidget*)parentWidget())->mayBeShow())
       ((KDockWidget*)parentWidget())->dockBack();
 
-    if (w->getHeader()->qt_cast("KDockWidgetHeader"))
+    if (::tqqt_cast<KDockWidgetHeader*>(w->getHeader()))
     {
       kdDebug(760)<<"*** KDockWidgetHeader has been found"<<endl;
 
-      KDockWidgetHeader *hdr=static_cast<KDockWidgetHeader*>(w->getHeader()->
-        qt_cast("KDockWidgetHeader"));
+      KDockWidgetHeader *hdr=::tqqt_cast<KDockWidgetHeader*>(w->getHeader());
 
       KDockButton_Private *btn = new KDockButton_Private( hdr, "OverlapButton" );
 
@@ -234,7 +233,7 @@ void DockContainer::insertWidget (KDockWidget *dwdg, TQPixmap pixmap, const TQSt
 
 bool DockContainer::eventFilter( TQObject *obj, TQEvent *event )
 {
-    if (obj==m_tb) {
+    if (TQT_BASE_OBJECT(obj)==TQT_BASE_OBJECT(m_tb)) {
 	if ( (event->type()==TQEvent::Resize)  && (m_ws->isHidden()) ) {
 		TQSize size=((TQResizeEvent*)event)->size();
 		  if (m_vertical)
@@ -247,7 +246,7 @@ bool DockContainer::eventFilter( TQObject *obj, TQEvent *event )
     switch ( event->type() ){
       case TQEvent::MouseButtonPress:
 	{
-		    KDockWidget * w=m_revMap[dynamic_cast<KMultiTabBarTab*>(obj)->id()];
+		    KDockWidget * w=m_revMap[tqt_dynamic_cast<KMultiTabBarTab*>(obj)->id()];
 		    if (!w)  {
 			kdDebug()<<"NoWidget"<<endl;
 			break;
@@ -256,14 +255,13 @@ bool DockContainer::eventFilter( TQObject *obj, TQEvent *event )
 				kdDebug()<<"NO HEADER"<<endl;
 				break;
 			}
-		      KDockWidgetHeader *hdr=static_cast<KDockWidgetHeader*>(w->getHeader()->
-	        	qt_cast("KDockWidgetHeader"));
+		      KDockWidgetHeader *hdr=::tqqt_cast<KDockWidgetHeader*>(w->getHeader());
 			if (!hdr) {
 				kdDebug()<<"Wrong header type in DockContainer::eventFilter"<<endl;
 				break;
 			}
 			m_dockManager=w->dockManager();
-			m_dragPanel=hdr->dragPanel();
+			m_dragPanel=TQT_TQOBJECT(hdr->dragPanel());
 			if (m_dragPanel) m_movingState=WaitingForMoveStart;
 			delete m_startEvent;
 			m_startEvent=new TQMouseEvent(* ((TQMouseEvent*)event));
@@ -281,7 +279,7 @@ bool DockContainer::eventFilter( TQObject *obj, TQEvent *event )
 		if (m_movingState==WaitingForMoveStart) {
 			TQPoint p( ((TQMouseEvent*)event)->pos() - m_startEvent->pos() );
 		        if( p.manhattanLength() > KGlobalSettings::dndEventDelay()) {
-				m_dockManager->eventFilter(m_dragPanel,m_startEvent);
+				m_dockManager->eventFilter(m_dragPanel,TQT_TQEVENT(m_startEvent));
 				m_dockManager->eventFilter(m_dragPanel,event);
 				m_movingState=Moving;
 			}
@@ -309,7 +307,7 @@ void DockContainer::showWidget(KDockWidget *w) {
 
 void DockContainer::changeOverlapMode()
 {
-  const KDockButton_Private *btn=dynamic_cast<const KDockButton_Private*>(sender());
+  const KDockButton_Private *btn=tqt_dynamic_cast<const KDockButton_Private*>(sender());
 
   kdDebug(760)<<"DockContainer::changeOverlapMode: button=="<<btn<<endl;
 
@@ -357,7 +355,7 @@ void DockContainer::removeWidget(KDockWidget* dwdg)
   m_map.remove(w);
   m_revMap.remove(id);
   if (m_overlapButtons.contains(w)) {
-    (static_cast<KDockWidgetHeader*>(w->getHeader()->qt_cast("KDockWidgetHeader")))->removeButton(m_overlapButtons[w]);
+    (::tqqt_cast<KDockWidgetHeader*>(w->getHeader()))->removeButton(m_overlapButtons[w]);
     m_overlapButtons.remove(w);
   }
   KDockContainer::removeWidget(w);
@@ -405,7 +403,7 @@ void DockContainer::tabClicked(int t)
     }
     m_ws->raiseWidget(t);
     if (m_ws->widget(t)) {
-      KDockWidget *tmpDw=static_cast<KDockWidget*>(m_ws->widget(t)->qt_cast("KDockWidget"));
+      KDockWidget *tmpDw=::tqqt_cast<KDockWidget*>(m_ws->widget(t));
       if (tmpDw) {
         if (tmpDw->getWidget()) tmpDw->getWidget()->setFocus();
       } else kdDebug(760)<<"Something really weird is going on"<<endl;
@@ -422,8 +420,8 @@ void DockContainer::tabClicked(int t)
        // try save splitter position
       if ( parentDockWidget() && parentDockWidget()->parent() )
       {
-        KDockSplitter *sp= static_cast<KDockSplitter*>(parentDockWidget()->
-                    parent()->qt_cast("KDockSplitter"));
+        KDockSplitter *sp= ::tqqt_cast<KDockSplitter*>(parentDockWidget()->
+                    parent());
         if ( sp )
           m_separatorPos = sp->separatorPos();
       }
@@ -475,8 +473,8 @@ void DockContainer::save(KConfig* cfg,const TQString& group_or_prefix)
   // try to save the splitter position
   if ( parentDockWidget() && parentDockWidget()->parent() )
   {
-    KDockSplitter *sp= static_cast<KDockSplitter*>(parentDockWidget()->
-                parent()->qt_cast("KDockSplitter"));
+    KDockSplitter *sp= ::tqqt_cast<KDockSplitter*>(parentDockWidget()->
+                parent());
     if ( sp )
       cfg->writeEntry( "separatorPosition", m_separatorPos );
   }
@@ -614,7 +612,7 @@ void DockContainer::toggle() {
     if (m_tb->isTabRaised(oldtab)) {
         m_tb->setTab(oldtab,false);
             tabClicked(oldtab);
-        //    KMDI::MainWindow *mainFrm = dynamic_cast<KMDI::MainWindow*>(m_mainWin);
+        //    KMDI::MainWindow *mainFrm = tqt_dynamic_cast<KMDI::MainWindow*>(m_mainWin);
         //     if (mainFrm && mainFrm->activeWindow() ) // TODO
          //           mainFrm->activeWindow()->setFocus();
 
@@ -635,7 +633,7 @@ void DockContainer::prevToolView() {
     if (pos==-1) return;
     pos--;
     if (pos<0) pos=tabs->count()-1;
-    KMultiTabBarTab *tab=tabs->at(pos);
+    KMultiTabBarTab *tab=tabs->tqat(pos);
     if (!tab) return; //can never happen here, but who knows
     m_tb->setTab(tab->id(),true);
     tabClicked(tab->id());
@@ -647,7 +645,7 @@ void DockContainer::nextToolView() {
     if (pos==-1) return;
     pos++;
     if (pos>=(int)tabs->count()) pos=0;
-    KMultiTabBarTab *tab=tabs->at(pos);
+    KMultiTabBarTab *tab=tabs->tqat(pos);
     if (!tab) return; //can never happen here, but who knows
     m_tb->setTab(tab->id(),true);
     tabClicked(tab->id());
