@@ -90,13 +90,13 @@ kmidClient::kmidClient(TQWidget *parent, KActionCollection *ac, const char *name
     //	currentsl=slman->getCollection(activecollection);
     itsme=0;
     m_kMid.pid=0;
-    timebar = new TQSlider(0,240000,30000,60000,TQSlider::Horizontal, this);
+    timebar = new TQSlider(0,240000,30000,60000,Qt::Horizontal, this);
     timebar->setSteps(30000,60000);
     timebar->setValue(0);
     connect (timebar,TQT_SIGNAL(valueChanged(int)),this,TQT_SLOT(slotSeek(int)));
 
     timetags = new QSliderTime(timebar,this);
-    timetags->setMinimumSize(timetags->sizeHint());
+    timetags->setMinimumSize(timetags->tqsizeHint());
 
     qlabelTempo= new TQLabel(i18n("Tempo:"), this,"tempolabel",
                             TQLabel::NoFrame);
@@ -108,7 +108,7 @@ kmidClient::kmidClient(TQWidget *parent, KActionCollection *ac, const char *name
     tempoLCD->setRange(3,999);
     tempoLCD->setDefaultValue(120);
     tempoLCD->setUserSetDefaultValue(true);
-    tempoLCD->setMinimumSize(tempoLCD->sizeHint());
+    tempoLCD->setMinimumSize(tempoLCD->tqsizeHint());
     connect(tempoLCD,TQT_SIGNAL(valueChanged(double)),this,TQT_SLOT(slotSetTempo(double)));
 
     comboSongs = new TQComboBox(FALSE, this,"Songs");
@@ -125,7 +125,7 @@ kmidClient::kmidClient(TQWidget *parent, KActionCollection *ac, const char *name
     rhythmview->setMaximumHeight(7);
     rhythmview->setMinimumHeight(7);
 
-    volumebar = new TQSlider(0,200,10,100,TQSlider::Vertical, this );
+    volumebar = new TQSlider(0,200,10,100,Qt::Vertical, this );
     volumebar->setSteps(10,20);
     volumebar->setValue(100);
     volumebar->setTickmarks(TQSlider::NoMarks);
@@ -290,10 +290,10 @@ int kmidClient::openFile(const char *filename)
         switch (r)
         {
         case (-1) : errormsg =
-                            i18n("The file %1 does not exist or cannot be opened.").arg(filename);
+                            i18n("The file %1 does not exist or cannot be opened.").tqarg(filename);
         break;
         case (-2) : errormsg =
-                            i18n("The file %1 is not a MIDI file.").arg(filename);break;
+                            i18n("The file %1 is not a MIDI file.").tqarg(filename);break;
         case (-3) : errormsg =
                             i18n("Ticks per quarter note is negative. Please send this file to larrosa@kde.org");break;
         case (-4) : errormsg =
@@ -301,7 +301,7 @@ int kmidClient::openFile(const char *filename)
         case (-5) : errormsg =
                             i18n("This file is corrupted or not well built.");break;
         case (-6) : errormsg =
-                            i18n("%1 is not a regular file.").arg(filename);break;
+                            i18n("%1 is not a regular file.").tqarg(filename);break;
         default :   errormsg = i18n("Unknown error message");break;
         }
         KMessageBox::error(this, errormsg);
@@ -310,10 +310,10 @@ int kmidClient::openFile(const char *filename)
         midifile_opened=0L;
         timebar->setRange(0,240000);
         timebar->setValue(0);
-        timetags->repaint(TRUE);
+        timetags->tqrepaint(TRUE);
         kdispt->ClearEv();
-        kdispt->repaint(TRUE);
-        topLevelWidget()->setCaption("KMid");
+        kdispt->tqrepaint(TRUE);
+        tqtopLevelWidget()->setCaption("KMid");
 
         return -1;
     }
@@ -327,7 +327,7 @@ int kmidClient::openFile(const char *filename)
     //    noteArray=player->parseNotes();
     noteArray=player->noteArray();
     timebar->setRange(0,(int)(player->information()->millisecsTotal));
-    timetags->repaint(TRUE);
+    timetags->tqrepaint(TRUE);
     kdispt->ClearEv();
     spev=player->specialEvents();
     while (spev)
@@ -343,7 +343,7 @@ int kmidClient::openFile(const char *filename)
     kdispt->CursorToHome();
 //    kdispt->updateScrollBars();
     emit mustRechooseTextEvent();
-    kdispt->repaint(TRUE);
+    kdispt->tqrepaint(TRUE);
     tempoLCD->display(tempoToMetronomeTempo(m_kMid.pctl->tempo));
     currentTempo=tempoLCD->getValue();
     tempoLCD->setDefaultValue(tempoToMetronomeTempo(m_kMid.pctl->tempo)*m_kMid.pctl->ratioTempo);
@@ -353,7 +353,7 @@ int kmidClient::openFile(const char *filename)
     char *capt=new char[strlen(fn)+20];
     sprintf(capt,"KMid - %s",fn);
     delete fn;
-    topLevelWidget()->setCaption(capt);
+    tqtopLevelWidget()->setCaption(capt);
     delete capt;
 
     timebar->setValue(0);
@@ -1129,7 +1129,7 @@ void kmidClient::repaintText(int type)
 {
     kdispt->ChangeTypeOfTextEvents(type);
     typeoftextevents=type;
-    kdispt->repaint(TRUE);
+    kdispt->tqrepaint(TRUE);
 }
 
 int kmidClient::ChooseTypeOfTextEvents(void)
@@ -1265,12 +1265,12 @@ void kmidClient::slotSelectSong(int i)
         player->removeSong();
         timebar->setRange(0,240000);
         timebar->setValue(0);
-        timetags->repaint(TRUE);
+        timetags->tqrepaint(TRUE);
         kdispt->ClearEv();
-        kdispt->repaint(TRUE);
+        kdispt->tqrepaint(TRUE);
         comboSongs->clear();
-        comboSongs->repaint(TRUE);
-        topLevelWidget()->setCaption("KMid");
+        comboSongs->tqrepaint(TRUE);
+        tqtopLevelWidget()->setCaption("KMid");
         return;
     }
 
@@ -1487,7 +1487,7 @@ void kmidClient::slotSetTempo(double value)
 
     timebar->setRange(0,(int)(player->information()->millisecsTotal));
     timebar->setValue(pausedatmillisec);
-    timetags->repaint(TRUE);
+    timetags->tqrepaint(TRUE);
 
     kdispt->ClearEv(false);
 
@@ -1522,9 +1522,9 @@ void kmidClient::downloadFinished(KIO::Job *)
     kapp->exit_loop();
 }
 
-TQSize kmidClient::sizeHint() const
+TQSize kmidClient::tqsizeHint() const
 {
-    TQSize sh = TQWidget::sizeHint();
+    TQSize sh = TQWidget::tqsizeHint();
     return sh.expandedTo(TQSize(560,420));
 }
 
@@ -1599,7 +1599,7 @@ void kmidClient::setPlayListMode(int i)
 void kmidClient::slotSelectEncoding(int i)
 {
   if (i == 0)
-     kdispt->setLyricsEncoding(TQString::null); // Default
+     kdispt->setLyricsEncoding(TQString()); // Default
   else
      kdispt->setLyricsEncoding(KGlobal::charsets()->encodingForName(comboEncodings->text(i)));
 }
