@@ -115,7 +115,7 @@ Mixer_ALSA::open()
 
     // Card information
     if ((unsigned)m_devnum > 31) m_devnum = -1;
-    devName = m_devnum == -1 ? "default" : TQString("hw:%1").arg(m_devnum);
+    devName = m_devnum == -1 ? "default" : TQString("hw:%1").tqarg(m_devnum);
 
     TQString probeMessage;
 
@@ -507,7 +507,7 @@ bool Mixer_ALSA::prepareUpdateFromHW()
 
     // Poll on fds with 10ms timeout
     // Hint: alsamixer has an infinite timeout, but we cannot do this because we would block
-    // the X11 event handling (Qt event loop) with this.
+    // the X11 event handling (TQt event loop) with this.
     //kdDebug(67100) << "Mixer_ALSA::prepareUpdate() 3\n";
     int finished = poll(m_fds, m_count, 10);
     //kdDebug(67100) << "Mixer_ALSA::prepareUpdate() 4\n";
@@ -795,7 +795,7 @@ Mixer_ALSA::writeVolumeToHW( int devnum, Volume& volume )
 	return 0;
 }
 
-QString
+TQString
 Mixer_ALSA::errorText( int mixer_error )
 {
 	TQString l_s_errmsg;
@@ -817,7 +817,7 @@ Mixer_ALSA::errorText( int mixer_error )
 }
 
 
-QString
+TQString
 ALSA_getDriverName()
 {
 	return "ALSA";
