@@ -10,6 +10,7 @@ class Mixer;
 class ViewSliders : public ViewBase
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     ViewSliders(TQWidget* parent, const char* name, const TQString & caption, Mixer* mixer, ViewBase::ViewFlags vflags);
     ~ViewSliders();
@@ -20,7 +21,7 @@ public:
     virtual TQWidget* add(MixDevice *mdw);
     virtual void constructionFinished();
 
-    TQSize sizeHint() const;
+    TQSize tqsizeHint() const;
 
 public slots:
     virtual void refreshVolumeLevels();
