@@ -13,6 +13,7 @@ class Mixer;
 class ViewSurround : public ViewBase
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     ViewSurround(TQWidget* parent, const char* name, const TQString & caption, Mixer* mixer, ViewBase::ViewFlags vflags);
     ~ViewSurround();
@@ -23,7 +24,7 @@ public:
     virtual TQWidget* add(MixDevice *mdw);
     virtual void constructionFinished();
 
-    TQSize sizeHint() const;
+    TQSize tqsizeHint() const;
 
 public slots:
     virtual void refreshVolumeLevels();
