@@ -10,6 +10,7 @@ class Mixer;
 class ViewSwitches : public ViewBase
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     ViewSwitches(TQWidget* parent, const char* name, const TQString & caption, Mixer* mixer, ViewBase::ViewFlags vflags);
     ~ViewSwitches();
@@ -21,7 +22,7 @@ public:
     virtual void constructionFinished();
     virtual void configurationUpdate();
 
-    TQSize sizeHint() const;
+    TQSize tqsizeHint() const;
 
 public slots:
     virtual void refreshVolumeLevels();
