@@ -48,7 +48,7 @@
 #define GNOKII_CHECK_ERROR(error) \
 	do { \
 		if (error) \
-			PRINT_DEBUG << TQString("ERROR %1: %2\n").arg(error).arg(gn_error_print(error));\
+			PRINT_DEBUG << TQString("ERROR %1: %2\n").tqarg(error).tqarg(gn_error_print(error));\
 	} while (0)
 
 
@@ -74,16 +74,16 @@ static gn_calnote_list calnote_list;
 
 
 /**
- *  The KDE gnokii mobile device driver.
+ *  The KDE gnokii mobile tqdevice driver.
  */
 
 KMobileGnokii::KMobileGnokii(TQObject *obj, const char *name, const TQStringList &args )
 	: KMobileDevice(obj, name, args)
 {
-  // set initial device info
+  // set initial tqdevice info
   setClassType( Phone );
-  m_deviceName = i18n("Mobile Phone accessed via GNOKII");
-  m_deviceRevision = "";
+  m_tqdeviceName = i18n("Mobile Phone accessed via GNOKII");
+  m_tqdeviceRevision = "";
   m_connectionName = "/dev/ircomm0";
   setCapabilities( hasAddressBook | hasNotes );
 
@@ -103,8 +103,8 @@ KMobileGnokii::KMobileGnokii(TQObject *obj, const char *name, const TQStringList
 	m_baud = "9600";
   }
 
-  PRINT_DEBUG << TQString("Using GNOKII configuration: %1 %2 %3 %4\n").arg(m_modelnr)
-		.arg(m_connection).arg(m_port).arg(m_baud);
+  PRINT_DEBUG << TQString("Using GNOKII configuration: %1 %2 %3 %4\n").tqarg(m_modelnr)
+		.tqarg(m_connection).tqarg(m_port).tqarg(m_baud);
 
   saveDeviceConfiguration();
   saveGnokiiConfiguration();
@@ -148,7 +148,7 @@ bool KMobileGnokii::setGnokiiStateMachine()
 {
   // set the state machine to our configuration
   qstrncpy( state.config.model, m_modelnr.utf8(), sizeof(state.config.model)-1 );
-  qstrncpy( state.config.port_device, m_port.utf8(), sizeof(state.config.port_device)-1 );
+  qstrncpy( state.config.port_tqdevice, m_port.utf8(), sizeof(state.config.port_tqdevice)-1 );
   state.config.connection_type = connectionToValue(m_connection);
   state.config.serial_baudrate = m_baud.toUInt();
   return true;
@@ -206,7 +206,7 @@ bool KMobileGnokii::loadDeviceConfiguration()
 static void busterminate(void)
 {
 	gn_sm_functions(GN_OP_Terminate, NULL, &state);
-	if (lockfile) gn_device_unlock(lockfile);
+	if (lockfile) gn_tqdevice_unlock(lockfile);
 }
 
 static TQString businit(void)
@@ -222,7 +222,7 @@ static TQString businit(void)
 	aux = gn_cfg_get(gn_cfg_info, "global", "use_locking");
 	// Defaults to 'no'
 	if (aux && !strcmp(aux, "yes")) {
-		lockfile = gn_device_lock(state.config.port_device);
+		lockfile = gn_tqdevice_lock(state.config.port_tqdevice);
 		if (lockfile == NULL) {
 			return i18n("Lock file error.\n "
 			"Please exit all other running instances of gnokii and try again.");
@@ -237,7 +237,7 @@ static TQString businit(void)
 	state.config.require_dcd = old_dcd;
 	if (error != GN_ERR_NONE) {
 		busterminate();
-		return i18n("Mobile phone interface initialization failed:\n%1").arg(gn_error_print(error));
+		return i18n("Mobile phone interface initialization failed:\n%1").tqarg(gn_error_print(error));
 	}
 
 	// model
@@ -265,11 +265,11 @@ static TQString businit(void)
 	data.imei = NULL;
 
 	GNOKII_DEBUG( TQString("Found mobile phone: Model: %1, Revision: %2, IMEI: %3\n")
-				.arg(model).arg(revision).arg(imei) ); 
+				.tqarg(model).tqarg(revision).tqarg(imei) ); 
 
-	PhoneProductId = TQString("%1-%2-%3-%4").arg(APP).arg(model).arg(revision).arg(imei);
+	PhoneProductId = TQString("%1-%2-%3-%4").tqarg(APP).tqarg(model).tqarg(revision).tqarg(imei);
 
-	return TQString::null;
+	return TQString();
 }
 
 
@@ -282,7 +282,7 @@ static gn_error read_phone_memstat( gn_memory_type memtype, gn_memory_status *me
 	memset(memstat, 0, sizeof(*memstat));
 	memstat->memory_type = memtype;
 	data.memory_status = memstat;
-	error = gn_sm_functions(GN_OP_GetMemoryStatus, &data, &state);
+	error = gn_sm_functions(GN_OP_GetMemorytqStatus, &data, &state);
 	GNOKII_CHECK_ERROR(error);
 	if (error != GN_ERR_NONE) {
 		switch (memtype) {
@@ -299,7 +299,7 @@ static gn_error read_phone_memstat( gn_memory_type memtype, gn_memory_status *me
 		}
 	}
 	GNOKII_DEBUG( TQString("\n\nMobile phone memory status: Type: %1, used=%2, free=%3, total=%4\n\n")
-					.arg(memtype).arg(memstat->used).arg(memstat->free).arg(memstat->used+memstat->free) );
+					.tqarg(memtype).tqarg(memstat->used).tqarg(memstat->free).tqarg(memstat->used+memstat->free) );
 	return error;
 }
 
@@ -372,8 +372,8 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt
   if (error != GN_ERR_NONE)
       return error;
 
-  GNOKII_DEBUG(TQString("%1: %2, num=%3, location=%4, group=%5, count=%6\n").arg(index).arg(entry.name)
-	.arg(entry.number).arg(entry.location).arg(entry.caller_group).arg(entry.subentries_count));
+  GNOKII_DEBUG(TQString("%1: %2, num=%3, location=%4, group=%5, count=%6\n").tqarg(index).tqarg(entry.name)
+	.tqarg(entry.number).tqarg(entry.location).tqarg(entry.caller_group).tqarg(entry.subentries_count));
 
   // try to split Name into FamilyName and GivenName
   s = TQString(entry.name).simplifyWhiteSpace();
@@ -395,7 +395,7 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt
   }
 
   a->insertCustom(APP, "X_GSM_CALLERGROUP", s.setNum(entry.caller_group));
-  a->insertCustom(APP, "X_GSM_STORE_AT", TQString("%1_%2").arg(GN_MT_ME).arg(entry.location));
+  a->insertCustom(APP, "X_GSM_STORE_AT", TQString("%1_%2").tqarg(GN_MT_ME).tqarg(entry.location));
 
   // set ProductId
   a->setProductId(PhoneProductId);
@@ -403,11 +403,11 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt
   // evaluate timestamp (ignore timezone)
   TQDateTime datetime;
   if (entry.date.year<1998)
-	datetime = TQDateTime::currentDateTime();
+	datetime = TQDateTime::tqcurrentDateTime();
   else
 	datetime = TQDateTime( TQDate(entry.date.year, entry.date.month, entry.date.day), 
 			  TQTime(entry.date.hour, entry.date.minute, entry.date.second) );
-  GNOKII_DEBUG(TQString(" date=%1\n").arg(datetime.toString()));
+  GNOKII_DEBUG(TQString(" date=%1\n").tqarg(datetime.toString()));
   a->setRevision(datetime);
 
   if (!entry.subentries_count)
@@ -418,8 +418,8 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt
 	 for (int n=0; n<entry.subentries_count; n++) {
 		TQString s = TQString(entry.subentries[n].data.number).simplifyWhiteSpace();
 		GNOKII_DEBUG(TQString(" Subentry#%1, entry_type=%2, number_type=%3, number=%4\n")
-			.arg(n).arg(entry.subentries[n].entry_type)
-			.arg(entry.subentries[n].number_type).arg(s));
+			.tqarg(n).tqarg(entry.subentries[n].entry_type)
+			.tqarg(entry.subentries[n].number_type).tqarg(s));
 		if (s.isEmpty())
 			continue;
 		switch(entry.subentries[n].entry_type) {
@@ -478,7 +478,7 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt
 				break;
 		   default:
 				GNOKII_DEBUG(TQString(" Not handled id=%1, entry=%2\n")
-					.arg(entry.subentries[n].entry_type).arg(s));
+					.tqarg(entry.subentries[n].entry_type).tqarg(s));
 				break;
 		  } // switch()
 	} // for(subentry)
@@ -493,7 +493,7 @@ static gn_error read_phone_entry_highlevel( int index, const gn_memory_type memt
 
 
 
-// connect the device and ask user to turn device on (if necessary)
+// connect the tqdevice and ask user to turn tqdevice on (if necessary)
 bool KMobileGnokii::connectDevice(TQWidget * /*parent*/)
 {
   if (connected())
@@ -501,18 +501,18 @@ bool KMobileGnokii::connectDevice(TQWidget * /*parent*/)
 
   TQString err = businit();
   m_connected = err.isEmpty();
-  PRINT_DEBUG << TQString("connectDevice() : %1\n").arg(m_connected ? "Ok" : err);
+  PRINT_DEBUG << TQString("connectDevice() : %1\n").tqarg(m_connected ? "Ok" : err);
   return m_connected;
 }
 
-// disconnect the device and return true, if sucessful
+// disconnect the tqdevice and return true, if sucessful
 bool KMobileGnokii::disconnectDevice(TQWidget * /*parent*/)
 {
   if (!connected())
 	return true;
   busterminate();
   m_connected = false;
-  PRINT_DEBUG << TQString("disconnectDevice() : %1\n").arg("done");
+  PRINT_DEBUG << TQString("disconnectDevice() : %1\n").tqarg("done");
   return true;
 }
 
@@ -545,9 +545,9 @@ TQString KMobileGnokii::iconFileName() const
 
 // return a unique ID, e.g. the IMEI number of phones, or a serial number
 // this String is used to have a unique identification for syncronisation.
-TQString KMobileGnokii::deviceUniqueID()
+TQString KMobileGnokii::tqdeviceUniqueID()
 { 
-  return TQString("GNOKII-IMEI-%1").arg(TQString::fromLocal8Bit(imei));
+  return TQString("GNOKII-IMEI-%1").tqarg(TQString::fromLocal8Bit(imei));
 }
 
 
@@ -587,7 +587,7 @@ int KMobileGnokii::numAddresses()
 
 int KMobileGnokii::readAddress( int index, KABC::Addressee &addr )
 {
-  PRINT_DEBUG << TQString("############   GET ADDRESS #%1\n").arg(index);
+  PRINT_DEBUG << TQString("############   GET ADDRESS #%1\n").tqarg(index);
   // index is zero-based, but in gnokii the first address starts at 1
   if (index<0 || index>=numAddresses())
     return KIO::ERR_DOES_NOT_EXIST;
@@ -609,7 +609,7 @@ int KMobileGnokii::readAddress( int index, KABC::Addressee &addr )
 
 int KMobileGnokii::storeAddress( int, const KABC::Addressee &, bool )
 {
-  /* XXX: this is a read-only device */
+  /* XXX: this is a read-only tqdevice */
   return KIO::ERR_WRITE_ACCESS_DENIED;
 }
 
@@ -619,7 +619,7 @@ int KMobileGnokii::storeAddress( int, const KABC::Addressee &, bool )
  * Calendar support                                                               *
  **********************************************************************************/
 
-static void QDateTime_2_timestamp( const TQDateTime &qdt, gn_timestamp &ts )
+static void TQDateTime_2_timestamp( const TQDateTime &qdt, gn_timestamp &ts )
 {
   ts.year = qdt.date().year();
   ts.month = qdt.date().month();
@@ -630,7 +630,7 @@ static void QDateTime_2_timestamp( const TQDateTime &qdt, gn_timestamp &ts )
   ts.timezone = 0;
 }
 
-static TQDateTime timestamp_2_QDateTime( const gn_timestamp &ts )
+static TQDateTime timestamp_2_TQDateTime( const gn_timestamp &ts )
 {
   return TQDateTime(	TQDate(ts.year, ts.month, ts.day),
 			TQTime(ts.hour, ts.minute, ts.second)    );
@@ -700,7 +700,7 @@ int KMobileGnokii::readCalendarEntry( int index, KCal::Event &event )
 
   print_calnote( entry );
 
-  TQDateTime dt_start = timestamp_2_QDateTime(entry.time);
+  TQDateTime dt_start = timestamp_2_TQDateTime(entry.time);
   TQDateTime dt_end = dt_start.addSecs( 60*60 ); // XXX: assume one hour
   event.setDtStart( dt_start );
   event.setDtEnd( dt_end );
@@ -727,7 +727,7 @@ int KMobileGnokii::readCalendarEntry( int index, KCal::Event &event )
 
   // alarm:
   if (entry.alarm.enabled) {
-    TQDateTime at = timestamp_2_QDateTime(entry.alarm.timestamp);
+    TQDateTime at = timestamp_2_TQDateTime(entry.alarm.timestamp);
     if (at.isValid() && dt_start.isValid()) {
       int seconds = abs(at.secsTo(dt_start));
       seconds %= 60*60*24; /* max. 1 day in advance... */
@@ -779,7 +779,7 @@ int KMobileGnokii::storeCalendarEntry( int index, const KCal::Event &event )
   error = gn_sm_functions(GN_OP_GetCalendarNote, &data, &state);
   // GNOKII_CHECK_ERROR(error);
 
-  QDateTime_2_timestamp( event.dtStart(), entry.time );
+  TQDateTime_2_timestamp( event.dtStart(), entry.time );
   strncpy(entry.text, event.summary().utf8(), sizeof(entry.text)-1);
 
   // type:
@@ -802,12 +802,12 @@ int KMobileGnokii::storeCalendarEntry( int index, const KCal::Event &event )
 	if (eventalarm) {
 		if (eventalarm->hasTime()) {
 
-		   QDateTime_2_timestamp( eventalarm->time(), entry.alarm.timestamp );
+		   TQDateTime_2_timestamp( eventalarm->time(), entry.alarm.timestamp );
 		} else
 		if (eventalarm->hasStartOffset()) {
 		   TQDateTime dt = event.dtStart();
 		   dt = dt.addSecs(-eventalarm->startOffset().asSeconds());
-		   QDateTime_2_timestamp( dt, entry.alarm.timestamp );
+		   TQDateTime_2_timestamp( dt, entry.alarm.timestamp );
 		}
 	}
   }
@@ -870,8 +870,8 @@ int KMobileGnokii::readNote( int index, TQString &note )
 	"DeviceClassName: %3\n"
 	"Device Driver  : %4\n"
 	"Device Revision: %5\n")
-	.arg(index).arg(index)
-	.arg(deviceClassName()).arg(deviceName()).arg(revision()); 
+	.tqarg(index).tqarg(index)
+	.tqarg(tqdeviceClassName()).tqarg(tqdeviceName()).tqarg(revision()); 
   return 0;
 }
 
