@@ -37,20 +37,20 @@
 
 class KConfig;
 
-#define KMOBILE_MIMETYPE_DEVICE			"kdedevice/mobiledevice"
-#define KMOBILE_MIMETYPE_DEVICE_KONQUEROR(name) TQString("kdedevice/kmobile_%1").arg(name)
+#define KMOBILE_MIMETYPE_DEVICE			"kdetqdevice/mobiletqdevice"
+#define KMOBILE_MIMETYPE_DEVICE_KONTQUEROR(name) TQString("kdetqdevice/kmobile_%1").tqarg(name)
 #define KMOBILE_MIMETYPE_INODE			"inode/"
 #define KMOBILE_ICON_UNKNOWN			"mobile_unknown"
 
 /**
- * @short Represents the base class for dynamically loaded mobile device drivers.
+ * @short Represents the base class for dynamically loaded mobile tqdevice drivers.
  *
- * KMobileDevice is the base class for all hardware device drivers.
+ * KMobileDevice is the base class for all hardware tqdevice drivers.
  * Every derived class has to add additional functionality.
  *
  * For a KMobileSomeDevice driver you have to write the following code:
  * <pre>
- * K_EXPORT_COMPONENT_FACTORY( libkmobile_somedevice, KMobileSomeDevice() );
+ * K_EXPORT_COMPONENT_FACTORY( libkmobile_sometqdevice, KMobileSomeDevice() );
  * TQObject *KMobileSomeDevice::createObject( TQObject *parent, const char *name,
  *      const char *, const TQStringList &args )
  * {
@@ -64,7 +64,8 @@ class KConfig;
 
 class KDE_EXPORT KMobileDevice : public KLibFactory
 {
-Q_OBJECT
+    Q_OBJECT
+    TQ_OBJECT
     friend class KMobileView;
 
 public:
@@ -94,34 +95,34 @@ public:
     virtual bool disconnectDevice( TQWidget *parent = 0 ) = 0;
 
     /**
-     * Returns true, if the device is currently connected and the link is online.
+     * Returns true, if the tqdevice is currently connected and the link is online.
      */
     virtual bool connected();
 
     /**
-     * Returns the classname, to which the device belongs. Examples are e.g.
+     * Returns the classname, to which the tqdevice belongs. Examples are e.g.
      *  "Nokia mobile phone", "MP3 Player", "Handspring Organizer"
      */
-    virtual TQString deviceClassName() const;
+    virtual TQString tqdeviceClassName() const;
 
     /**
-     * Returns the real devices name, e.g. "Nokia 6310" or "Rio MP3 Player"
+     * Returns the real tqdevices name, e.g. "Nokia 6310" or "Rio MP3 Player"
      */
-    virtual TQString deviceName() const;
+    virtual TQString tqdeviceName() const;
 
     /**
-     * Returns the hardware revision of the devices, e.g. "Revision 1.2"
+     * Returns the hardware revision of the tqdevices, e.g. "Revision 1.2"
      */
     virtual TQString revision() const;
 
     /**
-     * Returns an unique ID for the device, e.g. IMEI number on phones, or serial number.
+     * Returns an unique ID for the tqdevice, e.g. IMEI number on phones, or serial number.
      * The returned String is used to have a unique identification for syncronisation.
      */
-    virtual TQString deviceUniqueID() = 0;
+    virtual TQString tqdeviceUniqueID() = 0;
 
     /**
-     * Returns true, if the device is connected via a slow connection.
+     * Returns true, if the tqdevice is connected via a slow connection.
      * Good examples for slow connections are serial or infrared ports.
      */
     virtual bool isSlowDevice() const;
@@ -132,7 +133,7 @@ public:
     virtual bool isReadOnly() const;
 
     /**
-     * Pop-up a device-specific configuration dialog.
+     * Pop-up a tqdevice-specific configuration dialog.
      *
      * @param parent The parent widget. It will be used as parent for the configuration dialog.
      */
@@ -157,14 +158,14 @@ public:
     static TQString defaultIconFileName( ClassType ct = Unclassified );
     static TQString defaultClassName( ClassType ct = Unclassified );
 
-    // The capabilities of this device (bitmapped value)
+    // The capabilities of this tqdevice (bitmapped value)
     enum Capabilities {
 	hasNothing     = 0,	// not supported
 	hasAddressBook = 1,	// mobile phones, organizers, ...
 	hasCalendar    = 2,	// organizers, mobile phones, ...
 	hasNotes       = 4,	// organizers, mobile phones, ...
 	hasFileStorage = 8,	// organizers, handhelds, mp3-player, ...
-	hasAnyCapability = 0xffff // used to select devices independent of the capatibilities
+	hasAnyCapability = 0xffff // used to select tqdevices independent of the capatibilities
     };
     int capabilities() const;
     const TQString nameForCap(int cap) const;
@@ -205,7 +206,7 @@ public:
      */
 
     /**
-     * helper functions for the kmobile device drivers
+     * helper functions for the kmobile tqdevice drivers
      */
     void createDirEntry(KIO::UDSEntry& entry, const TQString& name,
 		const TQString& url, const TQString& mime) const;
@@ -351,10 +352,10 @@ signals:
      * KIO::AuthInfo authInfo;
      * if ( openPassDlg( authInfo ) )
      * {
-     *    kdDebug() << TQString::fromLatin1("User: ")
+     *    kdDebug() << TQString::tqfromLatin1("User: ")
      *              << authInfo.username << endl;
-     *    kdDebug() << TQString::fromLatin1("Password: ")
-     *              << TQString::fromLatin1("Not displayed here!") << endl;
+     *    kdDebug() << TQString::tqfromLatin1("Password: ")
+     *              << TQString::tqfromLatin1("Not displayed here!") << endl;
      * }
      * </pre>
      *
@@ -368,10 +369,10 @@ signals:
      * TQString errorMsg = "You entered an incorrect password.";
      * if ( openPassDlg( authInfo, errorMsg ) )
      * {
-     *    kdDebug() << TQString::fromLatin1("User: ")
+     *    kdDebug() << TQString::tqfromLatin1("User: ")
      *              << authInfo.username << endl;
-     *    kdDebug() << TQString::fromLatin1("Password: ")
-     *              << TQString::fromLatin1("Not displayed here!") << endl;
+     *    kdDebug() << TQString::tqfromLatin1("Password: ")
+     *              << TQString::tqfromLatin1("Not displayed here!") << endl;
      * }
      * </pre>
      *
@@ -427,9 +428,10 @@ signals:
      */
     void finished();
 
-
+#ifndef Q_MOC_RUN
     enum MessageBoxType { QuestionYesNo = 1, WarningYesNo = 2, WarningContinueCancel = 3,
 		WarningYesNoCancel = 4, Information = 5, SSLMessageBox = 6 };
+#endif // Q_MOC_RUN
 
     /**
      * Call this to show a message box from the slave (it will in fact be handled
@@ -447,9 +449,9 @@ signals:
      * @return a button code, as defined in KMessageBox, or 0 on communication error.
      */
     int messageBox( MessageBoxType type, const TQString &text,
-                    const TQString &caption = TQString::null,
-                    const TQString &buttonYes = TQString::null,
-                    const TQString &buttonNo = TQString::null );
+                    const TQString &caption = TQString(),
+                    const TQString &buttonYes = TQString(),
+                    const TQString &buttonNo = TQString() );
 
     /**
      * Call this in @ref #get and @ref #copy, to give the total size
@@ -469,7 +471,7 @@ signals:
     void connectionChanged( bool conn_established );
 
 protected:
-    // only available to sub-classed device drivers:
+    // only available to sub-classed tqdevice drivers:
     void setClassType( enum ClassType ct );
     void setCapabilities( int caps );
     KConfig *config() const { return m_config; };
@@ -477,21 +479,21 @@ protected:
 
 
     /**
-     * Lock/Unlock serial ports and other devices
-     * @param device Name of a device port (e.g. /dev/ttyS1, ttyS1, /dev/ircomm0)
-     * Returns true, if device could be locked or unlocked
+     * Lock/Unlock serial ports and other tqdevices
+     * @param tqdevice Name of a tqdevice port (e.g. /dev/ttyS1, ttyS1, /dev/ircomm0)
+     * Returns true, if tqdevice could be locked or unlocked
      */
-    bool lockDevice(const TQString &device, TQString &err_reason);
-    bool unlockDevice(const TQString &device);
+    bool lockDevice(const TQString &tqdevice, TQString &err_reason);
+    bool unlockDevice(const TQString &tqdevice);
 
 protected:
-    TQMutex  m_mutex;		// mutex to syncronize DCOP accesses to this device
+    TQMutex  m_mutex;		// mutex to syncronize DCOP accesses to this tqdevice
     TQString m_configFileName;
-    KConfig *m_config;		// this is where this device should store it's configuration
+    KConfig *m_config;		// this is where this tqdevice should store it's configuration
     enum ClassType m_classType;
-    TQString m_deviceClassName;	// e.g. "Nokia mobile phone", "MP3 Player", "Handspring Organizer"
-    TQString m_deviceName;	// e.g. "Nokia 6310", "Opie"
-    TQString m_deviceRevision;	// e.g. "Revision 1.2" or "n/a"
+    TQString m_tqdeviceClassName;	// e.g. "Nokia mobile phone", "MP3 Player", "Handspring Organizer"
+    TQString m_tqdeviceName;	// e.g. "Nokia 6310", "Opie"
+    TQString m_tqdeviceRevision;	// e.g. "Revision 1.2" or "n/a"
     TQString m_connectionName;	// e.g. "IRDA", "USB", "Cable", "gnokii", "gammu", ...
     int m_caps;			// see enum Capabilities
     bool m_connected;
