@@ -14,6 +14,7 @@ class KMobilePrefPageTwo;
 class KMobilePreferences : public KDialogBase
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     KMobilePreferences();
 
@@ -22,16 +23,18 @@ private:
     KMobilePrefPageTwo *m_pageTwo;
 };
 
-class KMobilePrefPageOne : public QFrame
+class KMobilePrefPageOne : public TQFrame
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     KMobilePrefPageOne(TQWidget *parent = 0);
 };
 
-class KMobilePrefPageTwo : public QFrame
+class KMobilePrefPageTwo : public TQFrame
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     KMobilePrefPageTwo(TQWidget *parent = 0);
 };
