@@ -28,6 +28,7 @@ class KAction;
 class SystemTray : public KSystemTray
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     SystemTray(KMainWindow *parent = 0, const char *name = 0);
@@ -41,7 +42,7 @@ protected:
     void contextMenuAboutToShow( KPopupMenu* menu );
 
 private:
-    void setToolTip(const TQString &tip = TQString::null);
+    void setToolTip(const TQString &tip = TQString());
 
     TQPixmap m_appPix;
     TQLabel *m_currentLabel;
