@@ -25,16 +25,16 @@ int main(int argc, char **argv)
 
     TQCString replyType;
     TQByteArray replyData;
-    ok = client->call("kmobile", "kmobileIface", "deviceNames()", data, replyType, replyData);
+    ok = client->call("kmobile", "kmobileIface", "tqdeviceNames()", data, replyType, replyData);
 
     TQDataStream reply(replyData, IO_ReadOnly); 
-    TQStringList deviceNames; 
-    reply >> deviceNames;
+    TQStringList tqdeviceNames; 
+    reply >> tqdeviceNames;
 
-    kdDebug() << TQString("%1\n").arg(ok?"Ok":"Failure");
-    kdDebug() << TQString("Number of currently registered drivers: %1\n").arg(deviceNames.count());
-    for (int i=0; i<deviceNames.count(); i++)
-      kdDebug() << TQString("Device %1: %2\n").arg(i+1).arg(deviceNames[i]);
+    kdDebug() << TQString("%1\n").tqarg(ok?"Ok":"Failure");
+    kdDebug() << TQString("Number of currently registered drivers: %1\n").tqarg(tqdeviceNames.count());
+    for (int i=0; i<tqdeviceNames.count(); i++)
+      kdDebug() << TQString("Device %1: %2\n").tqarg(i+1).tqarg(tqdeviceNames[i]);
 
   //  return app.exec();
 }
