@@ -15,7 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
-// $Id: wordlist.cpp 1157633 2010-07-31 19:20:30Z tpearson $
+// $Id: wordlist.cpp 1246075 2011-08-10 06:08:18Z tpearson $
 
 #include <tqregexp.h>
 #include <tqdir.h>
@@ -53,7 +53,7 @@ TQString XMLParser::errorString() {
 }
 
 bool XMLParser::startDocument() {
-   text = TQString::null;
+   text = TQString();
    return true;
 }
 
@@ -63,7 +63,7 @@ bool XMLParser::startElement (const TQString &, const TQString &,
 {
    if (!text.isNull() && !text.isEmpty()) {
       addWords (list, text);
-      text = TQString::null;
+      text = TQString();
    }
    return true;
 }
@@ -76,7 +76,7 @@ bool XMLParser::characters (const TQString &ch) {
 bool XMLParser::ignorableWhitespace (const TQString &) {
    if (!text.isNull() && !text.isEmpty()) {
       addWords (list, text);
-      text = TQString::null;
+      text = TQString();
    }
    return true;
 }
@@ -86,7 +86,7 @@ bool XMLParser::endElement (const TQString &, const TQString &,
 {
    if (!text.isNull() && !text.isEmpty()) {
       addWords (list, text);
-      text = TQString::null;
+      text = TQString();
    }
    return true;
 }
@@ -94,7 +94,7 @@ bool XMLParser::endElement (const TQString &, const TQString &,
 bool XMLParser::endDocument() {
    if (!text.isNull() && !text.isEmpty()) {
       addWords (list, text);
-      text = TQString::null;
+      text = TQString();
    }
    return true;
 }
@@ -160,7 +160,7 @@ void addWords (WordMap &map, WordMap add) {
 
 void addWordsFromFile (WordMap &map, TQString filename, TQTextStream::Encoding encoding, TQTextCodec *codec) {
    TQFile xmlfile(filename);
-   TQXmlInputSource source (&xmlfile);
+   TQXmlInputSource source (TQT_TQIODEVICE(&xmlfile));
    XMLParser parser;
    TQXmlSimpleReader reader;
    reader.setFeature ("http://trolltech.com/xml/features/report-start-end-entity", true);
@@ -228,7 +228,7 @@ WordMap parseFiles (TQStringList files, TQTextStream::Encoding encoding, TQTextC
       if (steps != 0 && progress*100/steps > percent) {
          percent = progress*100/steps;
          pdlg->progressBar()->setProgress(percent);
-         qApp->processEvents (20);
+         tqApp->tqprocessEvents (20);
       }
    }
    return map;
@@ -237,7 +237,7 @@ WordMap parseFiles (TQStringList files, TQTextStream::Encoding encoding, TQTextC
 WordMap mergeFiles  (TQMap<TQString,int> files, KProgressDialog *pdlg) {
    pdlg->setLabel (i18n("Merging dictionaries..."));
    pdlg->show();
-   qApp->processEvents (20);
+   tqApp->tqprocessEvents (20);
    
    int progress = 0;
    int steps = files.count();
@@ -269,7 +269,7 @@ WordMap mergeFiles  (TQMap<TQString,int> files, KProgressDialog *pdlg) {
       if (steps != 0 && progress*100/steps > percent) {
          percent = progress*100/steps;
          pdlg->progressBar()->setProgress(percent);
-         qApp->processEvents (20);
+         tqApp->tqprocessEvents (20);
       }
    }
    
@@ -290,7 +290,7 @@ WordMap mergeFiles  (TQMap<TQString,int> files, KProgressDialog *pdlg) {
 WordMap parseKDEDoc (TQString language, KProgressDialog *pdlg) {
    pdlg->setLabel (i18n("Parsing the KDE documentation..."));
    pdlg->show();
-   qApp->processEvents (20);
+   tqApp->tqprocessEvents (20);
    
    TQStringList files = KApplication::kApplication()->dirs()->findAllResources ("html", language + "/*.docbook", true, true);
    if ((files.count() == 0) && (language.length() == 5)) {
@@ -304,7 +304,7 @@ WordMap parseKDEDoc (TQString language, KProgressDialog *pdlg) {
 WordMap parseFile (TQString filename, TQTextStream::Encoding encoding, TQTextCodec *codec, KProgressDialog *pdlg) {
    pdlg->setLabel (i18n("Parsing file..."));
    pdlg->show();
-   qApp->processEvents (20);
+   tqApp->tqprocessEvents (20);
    
    TQStringList files = filename;
 
@@ -314,16 +314,16 @@ WordMap parseFile (TQString filename, TQTextStream::Encoding encoding, TQTextCod
 WordMap parseDir (TQString directory, TQTextStream::Encoding encoding, TQTextCodec *codec, KProgressDialog *pdlg) {
    pdlg->setLabel (i18n("Parsing directory..."));
    pdlg->show();
-   qApp->processEvents (20);
+   tqApp->tqprocessEvents (20);
    
    TQStringList directories;
    directories += directory;
    TQStringList files;
    for (TQStringList::Iterator it = directories.begin(); it != directories.end(); it = directories.remove(it)) {
       TQDir dir(*it);
-      const QFileInfoList *entries = dir.entryInfoList ("*", TQDir::Dirs | TQDir::Files | TQDir::NoSymLinks | TQDir::Readable);
+      const TQFileInfoList *entries = dir.entryInfoList ("*", TQDir::Dirs | TQDir::Files | TQDir::NoSymLinks | TQDir::Readable);
       if (entries != 0) {
-         QFileInfoListIterator iter (*entries);
+         TQFileInfoListIterator iter (*entries);
          while ((iter.current()) != 0) {
             TQString name = iter.current()->fileName();
             if (name != "." && name != "..") {
@@ -504,7 +504,7 @@ WordMap spellCheck  (WordMap map, TQString dictionary, KProgressDialog *pdlg) {
       pdlg->setLabel (i18n("Performing spell check..."));
       pdlg->progressBar()->setTotalSteps(100);
       pdlg->progressBar()->setProgress(0);
-      qApp->processEvents (20);
+      tqApp->tqprocessEvents (20);
       int progress = 0;
       int steps = 0;
       int percent = 0;
@@ -535,7 +535,7 @@ WordMap spellCheck  (WordMap map, TQString dictionary, KProgressDialog *pdlg) {
             if (steps != 0 && progress*100/steps > percent) {
                percent = progress*100/steps;
                pdlg->progressBar()->setProgress(percent);
-               qApp->processEvents (20);
+               tqApp->tqprocessEvents (20);
             }
          }
       }
