@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: indexcleaner.h 1158446 2010-08-02 19:23:46Z tpearson $
+** $Id: indexcleaner.h 1246260 2011-08-10 22:19:39Z tpearson $
 **
 ** Copyright (C) 2002 Carsten Pfeiffer <pfeiffer@kde.org>
 **
@@ -20,9 +20,10 @@ namespace KMrml
 
 namespace KMrmlConfig
 {
-    class IndexCleaner : public QObject
+    class IndexCleaner : public TQObject
     {
         Q_OBJECT
+  TQ_OBJECT
 
     public:
         IndexCleaner( const TQStringList& dirs, const KMrml::Config *config,
