@@ -42,16 +42,16 @@ CategoryItem::CategoryItem(TQListView *parent, const TQString &text)
 void CategoryItem::setOpen(bool open)
 {
 	if (open)
-		setPixmap(0, SmallIcon(TQString::fromLatin1("folder_open")));
+		setPixmap(0, SmallIcon(TQString::tqfromLatin1("folder_open")));
 	else
-		setPixmap(0, SmallIcon(TQString::fromLatin1("folder")));
+		setPixmap(0, SmallIcon(TQString::tqfromLatin1("folder")));
 
 	TQListViewItem::setOpen(open);
 }
 
 NewsSourceItem::NewsSourceItem(KNewsTickerConfig *kcm, CategoryItem *parent,
 		const NewsSourceBase::Data &nsd)
-	: TQCheckListItem(parent, TQString::null, TQCheckListItem::CheckBox),
+	: TQCheckListItem(parent, TQString(), TQCheckListItem::CheckBox),
 	m_parent(parent),
 	m_kcm(kcm)
 {
@@ -97,7 +97,7 @@ KNewsTickerConfig::KNewsTickerConfig(ConfigAccess *cfg, TQWidget *parent,  const
 {
 	setMainWidget(m_child);
 
-	// Change various properties of the view which the Qt Designer cannot
+	// Change various properties of the view which the TQt Designer cannot
 	// set at design time yet.
 	m_child->niInterval->setLabel(i18n("News query interval:"));
 	m_child->niInterval->setRange(4, 180);
@@ -251,7 +251,7 @@ bool KNewsTickerConfig::eventFilter(TQObject *o, TQEvent *e)
 			}
 			int i = 0;
 			while (validName == false) {
-				name = i18n("Unknown %1").arg(i);
+				name = i18n("Unknown %1").tqarg(i);
 				for (TQListViewItemIterator it(m_child->lvNewsSources); it.current(); it++) {
 					if (it.current()->text(0) == name) {
 						i++;
@@ -320,7 +320,7 @@ void KNewsTickerConfig::removeNewsSource()
 							" source?</p>",
 						 "<p>Do you really want to remove these %n news"
 							" sources?</p>",
-						 m_child->lvNewsSources->selectedItems().count()), TQString::null, KStdGuiItem::del()) == KMessageBox::Continue) {
+						 m_child->lvNewsSources->selectedItems().count()), TQString(), KStdGuiItem::del()) == KMessageBox::Continue) {
 		int itemCount = m_child->lvNewsSources->selectedItems().count();
 		for (int j = 0; j < itemCount; j++) {
 			if (m_child->lvNewsSources->selectedItems().isEmpty()) { break; }
@@ -343,7 +343,7 @@ void KNewsTickerConfig::removeNewsSource()
 void KNewsTickerConfig::removeFilter(TQListViewItem *item)
 {
 	if (KMessageBox::warningContinueCancel(this, i18n("<p>Do you really want to remove the selected"
-					" filter?</p>"), TQString::null, KStdGuiItem::del()) == KMessageBox::Continue) {
+					" filter?</p>"), TQString(), KStdGuiItem::del()) == KMessageBox::Continue) {
 		delete item;
 		m_child->bRemoveFilter->setEnabled(false);
 	}
@@ -356,17 +356,17 @@ void KNewsTickerConfig::slotNewsSourceContextMenu(KListView *, TQListViewItem *i
 
 	KPopupMenu *menu = new KPopupMenu();
 
-	TQPixmap addIcon = SmallIcon(TQString::fromLatin1("news_subscribe"));
-	TQPixmap modifyIcon = SmallIcon(TQString::fromLatin1("edit"));
-	TQPixmap removeIcon = SmallIcon(TQString::fromLatin1("news_unsubscribe"));
-	TQPixmap logoIcon = SmallIcon(TQString::fromLatin1("knewsticker"));
+	TQPixmap addIcon = SmallIcon(TQString::tqfromLatin1("news_subscribe"));
+	TQPixmap modifyIcon = SmallIcon(TQString::tqfromLatin1("edit"));
+	TQPixmap removeIcon = SmallIcon(TQString::tqfromLatin1("news_unsubscribe"));
+	TQPixmap logoIcon = SmallIcon(TQString::tqfromLatin1("knewsticker"));
 
 	menu->insertTitle(logoIcon, i18n("Edit News Source"));
 	menu->insertItem(addIcon, i18n("&Add News Source"), 0);
 	if (item) {
-		menu->insertItem(modifyIcon, i18n("&Modify '%1'").arg(item->text(0)), 1);
+		menu->insertItem(modifyIcon, i18n("&Modify '%1'").tqarg(item->text(0)), 1);
 		if (m_child->lvNewsSources->selectedItems().count() == 1) {
-			menu->insertItem(removeIcon, i18n("&Remove '%1'").arg(item->text(0)), 2);
+			menu->insertItem(removeIcon, i18n("&Remove '%1'").tqarg(item->text(0)), 2);
 		} else {
 			menu->insertItem(removeIcon, i18n("&Remove News Sources"), 2);
 		}
