@@ -26,27 +26,29 @@ namespace RSS {
 
 using RSS::Loader;
 using RSS::Document;
-using RSS::Status;
+using RSS::tqStatus;
 
 class KntSrcFilePropsFactory : public KLibFactory
 {
 	Q_OBJECT
+  TQ_OBJECT
 	
 	public:
 		virtual TQObject *createObject(TQObject * = 0, const char * = 0,
-				const char * = "TQObject", const TQStringList & = TQStringList());
+				const char * = TQOBJECT_OBJECT_NAME_STRING, const TQStringList & = TQStringList());
 };
 
 class KntSrcFilePropsDlg : public KPropsDlgPlugin
 {
 	Q_OBJECT
+  TQ_OBJECT
 	
 	public:
 		KntSrcFilePropsDlg(KPropertiesDialog *);
 	
 	protected slots:
 		void slotOpenURL(const TQString &);
-		void slotConstructUI(Loader *loader, Document doc, Status status);
+		void slotConstructUI(Loader *loader, Document doc, tqStatus status);
 		void slotGotIcon(const KURL &, const TQPixmap &);
 		void slotClickedArticle(TQListBoxItem *);
 	
