@@ -189,15 +189,15 @@ KNComposer::KNComposer(KNLocalArticle *a, const TQString &text, const TQString &
 
   //statusbar
   KStatusBar *sb=statusBar();
-  sb->insertItem(TQString::null, 1,1);                 // type
+  sb->insertItem(TQString(), 1,1);                 // type
   sb->setItemAlignment (1,AlignLeft | AlignVCenter);
-  sb->insertItem(TQString::null, 2,1);                 // charset
+  sb->insertItem(TQString(), 2,1);                 // charset
   sb->setItemAlignment (2,AlignLeft | AlignVCenter);
-  sb->insertItem(TQString::null, 3,0);                 // column
+  sb->insertItem(TQString(), 3,0);                 // column
   sb->setItemAlignment (3,AlignCenter | AlignVCenter);
-  sb->insertItem(TQString::null, 4,0);                 // column
+  sb->insertItem(TQString(), 4,0);                 // column
   sb->setItemAlignment (4,AlignCenter | AlignVCenter);
-  sb->insertItem(TQString::null, 5,0);                 // line
+  sb->insertItem(TQString(), 5,0);                 // line
   sb->setItemAlignment (5,AlignCenter | AlignVCenter);
   connect(v_iew->e_dit, TQT_SIGNAL(CursorPositionChanged()), TQT_SLOT(slotUpdateCursorPos()));
   connect(v_iew->e_dit, TQT_SIGNAL(toggle_overwrite_signal()), TQT_SLOT(slotUpdateStatusBar()));
@@ -205,70 +205,70 @@ KNComposer::KNComposer(KNLocalArticle *a, const TQString &text, const TQString &
   //------------------------------- <Actions> --------------------------------------
 
   //file menu
-  new KAction(i18n("&Send Now"),"mail_send", CTRL + Key_Return , this,
+  new KAction(i18n("&Send Now"),"mail_send", CTRL + Key_Return , TQT_TQOBJECT(this),
     TQT_SLOT(slotSendNow()), actionCollection(), "send_now");
 
-  new KAction(i18n("Send &Later"), "queue", 0, this,
+  new KAction(i18n("Send &Later"), "queue", 0, TQT_TQOBJECT(this),
     TQT_SLOT(slotSendLater()), actionCollection(), "send_later");
 
-  new KAction(i18n("Save as &Draft"),"filesave", 0 , this,
+  new KAction(i18n("Save as &Draft"),"filesave", 0 , TQT_TQOBJECT(this),
     TQT_SLOT(slotSaveAsDraft()), actionCollection(), "save_as_draft");
 
-  new KAction(i18n("D&elete"),"editdelete", 0 , this,
+  new KAction(i18n("D&elete"),"editdelete", 0 , TQT_TQOBJECT(this),
     TQT_SLOT(slotArtDelete()), actionCollection(), "art_delete");
 
-  KStdAction::close(this, TQT_SLOT(close()),actionCollection());
+  KStdAction::close(TQT_TQOBJECT(this), TQT_SLOT(close()),actionCollection());
 
   //edit menu
-  KStdAction::undo(this, TQT_SLOT(slotUndo()), actionCollection());
-  KStdAction::redo(this, TQT_SLOT(slotRedo()), actionCollection());
+  KStdAction::undo(TQT_TQOBJECT(this), TQT_SLOT(slotUndo()), actionCollection());
+  KStdAction::redo(TQT_TQOBJECT(this), TQT_SLOT(slotRedo()), actionCollection());
 
-  KStdAction::cut(this, TQT_SLOT(slotCut()), actionCollection());
+  KStdAction::cut(TQT_TQOBJECT(this), TQT_SLOT(slotCut()), actionCollection());
 
 
-  KStdAction::copy(this, TQT_SLOT(slotCopy()), actionCollection());
+  KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(slotCopy()), actionCollection());
 
-  KStdAction::pasteText(this, TQT_SLOT(slotPaste()), actionCollection());
+  KStdAction::pasteText(TQT_TQOBJECT(this), TQT_SLOT(slotPaste()), actionCollection());
 
-  new KAction(i18n("Paste as &Quotation"), 0, v_iew->e_dit,
+  new KAction(i18n("Paste as &Quotation"), 0, TQT_TQOBJECT(v_iew->e_dit),
                    TQT_SLOT(slotPasteAsQuotation()), actionCollection(), "paste_quoted");
 
-  KStdAction::selectAll(this, TQT_SLOT(slotSelectAll()), actionCollection());
+  KStdAction::selectAll(TQT_TQOBJECT(this), TQT_SLOT(slotSelectAll()), actionCollection());
 
-  KStdAction::find(v_iew->e_dit, TQT_SLOT(slotFind()), actionCollection());
-  KStdAction::findNext(v_iew->e_dit, TQT_SLOT(slotSearchAgain()), actionCollection());
+  KStdAction::find(TQT_TQOBJECT(v_iew->e_dit), TQT_SLOT(slotFind()), actionCollection());
+  KStdAction::findNext(TQT_TQOBJECT(v_iew->e_dit), TQT_SLOT(slotSearchAgain()), actionCollection());
 
-  KStdAction::replace(v_iew->e_dit, TQT_SLOT(slotReplace()), actionCollection());
+  KStdAction::replace(TQT_TQOBJECT(v_iew->e_dit), TQT_SLOT(slotReplace()), actionCollection());
 
   //attach menu
-  new KAction(i18n("Append &Signature"), 0 , this, TQT_SLOT(slotAppendSig()),
+  new KAction(i18n("Append &Signature"), 0 , TQT_TQOBJECT(this), TQT_SLOT(slotAppendSig()),
                    actionCollection(), "append_signature");
 
-  new KAction(i18n("&Insert File..."), 0, this, TQT_SLOT(slotInsertFile()),
+  new KAction(i18n("&Insert File..."), 0, TQT_TQOBJECT(this), TQT_SLOT(slotInsertFile()),
                    actionCollection(), "insert_file");
 
-  new KAction(i18n("Insert File (in a &box)..."), 0, this, TQT_SLOT(slotInsertFileBoxed()),
+  new KAction(i18n("Insert File (in a &box)..."), 0, TQT_TQOBJECT(this), TQT_SLOT(slotInsertFileBoxed()),
                    actionCollection(), "insert_file_boxed");
 
-  new KAction(i18n("Attach &File..."), "attach", 0, this, TQT_SLOT(slotAttachFile()),
+  new KAction(i18n("Attach &File..."), "attach", 0, TQT_TQOBJECT(this), TQT_SLOT(slotAttachFile()),
                    actionCollection(), "attach_file");
 
   a_ctPGPsign = new KToggleAction(i18n("Sign Article with &PGP"),
 		   "signature", 0,
                    actionCollection(), "sign_article");
 
-  a_ctRemoveAttachment = new KAction(i18n("&Remove"), 0, this,
+  a_ctRemoveAttachment = new KAction(i18n("&Remove"), 0, TQT_TQOBJECT(this),
                                     TQT_SLOT(slotRemoveAttachment()), actionCollection(), "remove_attachment");
 
-  a_ctAttachmentProperties  = new KAction(i18n("&Properties"), 0, this,
+  a_ctAttachmentProperties  = new KAction(i18n("&Properties"), 0, TQT_TQOBJECT(this),
                                           TQT_SLOT(slotAttachmentProperties()), actionCollection(), "attachment_properties");
 
   //options menu
 
-  a_ctDoPost = new KToggleAction(i18n("Send &News Article"), "filenew", 0 , this,
+  a_ctDoPost = new KToggleAction(i18n("Send &News Article"), "filenew", 0 , TQT_TQOBJECT(this),
                    TQT_SLOT(slotToggleDoPost()), actionCollection(), "send_news");
 
-  a_ctDoMail = new KToggleAction(i18n("Send E&mail"), "mail_generic" , 0 , this,
+  a_ctDoMail = new KToggleAction(i18n("Send E&mail"), "mail_generic" , 0 , TQT_TQOBJECT(this),
                    TQT_SLOT(slotToggleDoMail()), actionCollection(), "send_mail");
 
   a_ctSetCharset = new KSelectAction(i18n("Set &Charset"), 0, actionCollection(), "set_charset");
@@ -277,50 +277,50 @@ KNComposer::KNComposer(KNLocalArticle *a, const TQString &text, const TQString &
   connect(a_ctSetCharset, TQT_SIGNAL(activated(const TQString&)),
   this, TQT_SLOT(slotSetCharset(const TQString&)));
 
-  a_ctSetCharsetKeyb = new KAction(i18n("Set Charset"), 0, this,
+  a_ctSetCharsetKeyb = new KAction(i18n("Set Charset"), 0, TQT_TQOBJECT(this),
                                    TQT_SLOT(slotSetCharsetKeyboard()), actionCollection(), "set_charset_keyboard");
 
 
-  a_ctWordWrap  = new KToggleAction(i18n("&Word Wrap"), 0 , this,
+  a_ctWordWrap  = new KToggleAction(i18n("&Word Wrap"), 0 , TQT_TQOBJECT(this),
                       TQT_SLOT(slotToggleWordWrap()), actionCollection(), "toggle_wordwrap");
 
   //tools menu
 
-  new KAction(i18n("Add &Quote Characters"), 0, v_iew->e_dit,
+  new KAction(i18n("Add &Quote Characters"), 0, TQT_TQOBJECT(v_iew->e_dit),
               TQT_SLOT(slotAddQuotes()), actionCollection(), "tools_quote");
 
-  new KAction(i18n("&Remove Quote Characters"), 0, v_iew->e_dit,
+  new KAction(i18n("&Remove Quote Characters"), 0, TQT_TQOBJECT(v_iew->e_dit),
               TQT_SLOT(slotRemoveQuotes()), actionCollection(), "tools_unquote");
 
-  new KAction(i18n("Add &Box"), 0, v_iew->e_dit,
+  new KAction(i18n("Add &Box"), 0, TQT_TQOBJECT(v_iew->e_dit),
               TQT_SLOT(slotAddBox()), actionCollection(), "tools_box");
 
-  new KAction(i18n("Re&move Box"), 0, v_iew->e_dit,
+  new KAction(i18n("Re&move Box"), 0, TQT_TQOBJECT(v_iew->e_dit),
               TQT_SLOT(slotRemoveBox()), actionCollection(), "tools_unbox");
 
-  KAction *undoRewrap = new KAction(i18n("Get &Original Text (not re-wrapped)"), 0, this,
+  KAction *undoRewrap = new KAction(i18n("Get &Original Text (not re-wrapped)"), 0, TQT_TQOBJECT(this),
                                     TQT_SLOT(slotUndoRewrap()), actionCollection(), "tools_undoRewrap");
   undoRewrap->setEnabled(!u_nwraped.isNull());
 
-  KAction *rot13 = new KAction(i18n("S&cramble (Rot 13)"), "encrypted", 0, v_iew->e_dit,
+  KAction *rot13 = new KAction(i18n("S&cramble (Rot 13)"), "encrypted", 0, TQT_TQOBJECT(v_iew->e_dit),
                                TQT_SLOT(slotRot13()), actionCollection(), "tools_rot13");
   rot13->setEnabled(false);
   connect(v_iew->e_dit, TQT_SIGNAL(copyAvailable(bool)), rot13, TQT_SLOT(setEnabled(bool)));
 
-  a_ctExternalEditor = new KAction(i18n("Start &External Editor"), "run", 0, this,
+  a_ctExternalEditor = new KAction(i18n("Start &External Editor"), "run", 0, TQT_TQOBJECT(this),
                        TQT_SLOT(slotExternalEditor()), actionCollection(), "external_editor");
 
-  a_ctSpellCheck = KStdAction::spelling (this, TQT_SLOT(slotSpellcheck()), actionCollection());
+  a_ctSpellCheck = KStdAction::spelling (TQT_TQOBJECT(this), TQT_SLOT(slotSpellcheck()), actionCollection());
 
   //settings menu
   createStandardStatusBarAction();
   setStandardToolBarMenuEnabled(true);
 
-  KStdAction::keyBindings(this, TQT_SLOT(slotConfKeys()), actionCollection());
+  KStdAction::keyBindings(TQT_TQOBJECT(this), TQT_SLOT(slotConfKeys()), actionCollection());
 
-  KStdAction::configureToolbars(this, TQT_SLOT(slotConfToolbar()), actionCollection());
+  KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT(slotConfToolbar()), actionCollection());
 
-  KStdAction::preferences(knGlobals.top, TQT_SLOT(slotSettings()), actionCollection());
+  KStdAction::preferences(TQT_TQOBJECT(knGlobals.top), TQT_SLOT(slotSettings()), actionCollection());
 
   a_ccel=new KAccel(this);
   a_ctSetCharsetKeyb->plugAccel(a_ccel);
@@ -432,46 +432,46 @@ int KNComposer::listOfResultOfCheckWord( const TQStringList & lst , const TQStri
 
 void KNComposer::slotUndo()
 {
-    TQWidget* fw = focusWidget();
+    TQWidget* fw = tqfocusWidget();
     if (!fw) return;
 
     if (fw->inherits("KEdit"))
         ((TQMultiLineEdit*)fw)->undo();
-    else if (fw->inherits("TQLineEdit"))
+    else if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
         ((TQLineEdit*)fw)->undo();
 }
 
 void KNComposer::slotRedo()
 {
-    TQWidget* fw = focusWidget();
+    TQWidget* fw = tqfocusWidget();
     if (!fw) return;
 
     if (fw->inherits("KEdit"))
         ((TQMultiLineEdit*)fw)->redo();
-    else if (fw->inherits("TQLineEdit"))
+    else if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
         ((TQLineEdit*)fw)->redo();
 }
 
 void KNComposer::slotCut()
 {
-  TQWidget* fw = focusWidget();
+  TQWidget* fw = tqfocusWidget();
   if (!fw) return;
 
   if (fw->inherits("KEdit"))
     ((TQMultiLineEdit*)fw)->cut();
-  else if (fw->inherits("TQLineEdit"))
+  else if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
     ((TQLineEdit*)fw)->cut();
   else kdDebug(5003) << "wrong focus widget" << endl;
 }
 
 void KNComposer::slotCopy()
 {
-  TQWidget* fw = focusWidget();
+  TQWidget* fw = tqfocusWidget();
   if (!fw) return;
 
   if (fw->inherits("KEdit"))
     ((TQMultiLineEdit*)fw)->copy();
-  else if (fw->inherits("TQLineEdit"))
+  else if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
     ((TQLineEdit*)fw)->copy();
   else kdDebug(5003) << "wrong focus widget" << endl;
 
@@ -480,24 +480,24 @@ void KNComposer::slotCopy()
 
 void KNComposer::slotPaste()
 {
-  TQWidget* fw = focusWidget();
+  TQWidget* fw = tqfocusWidget();
   if (!fw) return;
 
   if (fw->inherits("KEdit"))
     ((TQMultiLineEdit*)fw)->paste();
-  else if (fw->inherits("TQLineEdit"))
+  else if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
     ((TQLineEdit*)fw)->paste();
   else kdDebug(5003) << "wrong focus widget" << endl;
 }
 
 void KNComposer::slotSelectAll()
 {
-  TQWidget* fw = focusWidget();
+  TQWidget* fw = tqfocusWidget();
   if (!fw) return;
 
-  if (fw->inherits("TQLineEdit"))
+  if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
       ((TQLineEdit*)fw)->selectAll();
-  else if (fw->inherits("TQMultiLineEdit"))
+  else if (fw->inherits(TQMULTILINEEDIT_OBJECT_NAME_STRING))
     ((TQMultiLineEdit*)fw)->selectAll();
 }
 
@@ -579,7 +579,7 @@ bool KNComposer::hasValidData()
 
     if (groupCount>5)
       if (!(KMessageBox::warningYesNo( this, i18n("You are crossposting to more than five newsgroups.\nPlease reconsider whether this is really useful\nand remove groups in which your article is off-topic.\nDo you want to re-edit the article or send it anyway?"),
-                                       TQString::null, i18n("&Send"),i18n("edit article","&Edit")) == KMessageBox::Yes))
+                                       TQString(), i18n("&Send"),i18n("edit article","&Edit")) == KMessageBox::Yes))
         return false;
 
     if ( !followUp && groupCount > 2 ) {
@@ -588,7 +588,7 @@ bool KNComposer::hasValidData()
                 "Please use the \"Followup-To\" header to direct the replies "
                 "to your article into one group.\n"
                 "Do you want to re-edit the article or send it anyway?"),
-           TQString::null, i18n("&Send"), i18n("edit article","&Edit"), "missingFollowUpTo" )
+           TQString(), i18n("&Send"), i18n("edit article","&Edit"), "missingFollowUpTo" )
            != KMessageBox::Yes )
         return false;
     }
@@ -600,7 +600,7 @@ bool KNComposer::hasValidData()
 
     if (fupCount>5)
       if (!(KMessageBox::warningYesNo( this, i18n("You are directing replies to more than five newsgroups.\nPlease reconsider whether this is really useful.\nDo you want to re-edit the article or send it anyway?"),
-                                       TQString::null, i18n("&Send"),i18n("edit article","&Edit")) == KMessageBox::Yes))
+                                       TQString(), i18n("&Send"),i18n("edit article","&Edit")) == KMessageBox::Yes))
         return false;
   }
 
@@ -670,7 +670,7 @@ bool KNComposer::hasValidData()
   if ((textLines>1)&&(notQuoted==1)) {
     if (hasAttributionLine)
       if (!(KMessageBox::warningYesNo( this, i18n("Your article seems to consist entirely of quoted text;\ndo you want to re-edit the article or send it anyway?"),
-                                       TQString::null, i18n("&Send"),i18n("edit article","&Edit")) == KMessageBox::Yes))
+                                       TQString(), i18n("&Send"),i18n("edit article","&Edit")) == KMessageBox::Yes))
         return false;
   } else {
     if (notQuoted==0) {
@@ -684,18 +684,18 @@ bool KNComposer::hasValidData()
     if (!(KMessageBox::warningYesNo( this,
           i18n("Your article contains lines longer than 80 characters.\n"
 	       "Do you want to re-edit the article or send it anyway?"),
-          TQString::null, i18n("&Send"),
+          TQString(), i18n("&Send"),
 	  i18n("edit article","&Edit")) == KMessageBox::Yes))
       return false;
 
   if (sigLength>8) {
     if (!(KMessageBox::warningYesNo( this, i18n("Your signature is more than 8 lines long.\nYou should shorten it to match the widely accepted limit of 4 lines.\nDo you want to re-edit the article or send it anyway?"),
-                                     TQString::null, i18n("&Send"),i18n("edit article","&Edit")) == KMessageBox::Yes))
+                                     TQString(), i18n("&Send"),i18n("edit article","&Edit")) == KMessageBox::Yes))
       return false;
   } else
     if (sigLength>4)
        KMessageBox::information(this, i18n("Your signature exceeds the widely-accepted limit of 4 lines:\nplease consider shortening your signature;\notherwise, you will probably annoy your readers."),
-                                TQString::null,"longSignatureWarning");
+                                TQString(),"longSignatureWarning");
 
   // check if article can be signed
   if ( a_ctPGPsign->isChecked() ) {
@@ -721,7 +721,7 @@ bool KNComposer::hasValidData()
                         "in the account properties or in the "
                         "group properties.\n"
                         "The article will be sent unsigned." ),
-                   TQString::null, i18n( "Send Unsigned" ),
+                   TQString(), i18n( "Send Unsigned" ),
                    "sendUnsignedDialog" )
                == KMessageBox::Cancel )
              return false;
@@ -876,7 +876,7 @@ void KNComposer::closeEvent(TQCloseEvent *e)
   }
   else {
     switch ( KMessageBox::warningYesNoCancel( this, i18n("Do you want to save this article in the draft folder?"),
-                                              TQString::null, KStdGuiItem::save(), KStdGuiItem::discard())) {
+                                              TQString(), KStdGuiItem::save(), KStdGuiItem::discard())) {
       case KMessageBox::Yes :
         r_esult=CRsave;
         break;
@@ -900,7 +900,7 @@ void KNComposer::initData(const TQString &text)
 {
   //Subject
   if(a_rticle->subject()->isEmpty())
-    slotSubjectChanged(TQString::null);
+    slotSubjectChanged(TQString());
   else
     v_iew->s_ubject->setText(a_rticle->subject()->asUnicodeString());
 
@@ -969,7 +969,7 @@ void KNComposer::insertFile(TQFile *file, bool clear, bool box, TQString boxTitl
   ts.setCodec(codec);
 
   if (box)
-    temp = TQString::fromLatin1(",----[ %1 ]\n").arg(boxTitle);
+    temp = TQString::tqfromLatin1(",----[ %1 ]\n").tqarg(boxTitle);
 
   if (box && (v_iew->e_dit->wordWrap()!=TQMultiLineEdit::NoWrap)) {
     int wrapAt = v_iew->e_dit->wrapColumnOrWidth();
@@ -993,7 +993,7 @@ void KNComposer::insertFile(TQFile *file, bool clear, bool box, TQString boxTitl
   }
 
   if (box)
-    temp += TQString::fromLatin1("`----");
+    temp += TQString::tqfromLatin1("`----");
 
   if(clear)
     v_iew->e_dit->setText(temp);
@@ -1165,7 +1165,7 @@ void KNComposer::slotToggleDoMail()
   if (a_ctDoMail->isChecked()) {
     if (a_uthorDislikesMailCopies) {
       if (!(KMessageBox::warningContinueCancel(this, i18n("The poster does not want a mail copy of your reply (Mail-Copies-To: nobody);\nplease respect their request."),
-                                               TQString::null, i18n("&Send Copy")) == KMessageBox::Continue)) {
+                                               TQString(), i18n("&Send Copy")) == KMessageBox::Continue)) {
         a_ctDoMail->setChecked(false); //revert
         return;
       }
@@ -1327,7 +1327,7 @@ void KNComposer::slotSpellcheck()
   a_ctExternalEditor->setEnabled(false);
   a_ctSpellCheck->setEnabled(false);
 
-  s_pellChecker = new KSpell(this, i18n("Spellcheck"), this, TQT_SLOT(slotSpellStarted(KSpell *)));
+  s_pellChecker = new KSpell(TQT_TQWIDGET(this), i18n("Spellcheck"), TQT_TQOBJECT(this), TQT_SLOT(slotSpellStarted(KSpell *)));
   TQStringList l = KSpellingHighlighter::personalWords();
   for ( TQStringList::Iterator it = l.begin(); it != l.end(); ++it ) {
       s_pellChecker->addPersonal( *it );
@@ -1374,18 +1374,18 @@ void KNComposer::slotUpdateStatusBar()
   else
     overwriteDesc = i18n(" INS ");
 
-  statusBar()->changeItem(i18n(" Type: %1 ").arg(typeDesc), 1);
-  statusBar()->changeItem(i18n(" Charset: %1 ").arg(c_harset), 2);
+  statusBar()->changeItem(i18n(" Type: %1 ").tqarg(typeDesc), 1);
+  statusBar()->changeItem(i18n(" Charset: %1 ").tqarg(TQString(c_harset)), 2);
   statusBar()->changeItem(overwriteDesc, 3);
-  statusBar()->changeItem(i18n(" Column: %1 ").arg(v_iew->e_dit->currentColumn() + 1), 4);
-  statusBar()->changeItem(i18n(" Line: %1 ").arg(v_iew->e_dit->currentLine() + 1), 5);
+  statusBar()->changeItem(i18n(" Column: %1 ").tqarg(v_iew->e_dit->currentColumn() + 1), 4);
+  statusBar()->changeItem(i18n(" Line: %1 ").tqarg(v_iew->e_dit->currentLine() + 1), 5);
 }
 
 
 void KNComposer::slotUpdateCursorPos()
 {
-  statusBar()->changeItem(i18n(" Column: %1 ").arg(v_iew->e_dit->currentColumn() + 1), 4);
-  statusBar()->changeItem(i18n(" Line: %1 ").arg(v_iew->e_dit->currentLine() + 1), 5);
+  statusBar()->changeItem(i18n(" Column: %1 ").tqarg(v_iew->e_dit->currentColumn() + 1), 4);
+  statusBar()->changeItem(i18n(" Line: %1 ").tqarg(v_iew->e_dit->currentLine() + 1), 5);
 }
 
 
@@ -1438,7 +1438,7 @@ void KNComposer::slotSubjectChanged(const TQString &t)
 
 void KNComposer::slotGroupsChanged(const TQString &t)
 {
-  KQCStringSplitter split;
+  KTQCStringSplitter split;
   bool splitOk;
   TQString currText=v_iew->f_up2->currentText();
 
@@ -1447,7 +1447,7 @@ void KNComposer::slotGroupsChanged(const TQString &t)
   split.init(t.latin1(), ",");
   splitOk=split.first();
   while(splitOk) {
-    v_iew->f_up2->insertItem(TQString::fromLatin1(split.string()));
+    v_iew->f_up2->insertItem(TQString::tqfromLatin1(split.string()));
     splitOk=split.next();
   }
   v_iew->f_up2->insertItem("");
@@ -1725,7 +1725,7 @@ TQPopupMenu * KNComposer::popupMenu( const TQString& name )
 
 
 KNComposer::ComposerView::ComposerView(KNComposer *composer, const char *n)
-  : TQSplitter(TQSplitter::Vertical, composer, n), a_ttWidget(0), a_ttView(0), v_iewOpen(false)
+  : TQSplitter(Qt::Vertical, composer, n), a_ttWidget(0), a_ttView(0), v_iewOpen(false)
 {
   TQWidget *main=new TQWidget(this);
 
@@ -1781,10 +1781,10 @@ KNComposer::ComposerView::ComposerView(KNComposer *composer, const char *n)
 
   KConfig *config = knGlobals.config();
   KConfigGroupSaver saver(config, "VISUAL_APPEARANCE");
-  TQColor defaultColor1( kapp->palette().active().text()); // defaults from kmreaderwin.cpp
-  TQColor defaultColor2( kapp->palette().active().text() );
-  TQColor defaultColor3( kapp->palette().active().text() );
-  TQColor defaultForeground( kapp->palette().active().text() );
+  TQColor defaultColor1( kapp->tqpalette().active().text()); // defaults from kmreaderwin.cpp
+  TQColor defaultColor2( kapp->tqpalette().active().text() );
+  TQColor defaultColor3( kapp->tqpalette().active().text() );
+  TQColor defaultForeground( kapp->tqpalette().active().text() );
   TQColor col1 = config->readColorEntry( "ForegroundColor", &defaultForeground );
   TQColor col2 = config->readColorEntry( "quote3Color", &defaultColor3 );
   TQColor col3 = config->readColorEntry( "quote2Color", &defaultColor2 );
@@ -1804,7 +1804,7 @@ KNComposer::ComposerView::ComposerView(KNComposer *composer, const char *n)
   n_otification->setFrameStyle(TQFrame::Panel | TQFrame::Raised);
   n_otification->setLineWidth(2);
   n_otification->hide();
-  notL->addWidget(n_otification, 0, Qt::AlignHCenter);
+  notL->addWidget(n_otification, 0, TQt::AlignHCenter);
   notL->addStretch(1);
 
   //finish GUI
@@ -1933,7 +1933,7 @@ void KNComposer::ComposerView::showAttachmentView()
     a_ttEditBtn=new TQPushButton(i18n("&Properties"), a_ttWidget);
     a_ttEditBtn->setEnabled(false);
     connect(a_ttEditBtn, TQT_SIGNAL(clicked()), parent(), TQT_SLOT(slotAttachmentProperties()));
-    topL->addWidget(a_ttEditBtn, 2,1, Qt::AlignTop);
+    topL->addWidget(a_ttEditBtn, 2,1, TQt::AlignTop);
 
     topL->setRowStretch(2,1);
     topL->setColStretch(0,1);
@@ -1998,7 +1998,7 @@ KNComposer::Editor::Editor(KNComposer::ComposerView *_composerView, KNComposer *
   spell = 0L;
   installEventFilter(this);
   KCursor::setAutoHideCursor( this, true, true );
-  m_bound = TQRegExp( TQString::fromLatin1("[\\s\\W]") );
+  m_bound = TQRegExp( TQString::tqfromLatin1("[\\s\\W]") );
 }
 
 
@@ -2011,7 +2011,7 @@ KNComposer::Editor::~Editor()
 //-----------------------------------------------------------------------------
 bool KNComposer::Editor::eventFilter(TQObject*o, TQEvent* e)
 {
-  if (o == this)
+  if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this))
     KCursor::autoHideEventFilter(o, e);
 
   if (e->type() == TQEvent::KeyPress)
@@ -2152,7 +2152,7 @@ TQStringList KNComposer::Editor::processedText()
 
 void KNComposer::Editor::slotPasteAsQuotation()
 {
-  TQString s = TQApplication::clipboard()->text();
+  TQString s = TQApplication::tqclipboard()->text();
   if (!s.isEmpty()) {
     for (int i=0; (uint)i<s.length(); i++) {
       if ( s[i] < ' ' && s[i] != '\n' && s[i] != '\t' )
@@ -2177,7 +2177,7 @@ void KNComposer::Editor::slotSearchAgain()
 
 void KNComposer::Editor::slotReplace()
 {
-  replace();
+    replace();
 }
 
 
@@ -2233,7 +2233,7 @@ void KNComposer::Editor::slotAddBox()
   } else {
     int l = currentLine();
     int c = currentColumn();
-    TQString s = TQString::fromLatin1(",----[  ]\n| %1\n`----").arg(textLine(l));
+    TQString s = TQString::tqfromLatin1(",----[  ]\n| %1\n`----").tqarg(textLine(l));
     insertLine(s,l);
     removeLine(l+3);
     setCursorPosition(l+1,c+2);
@@ -2244,7 +2244,7 @@ void KNComposer::Editor::slotAddBox()
 void KNComposer::Editor::slotRemoveBox()
 {
   if (hasMarkedText()) {
-    TQString s = TQString::fromLatin1("\n") + markedText() + TQString::fromLatin1("\n");
+    TQString s = TQString::tqfromLatin1("\n") + markedText() + TQString::tqfromLatin1("\n");
     s.replace(TQRegExp("\n,----[^\n]*\n"),"\n");
     s.replace(TQRegExp("\n| "),"\n");
     s.replace(TQRegExp("\n`----[^\n]*\n"),"\n");
@@ -2297,7 +2297,7 @@ void KNComposer::Editor::slotRemoveBox()
     setCursorPosition(l,c-2);
 
     setAutoUpdate(true);
-    repaint(false);
+    tqrepaint(false);
   }
 }
 
@@ -2332,7 +2332,7 @@ void KNComposer::Editor::keyPressEvent ( TQKeyEvent *e)
         int line, col;
         getCursorPosition( &line, &col );
         TQString lineText = text( line );
-        // returns line with additional trailing space (bug in Qt?), cut it off
+        // returns line with additional trailing space (bug in TQt?), cut it off
         lineText.truncate( lineText.length() - 1 );
         // special treatment of quoted lines only if the cursor is neither at
         // the begin nor at the end of the line
@@ -2398,7 +2398,7 @@ void KNComposer::Editor::contentsContextMenuEvent( TQContextMenuEvent */*e*/ )
     }
     else
     {
-        spell = new KSpell(this, i18n("Spellcheck"), this, TQT_SLOT(slotSpellStarted(KSpell *)));
+        spell = new KSpell(this, i18n("Spellcheck"), TQT_TQOBJECT(this), TQT_SLOT(slotSpellStarted(KSpell *)));
         TQStringList l = KSpellingHighlighter::personalWords();
         for ( TQStringList::Iterator it = l.begin(); it != l.end(); ++it ) {
             spell->addPersonal( *it );
@@ -2560,9 +2560,9 @@ KNComposer::AttachmentPropertiesDlg::AttachmentPropertiesDlg(KNAttachment *a, TQ
 
   fileL->addRowSpacing(0, fontMetrics().lineSpacing()-9);
   fileL->addWidget(new TQLabel(i18n("Name:"), fileGB) ,1,0);
-  fileL->addWidget(new TQLabel(TQString("<b>%1</b>").arg(a->name()), fileGB), 1,1, Qt::AlignLeft);
+  fileL->addWidget(new TQLabel(TQString("<b>%1</b>").tqarg(a->name()), fileGB), 1,1, TQt::AlignLeft);
   fileL->addWidget(new TQLabel(i18n("Size:"), fileGB), 2,0);
-  fileL->addWidget(new TQLabel(a->contentSize(), fileGB), 2,1, Qt::AlignLeft);
+  fileL->addWidget(new TQLabel(a->contentSize(), fileGB), 2,1, TQt::AlignLeft);
 
   fileL->setColStretch(1,1);
   topL->addWidget(fileGB);
@@ -2604,7 +2604,7 @@ KNComposer::AttachmentPropertiesDlg::AttachmentPropertiesDlg(KNAttachment *a, TQ
     this, TQT_SLOT(slotMimeTypeTextChanged(const TQString&)));
 
   //finish GUI
-  setFixedHeight(sizeHint().height());
+  setFixedHeight(tqsizeHint().height());
   KNHelper::restoreWindowSize("attProperties", this, TQSize(300,250));
   setHelp("anc-knode-editor-advanced");
 }
