@@ -112,8 +112,8 @@ bool KNConfig::Identity::emailIsValid()
 
 TQString KNConfig::Identity::getSignature()
 {
-  s_igContents = TQString::null;      // don't cache file contents
-  s_igStdErr = TQString::null;
+  s_igContents = TQString();      // don't cache file contents
+  s_igStdErr = TQString();
 
   if (u_seSigFile) {
     if(!s_igPath.isEmpty()) {
@@ -452,7 +452,7 @@ TQColor KNConfig::Appearance::defaultColor(int i) const
   switch(i) {
 
     case background:
-      return kapp->palette().active().base();
+      return kapp->tqpalette().active().base();
 
     case alternateBackground:
       return KGlobalSettings::alternateBackgroundColor();
@@ -466,13 +466,13 @@ TQColor KNConfig::Appearance::defaultColor(int i) const
 
     case normalText:
     case unreadThread:
-      return kapp->palette().active().text();
+      return kapp->tqpalette().active().text();
 
     case url:
       return KGlobalSettings::linkColor();
 
     case readThread:
-      return kapp->palette().disabled().text();
+      return kapp->tqpalette().disabled().text();
 
     case unreadArticle:
       return TQColor( 183, 154, 11 );
@@ -486,13 +486,13 @@ TQColor KNConfig::Appearance::defaultColor(int i) const
     case signWarn:
       return TQColor( 0xFF, 0xFF, 0x40 );
     case signErr:
-      return Qt::red;
+      return TQt::red;
 
     case htmlWarning:
       return TQColor( 0xFF, 0x40, 0x40 );
   }
 
-  return kapp->palette().disabled().text();
+  return kapp->tqpalette().disabled().text();
 }
 
 
@@ -942,11 +942,11 @@ void KNConfig::PostNewsTechnical::save()
   conf->setGroup("POSTNEWS");
 
   conf->writeEntry("ComposerCharsets", c_omposerCharsets);
-  conf->writeEntry("Charset", TQString::fromLatin1(c_harset));
+  conf->writeEntry("Charset", TQString::tqfromLatin1(c_harset));
   conf->writeEntry("8BitEncoding", a_llow8BitBody);
   conf->writeEntry("UseOwnCharset", u_seOwnCharset);
   conf->writeEntry("generateMId", g_enerateMID);
-  conf->writeEntry("MIdhost", TQString::fromLatin1(h_ostname));
+  conf->writeEntry("MIdhost", TQString::tqfromLatin1(h_ostname));
   conf->writeEntry("dontIncludeUA", d_ontIncludeUA);
   conf->writeEntry("useExternalMailer", u_seExternalMailer);
 
@@ -1100,7 +1100,7 @@ KNConfig::Cleanup::Cleanup( bool global ) :
   // default values for new accounts / groups
   d_oExpire( true ), r_emoveUnavailable( true ), p_reserveThr( true ),
   e_xpireInterval( 5 ), r_eadMaxAge( 10 ), u_nreadMaxAge( 15 ),
-  mGlobal(global), mDefault(!global), mLastExpDate( TQDate::currentDate() )
+  mGlobal(global), mDefault(!global), mLastExpDate( TQDate::tqcurrentDate() )
 {
   if (mGlobal) {
     KConfig *conf = knGlobals.config();
@@ -1174,17 +1174,17 @@ bool KNConfig::Cleanup::expireToday()
   if (!d_oExpire)
     return false;
 
-  TQDate today = TQDate::currentDate();
-  if (mLastExpDate == today)
+  TQDate today = TQDate::tqcurrentDate();
+  if (mLastExpDate == TQDateTime(today))
     return false;
 
-  return (mLastExpDate.daysTo( today ) >= e_xpireInterval);
+  return (mLastExpDate.daysTo( TQDateTime(today) ) >= e_xpireInterval);
 }
 
 
 void KNConfig::Cleanup::setLastExpireDate()
 {
-  mLastExpDate = TQDateTime::currentDateTime();
+  mLastExpDate = TQDateTime::tqcurrentDateTime();
 }
 
 
@@ -1193,17 +1193,17 @@ bool KNConfig::Cleanup::compactToday()
   if (!d_oCompact)
     return false;
 
-  TQDate today = TQDate::currentDate();
-  if (mLastCompDate == today)
+  TQDate today = TQDate::tqcurrentDate();
+  if (mLastCompDate == TQDateTime(today))
     return false;
 
-  return (mLastCompDate.daysTo( today ) >= c_ompactInterval);
+  return (mLastCompDate.daysTo( TQDateTime(today) ) >= c_ompactInterval);
 }
 
 
 void KNConfig::Cleanup::setLastCompactDate()
 {
-  mLastCompDate = TQDateTime::currentDateTime();
+  mLastCompDate = TQDateTime::tqcurrentDateTime();
 }
 
 
