@@ -163,7 +163,7 @@ KNConfig::IdentityWidget::IdentityWidget( Identity *d, TQWidget *p, const char *
   topL->addMultiCellWidget(s_igEdit, 9, 9, 0, 2);
 
   s_igEditor = new TQTextEdit(this);
-  s_igEditor->setTextFormat(Qt::PlainText);
+  s_igEditor->setTextFormat(TQt::PlainText);
   topL->addMultiCellWidget(s_igEditor, 10, 10, 0, 2);
   connect( s_igEditor, TQT_SIGNAL(textChanged()), TQT_SLOT(changed()) );
 
@@ -242,7 +242,7 @@ void KNConfig::IdentityWidget::slotSignatureType(int type)
 
 void KNConfig::IdentityWidget::slotSignatureChoose()
 {
-  TQString tmp=KFileDialog::getOpenFileName(c_ompletion->replacedPath(s_ig->text()),TQString::null,this,i18n("Choose Signature"));
+  TQString tmp=KFileDialog::getOpenFileName(c_ompletion->replacedPath(s_ig->text()),TQString(),this,i18n("Choose Signature"));
   if(!tmp.isEmpty()) s_ig->setText(tmp);
   emit changed( true );
 }
@@ -294,7 +294,7 @@ KNConfig::NntpAccountListWidget::NntpAccountListWidget(TQWidget *p, const char *
   topL->addMultiCellWidget(l_box, 0,4, 0,0);
 
   // info box
-  TQGroupBox *gb = new TQGroupBox(2,Qt::Vertical,TQString::null,this);
+  TQGroupBox *gb = new TQGroupBox(2,Qt::Vertical,TQString(),this);
   topL->addWidget(gb,5,0);
 
   s_erverInfo = new TQLabel(gb);
@@ -395,8 +395,8 @@ void KNConfig::NntpAccountListWidget::slotSelectionChanged()
 
   LBoxItem *it = static_cast<LBoxItem*>(l_box->item(curr));
   if(it) {
-    s_erverInfo->setText(i18n("Server: %1").arg(it->account->server()));
-    p_ortInfo->setText(i18n("Port: %1").arg(it->account->port()));
+    s_erverInfo->setText(i18n("Server: %1").tqarg(it->account->server()));
+    p_ortInfo->setText(i18n("Port: %1").tqarg(it->account->port()));
   }
   else {
     s_erverInfo->setText(i18n("Server: "));
@@ -461,7 +461,7 @@ void KNConfig::NntpAccountListWidget::slotSubBtnClicked()
 
 
 KNConfig::NntpAccountConfDialog::NntpAccountConfDialog(KNNntpAccount *a, TQWidget *p, const char *n)
-  : KDialogBase(Tabbed, (a->id()!=-1)? i18n("Properties of %1").arg(a->name()):i18n("New Account"),
+  : KDialogBase(Tabbed, (a->id()!=-1)? i18n("Properties of %1").tqarg(a->name()):i18n("New Account"),
                 Ok|Cancel|Help, Ok, p, n),
     a_ccount(a)
 {
@@ -561,7 +561,7 @@ KNConfig::NntpAccountConfDialog::NntpAccountConfDialog(KNNntpAccount *a, TQWidge
 
   connect( knGlobals.accountManager(), TQT_SIGNAL(passwordsChanged()), TQT_SLOT(slotPasswordChanged()) );
 
-  KNHelper::restoreWindowSize("accNewsPropDLG", this, sizeHint());
+  KNHelper::restoreWindowSize("accNewsPropDLG", this, tqsizeHint());
 
   setHelp("anc-setting-the-news-account");
 }
@@ -749,7 +749,7 @@ void KNConfig::AppearanceWidget::ColorListItem::paint( TQPainter *p )
 
   p->drawText( 30+3*2, fm.ascent() + fm.leading()/2, text() );
 
-  p->setPen( Qt::black );
+  p->setPen( TQt::black );
   p->drawRect( 3, 1, 30, h-1 );
   p->fillRect( 4, 2, 28, h-3, mColor );
 }
@@ -773,7 +773,7 @@ int KNConfig::AppearanceWidget::ColorListItem::width(const TQListBox *lb ) const
 KNConfig::AppearanceWidget::FontListItem::FontListItem( const TQString &name, const TQFont &font )
   : TQListBoxText(name), f_ont(font)
 {
-  fontInfo = TQString("[%1 %2]").arg(f_ont.family()).arg(f_ont.pointSize());
+  fontInfo = TQString("[%1 %2]").tqarg(f_ont.family()).tqarg(f_ont.pointSize());
 }
 
 
@@ -785,7 +785,7 @@ KNConfig::AppearanceWidget::FontListItem::~FontListItem()
 void KNConfig::AppearanceWidget::FontListItem::setFont(const TQFont &font)
 {
   f_ont = font;
-  fontInfo = TQString("[%1 %2]").arg(f_ont.family()).arg(f_ont.pointSize());
+  fontInfo = TQString("[%1 %2]").tqarg(f_ont.family()).tqarg(f_ont.pointSize());
 }
 
 
@@ -896,7 +896,7 @@ void KNConfig::AppearanceWidget::defaults()
     colorItem->setColor(d_ata->defaultColor(i));
   }
   c_List->triggerUpdate(true);
-  c_List->repaint(true);
+  c_List->tqrepaint(true);
 
   // default fonts
   FontListItem *fontItem;
@@ -1548,8 +1548,8 @@ KNConfig::DisplayedHeaderConfDialog::DisplayedHeaderConfDialog(KNDisplayedHeader
     v_alueCB[i]->setChecked(h->flag(i+4));
   }
 
-  setFixedHeight(sizeHint().height());
-  KNHelper::restoreWindowSize("accReadHdrPropDLG", this, sizeHint());
+  setFixedHeight(tqsizeHint().height());
+  KNHelper::restoreWindowSize("accReadHdrPropDLG", this, tqsizeHint());
 
   connect(n_ameE, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotNameChanged(const TQString&)));
 
@@ -2074,7 +2074,7 @@ void KNConfig::PostNewsTechnicalWidget::slotItemSelected(int)
 
 void KNConfig::PostNewsTechnicalWidget::slotAddBtnClicked()
 {
-  XHeaderConfDialog *dlg=new XHeaderConfDialog(TQString::null, this);
+  XHeaderConfDialog *dlg=new XHeaderConfDialog(TQString(), this);
   if (dlg->exec())
     l_box->insertItem(dlg->result());
 
@@ -2138,8 +2138,8 @@ KNConfig::XHeaderConfDialog::XHeaderConfDialog(const TQString &h, TQWidget *p, c
     v_alue->setText(h.mid(pos, h.length()-pos));
   }
 
-  setFixedHeight(sizeHint().height());
-  KNHelper::restoreWindowSize("XHeaderDlg", this, sizeHint());
+  setFixedHeight(tqsizeHint().height());
+  KNHelper::restoreWindowSize("XHeaderDlg", this, tqsizeHint());
 
   n_ame->setFocus();
 }
@@ -2158,7 +2158,7 @@ TQString KNConfig::XHeaderConfDialog::result()
   TQString value = v_alue->text();
   // just in case someone pastes a newline
   value.replace( '\n', ' ' );
-  return TQString( "X-%1: %2" ).arg( n_ame->text() ).arg( value );
+  return TQString( "X-%1: %2" ).tqarg( n_ame->text() ).tqarg( value );
 }
 
 
@@ -2293,7 +2293,7 @@ void KNConfig::PostNewsComposerWidget::slotChooseEditor()
   if (path.right(3) == " %f")
     path.truncate(path.length()-3);
 
-  path=KFileDialog::getOpenFileName(path, TQString::null, this, i18n("Choose Editor"));
+  path=KFileDialog::getOpenFileName(path, TQString(), this, i18n("Choose Editor"));
 
   if (!path.isEmpty())
     e_ditor->setText(path+" %f");
@@ -2373,10 +2373,10 @@ KNConfig::GroupCleanupWidget::GroupCleanupWidget( Cleanup *data, TQWidget *paren
 
   mExpGroup = new TQGroupBox( i18n("Newsgroup Cleanup Settings"), this );
   mExpGroup->setColumnLayout(0, Qt::Vertical );
-  mExpGroup->layout()->setSpacing( KDialog::spacingHint() );
-  mExpGroup->layout()->setMargin( KDialog::marginHint() );
+  mExpGroup->tqlayout()->setSpacing( KDialog::spacingHint() );
+  mExpGroup->tqlayout()->setMargin( KDialog::marginHint() );
   top->addWidget( mExpGroup );
-  TQGridLayout *grid = new TQGridLayout( mExpGroup->layout(), 7, 2 );
+  TQGridLayout *grid = new TQGridLayout( mExpGroup->tqlayout(), 7, 2 );
 
   grid->setRowSpacing( 0, KDialog::spacingHint() );
 
@@ -2387,7 +2387,7 @@ KNConfig::GroupCleanupWidget::GroupCleanupWidget( Cleanup *data, TQWidget *paren
   mExpDays = new KIntSpinBox( 0, 99999, 1, 0, 10, mExpGroup );
   TQLabel *label = new TQLabel( mExpDays, i18n("&Purge groups every:"), mExpGroup );
   grid->addWidget( label, 2, 0 );
-  grid->addWidget( mExpDays, 2, 1, Qt::AlignRight );
+  grid->addWidget( mExpDays, 2, 1, TQt::AlignRight );
   connect( mExpDays, TQT_SIGNAL(valueChanged(int)), TQT_SIGNAL(changed()) );
   connect( mExpDays, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(expDaysChanged(int)) );
   connect( mExpEnabled, TQT_SIGNAL(toggled(bool)), label, TQT_SLOT(setEnabled(bool)) );
@@ -2396,14 +2396,14 @@ KNConfig::GroupCleanupWidget::GroupCleanupWidget( Cleanup *data, TQWidget *paren
   mExpReadDays = new KIntSpinBox( 0, 99999, 1, 0, 10, mExpGroup );
   label = new TQLabel( mExpReadDays, i18n("&Keep read articles:"), mExpGroup );
   grid->addWidget( label, 3, 0 );
-  grid->addWidget( mExpReadDays, 3, 1, Qt::AlignRight );
+  grid->addWidget( mExpReadDays, 3, 1, TQt::AlignRight );
   connect( mExpReadDays, TQT_SIGNAL(valueChanged(int)), TQT_SIGNAL(changed()) );
   connect( mExpReadDays, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(expReadDaysChanged(int)) );
 
   mExpUnreadDays = new KIntSpinBox( 0, 99999, 1, 0, 10, mExpGroup );
   label = new TQLabel( mExpUnreadDays, i18n("Keep u&nread articles:"), mExpGroup );
   grid->addWidget( label, 4, 0 );
-  grid->addWidget( mExpUnreadDays, 4, 1, Qt::AlignRight );
+  grid->addWidget( mExpUnreadDays, 4, 1, TQt::AlignRight );
   connect( mExpUnreadDays, TQT_SIGNAL(valueChanged(int)), TQT_SIGNAL(changed()) );
   connect( mExpUnreadDays, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(expUnreadDaysChanged(int)) );
 
@@ -2482,11 +2482,11 @@ KNConfig::CleanupWidget::CleanupWidget( TQWidget *p, const char *n ) :
 
   TQGroupBox *foldersB=new TQGroupBox(i18n("Folders"), this);
   foldersB->setColumnLayout(0, Qt::Vertical );
-  foldersB->layout()->setSpacing( KDialog::spacingHint() );
-  foldersB->layout()->setMargin( KDialog::marginHint() );
+  foldersB->tqlayout()->setSpacing( KDialog::spacingHint() );
+  foldersB->tqlayout()->setMargin( KDialog::marginHint() );
 
   topL->addWidget(foldersB);
-  TQGridLayout *foldersL=new TQGridLayout(foldersB->layout(), 3,2);
+  TQGridLayout *foldersL=new TQGridLayout(foldersB->tqlayout(), 3,2);
 
   foldersL->setRowSpacing( 0, KDialog::spacingHint() );
 
@@ -2497,7 +2497,7 @@ KNConfig::CleanupWidget::CleanupWidget( TQWidget *p, const char *n ) :
   f_olderDays=new KIntSpinBox(0, 99999, 1, 0, 10, foldersB);
   f_olderDaysL=new TQLabel(f_olderDays,i18n("P&urge folders every:"), foldersB);
   foldersL->addWidget(f_olderDaysL,2,0);
-  foldersL->addWidget(f_olderDays,2,1,Qt::AlignRight);
+  foldersL->addWidget(f_olderDays,2,1,TQt::AlignRight);
   connect(f_olderDays, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(changed()));
   connect(f_olderDays, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotFolderDaysChanged(int)));
 
