@@ -85,7 +85,7 @@ KNMainWidget::KNMainWidget( KXMLGUIClient* client, bool detachable, TQWidget* pa
 
   //-------------------------------- <GUI> ------------------------------------
   TQAccel *accel = new TQAccel( this );
-  initStatusBar();
+  iniStatusBar();
 
   //setup splitter behavior
   manager()->setSplitterHighResolution(true);
@@ -253,7 +253,7 @@ KNMainWidget::KNMainWidget( KXMLGUIClient* client, bool detachable, TQWidget* pa
 
   c_olView->setFocus();
 
-  setStatusMsg();
+  seStatusMsg();
 
   if( firstStart() ) {  // open the config dialog on the first start
     show();              // the settings dialog must appear in front of the main window!
@@ -302,35 +302,35 @@ KNMainWidget::~KNMainWidget()
   delete a_rtDock;
 }
 
-void KNMainWidget::initStatusBar()
+void KNMainWidget::iniStatusBar()
 {
   //statusbar
-  KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+  KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
   KStatusBar *sb =  mainWin ? mainWin->statusBar() : 0;
-  s_tatusFilter = new KRSqueezedTextLabel( TQString::null, sb );
-  s_tatusFilter->setAlignment( AlignLeft | AlignVCenter );
-  s_tatusGroup = new KRSqueezedTextLabel( TQString::null, sb );
-  s_tatusGroup->setAlignment( AlignLeft | AlignVCenter );
+  s_tatusFilter = new KRSqueezedTextLabel( TQString(), sb );
+  s_tatusFilter->tqsetAlignment( AlignLeft | AlignVCenter );
+  s_tatusGroup = new KRSqueezedTextLabel( TQString(), sb );
+  s_tatusGroup->tqsetAlignment( AlignLeft | AlignVCenter );
 }
 
 //================================== GUI =================================
 
-void KNMainWidget::setStatusMsg(const TQString& text, int id)
+void KNMainWidget::seStatusMsg(const TQString& text, int id)
 {
-  KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+  KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
   KStatusBar *bar =  mainWin ? mainWin->statusBar() : 0;
   if ( !bar )
     return;
   bar->clear();
   if (text.isEmpty() && (id==SB_MAIN)) {
     if (knGlobals.netAccess()->currentMsg().isEmpty())
-      BroadcastStatus::instance()->setStatusMsg(i18n(" Ready"));
+      BroadcastStatus::instance()->seStatusMsg(i18n(" Ready"));
     else
-      BroadcastStatus::instance()->setStatusMsg(knGlobals.netAccess()->currentMsg());
+      BroadcastStatus::instance()->seStatusMsg(knGlobals.netAccess()->currentMsg());
   } else {
     switch(id) {
       case SB_MAIN:
-        BroadcastStatus::instance()->setStatusMsg(text); break;
+        BroadcastStatus::instance()->seStatusMsg(text); break;
       case SB_GROUP:
         s_tatusGroup->setText(text); break;
       case SB_FILTER:
@@ -340,9 +340,9 @@ void KNMainWidget::setStatusMsg(const TQString& text, int id)
 }
 
 
-void KNMainWidget::setStatusHelpMsg(const TQString& text)
+void KNMainWidget::seStatusHelpMsg(const TQString& text)
 {
-  KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+  KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
   KStatusBar *bar =  mainWin ? mainWin->statusBar() : 0;
   if ( bar )
     bar->message(text, 2000);
@@ -375,7 +375,7 @@ void KNMainWidget::setCursorBusy(bool b)
 void KNMainWidget::blockUI(bool b)
 {
   b_lockui = b;
-  KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+  KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
   KMenuBar *mbar =  mainWin ? mainWin->menuBar() : 0;
   if ( mbar )
     mbar->setEnabled(!b);
@@ -394,7 +394,7 @@ void KNMainWidget::blockUI(bool b)
 void KNMainWidget::disableAccels(bool b)
 {
   a_ccel->setEnabled(!b);
-  KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+  KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
   KAccel *naccel = mainWin ? mainWin->accel() : 0;
   if ( naccel )
     naccel->setEnabled(!b);
@@ -409,7 +409,7 @@ void KNMainWidget::disableAccels(bool b)
 void KNMainWidget::secureProcessEvents()
 {
   b_lockui = true;
-  KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+  KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
   KMenuBar *mbar =  mainWin ? mainWin->menuBar() : 0;
   if ( mbar )
     mbar->setEnabled(false);
@@ -431,7 +431,7 @@ void KNMainWidget::secureProcessEvents()
 }
 
 
-TQSize KNMainWidget::sizeHint() const
+TQSize KNMainWidget::tqsizeHint() const
 {
   return TQSize(759,478);    // default optimized for 800x600
 }
@@ -550,113 +550,113 @@ void KNMainWidget::initActions()
 
   //navigation
   a_ctNavNextArt            = new KAction( KGuiItem(i18n("&Next Article"), "next",
-                              i18n("Go to next article")), "N;Right", h_drView,
+                              i18n("Go to next article")), "N;Right", TQT_TQOBJECT(h_drView),
                               TQT_SLOT(nextArticle()), actionCollection(), "go_nextArticle" );
   a_ctNavPrevArt            = new KAction( KGuiItem(i18n("&Previous Article"), "previous",
-                              i18n("Go to previous article")), "P;Left" , h_drView,
+                              i18n("Go to previous article")), "P;Left" , TQT_TQOBJECT(h_drView),
                               TQT_SLOT(prevArticle()), actionCollection(), "go_prevArticle" );
-  a_ctNavNextUnreadArt      = new KAction(i18n("Next Unread &Article"), "1rightarrow", ALT+SHIFT+Key_Space , this,
+  a_ctNavNextUnreadArt      = new KAction(i18n("Next Unread &Article"), "1rightarrow", ALT+SHIFT+Key_Space , TQT_TQOBJECT(this),
                               TQT_SLOT(slotNavNextUnreadArt()), actionCollection(), "go_nextUnreadArticle");
-  a_ctNavNextUnreadThread   = new KAction(i18n("Next Unread &Thread"),"2rightarrow", SHIFT+Key_Space , this,
+  a_ctNavNextUnreadThread   = new KAction(i18n("Next Unread &Thread"),"2rightarrow", SHIFT+Key_Space , TQT_TQOBJECT(this),
                               TQT_SLOT(slotNavNextUnreadThread()), actionCollection(), "go_nextUnreadThread");
-  a_ctNavNextGroup          = new KAction(i18n("Ne&xt Group"), "down", Key_Plus , c_olView,
+  a_ctNavNextGroup          = new KAction(i18n("Ne&xt Group"), "down", Key_Plus , TQT_TQOBJECT(c_olView),
                               TQT_SLOT(nextGroup()), actionCollection(), "go_nextGroup");
-  a_ctNavPrevGroup          = new KAction(i18n("Pre&vious Group"), "up", Key_Minus , c_olView,
+  a_ctNavPrevGroup          = new KAction(i18n("Pre&vious Group"), "up", Key_Minus , TQT_TQOBJECT(c_olView),
                               TQT_SLOT(prevGroup()), actionCollection(), "go_prevGroup");
-  a_ctNavReadThrough        = new KAction(i18n("Read &Through Articles"), Key_Space , this,
+  a_ctNavReadThrough        = new KAction(i18n("Read &Through Articles"), Key_Space , TQT_TQOBJECT(this),
                               TQT_SLOT(slotNavReadThrough()), actionCollection(), "go_readThrough");
   a_ctNavReadThrough->plugAccel(a_ccel);
 
   TQAccel *accel = new TQAccel( this );
-  new KAction( i18n("Focus on Next Folder"), CTRL+Key_Right, c_olView,
+  new KAction( i18n("Focus on Next Folder"), CTRL+Key_Right, TQT_TQOBJECT(c_olView),
     TQT_SLOT(incCurrentFolder()), actionCollection(), "inc_current_folder" );
   accel->connectItem(accel->insertItem(CTRL+Key_Right),
     c_olView, TQT_SLOT(incCurrentFolder()));
-  new KAction( i18n("Focus on Previous Folder"), CTRL+Key_Left, c_olView,
+  new KAction( i18n("Focus on Previous Folder"), CTRL+Key_Left, TQT_TQOBJECT(c_olView),
     TQT_SLOT(decCurrentFolder()), actionCollection(), "dec_current_folder" );
   accel->connectItem(accel->insertItem(CTRL+Key_Left),
     c_olView, TQT_SLOT(decCurrentFolder()));
-  new KAction( i18n("Select Folder with Focus"), CTRL+Key_Space, c_olView,
+  new KAction( i18n("Select Folder with Focus"), CTRL+Key_Space, TQT_TQOBJECT(c_olView),
     TQT_SLOT(selectCurrentFolder()), actionCollection(), "select_current_folder" );
   accel->connectItem(accel->insertItem(CTRL+Key_Space),
     c_olView, TQT_SLOT(selectCurrentFolder()));
 
-  new KAction( i18n("Focus on Next Article"), ALT+Key_Right, h_drView,
+  new KAction( i18n("Focus on Next Article"), ALT+Key_Right, TQT_TQOBJECT(h_drView),
                TQT_SLOT(incCurrentArticle()), actionCollection(), "inc_current_article" );
   accel->connectItem( accel->insertItem(ALT+Key_Right),
-                      h_drView, TQT_SLOT(incCurrentArticle()) );
-  new KAction( i18n("Focus on Previous Article"), ALT+Key_Left, h_drView,
+                      TQT_TQOBJECT(h_drView), TQT_SLOT(incCurrentArticle()) );
+  new KAction( i18n("Focus on Previous Article"), ALT+Key_Left, TQT_TQOBJECT(h_drView),
                TQT_SLOT(decCurrentArticle()), actionCollection(), "dec_current_article" );
   accel->connectItem( accel->insertItem(ALT+Key_Left),
-                      h_drView, TQT_SLOT(decCurrentArticle()) );
-  new KAction( i18n("Select Article with Focus"), ALT+Key_Space, h_drView,
+                      TQT_TQOBJECT(h_drView), TQT_SLOT(decCurrentArticle()) );
+  new KAction( i18n("Select Article with Focus"), ALT+Key_Space, TQT_TQOBJECT(h_drView),
                TQT_SLOT(selectCurrentArticle()), actionCollection(), "select_current_article" );
   accel->connectItem( accel->insertItem(ALT+Key_Space),
-                      h_drView, TQT_SLOT(selectCurrentArticle()) );
+                      TQT_TQOBJECT(h_drView), TQT_SLOT(selectCurrentArticle()) );
 
   //collection-view - accounts
-  a_ctAccProperties         = new KAction(i18n("Account &Properties"), "configure", 0, this,
+  a_ctAccProperties         = new KAction(i18n("Account &Properties"), "configure", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotAccProperties()), actionCollection(), "account_properties");
-  a_ctAccRename             = new KAction(i18n("&Rename Account"), "text", 0, this,
+  a_ctAccRename             = new KAction(i18n("&Rename Account"), "text", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotAccRename()), actionCollection(), "account_rename");
-  a_ctAccSubscribe          = new KAction(i18n("&Subscribe to Newsgroups..."), "news_subscribe", 0, this,
+  a_ctAccSubscribe          = new KAction(i18n("&Subscribe to Newsgroups..."), "news_subscribe", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotAccSubscribe()), actionCollection(), "account_subscribe");
-  a_ctAccExpireAll          = new KAction(i18n("&Expire All Groups"), 0, this,
+  a_ctAccExpireAll          = new KAction(i18n("&Expire All Groups"), 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotAccExpireAll()), actionCollection(), "account_expire_all");
-  a_ctAccGetNewHdrs         = new KAction(i18n("&Get New Articles in All Groups"), "mail_get", 0, this,
+  a_ctAccGetNewHdrs         = new KAction(i18n("&Get New Articles in All Groups"), "mail_get", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotAccGetNewHdrs()), actionCollection(), "account_dnlHeaders");
-  a_ctAccGetNewHdrsAll      = new KAction(i18n("&Get New Articles in All Accounts"), "mail_get_all", 0, this,
+  a_ctAccGetNewHdrsAll      = new KAction(i18n("&Get New Articles in All Accounts"), "mail_get_all", 0, TQT_TQOBJECT(this),
                                           TQT_SLOT(slotAccGetNewHdrsAll()), actionCollection(), "account_dnlAllHeaders");
-  a_ctAccDelete             = new KAction(i18n("&Delete Account"), "editdelete", 0, this,
+  a_ctAccDelete             = new KAction(i18n("&Delete Account"), "editdelete", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotAccDelete()), actionCollection(), "account_delete");
-  a_ctAccPostNewArticle     = new KAction(i18n("&Post to Newsgroup..."), "mail_new", CTRL+Key_N, this,
+  a_ctAccPostNewArticle     = new KAction(i18n("&Post to Newsgroup..."), "mail_new", CTRL+Key_N, TQT_TQOBJECT(this),
                               TQT_SLOT(slotAccPostNewArticle()), actionCollection(), "article_postNew");
 
   //collection-view - groups
-  a_ctGrpProperties         = new KAction(i18n("Group &Properties"), "configure", 0, this,
+  a_ctGrpProperties         = new KAction(i18n("Group &Properties"), "configure", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotGrpProperties()), actionCollection(), "group_properties");
-  a_ctGrpRename             = new KAction(i18n("Rename &Group"), "text", 0, this,
+  a_ctGrpRename             = new KAction(i18n("Rename &Group"), "text", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotGrpRename()), actionCollection(), "group_rename");
-  a_ctGrpGetNewHdrs         = new KAction(i18n("&Get New Articles"), "mail_get" , 0, this,
+  a_ctGrpGetNewHdrs         = new KAction(i18n("&Get New Articles"), "mail_get" , 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotGrpGetNewHdrs()), actionCollection(), "group_dnlHeaders");
-  a_ctGrpExpire             = new KAction(i18n("E&xpire Group"), "wizard", 0, this,
+  a_ctGrpExpire             = new KAction(i18n("E&xpire Group"), "wizard", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotGrpExpire()), actionCollection(), "group_expire");
-  a_ctGrpReorganize         = new KAction(i18n("Re&organize Group"), 0, this,
+  a_ctGrpReorganize         = new KAction(i18n("Re&organize Group"), 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotGrpReorganize()), actionCollection(), "group_reorg");
-  a_ctGrpUnsubscribe        = new KAction(i18n("&Unsubscribe From Group"), "news_unsubscribe", 0, this,
+  a_ctGrpUnsubscribe        = new KAction(i18n("&Unsubscribe From Group"), "news_unsubscribe", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotGrpUnsubscribe()), actionCollection(), "group_unsubscribe");
-  a_ctGrpSetAllRead         = new KAction(i18n("Mark All as &Read"), "goto", 0, this,
+  a_ctGrpSetAllRead         = new KAction(i18n("Mark All as &Read"), "goto", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotGrpSetAllRead()), actionCollection(), "group_allRead");
-  a_ctGrpSetAllUnread       = new KAction(i18n("Mark All as U&nread"), 0, this,
+  a_ctGrpSetAllUnread       = new KAction(i18n("Mark All as U&nread"), 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotGrpSetAllUnread()), actionCollection(), "group_allUnread");
-  a_ctGrpSetUnread          = new KAction(i18n("Mark Last as Unr&ead..."), 0, this,
+  a_ctGrpSetUnread          = new KAction(i18n("Mark Last as Unr&ead..."), 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotGrpSetUnread()), actionCollection(), "group_unread");
 
 
 
    (void) new KAction( i18n("&Configure KNode..."),
-                       "configure", 0, this,
+                       "configure", 0, TQT_TQOBJECT(this),
                        TQT_SLOT(slotSettings()), actionCollection(),
                        "knode_configure_knode" );
 
   //collection-view - folder
-  a_ctFolNew                = new KAction(i18n("&New Folder"), "folder_new", 0, this,
+  a_ctFolNew                = new KAction(i18n("&New Folder"), "folder_new", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotFolNew()), actionCollection(), "folder_new");
-  a_ctFolNewChild           = new KAction(i18n("New &Subfolder"), "folder_new", 0, this,
+  a_ctFolNewChild           = new KAction(i18n("New &Subfolder"), "folder_new", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotFolNewChild()), actionCollection(), "folder_newChild");
-  a_ctFolDelete             = new KAction(i18n("&Delete Folder"), "editdelete", 0, this,
+  a_ctFolDelete             = new KAction(i18n("&Delete Folder"), "editdelete", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotFolDelete()), actionCollection(), "folder_delete");
-  a_ctFolRename             = new KAction(i18n("&Rename Folder"), "text", 0, this,
+  a_ctFolRename             = new KAction(i18n("&Rename Folder"), "text", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotFolRename()), actionCollection(), "folder_rename");
-  a_ctFolCompact            = new KAction(i18n("C&ompact Folder"), "wizard", 0, this,
+  a_ctFolCompact            = new KAction(i18n("C&ompact Folder"), "wizard", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotFolCompact()), actionCollection(), "folder_compact");
-  a_ctFolCompactAll         = new KAction(i18n("Co&mpact All Folders"), 0, this,
+  a_ctFolCompactAll         = new KAction(i18n("Co&mpact All Folders"), 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotFolCompactAll()), actionCollection(), "folder_compact_all");
-  a_ctFolEmpty              = new KAction(i18n("&Empty Folder"), 0, this,
+  a_ctFolEmpty              = new KAction(i18n("&Empty Folder"), 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotFolEmpty()), actionCollection(), "folder_empty");
-  a_ctFolMboxImport         = new KAction(i18n("&Import MBox Folder..."), 0, this,
+  a_ctFolMboxImport         = new KAction(i18n("&Import MBox Folder..."), 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotFolMBoxImport()), actionCollection(), "folder_MboxImport");
-  a_ctFolMboxExport         = new KAction(i18n("E&xport as MBox Folder..."), 0, this,
+  a_ctFolMboxExport         = new KAction(i18n("E&xport as MBox Folder..."), 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotFolMBoxExport()), actionCollection(), "folder_MboxExport");
 
   //header-view - list-handling
@@ -670,7 +670,7 @@ void KNMainWidget::initActions()
   a_ctArtSortHeaders->setItems(items);
   a_ctArtSortHeaders->setShortcutConfigurable(false);
   connect(a_ctArtSortHeaders, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotArtSortHeaders(int)));
-  a_ctArtSortHeadersKeyb   = new KAction(i18n("Sort"), TQString::null, Key_F7 , this,
+  a_ctArtSortHeadersKeyb   = new KAction(i18n("Sort"), TQString(), Key_F7 , TQT_TQOBJECT(this),
                              TQT_SLOT(slotArtSortHeadersKeyb()), actionCollection(), "view_Sort_Keyb");
   a_ctArtSortHeadersKeyb->plugAccel(a_ccel);
   a_ctArtFilter             = new KNFilterSelectAction(i18n("&Filter"), "filter",
@@ -678,86 +678,86 @@ void KNMainWidget::initActions()
   a_ctArtFilter->setShortcutConfigurable(false);
   a_ctArtFilterKeyb         = new KAction(i18n("Filter"), Key_F6, actionCollection(), "view_Filter_Keyb");
   a_ctArtFilterKeyb->plugAccel(a_ccel);
-  a_ctArtSearch             = new KAction(i18n("&Search Articles..."),"mail_find" , Key_F4 , this,
+  a_ctArtSearch             = new KAction(i18n("&Search Articles..."),"mail_find" , Key_F4 , TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtSearch()), actionCollection(), "article_search");
-  a_ctArtRefreshList        = new KAction(i18n("&Refresh List"),"reload", KStdAccel::shortcut(KStdAccel::Reload), this,
+  a_ctArtRefreshList        = new KAction(i18n("&Refresh List"),"reload", KStdAccel::shortcut(KStdAccel::Reload), TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtRefreshList()), actionCollection(), "view_Refresh");
-  a_ctArtCollapseAll        = new KAction(i18n("&Collapse All Threads"), 0 , this,
+  a_ctArtCollapseAll        = new KAction(i18n("&Collapse All Threads"), 0 , TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtCollapseAll()), actionCollection(), "view_CollapseAll");
-  a_ctArtExpandAll          = new KAction(i18n("E&xpand All Threads"), 0 , this,
+  a_ctArtExpandAll          = new KAction(i18n("E&xpand All Threads"), 0 , TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtExpandAll()), actionCollection(), "view_ExpandAll");
-  a_ctArtToggleThread       = new KAction(i18n("&Toggle Subthread"), Key_T, this,
+  a_ctArtToggleThread       = new KAction(i18n("&Toggle Subthread"), Key_T, TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtToggleThread()), actionCollection(), "thread_toggle");
-  a_ctArtToggleShowThreads  = new KToggleAction(i18n("Show T&hreads"), 0 , this,
+  a_ctArtToggleShowThreads  = new KToggleAction(i18n("Show T&hreads"), 0 , TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtToggleShowThreads()), actionCollection(), "view_showThreads");
   a_ctArtToggleShowThreads->setCheckedState(i18n("Hide T&hreads"));
 
   a_ctArtToggleShowThreads->setChecked(c_fgManager->readNewsGeneral()->showThreads());
 
   //header-view - remote articles
-  a_ctArtSetArtRead         = new KAction(i18n("Mark as &Read"), Key_D , this,
+  a_ctArtSetArtRead         = new KAction(i18n("Mark as &Read"), Key_D , TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtSetArtRead()), actionCollection(), "article_read");
-  a_ctArtSetArtUnread       = new KAction(i18n("Mar&k as Unread"), Key_U , this,
+  a_ctArtSetArtUnread       = new KAction(i18n("Mar&k as Unread"), Key_U , TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtSetArtUnread()), actionCollection(), "article_unread");
-  a_ctArtSetThreadRead      = new KAction(i18n("Mark &Thread as Read"), CTRL+Key_D , this,
+  a_ctArtSetThreadRead      = new KAction(i18n("Mark &Thread as Read"), CTRL+Key_D , TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtSetThreadRead()), actionCollection(), "thread_read");
-  a_ctArtSetThreadUnread    = new KAction(i18n("Mark T&hread as Unread"), CTRL+Key_U , this,
+  a_ctArtSetThreadUnread    = new KAction(i18n("Mark T&hread as Unread"), CTRL+Key_U , TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtSetThreadUnread()), actionCollection(), "thread_unread");
-  a_ctArtOpenNewWindow      = new KAction(i18n("Open in Own &Window"), "window_new", Key_O , this,
+  a_ctArtOpenNewWindow      = new KAction(i18n("Open in Own &Window"), "window_new", Key_O , TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtOpenNewWindow()), actionCollection(), "article_ownWindow");
 
   // scoring
-  a_ctScoresEdit            = new KAction(i18n("&Edit Scoring Rules..."), "edit", CTRL+Key_E, this,
+  a_ctScoresEdit            = new KAction(i18n("&Edit Scoring Rules..."), "edit", CTRL+Key_E, TQT_TQOBJECT(this),
                               TQT_SLOT(slotScoreEdit()), actionCollection(), "scoreedit");
-  a_ctReScore               = new KAction(i18n("Recalculate &Scores"), 0, this,
+  a_ctReScore               = new KAction(i18n("Recalculate &Scores"), 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotReScore()),actionCollection(),"rescore");
-  a_ctScoreLower            = new KAction(i18n("&Lower Score for Author..."), CTRL+Key_L, this,
+  a_ctScoreLower            = new KAction(i18n("&Lower Score for Author..."), CTRL+Key_L, TQT_TQOBJECT(this),
                               TQT_SLOT(slotScoreLower()), actionCollection(), "scorelower");
-  a_ctScoreRaise            = new KAction(i18n("&Raise Score for Author..."), CTRL+Key_I, this,
+  a_ctScoreRaise            = new KAction(i18n("&Raise Score for Author..."), CTRL+Key_I, TQT_TQOBJECT(this),
                               TQT_SLOT(slotScoreRaise()),actionCollection(),"scoreraise");
-  a_ctArtToggleIgnored      = new KAction(i18n("&Ignore Thread"), "bottom", Key_I , this,
+  a_ctArtToggleIgnored      = new KAction(i18n("&Ignore Thread"), "bottom", Key_I , TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtToggleIgnored()), actionCollection(), "thread_ignore");
-  a_ctArtToggleWatched      = new KAction(i18n("&Watch Thread"), "top", Key_W , this,
+  a_ctArtToggleWatched      = new KAction(i18n("&Watch Thread"), "top", Key_W , TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtToggleWatched()), actionCollection(), "thread_watch");
 
   //header-view local articles
-  a_ctArtSendOutbox         = new KAction(i18n("Sen&d Pending Messages"), "mail_send", 0, this,
+  a_ctArtSendOutbox         = new KAction(i18n("Sen&d Pending Messages"), "mail_send", 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtSendOutbox()), actionCollection(), "net_sendPending");
-  a_ctArtDelete             = new KAction(i18n("&Delete Article"), "editdelete", Key_Delete, this,
+  a_ctArtDelete             = new KAction(i18n("&Delete Article"), "editdelete", Key_Delete, TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtDelete()), actionCollection(), "article_delete");
-  a_ctArtSendNow            = new KAction(i18n("Send &Now"),"mail_send", 0 , this,
+  a_ctArtSendNow            = new KAction(i18n("Send &Now"),"mail_send", 0 , TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtSendNow()), actionCollection(), "article_sendNow");
-  a_ctArtEdit               = new KAction(i18n("edit article","&Edit Article..."), "edit", Key_E , this,
+  a_ctArtEdit               = new KAction(i18n("edit article","&Edit Article..."), "edit", Key_E , TQT_TQOBJECT(this),
                               TQT_SLOT(slotArtEdit()), actionCollection(), "article_edit");
 
   //network
-  a_ctNetCancel             = new KAction(i18n("Stop &Network"),"stop",0, this,
+  a_ctNetCancel             = new KAction(i18n("Stop &Network"),"stop",0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotNetCancel()), actionCollection(), "net_stop");
   a_ctNetCancel->setEnabled(false);
 
-  a_ctFetchArticleWithID    = new KAction(i18n("&Fetch Article with ID..."), 0, this,
+  a_ctFetchArticleWithID    = new KAction(i18n("&Fetch Article with ID..."), 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotFetchArticleWithID()), actionCollection(), "fetch_article_with_id");
   a_ctFetchArticleWithID->setEnabled(false);
 
-  a_ctToggleGroupView        = new KToggleAction(i18n("Show &Group View"), CTRL+Key_G, this,
+  a_ctToggleGroupView        = new KToggleAction(i18n("Show &Group View"), CTRL+Key_G, TQT_TQOBJECT(this),
                                TQT_SLOT(slotToggleGroupView()), actionCollection(), "settings_show_groupView");
   a_ctToggleGroupView->setCheckedState(i18n("Hide &Group View"));
-  a_ctToggleHeaderView       = new KToggleAction(i18n("Show &Header View"), CTRL+Key_H, this,
+  a_ctToggleHeaderView       = new KToggleAction(i18n("Show &Header View"), CTRL+Key_H, TQT_TQOBJECT(this),
                                TQT_SLOT(slotToggleHeaderView()), actionCollection(), "settings_show_headerView");
   a_ctToggleHeaderView->setCheckedState(i18n("Hide &Header View"));
-  a_ctToggleArticleViewer    = new KToggleAction(i18n("Show &Article Viewer"), CTRL+Key_J, this,
+  a_ctToggleArticleViewer    = new KToggleAction(i18n("Show &Article Viewer"), CTRL+Key_J, TQT_TQOBJECT(this),
                                TQT_SLOT(slotToggleArticleViewer()), actionCollection(), "settings_show_articleViewer");
   a_ctToggleArticleViewer->setCheckedState(i18n("Hide &Article Viewer"));
-  a_ctToggleQuickSearch      = new KToggleAction(i18n("Show Quick Search"), TQString::null, this,
+  a_ctToggleQuickSearch      = new KToggleAction(i18n("Show Quick Search"), TQString(), TQT_TQOBJECT(this),
                                TQT_SLOT(slotToggleQuickSearch()), actionCollection(), "settings_show_quickSearch");
   a_ctToggleQuickSearch->setCheckedState(i18n("Hide Quick Search"));
-  a_ctSwitchToGroupView      = new KAction(i18n("Switch to Group View"), Key_G , this,
+  a_ctSwitchToGroupView      = new KAction(i18n("Switch to Group View"), Key_G , TQT_TQOBJECT(this),
                                TQT_SLOT(slotSwitchToGroupView()), actionCollection(), "switch_to_group_view");
   a_ctSwitchToGroupView->plugAccel(a_ccel);
-  a_ctSwitchToHeaderView     = new KAction(i18n("Switch to Header View"), Key_H , this,
+  a_ctSwitchToHeaderView     = new KAction(i18n("Switch to Header View"), Key_H , TQT_TQOBJECT(this),
                                TQT_SLOT(slotSwitchToHeaderView()), actionCollection(), "switch_to_header_view");
   a_ctSwitchToHeaderView->plugAccel(a_ccel);
-  a_ctSwitchToArticleViewer  = new KAction(i18n("Switch to Article Viewer"), Key_J , this,
+  a_ctSwitchToArticleViewer  = new KAction(i18n("Switch to Article Viewer"), Key_J , TQT_TQOBJECT(this),
                                TQT_SLOT(slotSwitchToArticleViewer()), actionCollection(), "switch_to_article_viewer");
   a_ctSwitchToArticleViewer->plugAccel(a_ccel);
 }
@@ -775,7 +775,7 @@ bool KNMainWidget::firstStart()
   emailConf.setGroup("Defaults");
   TQString group = emailConf.readEntry("Profile","Default");
 
-  emailConf.setGroup(TQString("PROFILE_%1").arg(group));
+  emailConf.setGroup(TQString("PROFILE_%1").tqarg(group));
   KNConfig::Identity *id=knGlobals.configManager()->identity();
   id->setName(emailConf.readEntry("FullName"));
   id->setEmail(emailConf.readEntry("EmailAddress").latin1());
@@ -841,7 +841,7 @@ bool KNMainWidget::requestShutdown()
   if( a_rtFactory->jobsPending() &&
       KMessageBox::No==KMessageBox::warningYesNo(this, i18n(
 "KNode is currently sending articles. If you quit now you might lose these \
-articles.\nDo you want to quit anyway?"), TQString::null, KStdGuiItem::quit(), KStdGuiItem::cancel())
+articles.\nDo you want to quit anyway?"), TQString(), KStdGuiItem::quit(), KStdGuiItem::cancel())
     )
     return false;
 
@@ -903,7 +903,7 @@ bool KNMainWidget::queryClose()
 
 void KNMainWidget::showEvent(TQShowEvent *)
 {
-  slotCheckDockWidgetStatus();
+  slotCheckDockWidgetqStatus();
 }
 
 
@@ -1301,7 +1301,7 @@ void KNMainWidget::slotNetworkActive(bool b)
 }
 
 
-void KNMainWidget::slotCheckDockWidgetStatus()
+void KNMainWidget::slotCheckDockWidgetqStatus()
 {
   a_ctToggleGroupView->setChecked(c_olDock->isVisible());
   a_ctToggleArticleViewer->setChecked(a_rtDock->isVisible());
@@ -1511,7 +1511,7 @@ void KNMainWidget::slotGrpUnsubscribe()
   kdDebug(5003) << "KNMainWidget::slotGrpUnsubscribe()" << endl;
   if(g_rpManager->currentGroup()) {
     if(KMessageBox::Yes==KMessageBox::questionYesNo(knGlobals.topWidget,
-      i18n("Do you really want to unsubscribe from %1?").arg(g_rpManager->currentGroup()->groupname()), TQString::null, i18n("Unsubscribe"), KStdGuiItem::cancel()))
+      i18n("Do you really want to unsubscribe from %1?").tqarg(g_rpManager->currentGroup()->groupname()), TQString(), i18n("Unsubscribe"), KStdGuiItem::cancel()))
       if (g_rpManager->unsubscribeGroup(g_rpManager->currentGroup()))
         slotCollectionSelected(0);
   }
@@ -1588,7 +1588,7 @@ void KNMainWidget::slotFolDelete()
     KMessageBox::sorry(knGlobals.topWidget, i18n("You cannot delete a standard folder."));
 
   else if( KMessageBox::Continue==KMessageBox::warningContinueCancel(knGlobals.topWidget,
-      i18n("Do you really want to delete this folder and all its children?"),"",KGuiItem(i18n("&Delete"),"editdelete")) ) {
+      i18n("Do you really want to delete this folder and all its tqchildren?"),"",KGuiItem(i18n("&Delete"),"editdelete")) ) {
 
     if(!f_olManager->deleteFolder(f_olManager->currentFolder()))
       KMessageBox::sorry(knGlobals.topWidget,
@@ -1639,7 +1639,7 @@ void KNMainWidget::slotFolEmpty()
       return;
     }
     if( KMessageBox::Continue == KMessageBox::warningContinueCancel(
-        this, i18n("Do you really want to delete all articles in %1?").arg(f_olManager->currentFolder()->name()),"",KGuiItem(i18n("&Delete"),"editdelete")) )
+        this, i18n("Do you really want to delete all articles in %1?").tqarg(f_olManager->currentFolder()->name()),"",KGuiItem(i18n("&Delete"),"editdelete")) )
       f_olManager->emptyFolder(f_olManager->currentFolder());
   }
 }
@@ -1948,7 +1948,7 @@ void KNMainWidget::slotFetchArticleWithID()
     TQString id = dlg->messageId().simplifyWhiteSpace();
     if (id.find(TQRegExp("*@*",false,true))!=-1) {
       if (id.find(TQRegExp("<*>",false,true))==-1)   // add "<>" when necessary
-        id = TQString("<%1>").arg(id);
+        id = TQString("<%1>").tqarg(id);
 
       if(!KNArticleWindow::raiseWindowForArticle(id.latin1())) { //article not yet opened
         KNRemoteArticle *a=new KNRemoteArticle(g_rpManager->currentGroup());
@@ -1966,7 +1966,7 @@ void KNMainWidget::slotFetchArticleWithID()
 void KNMainWidget::slotToggleGroupView()
 {
   c_olDock->changeHideShowState();
-  slotCheckDockWidgetStatus();
+  slotCheckDockWidgetqStatus();
 }
 
 
@@ -1977,19 +1977,19 @@ void KNMainWidget::slotToggleHeaderView()
       if ( !h_drDock->isDockBackPossible() ) {
           h_drDock->manualDock( a_rtDock, KDockWidget::DockTop );
           h_drDock->makeDockVisible();
-          slotCheckDockWidgetStatus();
+          slotCheckDockWidgetqStatus();
           return;
       }
 
   h_drDock->changeHideShowState();
-  slotCheckDockWidgetStatus();
+  slotCheckDockWidgetqStatus();
 }
 
 
 void KNMainWidget::slotToggleArticleViewer()
 {
   a_rtDock->changeHideShowState();
-  slotCheckDockWidgetStatus();
+  slotCheckDockWidgetqStatus();
 }
 
 void KNMainWidget::slotToggleQuickSearch()
