@@ -93,7 +93,7 @@ void KNNntpClient::doFetchGroups()
 
   char *s, *line;
   TQString name;
-  KNGroup::Status status;
+  KNGroup::tqStatus status;
   bool subscribed;
 
   while (getNextLine()) {
@@ -132,7 +132,7 @@ void KNNntpClient::doFetchGroups()
         default  : status = KNGroup::unknown;
       }
 
-      target->groups->append(new KNGroupInfo(name,TQString::null,false,subscribed,status));
+      target->groups->append(new KNGroupInfo(name,TQString(),false,subscribed,status));
     }
     doneLines++;
   }
@@ -140,7 +140,7 @@ void KNNntpClient::doFetchGroups()
   if (!job->success() || job->canceled())
     return;     // stopped...
 
-  QSortedVector<KNGroupInfo> tempVector;
+  TQSortedVector<KNGroupInfo> tempVector;
   target->groups->toVector(&tempVector);
   tempVector.sort();
 
@@ -228,7 +228,7 @@ void KNNntpClient::doCheckNewGroups()
 
   char *s, *line;
   TQString name;
-  KNGroup::Status status;
+  KNGroup::tqStatus status;
   TQSortedList<KNGroupInfo> tmpList;
   tmpList.setAutoDelete(true);
 
@@ -261,7 +261,7 @@ void KNNntpClient::doCheckNewGroups()
         default  : status = KNGroup::unknown;
       }
 
-      tmpList.append(new KNGroupInfo(name,TQString::null,true,false,status));
+      tmpList.append(new KNGroupInfo(name,TQString(),true,false,status));
     }
     doneLines++;
   }
@@ -336,7 +336,7 @@ void KNNntpClient::doFetchNewHeaders()
 
   sendSignal(TSdownloadNew);
   errorPrefix=i18n("No new articles could be retrieved for\n%1/%2.\nThe following error occurred:\n")
-              .arg(account.server()).arg(target->groupname());
+              .tqarg(account.server()).tqarg(target->groupname());
 
   cmd="GROUP ";
   cmd+=target->groupname().utf8();
@@ -401,7 +401,7 @@ void KNNntpClient::doFetchNewHeaders()
   if ( sendCommand( cmd, rep ) && rep == 215 ) {
     TQStrList tmp;
     if (getMsg(tmp)) {
-      for(TQCString s = tmp.first(); s; s = tmp.next()) {
+      for(TQCString s = tmp.first(); !s.isNull(); s = tmp.next()) {
         s = s.stripWhiteSpace();
         // remove the mandatory xover header
         if (s == "Subject:" || s == "From:" || s == "Date:" || s == "Message-ID:"
@@ -482,7 +482,7 @@ void KNNntpClient::doFetchArticle()
       job->setErrorString( errorPrefix + getCurrentLine() +
         i18n("<br><br>The article you requested is not available on your news server."
              "<br>You could try to get it from <a href=\"http://groups.google.com/groups?selm=%1\">groups.google.com</a>.")
-          .arg( msgId ) );
+          .tqarg( msgId ) );
     }
     return;
   }
@@ -569,7 +569,7 @@ void KNNntpClient::doFetchSource()
 
 bool KNNntpClient::openConnection()
 {
-  currentGroup = TQString::null;
+  currentGroup = TQString();
 
   TQString oldPrefix = errorPrefix;
   errorPrefix=i18n("Unable to connect.\nThe following error occurred:\n");
@@ -638,7 +638,7 @@ bool KNNntpClient::openConnection()
         #ifndef NDEBUG
         qDebug("knode: Authorization failed");
         #endif
-        job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").arg(getCurrentLine()));
+        job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").tqarg(getCurrentLine()));
         job->setAuthError(true);
         closeConnection();
         return false;
@@ -695,7 +695,7 @@ bool KNNntpClient::sendCommand(const TQCString &cmd, int &rep)
       //qDebug("knode: Password required");
 
       if (!account.pass().length()) {
-        job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").arg(getCurrentLine()));
+        job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").tqarg(getCurrentLine()));
         job->setAuthError(true);
         closeConnection();
         return false;
@@ -716,7 +716,7 @@ bool KNNntpClient::sendCommand(const TQCString &cmd, int &rep)
       if (!KNProtocolClient::sendCommand(cmd,rep))    // retry the original command
         return false;
     } else {
-      job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").arg(getCurrentLine()));
+      job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").tqarg(getCurrentLine()));
       job->setAuthError(true);
       closeConnection();
       return false;
@@ -729,7 +729,7 @@ bool KNNntpClient::sendCommand(const TQCString &cmd, int &rep)
 void KNNntpClient::handleErrors()
 {
   if (errorPrefix.isEmpty())
-    job->setErrorString(i18n("An error occurred:\n%1").arg(getCurrentLine()));
+    job->setErrorString(i18n("An error occurred:\n%1").tqarg(getCurrentLine()));
   else
     job->setErrorString(errorPrefix + getCurrentLine());
 
