@@ -28,14 +28,15 @@ class TQEvent;
 class TQResizeEvent;
 
 
-class KNoteButton: public QPushButton
+class KNoteButton: public TQPushButton
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     KNoteButton( const TQString& icon, TQWidget *parent=0, const char *name=0 );
     ~KNoteButton();
 
-    virtual TQSize sizeHint() const;
+    virtual TQSize tqsizeHint() const;
 
 protected:
     virtual void enterEvent( TQEvent * );
