@@ -112,25 +112,25 @@ KNotesApp::KNotesApp()
 
     // create the GUI...
     new KAction( i18n("New Note"), "filenew", 0,
-        this, TQT_SLOT(newNote()), actionCollection(), "new_note" );
+        TQT_TQOBJECT(this), TQT_SLOT(newNote()), actionCollection(), "new_note" );
     new KAction( i18n("New Note From Clipboard"), "editpaste", 0,
-        this, TQT_SLOT(newNoteFromClipboard()), actionCollection(), "new_note_clipboard" );
+        TQT_TQOBJECT(this), TQT_SLOT(newNoteFromClipboard()), actionCollection(), "new_note_clipboard" );
     new KAction( i18n("Show All Notes"), "knotes", 0,
-        this, TQT_SLOT(showAllNotes()), actionCollection(), "show_all_notes" );
+        TQT_TQOBJECT(this), TQT_SLOT(showAllNotes()), actionCollection(), "show_all_notes" );
     new KAction( i18n("Hide All Notes"), "fileclose", 0,
-        this, TQT_SLOT(hideAllNotes()), actionCollection(), "hide_all_notes" );
+        TQT_TQOBJECT(this), TQT_SLOT(hideAllNotes()), actionCollection(), "hide_all_notes" );
     new KHelpMenu( this, kapp->aboutData(), false, actionCollection() );
 
-    m_findAction = KStdAction::find( this, TQT_SLOT(slotOpenFindDialog()), actionCollection() );
-    KStdAction::preferences( this, TQT_SLOT(slotPreferences()), actionCollection() );
-    KStdAction::keyBindings( this, TQT_SLOT(slotConfigureAccels()), actionCollection() );
+    m_findAction = KStdAction::find( TQT_TQOBJECT(this), TQT_SLOT(slotOpenFindDialog()), actionCollection() );
+    KStdAction::preferences( TQT_TQOBJECT(this), TQT_SLOT(slotPreferences()), actionCollection() );
+    KStdAction::keyBindings( TQT_TQOBJECT(this), TQT_SLOT(slotConfigureAccels()), actionCollection() );
     //FIXME: no shortcut removing!?
-    KStdAction::quit( this, TQT_SLOT(slotQuit()), actionCollection() )->setShortcut( 0 );
+    KStdAction::quit( TQT_TQOBJECT(this), TQT_SLOT(slotQuit()), actionCollection() )->setShortcut( 0 );
 
     setXMLFile( instance()->instanceName() + "appui.rc" );
 
     m_guiBuilder = new KXMLGUIBuilder( this );
-    m_guiFactory = new KXMLGUIFactory( m_guiBuilder, this );
+    m_guiFactory = new KXMLGUIFactory( m_guiBuilder, TQT_TQOBJECT(this) );
     m_guiFactory->addClient( this );
 
     m_context_menu = static_cast<KPopupMenu*>(m_guiFactory->container( "knotes_context", this ));
@@ -138,7 +138,7 @@ KNotesApp::KNotesApp()
 
     // get the most recent XML UI file
     TQString xmlFileName = instance()->instanceName() + "ui.rc";
-    TQString filter = TQString::fromLatin1( instance()->instanceName() + '/' ) + xmlFileName;
+    TQString filter = TQString::tqfromLatin1( instance()->instanceName() + '/' ) + xmlFileName;
     TQStringList fileList = instance()->dirs()->findAllResources( "data", filter ) +
                            instance()->dirs()->findAllResources( "data", xmlFileName );
 
@@ -147,19 +147,19 @@ KNotesApp::KNotesApp()
     m_noteGUI.setContent( doc );
 
     // create accels for global shortcuts
-    m_globalAccel = new KGlobalAccel( this, "global accel" );
+    m_globalAccel = new KGlobalAccel( TQT_TQOBJECT(this), "global accel" );
     m_globalAccel->insert( "global_new_note", i18n("New Note"), "",
                            ALT+SHIFT+Key_N, ALT+SHIFT+Key_N ,
-                           this, TQT_SLOT(newNote()), true, true );
+                           TQT_TQOBJECT(this), TQT_SLOT(newNote()), true, true );
     m_globalAccel->insert( "global_new_note_clipboard", i18n("New Note From Clipboard"), "",
                            ALT+SHIFT+Key_C, ALT+SHIFT+Key_C,
-                           this, TQT_SLOT(newNoteFromClipboard()), true, true );
+                           TQT_TQOBJECT(this), TQT_SLOT(newNoteFromClipboard()), true, true );
     m_globalAccel->insert( "global_hide_all_notes", i18n("Hide All Notes"), "",
                            ALT+SHIFT+Key_H, ALT+SHIFT+Key_H ,
-                           this, TQT_SLOT(hideAllNotes()), true, true );
+                           TQT_TQOBJECT(this), TQT_SLOT(hideAllNotes()), true, true );
     m_globalAccel->insert( "global_show_all_notes", i18n("Show All Notes"), "",
                            ALT+SHIFT+Key_S, ALT+SHIFT+Key_S,
-                           this, TQT_SLOT(showAllNotes()), true, true );
+                           TQT_TQOBJECT(this), TQT_SLOT(showAllNotes()), true, true );
 
     m_globalAccel->readSettings();
 
@@ -183,7 +183,7 @@ KNotesApp::KNotesApp()
     m_manager->load();
 
     // read the old config files, convert and add them
-    KCal::CalendarLocal calendar( TQString::fromLatin1( "UTC" ) );
+    KCal::CalendarLocal calendar( TQString::tqfromLatin1( "UTC" ) );
     if ( KNotesLegacy::convert( &calendar ) )
     {
         KCal::Journal::List notes = calendar.journals();
@@ -196,7 +196,7 @@ KNotesApp::KNotesApp()
 
     // set up the alarm reminder - do it after loading the notes because this
     // is used as a check if updateNoteActions has to be called for a new note
-    m_alarm = new KNotesAlarm( m_manager, this );
+    m_alarm = new KNotesAlarm( m_manager, TQT_TQOBJECT(this) );
 
     // create the socket and possibly start listening for connections
     m_listener = new KServerSocket();
@@ -236,7 +236,7 @@ KNotesApp::~KNotesApp()
     delete m_guiBuilder;
 }
 
-bool KNotesApp::commitData( QSessionManager& )
+bool KNotesApp::commitData( TQSessionManager& )
 {
     saveConfigs();
     return true;
@@ -253,7 +253,7 @@ TQString KNotesApp::newNote( const TQString& name, const TQString& text )
     if ( !name.isEmpty() )
         journal->setSummary( name );
     else
-        journal->setSummary( KGlobal::locale()->formatDateTime( TQDateTime::currentDateTime() ) );
+        journal->setSummary( KGlobal::locale()->formatDateTime( TQDateTime::tqcurrentDateTime() ) );
 
     // the body of the note
     journal->setDescription( text );
@@ -266,7 +266,7 @@ TQString KNotesApp::newNote( const TQString& name, const TQString& text )
 
 TQString KNotesApp::newNoteFromClipboard( const TQString& name )
 {
-    const TQString& text = KApplication::clipboard()->text();
+    const TQString& text = KApplication::tqclipboard()->text();
     return newNote( name, text );
 }
 
@@ -336,7 +336,7 @@ TQString KNotesApp::name( const TQString& id ) const
     if ( note )
         return note->name();
     else
-        return TQString::null;
+        return TQString();
 }
 
 TQString KNotesApp::text( const TQString& id ) const
@@ -345,7 +345,7 @@ TQString KNotesApp::text( const TQString& id ) const
     if ( note )
         return note->text();
     else
-        return TQString::null;
+        return TQString();
 }
 
 void KNotesApp::setName( const TQString& id, const TQString& newName )
@@ -372,7 +372,7 @@ TQString KNotesApp::fgColor( const TQString& id ) const
     if ( note )
         return note->fgColor().name();
     else
-        return TQString::null;
+        return TQString();
 }
 
 TQString KNotesApp::bgColor( const TQString& id ) const
@@ -381,7 +381,7 @@ TQString KNotesApp::bgColor( const TQString& id ) const
     if ( note )
         return note->bgColor().name();
     else
-        return TQString::null;
+        return TQString();
 }
 
 void KNotesApp::setColor( const TQString& id, const TQString& fgColor, const TQString& bgColor )
@@ -465,7 +465,7 @@ void KNotesApp::mousePressEvent( TQMouseEvent* e )
 
     switch ( e->button() )
     {
-    case LeftButton:
+    case Qt::LeftButton:
         if ( m_noteList.count() == 1 )
         {
             TQDictIterator<KNote> it( m_noteList );
@@ -474,10 +474,10 @@ void KNotesApp::mousePressEvent( TQMouseEvent* e )
         else if ( m_note_menu->count() > 0 )
             m_note_menu->popup( e->globalPos() );
         break;
-    case MidButton:
+    case Qt::MidButton:
         newNote();
         break;
-    case RightButton:
+    case Qt::RightButton:
         m_context_menu->popup( e->globalPos() );
     default: break;
     }
@@ -488,7 +488,7 @@ void KNotesApp::mousePressEvent( TQMouseEvent* e )
 void KNotesApp::slotShowNote()
 {
     // tell the WM to give this note focus
-    showNote( TQString::fromUtf8( sender()->name() ) );
+    showNote( TQString::fromUtf8( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() ) );
 }
 
 void KNotesApp::slotWalkThroughNotes()
@@ -554,8 +554,8 @@ void KNotesApp::slotPreferences()
     // create a new preferences dialog...
     KNoteConfigDlg *dialog = new KNoteConfigDlg( 0, i18n("Settings"), this,
                                                  "KNotes Settings" );
-    connect( dialog, TQT_SIGNAL(settingsChanged()), this, TQT_SLOT(updateNetworkListener()) );
-    connect( dialog, TQT_SIGNAL(settingsChanged()), this, TQT_SLOT(updateStyle()) );
+    connect( dialog, TQT_SIGNAL(settingsChanged()), TQT_TQOBJECT(this), TQT_SLOT(updateNetworkListener()) );
+    connect( dialog, TQT_SIGNAL(settingsChanged()), TQT_TQOBJECT(this), TQT_SLOT(updateStyle()) );
     dialog->show();
 }
 
@@ -673,7 +673,7 @@ void KNotesApp::acceptConnection()
     {
         KNotesNetworkReceiver *recv = new KNotesNetworkReceiver( s );
         connect( recv, TQT_SIGNAL(sigNoteReceived( const TQString &, const TQString & )),
-                 this, TQT_SLOT(newNote( const TQString &, const TQString & )) );
+                 TQT_TQOBJECT(this), TQT_SLOT(newNote( const TQString &, const TQString & )) );
     }
 }
 
@@ -704,7 +704,7 @@ void KNotesApp::updateNoteActions()
     for ( TQDictIterator<KNote> it( m_noteList ); it.current(); ++it )
     {
         KAction *action = new KAction( it.current()->name().replace("&", "&&"),
-                                       KShortcut(), this, TQT_SLOT(slotShowNote()),
+                                       KShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotShowNote()),
                                        (TQObject *)0,
                                        it.current()->noteId().utf8() );
         KIconEffect effect;
