@@ -37,7 +37,7 @@ static TQString escapeEnum( const TQString &str )
 
 Converter::Converter()
 {
-  mQObject = KODE::Class( "TQObject" );
+  mTQObject = KODE::Class( TQOBJECT_OBJECT_NAME_STRING );
 }
 
 void Converter::setWSDL( const WSDL &wsdl )
@@ -249,7 +249,7 @@ void Converter::createSimpleTypeSerializer( const Schema::SimpleType *type )
         escapedEnums.append( escapeEnum( enums[ i ] ) );
 
       // marshal value
-      KODE::Function marshalValue( "marshalValue", "TQString" );
+      KODE::Function marshalValue( "marshalValue", TQSTRING_OBJECT_NAME_STRING );
       marshalValue.setStatic( true );
       marshalValue.addArgument( "const " + typeName + "* value" );
       code += "switch ( value->type() ) {";
@@ -315,7 +315,7 @@ void Converter::createSimpleTypeSerializer( const Schema::SimpleType *type )
       demarshalCode.unindent();
       demarshalCode += "}";
 
-      KODE::Function marshalValue( "marshalValue", "TQString" );
+      KODE::Function marshalValue( "marshalValue", TQSTRING_OBJECT_NAME_STRING );
       marshalValue.setStatic( true );
       marshalValue.addArgument( "const " + typeName + "* value" );
       marshalValue.setBody( "return Serializer::marshalValue( value->value() );" );
@@ -660,7 +660,7 @@ void Converter::createComplexTypeSerializer( const Schema::ComplexType *type )
 void Converter::convertService( const Service &service )
 {
   KODE::Class newClass( service.name() );
-  newClass.addBaseClass( mQObject );
+  newClass.addBaseClass( mTQObject );
   newClass.addHeaderInclude( "tqobject.h" );
   newClass.addHeaderInclude( "tqstring.h" );
   newClass.addHeaderInclude( "transport.h" );
@@ -839,7 +839,7 @@ void Converter::createUtilClasses()
     of typing and is easier to maintain at the end ;)
    */
   TypeEntry types[] = {
-    { "TQString", "xsd:string", "*value", "str" },
+    { TQSTRING_OBJECT_NAME_STRING, "xsd:string", "*value", "str" },
     { "bool", "xsd:boolean", "(*value ? \"true\" : \"false\")", "(str.lower() == \"true\" ? true : false)" },
     { "float", "xsd:TODO", "TQString::number( *value )", "str.toFloat()" },
     { "int", "xsd:int", "TQString::number( *value )", "str.toInt()" },
@@ -848,9 +848,9 @@ void Converter::createUtilClasses()
     { "char", "xsd:byte", "TQString( TQChar( *value ) )", "str[ 0 ].latin1()" },
     { "unsigned char", "xsd:unsignedByte", "TQString( TQChar( *value ) )", "str[ 0 ].latin1()" },
     { "short", "xsd:short", "TQString::number( *value )", "str.toShort()" },
-    { "TQByteArray", "xsd:base64Binary", "TQString::fromUtf8( KCodecs::base64Encode( *value ) )", "KCodecs::base64Decode( str.utf8() )" },
-    { "TQDateTime", "xsd:dateTime", "value->toString( Qt::ISODate )", "TQDateTime::fromString( str, Qt::ISODate )" },
-    { "TQDate", "xsd:date", "value->toString( Qt::ISODate )", "TQDate::fromString( str, Qt::ISODate )" }
+    { TQBYTEARRAY_OBJECT_NAME_STRING, "xsd:base64Binary", "TQString::fromUtf8( KCodecs::base64Encode( *value ) )", "KCodecs::base64Decode( str.utf8() )" },
+    { "TQDateTime", "xsd:dateTime", "value->toString( TQt::ISODate )", "TQDateTime::fromString( str, TQt::ISODate )" },
+    { "TQDate", "xsd:date", "value->toString( TQt::ISODate )", "TQDate::fromString( str, TQt::ISODate )" }
   };
 
   for ( uint i = 0; i < sizeof( types ) / sizeof( TypeEntry ); ++i ) {
@@ -859,7 +859,7 @@ void Converter::createUtilClasses()
 
     TypeEntry entry = types[ i ]; 
 
-    marshal = KODE::Function( "marshalValue", "TQString" );
+    marshal = KODE::Function( "marshalValue", TQSTRING_OBJECT_NAME_STRING );
     marshal.setStatic( true );
     marshal.addArgument( "const " + entry.type + "* value" );
 
@@ -905,16 +905,16 @@ void Converter::createUtilClasses()
 void Converter::createTransportClass()
 {
   KODE::Class transport( "Transport" );
-  transport.addBaseClass( mQObject );
+  transport.addBaseClass( mTQObject );
   transport.addHeaderInclude( "tqobject.h" );
   transport.addHeaderInclude( "kio/job.h" );
 
   transport.addInclude( "kdebug.h" );
 
-  KODE::MemberVariable url( "url", "TQString" );
+  KODE::MemberVariable url( "url", TQSTRING_OBJECT_NAME_STRING );
   transport.addMemberVariable( url );
 
-  KODE::MemberVariable slotDataVar( "data", "TQByteArray" );
+  KODE::MemberVariable slotDataVar( "data", TQBYTEARRAY_OBJECT_NAME_STRING );
   transport.addMemberVariable( slotDataVar );
 
   // ctor
