@@ -26,9 +26,10 @@
 
 class Dispatcher;
 
-class Loader : public QObject
+class Loader : public TQObject
 {
   Q_OBJECT
+  TQ_OBJECT
 
   public:
     Loader();
