@@ -34,14 +34,14 @@ class KDE_EXPORT License
     License();
     License( Type );
 
-    void setQtException( bool );
+    void setTQtException( bool );
 
     TQString text();
 
   private:
     Type mType;
 
-    bool mQtException;
+    bool mTQtException;
 };
 
 }
