@@ -15,13 +15,13 @@ Editor::Editor(ObjectList *list, TQWidget *parent, const char *name)
 	this->list = list;
 	config = 0;
 
-	hlayout = new TQHBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
+	htqlayout = new TQHBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
 
-	TQVBoxLayout *vlayout = new TQVBoxLayout(hlayout, KDialog::spacingHint());
-	vlayout->addWidget(new TQLabel(i18n("Add object:"), this));
+	TQVBoxLayout *vtqlayout = new TQVBoxLayout(htqlayout, KDialog::spacingHint());
+	vtqlayout->addWidget(new TQLabel(i18n("Add object:"), this));
 	listbox = new KListBox(this, "Listbox");
-	vlayout->addWidget(listbox);
-	hlayout->setStretchFactor(vlayout, 2);
+	vtqlayout->addWidget(listbox);
+	htqlayout->setStretchFactor(vtqlayout, 2);
 
 	TQStringList items;
 	Object *obj = 0;
@@ -49,8 +49,8 @@ void Editor::setItem(CanvasItem *item)
 	if (!config)
 		return;
 	config->ctorDone();
-	hlayout->addWidget(config);
-	hlayout->setStretchFactor(config, 2);
+	htqlayout->addWidget(config);
+	htqlayout->setStretchFactor(config, 2);
 	config->setFrameStyle(TQFrame::Box | TQFrame::Raised);
 	config->setLineWidth(1);
 	config->show();
