@@ -104,7 +104,7 @@ private:
 };
 typedef TQValueList<Player> PlayerList;
 
-class Arrow : public QCanvasLine
+class Arrow : public TQCanvasLine
 {
 public:
 	Arrow(TQCanvas *canvas);
@@ -195,6 +195,7 @@ private:
 class EllipseConfig : public Config
 {
 	Q_OBJECT
+  TQ_OBJECT
 
 public:
 	EllipseConfig(Ellipse *ellipse, TQWidget *);
@@ -206,7 +207,7 @@ private slots:
 	void check2Changed(bool on);
 
 protected:
-	TQVBoxLayout *m_vlayout;
+	TQVBoxLayout *m_vtqlayout;
 
 private:
 	TQLabel *slow1;
@@ -317,6 +318,7 @@ class BlackHole;
 class BlackHoleConfig : public Config
 {
 	Q_OBJECT
+  TQ_OBJECT
 
 public:
 	BlackHoleConfig(BlackHole *blackHole, TQWidget *parent);
@@ -350,9 +352,10 @@ public:
 protected:
 	Arrow *arrow;
 };
-class BlackHoleTimer : public QObject
+class BlackHoleTimer : public TQObject
 {
 Q_OBJECT
+  TQ_OBJECT
 
 public:
 	BlackHoleTimer(Ball *ball, double speed, int msec);
@@ -372,6 +375,7 @@ protected:
 class BlackHole : public TQObject, public Hole
 {
 Q_OBJECT
+  TQ_OBJECT
 
 public:
 	BlackHole(TQCanvas *canvas);
@@ -541,6 +545,7 @@ class Bridge;
 class BridgeConfig : public Config
 {
 	Q_OBJECT
+  TQ_OBJECT
 
 public:
 	BridgeConfig(Bridge *bridge, TQWidget *);
@@ -552,7 +557,7 @@ protected slots:
 	void rightWallChanged(bool);
 
 protected:
-	TQVBoxLayout *m_vlayout;
+	TQVBoxLayout *m_vtqlayout;
 	TQCheckBox *top;
 	TQCheckBox *bot;
 	TQCheckBox *left;
@@ -613,6 +618,7 @@ class Sign;
 class SignConfig : public BridgeConfig
 {
 	Q_OBJECT
+  TQ_OBJECT
 
 public:
 	SignConfig(Sign *sign, TQWidget *parent);
@@ -661,6 +667,7 @@ protected:
 class WindmillConfig : public BridgeConfig
 {
 	Q_OBJECT
+  TQ_OBJECT
 
 public:
 	WindmillConfig(Windmill *windmill, TQWidget *parent);
@@ -708,6 +715,7 @@ class HoleInfo;
 class HoleConfig : public Config
 {
 	Q_OBJECT
+  TQ_OBJECT
 
 public:
 	HoleConfig(HoleInfo *holeInfo, TQWidget *);
@@ -755,7 +763,7 @@ private:
 	int m_lowestMaxStrokes;
 };
 
-class StrokeCircle : public QCanvasItem
+class StrokeCircle : public TQCanvasItem
 {
 public:
 	StrokeCircle(TQCanvas *canvas);
@@ -790,9 +798,10 @@ struct KDE_EXPORT CourseInfo
 	unsigned int par;
 };
 
-class KDE_EXPORT KolfGame : public QCanvasView
+class KDE_EXPORT KolfGame : public TQCanvasView
 {
 	Q_OBJECT
+  TQ_OBJECT
 
 public:
 	KolfGame(ObjectList *obj, PlayerList *players, TQString filename, TQWidget *parent=0, const char *name=0 );
