@@ -62,10 +62,10 @@ Kolf::Kolf()
 	obj = new ObjectList;
 	initPlugins();
 
-	filename = TQString::null;
+	filename = TQString();
 	dummy = new TQWidget(this);
 	setCentralWidget(dummy);
-	layout = new TQGridLayout(dummy, 3, 1);
+	tqlayout = new TQGridLayout(dummy, 3, 1);
 
 	resize(420, 480);
 }
@@ -79,75 +79,75 @@ Kolf::~Kolf()
 
 void Kolf::initGUI()
 {
-	newAction = KStdGameAction::gameNew(this, TQT_SLOT(newGame()), actionCollection());
+	newAction = KStdGameAction::gameNew(TQT_TQOBJECT(this), TQT_SLOT(newGame()), actionCollection());
 	newAction->setText(newAction->text() + TQString("..."));
 
-	endAction = KStdGameAction::end(this, TQT_SLOT(closeGame()), actionCollection());
-	printAction = KStdGameAction::print(this, TQT_SLOT(print()), actionCollection());
+	endAction = KStdGameAction::end(TQT_TQOBJECT(this), TQT_SLOT(closeGame()), actionCollection());
+	printAction = KStdGameAction::print(TQT_TQOBJECT(this), TQT_SLOT(print()), actionCollection());
 
-	(void) KStdGameAction::quit(this, TQT_SLOT(close()), actionCollection());
-	saveAction = KStdAction::save(this, TQT_SLOT(save()), actionCollection(), "game_save");
+	(void) KStdGameAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection());
+	saveAction = KStdAction::save(TQT_TQOBJECT(this), TQT_SLOT(save()), actionCollection(), "game_save");
 	saveAction->setText(i18n("Save &Course"));
-	saveAsAction = KStdAction::saveAs(this, TQT_SLOT(saveAs()), actionCollection(), "game_save_as");
+	saveAsAction = KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(saveAs()), actionCollection(), "game_save_as");
 	saveAsAction->setText(i18n("Save &Course As..."));
 
-	saveGameAction = new KAction(i18n("&Save Game"), 0, this, TQT_SLOT(saveGame()), actionCollection(), "savegame");
-	saveGameAsAction = new KAction(i18n("&Save Game As..."), 0, this, TQT_SLOT(saveGameAs()), actionCollection(), "savegameas");
+	saveGameAction = new KAction(i18n("&Save Game"), 0, TQT_TQOBJECT(this), TQT_SLOT(saveGame()), actionCollection(), "savegame");
+	saveGameAsAction = new KAction(i18n("&Save Game As..."), 0, TQT_TQOBJECT(this), TQT_SLOT(saveGameAs()), actionCollection(), "savegameas");
 
-	loadGameAction = KStdGameAction::load(this, TQT_SLOT(loadGame()), actionCollection());
+	loadGameAction = KStdGameAction::load(TQT_TQOBJECT(this), TQT_SLOT(loadGame()), actionCollection());
 	loadGameAction->setText(i18n("Load Saved Game..."));
 
-	highScoreAction = KStdGameAction::highscores(this, TQT_SLOT(showHighScores()), actionCollection());
+	highScoreAction = KStdGameAction::highscores(TQT_TQOBJECT(this), TQT_SLOT(showHighScores()), actionCollection());
 
-	editingAction = new KToggleAction(i18n("&Edit"), "pencil", CTRL+Key_E, this, TQT_SLOT(emptySlot()), actionCollection(), "editing");
-	newHoleAction = new KAction(i18n("&New"), "filenew", CTRL+SHIFT+Key_N, this, TQT_SLOT(emptySlot()), actionCollection(), "newhole");
-	clearHoleAction = new KAction(KStdGuiItem::clear().text(), "locationbar_erase", CTRL+Key_Delete, this, TQT_SLOT(emptySlot()), actionCollection(), "clearhole");
-	resetHoleAction = new KAction(i18n("&Reset"), CTRL+Key_R, this, TQT_SLOT(emptySlot()), actionCollection(), "resethole");
-	undoShotAction = KStdAction::undo(this, TQT_SLOT(emptySlot()), actionCollection(), "undoshot");
+	editingAction = new KToggleAction(i18n("&Edit"), "pencil", CTRL+Key_E, TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "editing");
+	newHoleAction = new KAction(i18n("&New"), "filenew", CTRL+SHIFT+Key_N, TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "newhole");
+	clearHoleAction = new KAction(KStdGuiItem::clear().text(), "locationbar_erase", CTRL+Key_Delete, TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "clearhole");
+	resetHoleAction = new KAction(i18n("&Reset"), CTRL+Key_R, TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "resethole");
+	undoShotAction = KStdAction::undo(TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "undoshot");
 	undoShotAction->setText(i18n("&Undo Shot"));
-	//replayShotAction = new KAction(i18n("&Replay Shot"), 0, this, TQT_SLOT(emptySlot()), actionCollection(), "replay");
+	//replayShotAction = new KAction(i18n("&Replay Shot"), 0, TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "replay");
 
-	holeAction = new KListAction(i18n("Switch to Hole"), 0, this, TQT_SLOT(emptySlot()), actionCollection(), "switchhole");
-	nextAction = new KAction(i18n("&Next Hole"), "forward", KStdAccel::shortcut(KStdAccel::Forward), this, TQT_SLOT(emptySlot()), actionCollection(), "nexthole");
-	prevAction = new KAction(i18n("&Previous Hole"), "back", KStdAccel::shortcut(KStdAccel::Back), this, TQT_SLOT(emptySlot()), actionCollection(), "prevhole");
-	firstAction = new KAction(i18n("&First Hole"), "gohome", KStdAccel::shortcut(KStdAccel::Home), this, TQT_SLOT(emptySlot()), actionCollection(), "firsthole");
-	lastAction = new KAction(i18n("&Last Hole"), CTRL+SHIFT+Key_End, this, TQT_SLOT(emptySlot()), actionCollection(), "lasthole");
-	randAction = new KAction(i18n("&Random Hole"), "goto", 0, this, TQT_SLOT(emptySlot()), actionCollection(), "randhole");
+	holeAction = new KListAction(i18n("Switch to Hole"), 0, TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "switchhole");
+	nextAction = new KAction(i18n("&Next Hole"), "forward", KStdAccel::shortcut(KStdAccel::Forward), TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "nexthole");
+	prevAction = new KAction(i18n("&Previous Hole"), "back", KStdAccel::shortcut(KStdAccel::Back), TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "prevhole");
+	firstAction = new KAction(i18n("&First Hole"), "gohome", KStdAccel::shortcut(KStdAccel::Home), TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "firsthole");
+	lastAction = new KAction(i18n("&Last Hole"), CTRL+SHIFT+Key_End, TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "lasthole");
+	randAction = new KAction(i18n("&Random Hole"), "goto", 0, TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "randhole");
 
-	useMouseAction = new KToggleAction(i18n("Enable &Mouse for Moving Putter"), 0, this, TQT_SLOT(emptySlot()), actionCollection(), "usemouse");
+	useMouseAction = new KToggleAction(i18n("Enable &Mouse for Moving Putter"), 0, TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "usemouse");
 	useMouseAction->setCheckedState(i18n("Disable &Mouse for Moving Putter"));
-	connect(useMouseAction, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(useMouseChanged(bool)));
+	connect(useMouseAction, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(useMouseChanged(bool)));
 	KConfig *config = kapp->config();
 	config->setGroup("Settings");
 	useMouseAction->setChecked(config->readBoolEntry("useMouse", true));
 
-	useAdvancedPuttingAction = new KToggleAction(i18n("Enable &Advanced Putting"), 0, this, TQT_SLOT(emptySlot()), actionCollection(), "useadvancedputting");
+	useAdvancedPuttingAction = new KToggleAction(i18n("Enable &Advanced Putting"), 0, TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "useadvancedputting");
 	useAdvancedPuttingAction->setCheckedState(i18n("Disable &Advanced Putting"));
-	connect(useAdvancedPuttingAction, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(useAdvancedPuttingChanged(bool)));
+	connect(useAdvancedPuttingAction, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(useAdvancedPuttingChanged(bool)));
 	useAdvancedPuttingAction->setChecked(config->readBoolEntry("useAdvancedPutting", false));
 
-	showInfoAction = new KToggleAction(i18n("Show &Info"), "info", CTRL+Key_I, this, TQT_SLOT(emptySlot()), actionCollection(), "showinfo");
+	showInfoAction = new KToggleAction(i18n("Show &Info"), "info", CTRL+Key_I, TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "showinfo");
 	showInfoAction->setCheckedState(i18n("Hide &Info"));
-	connect(showInfoAction, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(showInfoChanged(bool)));
+	connect(showInfoAction, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(showInfoChanged(bool)));
 	showInfoAction->setChecked(config->readBoolEntry("showInfo", false));
 
-	showGuideLineAction = new KToggleAction(i18n("Show Putter &Guideline"), 0, this, TQT_SLOT(emptySlot()), actionCollection(), "showguideline");
+	showGuideLineAction = new KToggleAction(i18n("Show Putter &Guideline"), 0, TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "showguideline");
 	showGuideLineAction->setCheckedState(i18n("Hide Putter &Guideline"));
-	connect(showGuideLineAction, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(showGuideLineChanged(bool)));
+	connect(showGuideLineAction, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(showGuideLineChanged(bool)));
 	showGuideLineAction->setChecked(config->readBoolEntry("showGuideLine", true));
 
-	KToggleAction *act=new KToggleAction(i18n("Enable All Dialog Boxes"), 0, this, TQT_SLOT(enableAllMessages()), actionCollection(), "enableAll");
+	KToggleAction *act=new KToggleAction(i18n("Enable All Dialog Boxes"), 0, TQT_TQOBJECT(this), TQT_SLOT(enableAllMessages()), actionCollection(), "enableAll");
 	act->setCheckedState(i18n("Disable All Dialog Boxes"));
 
-	soundAction = new KToggleAction(i18n("Play &Sounds"), 0, this, TQT_SLOT(emptySlot()), actionCollection(), "sound");
-	connect(soundAction, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(soundChanged(bool)));
+	soundAction = new KToggleAction(i18n("Play &Sounds"), 0, TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "sound");
+	connect(soundAction, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(soundChanged(bool)));
 	soundAction->setChecked(config->readBoolEntry("sound", true));
 
-	(void) new KAction(i18n("&Reload Plugins"), 0, this, TQT_SLOT(initPlugins()), actionCollection(), "reloadplugins");
-	(void) new KAction(i18n("Show &Plugins"), 0, this, TQT_SLOT(showPlugins()), actionCollection(), "showplugins");
+	(void) new KAction(i18n("&Reload Plugins"), 0, TQT_TQOBJECT(this), TQT_SLOT(initPlugins()), actionCollection(), "reloadplugins");
+	(void) new KAction(i18n("Show &Plugins"), 0, TQT_TQOBJECT(this), TQT_SLOT(showPlugins()), actionCollection(), "showplugins");
 
-	aboutAction = new KAction(i18n("&About Course"), 0, this, TQT_SLOT(emptySlot()), actionCollection(), "aboutcourse");
-	tutorialAction = new KAction(i18n("&Tutorial"), 0, this, TQT_SLOT(tutorial()), actionCollection(), "tutorial");
+	aboutAction = new KAction(i18n("&About Course"), 0, TQT_TQOBJECT(this), TQT_SLOT(emptySlot()), actionCollection(), "aboutcourse");
+	tutorialAction = new KAction(i18n("&Tutorial"), 0, TQT_TQOBJECT(this), TQT_SLOT(tutorial()), actionCollection(), "tutorial");
 
 	statusBar();
 	setupGUI();
@@ -176,7 +176,7 @@ void Kolf::startNewGame()
 	players.clear();
 	delete scoreboard;
 	scoreboard = new ScoreBoard(dummy, "Score Board");
-	layout->addWidget(scoreboard, 1, 0);
+	tqlayout->addWidget(scoreboard, 1, 0);
 	scoreboard->show();
 
 	if (loadedGame.isNull())
@@ -202,7 +202,7 @@ void Kolf::startNewGame()
 		if (isTutorial)
 			filename = KGlobal::dirs()->findResource("appdata", "tutorial.kolf");
 		else
-			filename = config.readEntry("Course", TQString::null);
+			filename = config.readEntry("Course", TQString());
 
 		if (filename.isNull())
 			return;
@@ -226,19 +226,19 @@ void Kolf::startNewGame()
 	connect(game, TQT_SIGNAL(newHole(int)), scoreboard, TQT_SLOT(newHole(int)));
 	connect(game, TQT_SIGNAL(scoreChanged(int, int, int)), scoreboard, TQT_SLOT(setScore(int, int, int)));
 	connect(game, TQT_SIGNAL(parChanged(int, int)), scoreboard, TQT_SLOT(parChanged(int, int)));
-	connect(game, TQT_SIGNAL(modifiedChanged(bool)), this, TQT_SLOT(updateModified(bool)));
-	connect(game, TQT_SIGNAL(newPlayersTurn(Player *)), this, TQT_SLOT(newPlayersTurn(Player *)));
-	connect(game, TQT_SIGNAL(holesDone()), this, TQT_SLOT(gameOver()));
-	connect(game, TQT_SIGNAL(checkEditing()), this, TQT_SLOT(checkEditing()));
-	connect(game, TQT_SIGNAL(editingStarted()), this, TQT_SLOT(editingStarted()));
-	connect(game, TQT_SIGNAL(editingEnded()), this, TQT_SLOT(editingEnded()));
-	connect(game, TQT_SIGNAL(inPlayStart()), this, TQT_SLOT(inPlayStart()));
-	connect(game, TQT_SIGNAL(inPlayEnd()), this, TQT_SLOT(inPlayEnd()));
-	connect(game, TQT_SIGNAL(maxStrokesReached(const TQString &)), this, TQT_SLOT(maxStrokesReached(const TQString &)));
-	connect(game, TQT_SIGNAL(largestHole(int)), this, TQT_SLOT(updateHoleMenu(int)));
-	connect(game, TQT_SIGNAL(titleChanged(const TQString &)), this, TQT_SLOT(titleChanged(const TQString &)));
-	connect(game, TQT_SIGNAL(newStatusText(const TQString &)), this, TQT_SLOT(newStatusText(const TQString &)));
-	connect(game, TQT_SIGNAL(currentHole(int)), this, TQT_SLOT(setCurrentHole(int)));
+	connect(game, TQT_SIGNAL(modifiedChanged(bool)), TQT_TQOBJECT(this), TQT_SLOT(updateModified(bool)));
+	connect(game, TQT_SIGNAL(newPlayersTurn(Player *)), TQT_TQOBJECT(this), TQT_SLOT(newPlayersTurn(Player *)));
+	connect(game, TQT_SIGNAL(holesDone()), TQT_TQOBJECT(this), TQT_SLOT(gameOver()));
+	connect(game, TQT_SIGNAL(checkEditing()), TQT_TQOBJECT(this), TQT_SLOT(checkEditing()));
+	connect(game, TQT_SIGNAL(editingStarted()), TQT_TQOBJECT(this), TQT_SLOT(editingStarted()));
+	connect(game, TQT_SIGNAL(editingEnded()), TQT_TQOBJECT(this), TQT_SLOT(editingEnded()));
+	connect(game, TQT_SIGNAL(inPlayStart()), TQT_TQOBJECT(this), TQT_SLOT(inPlayStart()));
+	connect(game, TQT_SIGNAL(inPlayEnd()), TQT_TQOBJECT(this), TQT_SLOT(inPlayEnd()));
+	connect(game, TQT_SIGNAL(maxStrokesReached(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(maxStrokesReached(const TQString &)));
+	connect(game, TQT_SIGNAL(largestHole(int)), TQT_TQOBJECT(this), TQT_SLOT(updateHoleMenu(int)));
+	connect(game, TQT_SIGNAL(titleChanged(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(titleChanged(const TQString &)));
+	connect(game, TQT_SIGNAL(newStatusText(const TQString &)), TQT_TQOBJECT(this), TQT_SLOT(newStatusText(const TQString &)));
+	connect(game, TQT_SIGNAL(currentHole(int)), TQT_TQOBJECT(this), TQT_SLOT(setCurrentHole(int)));
 	connect(holeAction, TQT_SIGNAL(activated(const TQString &)), game, TQT_SLOT(switchHole(const TQString &)));
 	connect(nextAction, TQT_SIGNAL(activated()), game, TQT_SLOT(nextHole()));
 	connect(prevAction, TQT_SIGNAL(activated()), game, TQT_SLOT(prevHole()));
@@ -264,7 +264,7 @@ void Kolf::startNewGame()
 	game->setShowGuideLine(showGuideLineAction->isChecked());
 	game->setSound(soundAction->isChecked());
 
-	layout->addWidget(game, 0, 0, AlignCenter);
+	tqlayout->addWidget(game, 0, 0, AlignCenter);
 
 	game->show();
 	game->setFocus();
@@ -299,7 +299,7 @@ void Kolf::startNewGame()
 void Kolf::newGame()
 {
 	isTutorial = false;
-	filename = TQString::null;
+	filename = TQString();
 	startNewGame();
 }
 
@@ -309,13 +309,13 @@ void Kolf::tutorial()
 	if (newfilename.isNull())
 	        return;
 
-	filename = TQString::null;
+	filename = TQString();
 	loadedGame = newfilename;
 	isTutorial = true;
 
 	startNewGame();
 
-	loadedGame = TQString::null;
+	loadedGame = TQString();
 }
 
 void Kolf::closeGame()
@@ -327,12 +327,12 @@ void Kolf::closeGame()
 		game->pause();
 	}
 
-	filename = TQString::null;
+	filename = TQString();
 
 	editingEnded();
 	delete game;
 	game = 0;
-	loadedGame = TQString::null;
+	loadedGame = TQString();
 
 	editingAction->setChecked(false);
 	setEditingEnabled(false);
@@ -353,10 +353,10 @@ void Kolf::closeGame()
 	loadGameAction->setEnabled(true);
 	tutorialAction->setEnabled(true);
 
-	titleChanged(TQString::null);
+	titleChanged(TQString());
 	updateModified(false);
 
-	TQTimer::singleShot(100, this, TQT_SLOT(createSpacer()));
+	TQTimer::singleShot(100, TQT_TQOBJECT(this), TQT_SLOT(createSpacer()));
 }
 
 void Kolf::createSpacer()
@@ -372,7 +372,7 @@ void Kolf::createSpacer()
 	spacer = new KolfGame(obj, &spacerPlayers, KGlobal::dirs()->findResource("appdata", "intro"), dummy);
 	spacer->setSound(false);
 	spacer->startFirstHole(1);
-	layout->addWidget(spacer, 0, 0, AlignCenter);
+	tqlayout->addWidget(spacer, 0, 0, AlignCenter);
 	spacer->hidePutter();
 	spacer->ignoreEvents(true);
 
@@ -431,10 +431,10 @@ void Kolf::gameOver()
 		if (names.count() > 1)
 		{
 			TQString winners = names.join(i18n(" and "));
-			KMessageBox::information(this, i18n("%1 tied").arg(winners));
+			KMessageBox::information(this, i18n("%1 tied").tqarg(winners));
 		}
 		else
-			KMessageBox::information(this, i18n("%1 won!").arg(names.first()));
+			KMessageBox::information(this, i18n("%1 won!").tqarg(names.first()));
 	}
 
 	if (competition)
@@ -459,11 +459,11 @@ void Kolf::gameOver()
 			scoreDialog->addScore((*it).score, info, false, true);
 		}
 
-		scoreDialog->setComment(i18n("High Scores for %1").arg(courseInfo.name));
+		scoreDialog->setComment(i18n("High Scores for %1").tqarg(courseInfo.name));
 		scoreDialog->show();
 	}
 
-	TQTimer::singleShot(700, this, TQT_SLOT(closeGame()));
+	TQTimer::singleShot(700, TQT_TQOBJECT(this), TQT_SLOT(closeGame()));
 }
 
 void Kolf::showHighScores()
@@ -475,7 +475,7 @@ void Kolf::showHighScores()
 	game->courseInfo(courseInfo, game->curFilename());
 
 	scoreDialog->setConfigGroup(courseInfo.untranslatedName + TQString(" Highscores"));
-	scoreDialog->setComment(i18n("High Scores for %1").arg(courseInfo.name));
+	scoreDialog->setComment(i18n("High Scores for %1").tqarg(courseInfo.name));
 	scoreDialog->show();
 }
 
@@ -537,7 +537,7 @@ void Kolf::saveGame()
 
 void Kolf::loadGame()
 {
-	loadedGame = KFileDialog::getOpenFileName(":savedkolf", TQString::fromLatin1("application/x-kolf"), this, i18n("Pick Kolf Saved Game"));
+	loadedGame = KFileDialog::getOpenFileName(":savedkolf", TQString::tqfromLatin1("application/x-kolf"), this, i18n("Pick Kolf Saved Game"));
 
 	if (loadedGame.isNull())
 		return;
@@ -564,7 +564,7 @@ void Kolf::openURL(KURL url)
 			return;
 		}
 
-		TQTimer::singleShot(10, this, TQT_SLOT(startNewGame()));
+		TQTimer::singleShot(10, TQT_TQOBJECT(this), TQT_SLOT(startNewGame()));
 	}
 	else
 		closeGame();
@@ -572,7 +572,7 @@ void Kolf::openURL(KURL url)
 
 void Kolf::newPlayersTurn(Player *player)
 {
-	tempStatusBarText = i18n("%1's turn").arg(player->name());
+	tempStatusBarText = i18n("%1's turn").tqarg(player->name());
 
 	if (showInfoAction->isChecked())
 		statusBar()->message(tempStatusBarText, 5 * 1000);
@@ -596,12 +596,12 @@ void Kolf::editingStarted()
 	editor = new Editor(obj, dummy, "Editor");
 	connect(editor, TQT_SIGNAL(addNewItem(Object *)), game, TQT_SLOT(addNewObject(Object *)));
 	connect(editor, TQT_SIGNAL(changed()), game, TQT_SLOT(setModified()));
-	connect(editor, TQT_SIGNAL(addNewItem(Object *)), this, TQT_SLOT(setHoleFocus()));
+	connect(editor, TQT_SIGNAL(addNewItem(Object *)), TQT_TQOBJECT(this), TQT_SLOT(setHoleFocus()));
 	connect(game, TQT_SIGNAL(newSelectedItem(CanvasItem *)), editor, TQT_SLOT(setItem(CanvasItem *)));
 
 	scoreboard->hide();
 
-	layout->addWidget(editor, 1, 0);
+	tqlayout->addWidget(editor, 1, 0);
 	editor->show();
 
 	clearHoleAction->setEnabled(true);
@@ -643,7 +643,7 @@ void Kolf::inPlayEnd()
 
 void Kolf::maxStrokesReached(const TQString &name)
 {
-	KMessageBox::sorry(this, i18n("%1's score has reached the maximum for this hole.").arg(name));
+	KMessageBox::sorry(this, i18n("%1's score has reached the maximum for this hole.").tqarg(name));
 }
 
 void Kolf::updateHoleMenu(int largest)
@@ -697,7 +697,7 @@ void Kolf::print()
 	KPrinter pr;
 	pr.addDialogPage(new PrintDialogPage());
 
-    if (pr.setup(this, i18n("Print %1 - Hole %2").arg(game->courseName()).arg(game->currentHole())))
+    if (pr.setup(this, i18n("Print %1 - Hole %2").tqarg(game->courseName()).tqarg(game->currentHole())))
 	{
 		pr.newPage();
 		if (game)
@@ -785,14 +785,14 @@ void Kolf::initPlugins()
 
 void Kolf::showPlugins()
 {
-	TQString text = TQString("<h2>%1</h2><ol>").arg(i18n("Currently Loaded Plugins"));
+	TQString text = TQString("<h2>%1</h2><ol>").tqarg(i18n("Currently Loaded Plugins"));
 	Object *object = 0;
 	for (object = plugins.first(); object; object = plugins.next())
 	{
 		text.append("<li>");
 		text.append(object->name());
 		text.append(" - ");
-		text.append(i18n("by %1").arg(object->author()));
+		text.append(i18n("by %1").tqarg(object->author()));
 		text.append("</li>");
 	}
 	text.append("</ol>");
