@@ -94,7 +94,7 @@ kpDocument::kpDocument (int w, int h, kpMainWindow *mainWindow)
 #endif
 
     m_pixmap = new TQPixmap (w, h);
-    m_pixmap->fill (Qt::white);
+    m_pixmap->fill (TQt::white);
 }
 
 kpDocument::~kpDocument ()
@@ -156,7 +156,7 @@ TQPixmap kpDocument::convertToPixmapAsLosslessAsPossible (
         metaInfo->setDotsPerMeterY (image.dotsPerMeterY ());
         metaInfo->setOffset (image.offset ());
 
-        TQValueList <TQImageTextKeyLang> keyList = image.textList ();
+        TQValueList <TQImageTextKeyLang> keyList = image.tqtextList ();
         for (TQValueList <TQImageTextKeyLang>::const_iterator it = keyList.begin ();
              it != keyList.end ();
              it++)
@@ -179,7 +179,7 @@ TQPixmap kpDocument::convertToPixmapAsLosslessAsPossible (
         {
             for (int x = 0; x < image.width (); x++)
             {
-                const QRgb rgb = image.pixel (x, y);
+                const TQRgb rgb = image.pixel (x, y);
                 fprintf (stderr, " %08X", rgb);
             }
             fprintf (stderr, "\n");
@@ -204,7 +204,7 @@ TQPixmap kpDocument::convertToPixmapAsLosslessAsPossible (
     {
         for (int x = 0; x < image2.width (); x++)
         {
-            const QRgb rgb = image2.pixel (x, y);
+            const TQRgb rgb = image2.pixel (x, y);
             hash += ((x % 2) + 1) * rgb;
             if (rgb != image.pixel (x, y))
             {
@@ -352,7 +352,7 @@ void kpDocument::openNew (const KURL &url)
     kdDebug () << "KpDocument::openNew (" << url << ")" << endl;
 #endif
 
-    m_pixmap->fill (Qt::white);
+    m_pixmap->fill (TQt::white);
 
     setURL (url, false/*not from url*/);
     *m_saveOptions = kpDocumentSaveOptions ();
@@ -452,7 +452,7 @@ bool kpDocument::lossyPromptContinue (const TQPixmap &pixmap,
     kdDebug () << "kpDocument::lossyPromptContinue()" << endl;
 #endif
 
-#define QUIT_IF_CANCEL(messageBoxCommand)            \
+#define TQUIT_IF_CANCEL(messageBoxCommand)            \
 {                                                    \
     if (messageBoxCommand != KMessageBox::Continue)  \
     {                                                \
@@ -464,7 +464,7 @@ bool kpDocument::lossyPromptContinue (const TQPixmap &pixmap,
     if (lossyType & (kpDocumentSaveOptions::MimeTypeMaximumColorDepthLow |
                      kpDocumentSaveOptions::Quality))
     {
-        QUIT_IF_CANCEL (
+        TQUIT_IF_CANCEL (
             KMessageBox::warningContinueCancel (parent,
                 i18n ("<qt><p>The <b>%1</b> format may not be able"
                       " to preserve all of the image's color information.</p>"
@@ -475,11 +475,11 @@ bool kpDocument::lossyPromptContinue (const TQPixmap &pixmap,
                 //       low maximum colour depth
                 i18n ("Lossy File Format"),
                 KStdGuiItem::save (),
-                TQString::fromLatin1 ("SaveInLossyMimeTypeDontAskAgain")));
+                TQString::tqfromLatin1 ("SaveInLossyMimeTypeDontAskAgain")));
     }
     else if (lossyType & kpDocumentSaveOptions::ColorDepthLow)
     {
-        QUIT_IF_CANCEL (
+        TQUIT_IF_CANCEL (
             KMessageBox::warningContinueCancel (parent,
                 i18n ("<qt><p>Saving the image at the low color depth of %1-bit"
                         " may result in the loss of color information."
@@ -490,9 +490,9 @@ bool kpDocument::lossyPromptContinue (const TQPixmap &pixmap,
                     .arg (saveOptions.colorDepth ()),
                 i18n ("Low Color Depth"),
                 KStdGuiItem::save (),
-                TQString::fromLatin1 ("SaveAtLowColorDepthDontAskAgain")));
+                TQString::tqfromLatin1 ("SaveAtLowColorDepthDontAskAgain")));
     }
-#undef QUIT_IF_CANCEL
+#undef TQUIT_IF_CANCEL
 
     return true;
 }
@@ -529,7 +529,7 @@ bool kpDocument::savePixmapToDevice (const TQPixmap &pixmap,
 
     TQPixmap pixmapToSave =
         kpPixmapFX::pixmapWithDefinedTransparentPixels (pixmap,
-            Qt::white);  // CONFIG
+            TQt::white);  // CONFIG
     TQImage imageToSave = kpPixmapFX::convertToImage (pixmapToSave);
 
 
@@ -584,7 +584,7 @@ bool kpDocument::savePixmapToDevice (const TQPixmap &pixmap,
     if (!imageToSave.save (device, type.latin1 (), quality))
     {
     #if DEBUG_KP_DOCUMENT
-        kdDebug () << "\tQImage::save() returned false" << endl;
+        kdDebug () << "\tTQImage::save() returned false" << endl;
     #endif
         return false;
     }
@@ -628,8 +628,8 @@ bool kpDocument::savePixmapToFile (const TQPixmap &pixmap,
                << ",overwritePrompt=" << overwritePrompt
                << ",lossyPrompt=" << lossyPrompt
                << ")" << endl;
-    saveOptions.printDebug (TQString::fromLatin1 ("\tsaveOptions"));
-    metaInfo.printDebug (TQString::fromLatin1 ("\tmetaInfo"));
+    saveOptions.printDebug (TQString::tqfromLatin1 ("\tsaveOptions"));
+    metaInfo.printDebug (TQString::tqfromLatin1 ("\tmetaInfo"));
 #endif
 
     if (overwritePrompt && KIO::NetAccess::exists (url, false/*write*/, parent))
@@ -638,7 +638,7 @@ bool kpDocument::savePixmapToFile (const TQPixmap &pixmap,
             i18n ("A document called \"%1\" already exists.\n"
                   "Do you want to overwrite it?")
                 .arg (prettyFilenameForURL (url)),
-            TQString::null,
+            TQString(),
             i18n ("Overwrite"));
 
         if (result != KMessageBox::Continue)
@@ -686,7 +686,7 @@ bool kpDocument::savePixmapToFile (const TQPixmap &pixmap,
             }
 
             // Write to local temporary file.
-            if (!savePixmapToDevice (pixmap, atomicFileWriter.file (),
+            if (!savePixmapToDevice (pixmap, TQT_TQIODEVICE(atomicFileWriter.file ()),
                                      saveOptions, metaInfo,
                                      false/*no lossy prompt*/,
                                      parent))
@@ -746,7 +746,7 @@ bool kpDocument::savePixmapToFile (const TQPixmap &pixmap,
                 return false;
             }
 
-            if (!savePixmapToDevice (pixmap, &file,
+            if (!savePixmapToDevice (pixmap, TQT_TQIODEVICE(&file),
                                      saveOptions, metaInfo,
                                      false/*no lossy prompt*/,
                                      parent))
@@ -1109,22 +1109,22 @@ void kpDocument::setSelection (const kpSelection &selection)
                                 (selection.type () == kpSelection::Text));
 
     // We don't change the Selection Tool if the new selection's
-    // shape is merely different to the current tool's (e.g. rectangular
+    // tqshape is merely different to the current tool's (e.g. rectangular
     // vs elliptical) because:
     //
     // 1. All image selection tools support editing selections of all the
-    //    different shapes anyway.
+    //    different tqshapes anyway.
     // 2. Suppose the user is trying out different drags of selection borders
-    //    and then decides to paste a differently shaped selection before continuing
+    //    and then decides to paste a differently tqshaped selection before continuing
     //    to try out different borders.  If the pasting were to switch to
-    //    a differently shaped tool, the borders drawn after the paste would
-    //    be using a new shape rather than the shape before the paste.  This
+    //    a differently tqshaped tool, the borders drawn after the paste would
+    //    be using a new tqshape rather than the tqshape before the paste.  This
     //    could get irritating so we don't do the switch.
     //
     if (m_mainWindow &&
         (!m_mainWindow->toolIsASelectionTool () || isTextChanged))
     {
-        // Switch to the appropriately shaped selection tool
+        // Switch to the appropriately tqshaped selection tool
         // _before_ we change the selection
         // (all selection tool's ::end() functions nuke the current selection)
         switch (selection.type ())
@@ -1288,7 +1288,7 @@ TQPixmap kpDocument::getSelectedPixmap (const TQBitmap &maskBitmap_) const
                 TQPoint (0, 0),
                 &maskBitmap,
                 TQRect (0, 0, maskBitmap.width (), maskBitmap.height ()),
-                Qt::AndROP);
+                TQt::AndROP);
         selPixmap.setMask (selMaskBitmap);
     }
 
@@ -1353,7 +1353,7 @@ bool kpDocument::selectionPullFromDocument (const kpColor &backgroundColor)
     if (backgroundColor.isOpaque ())
     {
         TQPixmap erasePixmap (boundingRect.width (), boundingRect.height ());
-        erasePixmap.fill (backgroundColor.toQColor ());
+        erasePixmap.fill (backgroundColor.toTQColor ());
 
         if (selTransparentPixmap.mask ())
             erasePixmap.setMask (*selTransparentPixmap.mask ());
