@@ -214,7 +214,7 @@ int kpPixmapFX::pointArraySize (const TQPointArray &points)
 
 
 //
-// QPixmap/TQImage Conversion Functions
+// TQPixmap/TQImage Conversion Functions
 //
 
 // public static
@@ -238,9 +238,9 @@ static bool imageHasAlphaChannel (const TQImage &image)
     {
         for (int x = 0; x < image.width (); x++)
         {
-            const QRgb rgb = image.pixel (x, y);
+            const TQRgb rgb = image.pixel (x, y);
 
-            if (qAlpha (rgb) > 0 && qAlpha (rgb) < 255)
+            if (tqAlpha (rgb) > 0 && tqAlpha (rgb) < 255)
                 return true;
         }
     }
@@ -250,7 +250,7 @@ static bool imageHasAlphaChannel (const TQImage &image)
 
 static int imageNumColorsUpTo (const TQImage &image, int max)
 {
-    TQMap <QRgb, bool> rgbMap;
+    TQMap <TQRgb, bool> rgbMap;
 
     if (image.depth () <= 8)
     {
@@ -309,7 +309,7 @@ static void convertToPixmapWarnAboutLoss (const TQImage &image,
     int screenDepthNeeded = 0;
 
     if (moreColorsThanDisplay)
-        screenDepthNeeded = QMIN (24, image.depth ());
+        screenDepthNeeded = TQMIN (24, image.depth ());
 
 #if DEBUG_KP_PIXMAP_FX && 1
     kdDebug () << "\ttranslucencyShouldBeShown="
@@ -331,14 +331,14 @@ static void convertToPixmapWarnAboutLoss (const TQImage &image,
 #endif
 
 
-    TQApplication::setOverrideCursor (Qt::arrowCursor);
+    TQApplication::setOverrideCursor (TQt::arrowCursor);
 
     if (moreColorsThanDisplay && hasAlphaChannel)
     {
         KMessageBox::information (wali.m_parent,
             wali.m_moreColorsThanDisplayAndHasAlphaChannelMessage
                 .arg (screenDepthNeeded),
-            TQString::null,  // or would you prefer "Low Screen Depth and Image Contains Transparency"? :)
+            TQString(),  // or would you prefer "Low Screen Depth and Image Contains Transparency"? :)
             colorDepthTranslucencyDontAskAgain);
 
         if (!KMessageBox::shouldBeShownContinue (colorDepthTranslucencyDontAskAgain))
@@ -387,18 +387,18 @@ TQPixmap kpPixmapFX::convertToPixmap (const TQImage &image, bool pretty,
     if (!pretty)
     {
         destPixmap.convertFromImage (image,
-                                     Qt::ColorOnly/*always display depth*/ |
-                                     Qt::ThresholdDither/*no dither*/ |
-                                     Qt::ThresholdAlphaDither/*no dither alpha*/|
-                                     Qt::AvoidDither);
+                                     TQt::ColorOnly/*always display depth*/ |
+                                     TQt::ThresholdDither/*no dither*/ |
+                                     TQt::ThresholdAlphaDither/*no dither alpha*/|
+                                     TQt::AvoidDither);
     }
     else
     {
         destPixmap.convertFromImage (image,
-                                     Qt::ColorOnly/*always display depth*/ |
-                                     Qt::DiffuseDither/*hi quality dither*/ |
-                                     Qt::ThresholdAlphaDither/*no dither alpha*/ |
-                                     Qt::PreferDither/*(dither even if <256 colours)*/);
+                                     TQt::ColorOnly/*always display depth*/ |
+                                     TQt::DiffuseDither/*hi quality dither*/ |
+                                     TQt::ThresholdAlphaDither/*no dither alpha*/ |
+                                     TQt::PreferDither/*(dither even if <256 colours)*/);
     }
 
 #if DEBUG_KP_PIXMAP_FX && 1
@@ -449,7 +449,7 @@ TQPixmap kpPixmapFX::convertToPixmapAsLosslessAsPossible (const TQImage &image,
                    << " (AvoidDither | ThresholdDither)" << endl;
     #endif
 
-        ditherFlags = (Qt::AvoidDither | Qt::ThresholdDither);
+        ditherFlags = (TQt::AvoidDither | TQt::ThresholdDither);
     }
     // PRE: image.depth() > screenDepth
     // ASSERT: screenDepth < 32
@@ -470,7 +470,7 @@ TQPixmap kpPixmapFX::convertToPixmapAsLosslessAsPossible (const TQImage &image,
             kdDebug () << "\t\tcolors fit on screen - don't dither"
                        << " (AvoidDither | ThresholdDither)" << endl;
         #endif
-            ditherFlags = (Qt::AvoidDither | Qt::ThresholdDither);
+            ditherFlags = (TQt::AvoidDither | TQt::ThresholdDither);
         }
         else
         {
@@ -478,7 +478,7 @@ TQPixmap kpPixmapFX::convertToPixmapAsLosslessAsPossible (const TQImage &image,
             kdDebug () << "\t\tcolors don't fit on screen - dither"
                        << " (PreferDither | DiffuseDither)" << endl;
         #endif
-            ditherFlags = (Qt::PreferDither | Qt::DiffuseDither);
+            ditherFlags = (TQt::PreferDither | TQt::DiffuseDither);
         }
     }
     // PRE: image.depth() > screenDepth &&
@@ -519,7 +519,7 @@ TQPixmap kpPixmapFX::convertToPixmapAsLosslessAsPossible (const TQImage &image,
             kdDebug () << "\t\t\talways dither (PreferDither | DiffuseDither)"
                         << endl;
         #endif
-            ditherFlags = (Qt::PreferDither | Qt::DiffuseDither);
+            ditherFlags = (TQt::PreferDither | TQt::DiffuseDither);
         }
         else
         {
@@ -527,14 +527,14 @@ TQPixmap kpPixmapFX::convertToPixmapAsLosslessAsPossible (const TQImage &image,
             kdDebug () << "\t\t\tdon't dither (AvoidDither | ThresholdDither)"
                        << endl;
         #endif
-            ditherFlags = (Qt::AvoidDither | Qt::ThresholdDither);
+            ditherFlags = (TQt::AvoidDither | TQt::ThresholdDither);
         }
     }
 
 
     destPixmap.convertFromImage (image,
-                                 Qt::ColorOnly/*always display depth*/ |
-                                 Qt::ThresholdAlphaDither/*no dither alpha*/ |
+                                 TQt::ColorOnly/*always display depth*/ |
+                                 TQt::ThresholdAlphaDither/*no dither alpha*/ |
                                  ditherFlags);
 
 #if DEBUG_KP_PIXMAP_FX && 1
@@ -599,7 +599,7 @@ TQPixmap kpPixmapFX::getPixmapAt (const TQPixmap &pm, const TQRect &rect)
         kdDebug () << "\tret would contain undefined pixels - setting them to transparent" << endl;
     #endif
         TQBitmap transparentMask (rect.width (), rect.height ());
-        transparentMask.fill (Qt::color0/*transparent*/);
+        transparentMask.fill (TQt::color0/*transparent*/);
         retPixmap.setMask (transparentMask);
     }
 
@@ -673,7 +673,7 @@ void kpPixmapFX::setPixmapAt (TQPixmap *destPixmapPtr, const TQRect &destRect,
         {
             for (int x = 0; x < image.width (); x++)
             {
-                if (qAlpha (image.pixel (x, y)) == 0)
+                if (tqAlpha (image.pixel (x, y)) == 0)
                     numTrans++;
             }
         }
@@ -685,7 +685,7 @@ void kpPixmapFX::setPixmapAt (TQPixmap *destPixmapPtr, const TQRect &destRect,
 #if 0
     // TODO: why does undo'ing a single pen dot on a transparent pixel,
     //       result in a opaque image, except for that single transparent pixel???
-    //       Qt bug on boundary case?
+    //       TQt bug on boundary case?
 
     // copy data _and_ mask
     copyBlt (destPixmapPtr,
@@ -694,23 +694,23 @@ void kpPixmapFX::setPixmapAt (TQPixmap *destPixmapPtr, const TQRect &destRect,
              0, 0,
              destRect.width (), destRect.height ());
 #else
-    bitBlt (destPixmapPtr,
+    bitBlt (TQT_TQPAINTDEVICE(destPixmapPtr),
             destRect.x (), destRect.y (),
-            &srcPixmap,
+            TQT_TQPAINTDEVICE(const_cast<TQPixmap*>(&srcPixmap)),
             0, 0,
             destRect.width (), destRect.height (),
-            Qt::CopyROP,
+            TQt::CopyROP,
             true/*ignore mask*/);
 
     if (srcPixmap.mask ())
     {
         TQBitmap mask = getNonNullMask (*destPixmapPtr);
-        bitBlt (&mask,
+        bitBlt (TQT_TQPAINTDEVICE(&mask),
                 destRect.x (), destRect.y (),
-                srcPixmap.mask (),
+                TQT_TQPAINTDEVICE(const_cast<TQBitmap*>(srcPixmap.mask ())),
                 0, 0,
                 destRect.width (), destRect.height (),
-                Qt::CopyROP,
+                TQt::CopyROP,
                 true/*ignore mask*/);
         destPixmapPtr->setMask (mask);
     }
@@ -737,7 +737,7 @@ void kpPixmapFX::setPixmapAt (TQPixmap *destPixmapPtr, const TQRect &destRect,
         {
             for (int x = 0; x < image.width (); x++)
             {
-                if (qAlpha (image.pixel (x, y)) == 0)
+                if (tqAlpha (image.pixel (x, y)) == 0)
                     numTrans++;
             }
         }
@@ -825,7 +825,7 @@ kpColor kpPixmapFX::getColorAtPixel (const TQImage &img, const TQPoint &at)
     if (!img.valid (at.x (), at.y ()))
         return kpColor::invalid;
 
-    QRgb rgba = img.pixel (at.x (), at.y ());
+    TQRgb rgba = img.pixel (at.x (), at.y ());
     return kpColor (rgba);
 }
 
@@ -857,7 +857,7 @@ TQBitmap kpPixmapFX::getNonNullMask (const TQPixmap &pm)
     else
     {
         TQBitmap maskBitmap (pm.width (), pm.height ());
-        maskBitmap.fill (Qt::color1/*opaque*/);
+        maskBitmap.fill (TQt::color1/*opaque*/);
 
         return maskBitmap;
     }
@@ -874,8 +874,8 @@ void kpPixmapFX::ensureTransparentAt (TQPixmap *destPixmapPtr, const TQRect &des
 
     TQPainter p (&maskBitmap);
 
-    p.setPen (Qt::color0/*transparent*/);
-    p.setBrush (Qt::color0/*transparent*/);
+    p.setPen (TQt::color0/*transparent*/);
+    p.setBrush (TQt::color0/*transparent*/);
 
     p.drawRect (destRect);
 
@@ -916,7 +916,7 @@ void kpPixmapFX::paintMaskTransparentWithBrush (TQPixmap *destPixmapPtr, const T
             &brushBitmap,
             0, 0,
             brushBitmap.width (), brushBitmap.height (),
-            Qt::NotAndROP);
+            TQt::NotAndROP);
 
     destPixmapPtr->setMask (destMaskBitmap);
 }
@@ -941,8 +941,8 @@ void kpPixmapFX::ensureOpaqueAt (TQPixmap *destPixmapPtr, const TQRect &destRect
 
     TQPainter p (&maskBitmap);
 
-    p.setPen (Qt::color1/*opaque*/);
-    p.setBrush (Qt::color1/*opaque*/);
+    p.setPen (TQt::color1/*opaque*/);
+    p.setBrush (TQt::color1/*opaque*/);
 
     p.drawRect (destRect);
 
@@ -966,14 +966,14 @@ void kpPixmapFX::ensureOpaqueAt (TQPixmap *destPixmapPtr, const TQPoint &destAt,
                 destAt, /* dest pt */
                 srcPixmap.mask (), /* src */
                 TQRect (0, 0, srcPixmap.width (), srcPixmap.height ()), /* src rect */
-                Qt::OrROP/*if either is opaque, it's opaque*/);
+                TQt::OrROP/*if either is opaque, it's opaque*/);
     }
     else
     {
         TQPainter p (&destMask);
 
-        p.setPen (Qt::color1/*opaque*/);
-        p.setBrush (Qt::color1/*opaque*/);
+        p.setPen (TQt::color1/*opaque*/);
+        p.setBrush (TQt::color1/*opaque*/);
 
         p.drawRect (destAt.x (), destAt.y (),
                     srcPixmap.width (), srcPixmap.height ());
@@ -1012,16 +1012,16 @@ TQPixmap kpPixmapFX::convertToGrayscale (const TQPixmap &pm)
     return kpPixmapFX::convertToPixmap (image);
 }
 
-static QRgb toGray (QRgb rgb)
+static TQRgb toGray (TQRgb rgb)
 {
     // naive way that doesn't preserve brightness
-    // int gray = (qRed (rgb) + qGreen (rgb) + qBlue (rgb)) / 3;
+    // int gray = (tqRed (rgb) + tqGreen (rgb) + tqBlue (rgb)) / 3;
 
     // over-exaggerates red & blue
-    // int gray = qGray (rgb);
+    // int gray = tqGray (rgb);
 
-    int gray = (212671 * qRed (rgb) + 715160 * qGreen (rgb) + 72169 * qBlue (rgb)) / 1000000;
-    return qRgba (gray, gray, gray, qAlpha (rgb));
+    int gray = (212671 * tqRed (rgb) + 715160 * tqGreen (rgb) + 72169 * tqBlue (rgb)) / 1000000;
+    return tqRgba (gray, gray, gray, tqAlpha (rgb));
 }
 
 // public static
@@ -1065,7 +1065,7 @@ void kpPixmapFX::fill (TQPixmap *destPixmapPtr, const kpColor &color)
     if (color.isOpaque ())
     {
         destPixmapPtr->setMask (TQBitmap ());  // no mask = opaque
-        destPixmapPtr->fill (color.toQColor ());
+        destPixmapPtr->fill (color.toTQColor ());
     }
     else
     {
@@ -1113,8 +1113,8 @@ void kpPixmapFX::resize (TQPixmap *destPixmapPtr, int w, int h,
         if (backgroundColor.isOpaque ())
         {
             painter.begin (destPixmapPtr);
-            painter.setPen (backgroundColor.toQColor ());
-            painter.setBrush (backgroundColor.toQColor ());
+            painter.setPen (backgroundColor.toTQColor ());
+            painter.setBrush (backgroundColor.toTQColor ());
         }
 
         if (backgroundColor.isTransparent () || destPixmapPtr->mask ())
@@ -1373,7 +1373,7 @@ static TQPixmap xForm (const TQPixmap &pm, const TQWMatrix &transformMatrix_,
     TQBitmap newBitmapMask;
 
     if (backgroundColor.isOpaque ())
-        newPixmap.fill (backgroundColor.toQColor ());
+        newPixmap.fill (backgroundColor.toTQColor ());
 
     if (backgroundColor.isTransparent () || pm.mask ())
     {
@@ -1403,12 +1403,12 @@ static TQPixmap xForm (const TQPixmap &pm, const TQWMatrix &transformMatrix_,
     painter.setWorldMatrix (transformMatrix);
 #if DEBUG_KP_PIXMAP_FX && 0
     kdDebug () << "\ttranslate top=" << painter.xForm (TQPoint (0, 0)) << endl;
-    kdDebug () << "\tmatrix: m11=" << painter.worldMatrix ().m11 ()
-               << " m12=" << painter.worldMatrix ().m12 ()
-               << " m21=" << painter.worldMatrix ().m21 ()
-               << " m22=" << painter.worldMatrix ().m22 ()
-               << " dx=" << painter.worldMatrix ().dx ()
-               << " dy=" << painter.worldMatrix ().dy ()
+    kdDebug () << "\tmatrix: m11=" << painter.tqworldMatrix ().m11 ()
+               << " m12=" << painter.tqworldMatrix ().m12 ()
+               << " m21=" << painter.tqworldMatrix ().m21 ()
+               << " m22=" << painter.tqworldMatrix ().m22 ()
+               << " dx=" << painter.tqworldMatrix ().dx ()
+               << " dy=" << painter.tqworldMatrix ().dy ()
                << endl;
 #endif
     painter.drawPixmap (TQPoint (0, 0), pm);
