@@ -1,7 +1,7 @@
 /**********************************************************************
 ** Copyright (C) 2000 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
@@ -47,7 +47,7 @@ bool QDesignerAction::addTo( TQWidget *w )
     if ( !widgetToInsert )
 	return TQAction::addTo( w );
 
-    if ( w->inherits( "TQPopupMenu" ) )
+    if ( w->inherits( TQPOPUPMENU_OBJECT_NAME_STRING ) )
 	return false;
 
     widgetToInsert->reparent( w, TQPoint( 0, 0 ), false );
@@ -68,23 +68,23 @@ void QDesignerAction::remove()
 {
     if ( !widgetToInsert )
 	return;
-    MainWindow::self->formWindow()->selectWidget( widgetToInsert, false );
+    MainWindow::self->formWindow()->selectWidget( TQT_TQOBJECT(widgetToInsert), false );
     widgetToInsert->reparent( 0, TQPoint( 0, 0 ), false );
 }
 
-QDesignerToolBarSeparator::QDesignerToolBarSeparator(Orientation o , TQToolBar *parent,
+QDesignerToolBarSeparator::QDesignerToolBarSeparator(Qt::Orientation o , TQToolBar *parent,
                                      const char* name )
     : TQWidget( parent, name )
 {
-    connect( parent, TQT_SIGNAL(orientationChanged(Orientation)),
-             this, TQT_SLOT(setOrientation(Orientation)) );
+    connect( parent, TQT_SIGNAL(orientationChanged(Qt::Orientation)),
+             this, TQT_SLOT(setOrientation(Qt::Orientation)) );
     setOrientation( o );
     setBackgroundMode( parent->backgroundMode() );
     setBackgroundOrigin( ParentOrigin );
-    setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
+    tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
 }
 
-void QDesignerToolBarSeparator::setOrientation( Orientation o )
+void QDesignerToolBarSeparator::setOrientation( Qt::Orientation o )
 {
     orient = o;
 }
@@ -94,11 +94,11 @@ void QDesignerToolBarSeparator::styleChange( TQStyle& )
     setOrientation( orient );
 }
 
-TQSize QDesignerToolBarSeparator::sizeHint() const
+TQSize QDesignerToolBarSeparator::tqsizeHint() const
 {
-    int extent = style().pixelMetric( TQStyle::PM_DockWindowSeparatorExtent,
+    int extent = tqstyle().tqpixelMetric( TQStyle::PM_DockWindowSeparatorExtent,
 				      this );
-    if ( orient == Horizontal )
+    if ( orient ==Qt::Horizontal )
 	return TQSize( extent, 0 );
     else
 	return TQSize( 0, extent );
@@ -109,11 +109,11 @@ void QDesignerToolBarSeparator::paintEvent( TQPaintEvent * )
     TQPainter p( this );
     TQStyle::SFlags flags = TQStyle::Style_Default;
 
-    if ( orientation() == Horizontal )
+    if ( orientation() ==Qt::Horizontal )
 	flags |= TQStyle::Style_Horizontal;
 
-    style().drawPrimitive( TQStyle::PE_DockWindowSeparator, &p, rect(),
-			   colorGroup(), flags );
+    tqstyle().tqdrawPrimitive( TQStyle::PE_DockWindowSeparator, &p, rect(),
+			   tqcolorGroup(), flags );
 }
 
 
@@ -125,11 +125,11 @@ QSeparatorAction::QSeparatorAction( TQObject *parent )
 
 bool QSeparatorAction::addTo( TQWidget *w )
 {
-    if ( w->inherits( "TQToolBar" ) ) {
+    if ( w->inherits( TQTOOLBAR_OBJECT_NAME_STRING ) ) {
 	TQToolBar *tb = (TQToolBar*)w;
 	wid = new QDesignerToolBarSeparator( tb->orientation(), tb );
 	return true;
-    } else if ( w->inherits( "TQPopupMenu" ) ) {
+    } else if ( w->inherits( TQPOPUPMENU_OBJECT_NAME_STRING ) ) {
 	idx = ( (TQPopupMenu*)w )->count();
 	( (TQPopupMenu*)w )->insertSeparator( idx );
 	return true;
@@ -139,10 +139,10 @@ bool QSeparatorAction::addTo( TQWidget *w )
 
 bool QSeparatorAction::removeFrom( TQWidget *w )
 {
-    if ( w->inherits( "TQToolBar" ) ) {
+    if ( w->inherits( TQTOOLBAR_OBJECT_NAME_STRING ) ) {
 	delete wid;
 	return true;
-    } else if ( w->inherits( "TQPopupMenu" ) ) {
+    } else if ( w->inherits( TQPOPUPMENU_OBJECT_NAME_STRING ) ) {
 	( (TQPopupMenu*)w )->removeItemAt( idx );
 	return true;
     }
@@ -163,7 +163,7 @@ QDesignerToolBar::QDesignerToolBar( TQMainWindow *mw )
     insertAnchor = 0;
     afterAnchor = true;
     setAcceptDrops( true );
-    MetaDataBase::addEntry( this );
+    MetaDataBase::addEntry( TQT_TQOBJECT(this) );
     lastIndicatorPos = TQPoint( -1, -1 );
     indicator = new QDesignerIndicatorWidget( this );
     indicator->hide();
@@ -174,14 +174,14 @@ QDesignerToolBar::QDesignerToolBar( TQMainWindow *mw )
 }
 
 QDesignerToolBar::QDesignerToolBar( TQMainWindow *mw, Dock dock )
-    : TQToolBar( TQString::null, mw, dock), lastIndicatorPos( -1, -1 )
+    : TQToolBar( TQString(), mw, dock), lastIndicatorPos( -1, -1 )
 {
     insertAnchor = 0;
     afterAnchor = true;
     setAcceptDrops( true );
     indicator = new QDesignerIndicatorWidget( this );
     indicator->hide();
-    MetaDataBase::addEntry( this );
+    MetaDataBase::addEntry( TQT_TQOBJECT(this) );
     installEventFilter( this );
     widgetInserting = false;
     findFormWindow();
@@ -202,7 +202,7 @@ void QDesignerToolBar::addAction( TQAction *a )
 {
     actionList.append( a );
     connect( a, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( actionRemoved() ) );
-    if ( a->inherits( "TQActionGroup" ) ) {
+    if ( a->inherits( TQACTIONGROUP_OBJECT_NAME_STRING ) ) {
 	( (QDesignerActionGroup*)a )->widget()->installEventFilter( this );
 	actionMap.insert( ( (QDesignerActionGroup*)a )->widget(), a );
     } else if ( a->inherits( "QSeparatorAction" ) ) {
@@ -222,16 +222,16 @@ static void fixObject( TQObject *&o )
 
 bool QDesignerToolBar::eventFilter( TQObject *o, TQEvent *e )
 {
-    if ( !o || !e || o->inherits( "QDockWindowHandle" ) || o->inherits( "QDockWindowTitleBar" ) )
+    if ( !o || !e || o->inherits( TQDOCKWINDOWHANDLE_OBJECT_NAME_STRING ) || o->inherits( "TQDockWindowTitleBar" ) )
 	return TQToolBar::eventFilter( o, e );
 
-    if ( o == this && e->type() == TQEvent::MouseButtonPress &&
-	 ( ( TQMouseEvent*)e )->button() == LeftButton ) {
+    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) && e->type() == TQEvent::MouseButtonPress &&
+	 ( ( TQMouseEvent*)e )->button() == Qt::LeftButton ) {
 	mousePressEvent( (TQMouseEvent*)e );
 	return true;
     }
 
-    if ( o == this )
+    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) )
 	return TQToolBar::eventFilter( o, e );
 
     if ( e->type() == TQEvent::MouseButtonPress ) {
@@ -294,7 +294,7 @@ void QDesignerToolBar::contextMenuEvent( TQContextMenuEvent *e )
     menu.insertItem( i18n("Delete Toolbar" ), 1 );
     int res = menu.exec( e->globalPos() );
     if ( res != -1 ) {
-	RemoveToolBarCommand *cmd = new RemoveToolBarCommand( i18n("Delete Toolbar '%1'" ).arg( name() ),
+	RemoveToolBarCommand *cmd = new RemoveToolBarCommand( i18n("Delete Toolbar '%1'" ).tqarg( name() ),
 							      formWindow, 0, this );
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
@@ -304,7 +304,7 @@ void QDesignerToolBar::contextMenuEvent( TQContextMenuEvent *e )
 void QDesignerToolBar::mousePressEvent( TQMouseEvent *e )
 {
     widgetInserting = false;
-    if ( e->button() == LeftButton &&
+    if ( e->button() == Qt::LeftButton &&
 	 MainWindow::self->currentTool() != POINTER_TOOL &&
 	 MainWindow::self->currentTool() != ORDER_TOOL ) {
 
@@ -360,7 +360,7 @@ void QDesignerToolBar::buttonContextMenuEvent( TQContextMenuEvent *e, TQObject *
 	int index = actionList.find( a );
 	RemoveActionFromToolBarCommand *cmd = new RemoveActionFromToolBarCommand(
 	    i18n("Delete Action '%1' From Toolbar '%2'" ).
-	    arg( a->name() ).arg( caption() ),
+	    tqarg( a->name() ).tqarg( caption() ),
 	    formWindow, a, this, index );
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
@@ -380,7 +380,7 @@ void QDesignerToolBar::buttonContextMenuEvent( TQContextMenuEvent *e, TQObject *
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
     } else if ( res == ID_DELTOOLBAR ) {
-	RemoveToolBarCommand *cmd = new RemoveToolBarCommand( i18n("Delete Toolbar '%1'" ).arg( name() ),
+	RemoveToolBarCommand *cmd = new RemoveToolBarCommand( i18n("Delete Toolbar '%1'" ).tqarg( name() ),
 							      formWindow, 0, this );
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
@@ -391,10 +391,10 @@ void QDesignerToolBar::buttonMousePressEvent( TQMouseEvent *e, TQObject * )
 {
     widgetInserting = false;
 
-    if ( e->button() == MidButton )
+    if ( e->button() == Qt::MidButton )
 	return;
 
-    if ( e->button() == LeftButton &&
+    if ( e->button() == Qt::LeftButton &&
 	 MainWindow::self->currentTool() != POINTER_TOOL &&
 	 MainWindow::self->currentTool() != ORDER_TOOL ) {
 
@@ -420,7 +420,7 @@ void QDesignerToolBar::removeWidget( TQWidget *w )
     int index = actionList.find( a );
     RemoveActionFromToolBarCommand *cmd =
 	new RemoveActionFromToolBarCommand( i18n("Delete Action '%1' From Toolbar '%2'" ).
-					    arg( a->name() ).arg( caption() ),
+					    tqarg( a->name() ).tqarg( caption() ),
 					    formWindow, a, this, index );
     formWindow->commandHistory()->addCommand( cmd );
     cmd->execute();
@@ -430,9 +430,9 @@ void QDesignerToolBar::removeWidget( TQWidget *w )
 
 void QDesignerToolBar::buttonMouseMoveEvent( TQMouseEvent *e, TQObject *o )
 {
-    if ( widgetInserting || ( e->state() & LeftButton ) == 0 )
+    if ( widgetInserting || ( e->state() & Qt::LeftButton ) == 0 )
 	return;
-    if ( QABS( TQPoint( dragStartPos - e->pos() ).manhattanLength() ) < TQApplication::startDragDistance() )
+    if ( TQABS( TQPoint( dragStartPos - e->pos() ).manhattanLength() ) < TQApplication::startDragDistance() )
 	return;
     TQMap<TQWidget*, TQAction*>::Iterator it = actionMap.find( (TQWidget*)o );
     if ( it == actionMap.end() )
@@ -443,14 +443,14 @@ void QDesignerToolBar::buttonMouseMoveEvent( TQMouseEvent *e, TQObject *o )
     int index = actionList.find( a );
     RemoveActionFromToolBarCommand *cmd =
 	new RemoveActionFromToolBarCommand( i18n("Delete Action '%1' From Toolbar '%2'" ).
-					    arg( a->name() ).arg( caption() ),
+					    tqarg( a->name() ).tqarg( caption() ),
 					    formWindow, a, this, index );
     formWindow->commandHistory()->addCommand( cmd );
     cmd->execute();
     TQApplication::sendPostedEvents();
     adjustSize();
 
-    TQString type = a->inherits( "TQActionGroup" ) ? TQString( "application/x-designer-actiongroup" ) :
+    TQString type = a->inherits( TQACTIONGROUP_OBJECT_NAME_STRING ) ? TQString( "application/x-designer-actiongroup" ) :
 	a->inherits( "QSeparatorAction" ) ? TQString( "application/x-designer-separator" ) : TQString( "application/x-designer-actions" );
     TQStoredDrag *drag = new TQStoredDrag( type, this );
     TQString s = TQString::number( (long)a ); // #### huha, that is evil
@@ -458,11 +458,11 @@ void QDesignerToolBar::buttonMouseMoveEvent( TQMouseEvent *e, TQObject *o )
     drag->setPixmap( a->iconSet().pixmap() );
     if ( a->inherits( "QDesignerAction" ) ) {
 	if ( formWindow->widgets()->find( ( (QDesignerAction*)a )->widget() ) )
-	    formWindow->selectWidget( ( (QDesignerAction*)a )->widget(), false );
+	    formWindow->selectWidget( TQT_TQOBJECT(( (QDesignerAction*)a )->widget()), false );
     }
     if ( !drag->drag() ) {
 	AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( i18n("Add Action '%1' to Toolbar '%2'" ).
-									arg( a->name() ).arg( caption() ),
+									tqarg( a->name() ).tqarg( caption() ),
 									formWindow, a, this, index );
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
@@ -471,7 +471,7 @@ void QDesignerToolBar::buttonMouseMoveEvent( TQMouseEvent *e, TQObject *o )
     indicator->hide();
 }
 
-#ifndef QT_NO_DRAGANDDROP
+#ifndef TQT_NO_DRAGANDDROP
 
 void QDesignerToolBar::dragEnterEvent( TQDragEnterEvent *e )
 {
@@ -511,11 +511,11 @@ void QDesignerToolBar::dropEvent( TQDropEvent *e )
 	return;
     TQString s;
     if ( e->provides( "application/x-designer-actiongroup" ) )
-	s = TQString( e->encodedData( "application/x-designer-actiongroup" ) );
+	s = TQString( e->tqencodedData( "application/x-designer-actiongroup" ) );
     else if ( e->provides( "application/x-designer-separator" ) )
-	s = TQString( e->encodedData( "application/x-designer-separator" ) );
+	s = TQString( e->tqencodedData( "application/x-designer-separator" ) );
     else
-	s = TQString( e->encodedData( "application/x-designer-actions" ) );
+	s = TQString( e->tqencodedData( "application/x-designer-actions" ) );
 
     indicator->hide();
     TQAction *a = 0;
@@ -543,7 +543,7 @@ void QDesignerToolBar::dropEvent( TQDropEvent *e )
     }
 
     AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( i18n("Add Action '%1' to Toolbar '%2'" ).
-								    arg( a->name() ).arg( caption() ),
+								    tqarg( a->name() ).tqarg( caption() ),
 								    formWindow, a, this, index );
     formWindow->commandHistory()->addCommand( cmd );
     cmd->execute();
@@ -560,7 +560,7 @@ void QDesignerToolBar::reInsert()
     clear();
     for ( a = actionList.first(); a; a = actionList.next() ) {
 	a->addTo( this );
-	if ( a->inherits( "TQActionGroup" ) ) {
+	if ( a->inherits( TQACTIONGROUP_OBJECT_NAME_STRING ) ) {
 	    actionMap.insert( ( (QDesignerActionGroup*)a )->widget(), a );
 	    if ( ( (QDesignerActionGroup*)a )->widget() )
 		( (QDesignerActionGroup*)a )->widget()->installEventFilter( this );
@@ -583,14 +583,15 @@ void QDesignerToolBar::actionRemoved()
 
 TQPoint QDesignerToolBar::calcIndicatorPos( const TQPoint &pos )
 {
-    if ( orientation() == Horizontal ) {
+    if ( orientation() ==Qt::Horizontal ) {
 	TQPoint pnt( width() - 2, 0 );
 	insertAnchor = 0;
 	afterAnchor = true;
-	if ( !children() )
+	TQObjectList clo = childrenListObject();
+	if ( clo.isEmpty() )
 	    return pnt;
 	pnt = TQPoint( 13, 0 );
-	TQObjectListIt it( *children() );
+	TQObjectListIt it( clo );
 	TQObject * obj;
 	while( (obj=it.current()) != 0 ) {
 	    ++it;
@@ -609,10 +610,11 @@ TQPoint QDesignerToolBar::calcIndicatorPos( const TQPoint &pos )
 	TQPoint pnt( 0, height() - 2 );
 	insertAnchor = 0;
 	afterAnchor = true;
-	if ( !children() )
+	TQObjectList clo = childrenListObject();
+	if ( clo.isEmpty() )
 	    return pnt;
 	pnt = TQPoint( 0, 13 );
-	TQObjectListIt it( *children() );
+	TQObjectListIt it( clo );
 	TQObject * obj;
 	while( (obj=it.current()) != 0 ) {
 	    ++it;
@@ -635,7 +637,7 @@ void QDesignerToolBar::drawIndicator( const TQPoint &pos )
     if ( lastIndicatorPos == pos )
 	return;
     bool wasVsisible = indicator->isVisible();
-    if ( orientation() == Horizontal ) {
+    if ( orientation() ==Qt::Horizontal ) {
 	indicator->resize( 3, height() );
 	if ( pos != TQPoint( -1, -1 ) )
 	     indicator->move( pos.x() - 1, 0 );
@@ -669,7 +671,7 @@ void QDesignerToolBar::doInsertWidget( const TQPoint &p )
     if ( !insertAnchor )
 	index = 0;
     AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( i18n("Add Widget '%1' to Toolbar '%2'" ).
-								    arg( w->name() ).arg( caption() ),
+								    tqarg( w->name() ).tqarg( caption() ),
 								    formWindow, a, this, index );
     formWindow->commandHistory()->addCommand( cmd );
     cmd->execute();
@@ -689,7 +691,7 @@ void QDesignerToolBar::installEventFilters( TQWidget *w )
 {
     if ( !w )
 	return;
-    TQObjectList *l = w->queryList( "TQWidget" );
+    TQObjectList *l = w->queryList( TQWIDGET_OBJECT_NAME_STRING );
     for ( TQObject *o = l->first(); o; o = l->next() )
 	o->installEventFilter( this );
     delete l;
@@ -702,7 +704,7 @@ QDesignerMenuBar::QDesignerMenuBar( TQWidget *mw )
 {
     show();
     setAcceptDrops( true );
-    MetaDataBase::addEntry( this );
+    MetaDataBase::addEntry( TQT_TQOBJECT(this) );
     itemNum = 0;
     mousePressed = false;
     lastIndicatorPos = TQPoint( -1, -1 );
@@ -737,16 +739,16 @@ void QDesignerMenuBar::contextMenuEvent( TQContextMenuEvent *e )
     int res = menu.exec( e->globalPos() );
     if ( res == 1 ) {
 	TQMenuItem *item = findItem( idAt( itm ) );
-	RemoveMenuCommand *cmd = new RemoveMenuCommand( i18n("Delete Menu '%1'" ).arg( item->text() ),
+	RemoveMenuCommand *cmd = new RemoveMenuCommand( i18n("Delete Menu '%1'" ).tqarg( item->text() ),
 							formWindow,
 							(TQMainWindow*)parentWidget(), this,
 							(QDesignerPopupMenu*)item->popup(),
 							idAt( itm ), itm, item->text() );
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
-	// #### need to do a proper invalidate and re-layout
-	parentWidget()->layout()->invalidate();
-	parentWidget()->layout()->activate();
+	// #### need to do a proper tqinvalidate and re-tqlayout
+	parentWidget()->tqlayout()->tqinvalidate();
+	parentWidget()->tqlayout()->activate();
     } else if ( res == 2 ) {
 	bool ok;
 	TQString old = text( idAt( itm ) );
@@ -754,7 +756,7 @@ void QDesignerMenuBar::contextMenuEvent( TQContextMenuEvent *e )
 					     text( idAt( itm ) ), &ok, 0 );
 	if ( ok ) {
 	    RenameMenuCommand *cmd = new RenameMenuCommand(
-		i18n("Rename Menu '%1' to '%2'" ).arg( old ).arg( txt ),
+		i18n("Rename Menu '%1' to '%2'" ).tqarg( old ).tqarg( txt ),
 		formWindow, this, idAt( itm ), old, txt );
 	    formWindow->commandHistory()->addCommand( cmd );
 	    cmd->execute();
@@ -767,7 +769,7 @@ void QDesignerMenuBar::mousePressEvent( TQMouseEvent *e )
     lastIndicatorPos = TQPoint( -1, -1 );
     insertAt = -1;
     mousePressed = true;
-    if ( e->button() == MidButton || e->button() == RightButton )
+    if ( e->button() == Qt::MidButton || e->button() == Qt::RightButton )
 	return;
 
     dragStartPos = e->pos();
@@ -776,11 +778,11 @@ void QDesignerMenuBar::mousePressEvent( TQMouseEvent *e )
 
 void QDesignerMenuBar::mouseMoveEvent( TQMouseEvent *e )
 {
-    if ( !mousePressed || e->state() == NoButton ) {
+    if ( !mousePressed || e->state() == Qt::NoButton ) {
 	TQMenuBar::mouseMoveEvent( e );
 	return;
     }
-    if ( QABS( TQPoint( dragStartPos - e->pos() ).manhattanLength() ) < TQApplication::startDragDistance() )
+    if ( TQABS( TQPoint( dragStartPos - e->pos() ).manhattanLength() ) < TQApplication::startDragDistance() )
 	return;
     hidePopups();
     activateItemAt( -1 );
@@ -818,7 +820,7 @@ void QDesignerMenuBar::mouseReleaseEvent( TQMouseEvent *e )
     mousePressed = false;
 }
 
-#ifndef QT_NO_DRAGANDDROP
+#ifndef TQT_NO_DRAGANDDROP
 
 void QDesignerMenuBar::dragEnterEvent( TQDragEnterEvent *e )
 {
@@ -845,12 +847,12 @@ void QDesignerMenuBar::dragMoveEvent( TQDragMoveEvent *e )
 	 e->provides( "application/x-designer-actiongroup" ) ||
 	 e->provides( "application/x-designer-separator" ) ) {
 	int item = itemAtPos( e->pos() );
-	bool uieffect = TQApplication::isEffectEnabled( UI_AnimateMenu );
-	TQApplication::setEffectEnabled( UI_AnimateMenu, false );
-	if ( !qApp->activePopupWidget() )
+	bool uieffect = TQApplication::isEffectEnabled( Qt::UI_AnimateMenu );
+	TQApplication::setEffectEnabled( Qt::UI_AnimateMenu, false );
+	if ( !tqApp->activePopupWidget() )
 	    actItem = -1;
 	activateItemAt( item );
-	TQApplication::setEffectEnabled( UI_AnimateMenu, uieffect );
+	TQApplication::setEffectEnabled( Qt::UI_AnimateMenu, uieffect );
 	if ( item == -1 )
 	    hidePopups();
     } else {
@@ -871,14 +873,14 @@ void QDesignerMenuBar::dropEvent( TQDropEvent *e )
     if ( !e->provides( "application/x-designer-menuitem" ) )
 	return;
     e->accept();
-    TQString s( e->encodedData( "application/x-designer-menuitem" ) );
+    TQString s( e->tqencodedData( "application/x-designer-menuitem" ) );
     TQString s1 = s.left( s.find( "/" ) );
     TQString s2 = s.mid( s.find( "/" ) + 1 );
     TQPopupMenu *popup = (TQPopupMenu*)s1.toLong();  // #### huha, that is evil
     TQString txt = s2;
     insertItem( txt, popup, -1, insertAt );
 
-    MoveMenuCommand *cmd = new MoveMenuCommand( i18n("Move Menu '%1'" ).arg( txt ), formWindow,
+    MoveMenuCommand *cmd = new MoveMenuCommand( i18n("Move Menu '%1'" ).tqarg( txt ), formWindow,
 						this, (QDesignerPopupMenu*)popup, oldPos, insertAt, txt );
     // do not execute, we did the work already
     formWindow->commandHistory()->addCommand( cmd );
@@ -893,7 +895,7 @@ TQPoint QDesignerMenuBar::calcIndicatorPos( const TQPoint &pos )
     int w = frameWidth();
     insertAt = count();
     for ( int i = 0; i < (int)count(); ++i ) {
-	TQRect r = itemRect( i );
+	TQRect r = tqitemRect( i );
 	if ( pos.x() < w + r.width() / 2 ) {
 	    insertAt = i;
 	    break;
@@ -938,7 +940,7 @@ void QDesignerMenuBar::setItemText( const TQString &s )
 TQString QDesignerMenuBar::itemText() const
 {
     if ( itemNum < 0 || (int)itemNum >= (int)count() )
-	return TQString::null;
+	return TQString();
     return text( idAt( itemNum ) );
 }
 
@@ -973,9 +975,9 @@ QDesignerPopupMenu::QDesignerPopupMenu( TQWidget *w )
 
 void QDesignerPopupMenu::contextMenuEvent( TQContextMenuEvent *e )
 {
-#if defined( Q_WS_MAC ) //the mac needs us to use context menu rather than right click
+#if defined( TQ_WS_MAC ) //the mac needs us to use context menu rather than right click
     e->accept();
-    TQMouseEvent me( TQEvent::MouseButtonPress, e->pos(), e->globalPos(), RightButton, RightButton );
+    TQMouseEvent me( TQEvent::MouseButtonPress, e->pos(), e->globalPos(), Qt::RightButton, Qt::RightButton );
     mousePressEvent(&me);
 #else
     Q_UNUSED( e );
@@ -984,10 +986,10 @@ void QDesignerPopupMenu::contextMenuEvent( TQContextMenuEvent *e )
 
 void QDesignerPopupMenu::mousePressEvent( TQMouseEvent *e )
 {
-    if ( e->button() == MidButton )
+    if ( e->button() == Qt::MidButton )
 	return;
 
-    if ( e->button() == RightButton ) {
+    if ( e->button() == Qt::RightButton ) {
 	// A popup for a popup, we only need one, so make sure that
 	// we don't create multiple.  The timer keeps the event loop sane.
 	popupPos = e->globalPos();
@@ -1028,7 +1030,7 @@ void QDesignerPopupMenu::createPopupMenu()
 	    return;
 	RemoveActionFromPopupCommand *cmd = new RemoveActionFromPopupCommand(
 									     i18n("Delete Action '%1' From Popup Menu '%2'" ).
-									     arg( a->name() ).arg( caption() ),
+									     tqarg( a->name() ).tqarg( caption() ),
 									     formWindow, a, this, itm );
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
@@ -1052,11 +1054,11 @@ void QDesignerPopupMenu::createPopupMenu()
 
 void QDesignerPopupMenu::mouseMoveEvent( TQMouseEvent *e )
 {
-    if ( !mousePressed || e->state() == NoButton ) {
+    if ( !mousePressed || e->state() == Qt::NoButton ) {
 	TQPopupMenu::mouseMoveEvent( e );
 	return;
     }
-    if ( QABS( TQPoint( dragStartPos - e->pos() ).manhattanLength() ) < TQApplication::startDragDistance() ) {
+    if ( TQABS( TQPoint( dragStartPos - e->pos() ).manhattanLength() ) < TQApplication::startDragDistance() ) {
 	TQPopupMenu::mouseMoveEvent( e );
 	return;
     }
@@ -1067,12 +1069,12 @@ void QDesignerPopupMenu::mouseMoveEvent( TQMouseEvent *e )
     if ( !a )
 	return;
     RemoveActionFromPopupCommand *cmd = new RemoveActionFromPopupCommand( i18n("Delete Action '%1' From Popup Menu '%2'" ).
-									  arg( a->name() ).arg( caption() ),
+									  tqarg( a->name() ).tqarg( caption() ),
 									  formWindow, a, this, itm );
     formWindow->commandHistory()->addCommand( cmd );
     cmd->execute();
 
-    TQString type = a->inherits( "TQActionGroup" ) ? TQString( "application/x-designer-actiongroup" ) :
+    TQString type = a->inherits( TQACTIONGROUP_OBJECT_NAME_STRING ) ? TQString( "application/x-designer-actiongroup" ) :
 	a->inherits( "QSeparatorAction" ) ? TQString( "application/x-designer-separator" ) : TQString( "application/x-designer-actions" );
     TQStoredDrag *drag = new TQStoredDrag( type, this );
     TQString s = TQString::number( (long)a ); // #### huha, that is evil
@@ -1080,7 +1082,7 @@ void QDesignerPopupMenu::mouseMoveEvent( TQMouseEvent *e )
     drag->setPixmap( a->iconSet().pixmap() );
     if ( !drag->drag() ) {
 	AddActionToPopupCommand *cmd = new AddActionToPopupCommand( i18n("Add Action '%1' to Popup Menu '%2'" ).
-								    arg( a->name() ).arg( name() ),
+								    tqarg( a->name() ).tqarg( name() ),
 								    formWindow, a, this, itm );
 	formWindow->commandHistory()->addCommand( cmd );
 	cmd->execute();
@@ -1096,7 +1098,7 @@ void QDesignerPopupMenu::mouseReleaseEvent( TQMouseEvent *e )
     TQPopupMenu::mouseReleaseEvent( e );
 }
 
-#ifndef QT_NO_DRAGANDDROP
+#ifndef TQT_NO_DRAGANDDROP
 
 void QDesignerPopupMenu::dragEnterEvent( TQDragEnterEvent *e )
 {
@@ -1140,15 +1142,15 @@ void QDesignerPopupMenu::dropEvent( TQDropEvent *e )
     TQPoint p = pos();
     TQAction *a = 0;
     if ( e->provides( "application/x-designer-actiongroup" ) ) {
-	TQString s( e->encodedData( "application/x-designer-actiongroup" ) );
+	TQString s( e->tqencodedData( "application/x-designer-actiongroup" ) );
 	a = (QDesignerActionGroup*)s.toLong();
     } else {
 	TQString s;
 	if ( e->provides( "application/x-designer-separator" ) ) {
-	    s = TQString( e->encodedData( "application/x-designer-separator" ) );
+	    s = TQString( e->tqencodedData( "application/x-designer-separator" ) );
 	    a = (QSeparatorAction*)s.toLong();
 	} else {
-	    s = TQString( e->encodedData( "application/x-designer-actions" ) );
+	    s = TQString( e->tqencodedData( "application/x-designer-actions" ) );
 	    a = (QDesignerAction*)s.toLong();
 	}
     }
@@ -1162,7 +1164,7 @@ void QDesignerPopupMenu::dropEvent( TQDropEvent *e )
     }
 
     AddActionToPopupCommand *cmd = new AddActionToPopupCommand( i18n("Add Action '%1' to Popup Menu '%2'" ).
-								arg( a->name() ).arg( name() ),
+								tqarg( a->name() ).tqarg( name() ),
 								formWindow, a, this, insertAt );
     formWindow->commandHistory()->addCommand( cmd );
     cmd->execute();
