@@ -1,7 +1,7 @@
 /**********************************************************************
 ** Copyright (C) 2000 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
@@ -25,9 +25,10 @@
 #include <tqvalidator.h>
 
 
-class AsciiValidator: public QValidator
+class AsciiValidator: public TQValidator
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     AsciiValidator( TQObject * parent, const char *name = 0 );
     AsciiValidator( bool funcName, TQObject * parent, const char *name = 0 );
