@@ -1,7 +1,7 @@
 /**********************************************************************
 ** Copyright (C) 2000 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
@@ -50,7 +50,7 @@ class QDesignerPopupMenu;
 class QDesignerMenuBar;
 class TQToolBox;
 
-class Command : public Qt
+class Command : public TQt
 {
 public:
     Command( const TQString &n, FormWindow *fw );
@@ -120,9 +120,10 @@ private:
 };
 
 
-class CommandHistory : public QObject
+class CommandHistory : public TQObject
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     CommandHistory( int s );
@@ -180,7 +181,7 @@ public:
 
 private:
     TQWidget *widget;
-    TQRect geometry;
+    TQRect tqgeometry;
 
 };
 
@@ -262,7 +263,7 @@ public:
     Type type() const { return LayoutHorizontal; }
 
 private:
-    HorizontalLayout layout;
+    HorizontalLayout tqlayout;
 
 };
 
@@ -278,7 +279,7 @@ public:
     Type type() const { return LayoutHorizontalSplitter; }
 
 private:
-    HorizontalLayout layout;
+    HorizontalLayout tqlayout;
 
 };
 
@@ -294,7 +295,7 @@ public:
     Type type() const { return LayoutVertical; }
 
 private:
-    VerticalLayout layout;
+    VerticalLayout tqlayout;
 
 };
 
@@ -310,7 +311,7 @@ public:
     Type type() const { return LayoutVerticalSplitter; }
 
 private:
-    VerticalLayout layout;
+    VerticalLayout tqlayout;
 
 };
 
@@ -326,7 +327,7 @@ public:
     Type type() const { return LayoutGrid; }
 
 private:
-    GridLayout layout;
+    GridLayout tqlayout;
 
 };
 
@@ -341,7 +342,7 @@ public:
     Type type() const { return BreakLayout; }
 
 private:
-    Layout *layout;
+    Layout *tqlayout;
     int spacing;
     int margin;
     TQWidget *lb;
@@ -658,7 +659,7 @@ public:
     {
 	TQString text;
 	TQPixmap pix;
-#if defined(Q_FULL_TEMPLATE_INSTANTIATION)
+#if defined(TQ_FULL_TEMPLATE_INSTANTIATION)
 	bool operator==( const Item & ) const { return FALSE; }
 #endif
     };
@@ -684,7 +685,7 @@ public:
     {
 	TQString text;
 	TQPixmap pix;
-#if defined(Q_FULL_TEMPLATE_INSTANTIATION)
+#if defined(TQ_FULL_TEMPLATE_INSTANTIATION)
 	bool operator==( const Item & ) const { return FALSE; }
 #endif
     };
@@ -744,7 +745,7 @@ public:
     {
 	TQString text;
 	TQPixmap pix;
-#if defined(Q_FULL_TEMPLATE_INSTANTIATION)
+#if defined(TQ_FULL_TEMPLATE_INSTANTIATION)
 	bool operator==( const Row& ) const { return FALSE; }
 #endif
     };
@@ -754,7 +755,7 @@ public:
 	TQString text;
 	TQPixmap pix;
 	TQString field;
-#if defined(Q_FULL_TEMPLATE_INSTANTIATION)
+#if defined(TQ_FULL_TEMPLATE_INSTANTIATION)
 	bool operator==( const Column& ) const { return FALSE; }
 #endif
     };
