@@ -7,18 +7,18 @@
 FileChooser::FileChooser( TQWidget *parent, const char *name )
     : TQWidget( parent, name ), md( File )
 {
-    TQHBoxLayout *layout = new TQHBoxLayout( this );
-    layout->setMargin( 0 );
+    TQHBoxLayout *tqlayout = new TQHBoxLayout( this );
+    tqlayout->setMargin( 0 );
 
     lineEdit = new TQLineEdit( this, "filechooser_lineedit" );
-    layout->addWidget( lineEdit );
+    tqlayout->addWidget( lineEdit );
 
     connect( lineEdit, TQT_SIGNAL( textChanged( const TQString & ) ),
 	     this, TQT_SIGNAL( fileNameChanged( const TQString & ) ) );
 
     button = new TQPushButton( "...", this, "filechooser_button" );
     button->setFixedWidth( button->fontMetrics().width( " ... " ) );
-    layout->addWidget( button );
+    tqlayout->addWidget( button );
 
     connect( button, TQT_SIGNAL( clicked() ),
 	     this, TQT_SLOT( chooseFile() ) );
@@ -50,7 +50,7 @@ void FileChooser::chooseFile()
 {
     TQString fn;
     if ( mode() == File )
-	fn = KFileDialog::getOpenFileName( lineEdit->text(), TQString::null, this );
+	fn = KFileDialog::getOpenFileName( lineEdit->text(), TQString(), this );
     else
 	fn = KFileDialog::getExistingDirectory( lineEdit->text(),this );
 
