@@ -1,7 +1,7 @@
 /**********************************************************************
 ** Copyright (C) 2000-2001 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
@@ -90,8 +90,8 @@ void HierarchyItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
 {
     TQColorGroup g( cg );
     g.setColor( TQColorGroup::Base, backgroundColor() );
-    g.setColor( TQColorGroup::Foreground, Qt::black );
-    g.setColor( TQColorGroup::Text, Qt::black );
+    g.setColor( TQColorGroup::Foreground, TQt::black );
+    g.setColor( TQColorGroup::Text, TQt::black );
     TQString txt = text( 0 );
     if ( rtti() == Slot &&
    ( txt == "init()" || txt == "destroy()" ) ) {
@@ -250,21 +250,21 @@ void HierarchyList::objectClicked( TQListViewItem *i )
     if ( formWindow == w ) {
   if ( deselect )
       formWindow->clearSelection( false );
-  formWindow->emitShowProperties( formWindow );
+  formWindow->emitShowProperties( TQT_TQOBJECT(formWindow) );
   return;
     }
 
     if ( !formWindow->widgets()->find( w ) ) {
-  if ( w->parent() && w->parent()->inherits( "TQWidgetStack" ) &&
+  if ( w->parent() && w->parent()->inherits( TQWIDGETSTACK_OBJECT_NAME_STRING ) &&
        w->parent()->parent() &&
-       ( w->parent()->parent()->inherits( "TQTabWidget" ) ||
-         w->parent()->parent()->inherits( "TQWizard" ) ) ) {
-      if ( w->parent()->parent()->inherits( "TQTabWidget" ) )
+       ( w->parent()->parent()->inherits( TQTABWIDGET_OBJECT_NAME_STRING ) ||
+         w->parent()->parent()->inherits( TQWIZARD_OBJECT_NAME_STRING ) ) ) {
+      if ( w->parent()->parent()->inherits( TQTABWIDGET_OBJECT_NAME_STRING ) )
     ( (TQTabWidget*)w->parent()->parent() )->showPage( w );
       else
         ( (QDesignerWizard*)w->parent()->parent() )->setCurrentPage( ( (QDesignerWizard*)w->parent()->parent() )->pageNum( w ) );
       w = (TQWidget*)w->parent()->parent();
-      formWindow->emitUpdateProperties( formWindow->currentWidget() );
+      formWindow->emitUpdateProperties( TQT_TQOBJECT(formWindow->currentWidget()) );
   } else {
       return;
   }
@@ -273,7 +273,7 @@ void HierarchyList::objectClicked( TQListViewItem *i )
     if ( deselect )
   formWindow->clearSelection( false );
     if ( w->isVisibleTo( formWindow ) )
-  formWindow->selectWidget( w, true );
+  formWindow->selectWidget( TQT_TQOBJECT(w), true );
 }
 
 TQWidget *HierarchyList::findWidget( TQListViewItem *i )
@@ -310,7 +310,7 @@ void HierarchyList::changeNameOf( TQWidget *w, const TQString &name )
 
 void HierarchyList::changeDatabaseOf( TQWidget *w, const TQString & info )
 {
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
     if ( !formWindow->isDatabaseAware() )
   return;
     TQListViewItem *item = findItem( w );
@@ -329,7 +329,7 @@ void HierarchyList::setup()
   return;
     clear();
     TQWidget *w = formWindow->mainContainer();
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
     if ( formWindow->isDatabaseAware() ) {
   if ( columns() == 2 ) {
       addColumn( i18n("Database" ) );
@@ -345,7 +345,7 @@ void HierarchyList::setup()
     }
 #endif
     if ( w )
-  insertObject( w, 0 );
+  insertObject( TQT_TQOBJECT(w), 0 );
 }
 
 void HierarchyList::setOpen( TQListViewItem *i, bool b )
@@ -356,8 +356,8 @@ void HierarchyList::setOpen( TQListViewItem *i, bool b )
 void HierarchyList::insertObject( TQObject *o, TQListViewItem *parent )
 {
     bool fakeMainWindow = false;
-    if ( o && o->inherits( "TQMainWindow" ) ) {
-  TQObject *cw = ( (TQMainWindow*)o )->centralWidget();
+    if ( o && o->inherits( TQMAINWINDOW_OBJECT_NAME_STRING ) ) {
+  TQObject *cw = TQT_TQOBJECT(( (TQMainWindow*)o )->centralWidget());
   if ( cw ) {
       o = cw;
       fakeMainWindow = true;
@@ -365,7 +365,7 @@ void HierarchyList::insertObject( TQObject *o, TQListViewItem *parent )
     }
     TQListViewItem *item = 0;
     TQString className = WidgetFactory::classNameOf( o );
-    if ( o->inherits( "QLayoutWidget" ) ) {
+    if ( o->inherits( TQLAYOUTWIDGET_OBJECT_NAME_STRING ) ) {
   switch ( WidgetFactory::layoutType( (TQWidget*)o ) ) {
   case WidgetFactory::HBox:
       className = "HBox";
@@ -382,28 +382,28 @@ void HierarchyList::insertObject( TQObject *o, TQListViewItem *parent )
     }
 
     TQString dbInfo;
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
     dbInfo = MetaDataBase::fakeProperty( o, "database" ).toStringList().join(".");
 #endif
 
     TQString name = o->name();
-    if ( o->parent() && o->parent()->inherits( "TQWidgetStack" ) &&
+    if ( o->parent() && o->parent()->inherits( TQWIDGETSTACK_OBJECT_NAME_STRING ) &&
    o->parent()->parent() ) {
-  if ( o->parent()->parent()->inherits( "TQTabWidget" ) )
+  if ( o->parent()->parent()->inherits( TQTABWIDGET_OBJECT_NAME_STRING ) )
       name = ( (TQTabWidget*)o->parent()->parent() )->tabLabel( (TQWidget*)o );
-  else if ( o->parent()->parent()->inherits( "TQWizard" ) )
+  else if ( o->parent()->parent()->inherits( TQWIZARD_OBJECT_NAME_STRING ) )
       name = ( (TQWizard*)o->parent()->parent() )->title( (TQWidget*)o );
     }
 
     TQToolBox *tb;
     if ( o->parent() && o->parent()->parent() &&
-     (tb = ::qt_cast<TQToolBox*>(o->parent()->parent()->parent())) )
+     (tb = ::tqqt_cast<TQToolBox*>(o->parent()->parent()->parent())) )
     name = tb->itemLabel( tb->indexOf((TQWidget*)o) );
 
 
     if ( fakeMainWindow ) {
   name = o->parent()->name();
-  className = "TQMainWindow";
+  className = TQMAINWINDOW_OBJECT_NAME_STRING;
     }
 
     if ( !parent )
@@ -412,49 +412,49 @@ void HierarchyList::insertObject( TQObject *o, TQListViewItem *parent )
   item = new HierarchyItem( HierarchyItem::Widget, parent, name, className, dbInfo );
     if ( !parent )
   item->setPixmap( 0, PixmapChooser::loadPixmap( "form.xpm", PixmapChooser::Mini ) );
-    else if ( o->inherits( "QLayoutWidget") )
-  item->setPixmap( 0, PixmapChooser::loadPixmap( "layout.xpm", PixmapChooser::Small ) );
+    else if ( o->inherits( TQLAYOUTWIDGET_OBJECT_NAME_STRING) )
+  item->setPixmap( 0, PixmapChooser::loadPixmap( "tqlayout.xpm", PixmapChooser::Small ) );
     else
   item->setPixmap( 0, WidgetDatabase::iconSet( WidgetDatabase::idFromClassName( WidgetFactory::classNameOf( o ) ) ).
        pixmap( TQIconSet::Small, TQIconSet::Normal ) );
     ( (HierarchyItem*)item )->setWidget( (TQWidget*)o );
 
-    const TQObjectList *l = o->children();
-    if ( !l )
+    const TQObjectList l = o->childrenListObject();
+    if ( l.isEmpty() )
   return;
-    TQObjectListIt it( *l );
+    TQObjectListIt it( l );
     it.toLast();
     for ( ; it.current(); --it ) {
   if ( !it.current()->isWidgetType() || ( (TQWidget*)it.current() )->isHidden() )
       continue;
   if (  !formWindow->widgets()->find( (TQWidget*)it.current() ) ) {
       if ( it.current()->parent() &&
-     ( it.current()->parent()->inherits( "TQTabWidget" ) ||
-       it.current()->parent()->inherits( "TQWizard" ) ) &&
-     it.current()->inherits( "TQWidgetStack" ) ) {
+     ( it.current()->parent()->inherits( TQTABWIDGET_OBJECT_NAME_STRING ) ||
+       it.current()->parent()->inherits( TQWIZARD_OBJECT_NAME_STRING ) ) &&
+     it.current()->inherits( TQWIDGETSTACK_OBJECT_NAME_STRING ) ) {
     TQObject *obj = it.current();
-    TQObjectList *l2 = obj->queryList( "TQWidget", 0, true, false );
+    TQObjectList *l2 = obj->queryList( TQWIDGET_OBJECT_NAME_STRING, 0, true, false );
     QDesignerTabWidget *tw = 0;
     QDesignerWizard *dw = 0;
-    if ( it.current()->parent()->inherits( "TQTabWidget" ) )
+    if ( it.current()->parent()->inherits( TQTABWIDGET_OBJECT_NAME_STRING ) )
         tw = (QDesignerTabWidget*)it.current()->parent();
-    if ( it.current()->parent()->inherits( "TQWizard" ) )
+    if ( it.current()->parent()->inherits( TQWIZARD_OBJECT_NAME_STRING ) )
       dw = (QDesignerWizard*)it.current()->parent();
     TQWidgetStack *stack = (TQWidgetStack*)obj;
     for ( obj = l2->last(); obj; obj = l2->prev() ) {
-        if ( qstrcmp( obj->className(), "QWidgetStackPrivate::Invisible" ) == 0 ||
+        if ( qstrcmp( obj->className(), "TQWidgetStackPrivate::Invisible" ) == 0 ||
        ( tw && !tw->tabBar()->tab( stack->id( (TQWidget*)obj ) ) ) ||
        ( dw && dw->isPageRemoved( (TQWidget*)obj ) ) )
       continue;
         insertObject( obj, item );
     }
     delete l2;
-      } else if ( ::qt_cast<TQToolBox*>(it.current()->parent()) ) {
-            if ( !::qt_cast<TQScrollView*>(it.current()) )
+      } else if ( ::tqqt_cast<TQToolBox*>(it.current()->parent()) ) {
+            if ( !::tqqt_cast<TQScrollView*>(it.current()) )
             continue;
             TQToolBox *tb = (TQToolBox*)it.current()->parent();
             for ( int i = tb->count() - 1; i >= 0; --i )
-            insertObject( tb->item( i ), item );
+            insertObject( TQT_TQOBJECT(tb->item( i )), item );
         }
       continue;
   }
@@ -495,7 +495,7 @@ void HierarchyList::showRMBMenu( TQListViewItem *i, const TQPoint & p )
   return;
 
     if ( w->isVisibleTo( formWindow ) ) {
-  if ( !w->inherits( "TQTabWidget" ) && !w->inherits( "TQWizard" ) ) {
+  if ( !w->inherits( TQTABWIDGET_OBJECT_NAME_STRING ) && !w->inherits( TQWIZARD_OBJECT_NAME_STRING ) ) {
       if ( !normalMenu )
     normalMenu = formWindow->mainWindow()->setupNormalHierarchyMenu( this );
       normalMenu->popup( p );
@@ -514,15 +514,15 @@ void HierarchyList::addTabPage()
     TQWidget *w = current();
     if ( !w )
   return;
-    if ( w->inherits( "TQTabWidget" ) ) {
+    if ( w->inherits( TQTABWIDGET_OBJECT_NAME_STRING ) ) {
   TQTabWidget *tw = (TQTabWidget*)w;
-  AddTabPageCommand *cmd = new AddTabPageCommand( i18n("Add Page to %1" ).arg( tw->name() ), formWindow,
+  AddTabPageCommand *cmd = new AddTabPageCommand( i18n("Add Page to %1" ).tqarg( tw->name() ), formWindow,
               tw, "Tab" );
   formWindow->commandHistory()->addCommand( cmd );
   cmd->execute();
-    } else if ( w->inherits( "TQWizard" ) ) {
+    } else if ( w->inherits( TQWIZARD_OBJECT_NAME_STRING ) ) {
   TQWizard *wiz = (TQWizard*)formWindow->mainContainer();
-  AddWizardPageCommand *cmd = new AddWizardPageCommand( i18n("Add Page to %1" ).arg( wiz->name() ), formWindow,
+  AddWizardPageCommand *cmd = new AddWizardPageCommand( i18n("Add Page to %1" ).tqarg( wiz->name() ), formWindow,
                     wiz, "Page" );
   formWindow->commandHistory()->addCommand( cmd );
   cmd->execute();
@@ -534,22 +534,22 @@ void HierarchyList::removeTabPage()
     TQWidget *w = current();
     if ( !w )
   return;
-    if ( w->inherits( "TQTabWidget" ) ) {
+    if ( w->inherits( TQTABWIDGET_OBJECT_NAME_STRING ) ) {
   TQTabWidget *tw = (TQTabWidget*)w;
   if ( tw->currentPage() ) {
       QDesignerTabWidget *dtw = (QDesignerTabWidget*)tw;
       DeleteTabPageCommand *cmd = new DeleteTabPageCommand( i18n("Delete Page %1 of %2" ).
-                  arg( dtw->pageTitle() ).arg( tw->name() ),
+                  tqarg( dtw->pageTitle() ).tqarg( tw->name() ),
                   formWindow, tw, tw->currentPage() );
       formWindow->commandHistory()->addCommand( cmd );
       cmd->execute();
   }
-    } else if ( w->inherits( "TQWizard" ) ) {
+    } else if ( w->inherits( TQWIZARD_OBJECT_NAME_STRING ) ) {
   TQWizard *wiz = (TQWizard*)formWindow->mainContainer();
   if ( wiz->currentPage() ) {
       QDesignerWizard *dw = (QDesignerWizard*)wiz;
       DeleteWizardPageCommand *cmd = new DeleteWizardPageCommand( i18n("Delete Page %1 of %2" ).
-                  arg( dw->pageTitle() ).arg( wiz->name() ),
+                  tqarg( dw->pageTitle() ).tqarg( wiz->name() ),
                   formWindow, wiz,
                   wiz->indexOf( wiz->currentPage() ), true );
       formWindow->commandHistory()->addCommand( cmd );
@@ -587,13 +587,13 @@ static HierarchyItem::Type getChildType( int type )
 void HierarchyList::insertEntry( TQListViewItem *i, const TQPixmap &pix, const TQString &s )
 {
     HierarchyItem *item = new HierarchyItem( getChildType( i->rtti() ), i, s,
-               TQString::null, TQString::null );
+               TQString(), TQString() );
     if ( !pix.isNull() )
   item->setPixmap( 0, pix );
     item->setRenameEnabled( 0, true );
     setCurrentItem( item );
     ensureItemVisible( item );
-    qApp->processEvents();
+    tqApp->processEvents();
     newItem = item;
     item->startRename( 0 );
 }
@@ -677,7 +677,7 @@ void HierarchyView::widgetsRemoved( const TQWidgetList & )
 void HierarchyView::namePropertyChanged( TQWidget *w, const TQVariant & )
 {
     TQWidget *w2 = w;
-    if ( w->inherits( "TQMainWindow" ) )
+    if ( w->inherits( TQMAINWINDOW_OBJECT_NAME_STRING ) )
   w2 = ( (TQMainWindow*)w )->centralWidget();
     listview->changeNameOf( w2, w->name() );
 }
@@ -685,7 +685,7 @@ void HierarchyView::namePropertyChanged( TQWidget *w, const TQVariant & )
 
 void HierarchyView::databasePropertyChanged( TQWidget *w, const TQStringList& info )
 {
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
     TQString i = info.join( "." );
     listview->changeDatabaseOf( w, i );
 #else
