@@ -1,5 +1,5 @@
 /**********************************************************************
- This file is based on Qt Designer, Copyright (C) 2000 Trolltech AS. All rights reserved.
+ This file is based on TQt Designer, Copyright (C) 2000 Trolltech AS. All rights reserved.
 
  This file may be distributed and/or modified under the terms of the
  GNU General Public License version 2 as published by the Free Software
@@ -34,7 +34,7 @@
 #include <tqwidgetlist.h>
 #include <tqmainwindow.h>
 #include <tqregexp.h>
-#include <private/qpluginmanager_p.h>
+#include <tqpluginmanager_p.h>
 #include <tqdatetime.h>
 #include <tqfile.h>
 #include <tqfileinfo.h>
@@ -147,14 +147,14 @@ void MetaDataBase::setPropertyChanged( TQObject *o, const TQString &property, bo
     if ( doUpdate &&
          ( property == "hAlign" || property == "vAlign" || property == "wordwrap" ) ) {
         doUpdate = false;
-        setPropertyChanged( o, "alignment", changed ||
+        setPropertyChanged( o, "tqalignment", changed ||
                             isPropertyChanged( o, "hAlign" ) ||
                             isPropertyChanged( o, "vAlign" ) ||
                             isPropertyChanged( o, "wordwrap" ) );
         doUpdate = true;
     }
 
-    if ( doUpdate && property == "alignment" ) {
+    if ( doUpdate && property == "tqalignment" ) {
         doUpdate = false;
         setPropertyChanged( o, "hAlign", changed );
         setPropertyChanged( o, "vAlign", changed );
@@ -210,7 +210,7 @@ TQString MetaDataBase::propertyComment( TQObject *o, const TQString &property )
     if ( !r ) {
         qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
                   o, o->name(), o->className() );
-        return TQString::null;
+        return TQString();
     }
 
     return *r->propertyComments.find( property );
@@ -269,10 +269,10 @@ void MetaDataBase::setSpacing( TQObject *o, int spacing )
     }
 
     r->spacing = spacing;
-    TQLayout * layout = 0;
-    WidgetFactory::layoutType( (TQWidget*)o, layout );
-    if ( layout )
-        layout->setSpacing( spacing );
+    TQLayout * tqlayout = 0;
+    WidgetFactory::layoutType( (TQWidget*)o, tqlayout );
+    if ( tqlayout )
+        tqlayout->setSpacing( spacing );
 }
 
 int MetaDataBase::spacing( TQObject *o )
@@ -280,9 +280,9 @@ int MetaDataBase::spacing( TQObject *o )
     if ( !o )
         return -1;
     setupDataBase();
-    if ( o->inherits( "TQMainWindow" ) )
-        o = ( (TQMainWindow*)o )->centralWidget();
-    MetaDataBaseRecord *r = db->find( (void*)o );
+    if ( o->inherits( TQMAINWINDOW_OBJECT_NAME_STRING ) )
+        o = TQT_TQOBJECT(( (TQMainWindow*)o )->centralWidget());
+    MetaDataBaseRecord *r = db->find( TQT_TQOBJECT(o) );
     if ( !r || !o->isWidgetType() ) {
         qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
                   o, o->name(), o->className() );
@@ -305,12 +305,12 @@ void MetaDataBase::setMargin( TQObject *o, int margin )
     }
 
     r->margin = margin;
-    TQLayout * layout = 0;
-    WidgetFactory::layoutType( (TQWidget*)o, layout );
+    TQLayout * tqlayout = 0;
+    WidgetFactory::layoutType( (TQWidget*)o, tqlayout );
     if ( margin < 1 )
         margin = 1;
-    if ( layout )
-        layout->setMargin( margin );
+    if ( tqlayout )
+        tqlayout->setMargin( margin );
 }
 
 int MetaDataBase::margin( TQObject *o )
@@ -318,8 +318,8 @@ int MetaDataBase::margin( TQObject *o )
     if ( !o )
         return -1;
     setupDataBase();
-    if ( o->inherits( "TQMainWindow" ) )
-        o = ( (TQMainWindow*)o )->centralWidget();
+    if ( o->inherits( TQMAINWINDOW_OBJECT_NAME_STRING ) )
+        o = TQT_TQOBJECT(( (TQMainWindow*)o )->centralWidget());
     MetaDataBaseRecord *r = db->find( (void*)o );
     if ( !r || !o->isWidgetType() ) {
         qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
@@ -465,12 +465,12 @@ void MetaDataBase::doConnections( TQObject *o )
             delete l;
         }
         TQString s = "2""%1";
-        s = s.arg( conn.signal );
+        s = s.tqarg( conn.signal.data() );
         TQString s2 = "1""%1";
-        s2 = s2.arg( conn.slot );
+        s2 = s2.tqarg( conn.slot.data() );
 
-        TQStrList signalList = sender->metaObject()->signalNames( true );
-        TQStrList slotList = receiver->metaObject()->slotNames( true );
+        TQStrList signalList = sender->tqmetaObject()->signalNames( true );
+        TQStrList slotList = receiver->tqmetaObject()->slotNames( true );
 
         // avoid warnings
         if ( signalList.find( conn.signal ) == -1 ||
@@ -647,13 +647,13 @@ bool MetaDataBase::hasSlot( TQObject *o, const TQCString &slot, bool onlyCustom
     }
 
     if ( !onlyCustom ) {
-        TQStrList slotList = o->metaObject()->slotNames( true );
+        TQStrList slotList = o->tqmetaObject()->slotNames( true );
         if ( slotList.find( slot ) != -1 )
             return true;
 
         if ( o->inherits( "FormWindow" ) ) {
-            o = ( (FormWindow*)o )->mainContainer();
-            slotList = o->metaObject()->slotNames( true );
+            o = TQT_TQOBJECT(( (FormWindow*)o )->mainContainer());
+            slotList = o->tqmetaObject()->slotNames( true );
             if ( slotList.find( slot ) != -1 )
                 return true;
         }
@@ -686,7 +686,7 @@ TQString MetaDataBase::languageOfSlot( TQObject *o, const TQCString &slot )
     if ( !r ) {
         qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
                   o, o->name(), o->className() );
-        return TQString::null;
+        return TQString();
     }
 
     TQString sl = slot;
@@ -698,7 +698,7 @@ TQString MetaDataBase::languageOfSlot( TQObject *o, const TQCString &slot )
         if ( sl == sl2 )
             return s.language;
     }
-    return TQString::null;
+    return TQString();
 }
 
 bool MetaDataBase::addCustomWidget( CustomWidget *wid )
@@ -934,7 +934,7 @@ MetaDataBase::CustomWidget::CustomWidget()
     className = "MyCustomWidget";
     includeFile = "mywidget.h";
     includePolicy = Local;
-    sizeHint = TQSize( -1, -1 );
+    tqsizeHint = TQSize( -1, -1 );
     pixmap = new TQPixmap( PixmapChooser::loadPixmap( "customwidget.xpm" ) );
     id = -1;
     sizePolicy = TQSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Preferred );
@@ -946,7 +946,7 @@ MetaDataBase::CustomWidget::CustomWidget( const CustomWidget &w )
     className = w.className;
     includeFile = w.includeFile;
     includePolicy = w.includePolicy;
-    sizeHint = w.sizeHint;
+    tqsizeHint = w.tqsizeHint;
     if ( w.pixmap )
         pixmap = new TQPixmap( *w.pixmap );
     else
@@ -991,7 +991,7 @@ MetaDataBase::CustomWidget &MetaDataBase::CustomWidget::operator=( const CustomW
     className = w.className;
     includeFile = w.includeFile;
     includePolicy = w.includePolicy;
-    sizeHint = w.sizeHint;
+    tqsizeHint = w.tqsizeHint;
     if ( w.pixmap )
         pixmap = new TQPixmap( *w.pixmap );
     else
@@ -1006,7 +1006,7 @@ MetaDataBase::CustomWidget &MetaDataBase::CustomWidget::operator=( const CustomW
 
 bool MetaDataBase::CustomWidget::hasSignal( const TQCString &signal ) const
 {
-    TQStrList sigList = TQWidget::staticMetaObject()->signalNames( true );
+    TQStrList sigList = TQWidget::tqstaticMetaObject()->signalNames( true );
     if ( sigList.find( signal ) != -1 )
         return true;
     for ( TQValueList<TQCString>::ConstIterator it = lstSignals.begin(); it != lstSignals.end(); ++it ) {
@@ -1018,7 +1018,7 @@ bool MetaDataBase::CustomWidget::hasSignal( const TQCString &signal ) const
 
 bool MetaDataBase::CustomWidget::hasSlot( const TQCString &slot ) const
 {
-    TQStrList slotList = TQWidget::staticMetaObject()->slotNames( true );
+    TQStrList slotList = TQWidget::tqstaticMetaObject()->slotNames( true );
     if ( slotList.find( normalizeSlot( slot ) ) != -1 )
         return true;
 
@@ -1031,7 +1031,7 @@ bool MetaDataBase::CustomWidget::hasSlot( const TQCString &slot ) const
 
 bool MetaDataBase::CustomWidget::hasProperty( const TQCString &prop ) const
 {
-    TQStrList propList = TQWidget::staticMetaObject()->propertyNames( true );
+    TQStrList propList = TQWidget::tqstaticMetaObject()->propertyNames( true );
     if ( propList.find( prop ) != -1 )
         return true;
 
@@ -1061,13 +1061,13 @@ void MetaDataBase::setPixmapArgument( TQObject *o, int pixmap, const TQString &a
 TQString MetaDataBase::pixmapArgument( TQObject *o, int pixmap )
 {
     if ( !o )
-        return TQString::null;
+        return TQString();
     setupDataBase();
     MetaDataBaseRecord *r = db->find( (void*)o );
     if ( !r ) {
         qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
                   o, o->name(), o->className() );
-        return TQString::null;
+        return TQString();
     }
 
     return *r->pixmapArguments.find( pixmap );
@@ -1108,13 +1108,13 @@ void MetaDataBase::setPixmapKey( TQObject *o, int pixmap, const TQString &arg )
 TQString MetaDataBase::pixmapKey( TQObject *o, int pixmap )
 {
     if ( !o )
-        return TQString::null;
+        return TQString();
     setupDataBase();
     MetaDataBaseRecord *r = db->find( (void*)o );
     if ( !r ) {
         qWarning( "No entry for %p (%s, %s) found in MetaDataBase",
                   o, o->name(), o->className() );
-        return TQString::null;
+        return TQString();
     }
 
     return *r->pixmapKeys.find( pixmap );
