@@ -1,7 +1,7 @@
 /**********************************************************************
 ** Copyright (C) 2000-2001 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
@@ -50,8 +50,8 @@
 #if defined(DESIGNER)
 #include "pics/images.h"
 
-#ifdef Q_WS_MACX
-//logo is 40x40 on the mac, if it changes - please notify the Qt/Mac team
+#ifdef TQ_WS_MACX
+//logo is 40x40 on the mac, if it changes - please notify the TQt/Mac team
 static const char * const logo_xpm[] = {
 "40 40 543 2",
 "  	c None",
@@ -886,12 +886,12 @@ void PixmapView::setPixmap( const TQPixmap &pix )
 {
     pixmap = pix;
     resizeContents( pixmap.size().width(), pixmap.size().height() );
-    viewport()->repaint( false );
+    viewport()->tqrepaint( false );
 }
 
 void PixmapView::drawContents( TQPainter *p, int cx, int cy, int cw, int ch )
 {
-    p->fillRect( cx, cy, cw, ch, colorGroup().brush( TQColorGroup::Base ) );
+    p->fillRect( cx, cy, cw, ch, tqcolorGroup().brush( TQColorGroup::Base ) );
     p->drawPixmap( 0, 0, pixmap );
 }
 
@@ -913,24 +913,24 @@ TQStringList qChoosePixmaps( TQWidget *parent )
 	TQFileDialog::setIconProvider( ( imageIconProvider = new ImageIconProvider ) );
 
     TQString filter;
-    TQString all = qApp->translate( "qChoosePixmap", "All Pixmaps (" );
+    TQString all = tqApp->translate( "qChoosePixmap", "All Pixmaps (" );
     for ( uint i = 0; i < TQImageIO::outputFormats().count(); i++ ) {
-	filter += qApp->translate( "qChoosePixmap", "%1-Pixmaps (%2)\n" ).
+	filter += tqApp->translate( "qChoosePixmap", "%1-Pixmaps (%2)\n" ).
 		  arg( TQImageIO::outputFormats().at( i ) ).
 		  arg( "*." + TQString( TQImageIO::outputFormats().at( i ) ).lower() );
 	all += "*." + TQString( TQImageIO::outputFormats().at( i ) ).lower() + ";";
     }
-    filter.prepend( all + qApp->translate( "qChoosePixmap", ")\n" ) );
-    filter += qApp->translate( "qChoosePixmap", "All Files (*)" );
+    filter.prepend( all + tqApp->translate( "qChoosePixmap", ")\n" ) );
+    filter += tqApp->translate( "qChoosePixmap", "All Files (*)" );
 
-    TQFileDialog fd( TQString::null, filter, parent, 0, true );
+    TQFileDialog fd( TQString(), filter, parent, 0, true );
     fd.setMode( TQFileDialog::ExistingFiles );
     fd.setContentsPreviewEnabled( true );
     PixmapView *pw = new PixmapView( &fd );
     fd.setContentsPreview( pw, pw );
     fd.setViewMode( TQFileDialog::List );
     fd.setPreviewMode( TQFileDialog::Contents );
-    fd.setCaption( qApp->translate( "qChoosePixmap", "Choose Images" ) );
+    fd.setCaption( tqApp->translate( "qChoosePixmap", "Choose Images" ) );
     if ( fd.exec() == TQDialog::Accepted )
 	return fd.selectedFiles();
     return TQStringList();
@@ -955,7 +955,7 @@ TQPixmap qChoosePixmap( TQWidget *parent, FormWindow *fw, const TQPixmap &old, T
 	filter.prepend( all + ")\n" );
 	filter += i18n( "All Files (*)" );
 
-	TQFileDialog fd( TQString::null, filter, parent, 0, true );
+	TQFileDialog fd( TQString(), filter, parent, 0, true );
 	fd.setContentsPreviewEnabled( true );
 	PixmapView *pw = new PixmapView( &fd );
 	fd.setContentsPreview( pw, pw );
@@ -966,7 +966,7 @@ TQPixmap qChoosePixmap( TQWidget *parent, FormWindow *fw, const TQPixmap &old, T
 	    TQPixmap pix( fd.selectedFile() );
 	    if ( fn )
 		*fn = fd.selectedFile();
-	    MetaDataBase::setPixmapArgument( fw, pix.serialNumber(), fd.selectedFile() );
+	    MetaDataBase::setPixmapArgument( TQT_TQOBJECT(fw), pix.serialNumber(), fd.selectedFile() );
 	    return pix;
 	}
     }
@@ -987,11 +987,11 @@ TQPixmap qChoosePixmap( TQWidget *parent, FormWindow *fw, const TQPixmap &old, T
 	PixmapFunction dia( parent, 0, true );
 	TQObject::connect( dia.helpButton, TQT_SIGNAL( clicked() ), MainWindow::self, TQT_SLOT( showDialogHelp() ) );
 	dia.labelFunction->setText( fw->pixmapLoaderFunction() + "(" );
-	dia.editArguments->setText( MetaDataBase::pixmapArgument( fw, old.serialNumber() ) );
+	dia.editArguments->setText( MetaDataBase::pixmapArgument( TQT_TQOBJECT(fw), old.serialNumber() ) );
 	dia.editArguments->setFocus();
 	if ( dia.exec() == TQDialog::Accepted ) {
 	    TQPixmap pix( PixmapChooser::loadPixmap( "image.xpm" ) );
-	    MetaDataBase::setPixmapArgument( fw, pix.serialNumber(), dia.editArguments->text() );
+	    MetaDataBase::setPixmapArgument( TQT_TQOBJECT(fw), pix.serialNumber(), dia.editArguments->text() );
 	    return pix;
 	}
     }
@@ -1004,7 +1004,7 @@ TQPixmap qChoosePixmap( TQWidget *parent, FormWindow *fw, const TQPixmap &old, T
 }
 
 ImageIconProvider::ImageIconProvider( TQWidget *parent, const char *name )
-    : TQFileIconProvider( parent, name ), imagepm( PixmapChooser::loadPixmap( "image.xpm", PixmapChooser::Mini ) )
+    : TQFileIconProvider( TQT_TQOBJECT(parent), name ), imagepm( PixmapChooser::loadPixmap( "image.xpm", PixmapChooser::Mini ) )
 {
     fmts = TQImage::inputFormats();
 }
