@@ -1,7 +1,7 @@
 /**********************************************************************
 ** Copyright (C) 2000-2001 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
@@ -180,7 +180,7 @@ void WorkspaceItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
 {
     TQColorGroup g( cg );
     g.setColor( TQColorGroup::Base, backgroundColor() );
-    g.setColor( TQColorGroup::Foreground, Qt::black );
+    g.setColor( TQColorGroup::Foreground, TQt::black );
 
 #ifndef KOMMANDER
     if ( type() == FormSourceType && !formFile->hasFormCode() ) {
@@ -188,7 +188,7 @@ void WorkspaceItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
   g.setColor( TQColorGroup::HighlightedText, listView()->palette().disabled().color( TQColorGroup::Text) );
     } else {
 #endif
-  g.setColor( TQColorGroup::Text, Qt::black );
+  g.setColor( TQColorGroup::Text, TQt::black );
 #ifndef KOMMANDER
     }
 #endif
@@ -236,7 +236,7 @@ TQString WorkspaceItem::text( int column ) const
 #endif
     }
 
-    return TQString::null; // shut up compiler
+    return TQString(); // shut up compiler
 }
 
 void WorkspaceItem::fillCompletionList( TQStringList& completion )
@@ -485,9 +485,9 @@ void Workspace::update( FormFile* ff )
 {
     TQListViewItem* i = findItem( ff );
     if ( i ) {
-  i->repaint();
+  i->tqrepaint();
   if ( (i = i->firstChild()) )
-      i->repaint();
+      i->tqrepaint();
     }
 }
 
@@ -583,7 +583,7 @@ void Workspace::itemDoubleClicked( TQListViewItem *i )
 
 void Workspace::itemClicked( int button, TQListViewItem *i, const TQPoint& )
 {
-    if ( !i || button != LeftButton )
+    if ( !i || button != Qt::LeftButton )
   return;
 
     closeAutoOpenItems();
@@ -699,7 +699,7 @@ void Workspace::rmbClicked( TQListViewItem *i, const TQPoint& pos )
   break;
 #endif
     case OPEN_SOURCE:
-  itemClicked( LeftButton, i, pos );
+  itemClicked( Qt::LeftButton, i, pos );
   break;
 #ifndef KOMMANDER
     case REMOVE_FORM: // FIXME
@@ -707,10 +707,10 @@ void Workspace::rmbClicked( TQListViewItem *i, const TQPoint& pos )
   break;
 #endif
     case OPEN_FORM:
-  itemClicked( LeftButton, i, pos );
+  itemClicked( Qt::LeftButton, i, pos );
   break;
     case OPEN_FORM_SOURCE:
-  itemClicked( LeftButton, i, pos );
+  itemClicked( Qt::LeftButton, i, pos );
   break;
     default:
   break;
@@ -720,7 +720,7 @@ void Workspace::rmbClicked( TQListViewItem *i, const TQPoint& pos )
 bool Workspace::eventFilter( TQObject *o, TQEvent * e )
 {
     // Reggie, on what type of events do we have to execute updateBufferEdit()
-    if ( o ==bufferEdit && e->type() != TQEvent::ChildRemoved )
+    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(bufferEdit) && e->type() != TQEvent::ChildRemoved )
   updateBufferEdit();
     return TQListView::eventFilter( o, e );
 }
@@ -764,7 +764,7 @@ void Workspace::bufferChosen( const TQString &buffer )
     TQListViewItemIterator it( this );
     while ( it.current() ) {
   if ( ( (WorkspaceItem*)it.current())->checkCompletion( buffer ) ) {
-      itemClicked( LeftButton, it.current(), TQPoint() );
+      itemClicked( Qt::LeftButton, it.current(), TQPoint() );
       break;
   }
   ++it;
