@@ -75,7 +75,7 @@ void Instance::addCmdlineArguments(const TQStringList& args)
   }
   int i = 0;
   for (TQStringList::ConstIterator it = stdArgs.begin(); it != stdArgs.end(); ++it)
-    m_textInstance->setGlobal(TQString("_ARG%1").arg(++i), *it);
+    m_textInstance->setGlobal(TQString("_ARG%1").tqarg(++i), *it);
   m_textInstance->setGlobal("_ARGS", stdArgs.join(" "));
   m_textInstance->setGlobal("_ARGCOUNT", TQString::number(stdArgs.count()));
 }
@@ -97,7 +97,7 @@ bool Instance::build(const KURL& fname)
   if (!fname.isValid() || !isFileValid(fname))
     return false; // Check if file is correct
 
-  // create the main instance, must inherit QDialog
+  // create the main instance, must inherit TQDialog
   KommanderFactory::loadPlugins();
 
   if (fname.isValid())
@@ -106,7 +106,7 @@ bool Instance::build(const KURL& fname)
   {
     TQFile inputFile;
     inputFile.open(IO_ReadOnly, stdin);
-    m_instance = KommanderFactory::create(&inputFile);
+    m_instance = KommanderFactory::create(TQT_TQIODEVICE(&inputFile));
   }
 
   // check if build was successful
@@ -121,7 +121,7 @@ bool Instance::build(const KURL& fname)
     window->setFileName(fname.path().local8Bit());
 
   // FIXME : Should verify that all of the widgets in the dialog derive from KommanderWidget
-  m_textInstance = kommanderWidget(m_instance);
+  m_textInstance = kommanderWidget(TQT_TQOBJECT(m_instance));
 
   if (!m_textInstance)  // Main dialog/window is not a Kommander widget - look for one
   {
@@ -158,9 +158,9 @@ bool Instance::run()
     return false;
 
   // Handle both dialogs and main windows
-  if (m_instance->inherits("TQDialog"))
+  if (m_instance->inherits(TQDIALOG_OBJECT_NAME_STRING))
     dynamic_cast<TQDialog*>((TQWidget*)m_instance)->exec();
-  else if (m_instance->inherits("TQMainWindow"))
+  else if (m_instance->inherits(TQMAINWINDOW_OBJECT_NAME_STRING))
   {
     kapp->setMainWidget(m_instance);
     dynamic_cast<TQMainWindow*>((TQWidget*)m_instance)->show();
@@ -185,7 +185,7 @@ bool Instance::isFileValid(const KURL& fname) const
   if (!TQFileInfo(fname.path()).exists())
   {
     KMessageBox::sorry(0, i18n("<qt>Kommander file<br><b>%1</b><br>does not "
-      "exist.</qt>").arg(fname.path()));
+      "exist.</qt>").tqarg(fname.path()));
     return false;
   }
 
@@ -220,7 +220,7 @@ bool Instance::isFileValid(const KURL& fname) const
   }
   if (!TQFileInfo(fname.path()).isExecutable())
   {
-     if (KMessageBox::warningContinueCancel(0, i18n("<qt>The Kommander file <i>%1</i> does not have the <b>executable attribute</b> set and could possibly contain dangerous exploits.<p>If you trust the scripting (viewable in kmdr-editor) in this program, make it executable to get rid of this warning.<p>Are you sure you want to continue?</qt>").arg(fname.pathOrURL()), TQString(), i18n("Run Nevertheless")) == KMessageBox::Cancel)
+     if (KMessageBox::warningContinueCancel(0, i18n("<qt>The Kommander file <i>%1</i> does not have the <b>executable attribute</b> set and could possibly contain dangerous exploits.<p>If you trust the scripting (viewable in kmdr-editor) in this program, make it executable to get rid of this warning.<p>Are you sure you want to continue?</qt>").tqarg(fname.pathOrURL()), TQString(), i18n("Run Nevertheless")) == KMessageBox::Cancel)
        return false;
   }
   return true;
@@ -234,14 +234,14 @@ bool Instance::isFileValid(const KURL& fname) const
 void Instance::setEnabled(const TQString& widgetName, bool enable)
 {
   TQObject* child = stringToWidget(widgetName);
-  if (child && child->inherits("TQWidget"))
+  if (child && child->inherits(TQWIDGET_OBJECT_NAME_STRING))
     ((TQWidget*)child)->setEnabled(enable);
 }
 
 void Instance::setVisible(const TQString& widgetName, bool visible)
 {
   TQObject* child = stringToWidget(widgetName);
-  if (child && child->inherits("TQWidget"))
+  if (child && child->inherits(TQWIDGET_OBJECT_NAME_STRING))
     ((TQWidget*)child)->setShown(visible);
 }
 
@@ -250,7 +250,7 @@ void Instance::setText(const TQString& widgetName, const TQString& text)
   TQObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
     kommanderWidget(child)->handleDCOP(DCOP::setText, text);
-  else if (child && child->inherits("TQLabel"))
+  else if (child && child->inherits(TQLABEL_OBJECT_NAME_STRING))
   {
     TQLabel* label = (TQLabel*)child;
     if (label->pixmap())
@@ -269,7 +269,7 @@ TQString Instance::text(const TQString& widgetName)
   TQObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
     return kommanderWidget(child)->handleDCOP(DCOP::text);
-  else if (child && child->inherits("TQLabel"))
+  else if (child && child->inherits(TQLABEL_OBJECT_NAME_STRING))
     return ((TQLabel*)child)->text();
   return TQString();
 }
@@ -279,7 +279,7 @@ void Instance::setSelection(const TQString& widgetName, const TQString& text)
   TQObject* child = stringToWidget(widgetName);
   if (kommanderWidget(child))
     kommanderWidget(child)->handleDCOP(DCOP::setSelection, text);
-  else if (child && child->inherits("TQLabel"))
+  else if (child && child->inherits(TQLABEL_OBJECT_NAME_STRING))
     ((TQLabel*)child)->setText(text);
 }
 
@@ -426,21 +426,21 @@ TQStringList Instance::associatedText(const TQString &widgetName)
 TQString Instance::type(const TQString& widget)
 {
   TQObject* child = stringToWidget(widget);  
-  if (child && child->inherits("TQWidget"))
+  if (child && child->inherits(TQWIDGET_OBJECT_NAME_STRING))
     return child->className();
   return TQString();
 }
 
-TQStringList Instance::children(const TQString& parent, bool recursive)
+TQStringList Instance::tqchildren(const TQString& parent, bool recursive)
 {
   TQStringList matching;
   TQObject* child = stringToWidget(parent);
   TQObjectList* widgets;
   if (!child)
-     child = m_instance; 
-  if (child->inherits("TQWidget"))
+     child = TQT_TQOBJECT(m_instance);
+  if (child->inherits(TQWIDGET_OBJECT_NAME_STRING))
   {
-    widgets = child->queryList("TQWidget", 0, false, recursive);
+    widgets = child->queryList(TQWIDGET_OBJECT_NAME_STRING, 0, false, recursive);
     for (TQObject* w = widgets->first(); w; w = widgets->next())
       if (w->name() && kommanderWidget(w))
         matching.append(w->name());
@@ -674,9 +674,9 @@ int Instance::getWinID()
 void Instance::setBusyCursor(bool busy)
 {
   if (busy)
-    m_instance->setCursor(TQCursor(Qt::WaitCursor));
+    m_instance->setCursor(TQCursor(TQt::WaitCursor));
  else
-    m_instance->setCursor(TQCursor(Qt::ArrowCursor));
+    m_instance->setCursor(TQCursor(TQt::ArrowCursor));
 }
 
 
