@@ -1,7 +1,7 @@
 /**********************************************************************
 ** Copyright (C) 2000-2002 Trolltech AS.  All rights reserved.
 **
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
@@ -25,10 +25,13 @@
 #include "kommanderfactory.h"
 #include <kommanderplugin.h>
 
+#ifdef QT_NO_SQL
+#define TQT_NO_SQL
+#endif // QT_NO_SQL
 
 #include <tqfeatures.h>
 #include "config.h"
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 #include "database2.h"
 #endif
 #include <tqdom.h>
@@ -40,18 +43,18 @@
 #include <tqtooltip.h>
 #include <tqwhatsthis.h>
 #include <tqobjectlist.h>
-#include <private/qpluginmanager_p.h>
+#include <tqpluginmanager_p.h>
 #include <tqmime.h>
 #include <tqdragobject.h>
 #include <zlib.h>
 
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 #include <tqsqlrecord.h>
 #include <tqsqldatabase.h>
 #include <tqdatatable.h>
 #endif
 
-// include all Qt widgets we support
+// include all TQt widgets we support
 #include <tqpushbutton.h>
 #include <tqtoolbutton.h>
 #include <tqcheckbox.h>
@@ -60,7 +63,7 @@
 #include <tqbuttongroup.h>
 #include <tqiconview.h>
 #include <tqheader.h>
-#ifndef QT_NO_TABLE
+#ifndef TQT_NO_TABLE
 #include <tqtable.h>
 #endif
 #include <tqlistbox.h>
@@ -132,7 +135,7 @@ TQWidget *KommanderFactory::create( const TQString &uiFile, TQObject *connector,
     if (!qwf_currFileName)
       qwf_currFileName = new TQString();
     *qwf_currFileName = uiFile;
-    TQWidget *w = KommanderFactory::create( &f, connector, parent, name );
+    TQWidget *w = KommanderFactory::create( TQT_TQIODEVICE(&f), connector, parent, name );
     if ( !qwf_forms )
 	qwf_forms = new TQMap<TQWidget*, TQString>;
     qwf_forms->insert( w, uiFile );
@@ -214,7 +217,7 @@ TQWidget *KommanderFactory::create( TQIODevice *dev, TQObject *connector, TQWidg
     if ( !imageCollection.isNull() )
 	widgetFactory->loadImageCollection( imageCollection );
 
-    widgetFactory->createWidgetInternal( widget, parent, 0, widget.attribute("class", "TQWidget") );
+    widgetFactory->createWidgetInternal( widget, parent, 0, widget.attribute("class", TQWIDGET_OBJECT_NAME_STRING) );
     TQWidget *w = widgetFactory->toplevel;
     if ( !w ) {
 	delete widgetFactory;
@@ -243,7 +246,7 @@ TQWidget *KommanderFactory::create( TQIODevice *dev, TQObject *connector, TQWidg
 
     if ( !connections.isNull() )
 	widgetFactory->loadConnections( connections, connector );
-    if ( w && name && qstrlen( name ) > 0 )
+    if ( w && name && tqstrlen( name ) > 0 )
 	w->setName( name );
 
     if ( !tabOrder.isNull() )
@@ -251,7 +254,7 @@ TQWidget *KommanderFactory::create( TQIODevice *dev, TQObject *connector, TQWidg
 
 
     if ( widgetFactory->toplevel ) {
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 	TQMap<TQWidget*, SqlWidgetConnection>::Iterator cit = widgetFactory->sqlWidgetConnections.begin();
 	for( ; cit != widgetFactory->sqlWidgetConnections.end(); ++cit ) {
 	    if ( widgetFactory->noDatabaseWidgets.find( cit.key()->name() ) != widgetFactory->noDatabaseWidgets.end() )
@@ -263,7 +266,7 @@ TQWidget *KommanderFactory::create( TQIODevice *dev, TQObject *connector, TQWidg
 	}
 
 	for ( TQMap<TQString, TQStringList>::Iterator it = widgetFactory->dbTables.begin(); it != widgetFactory->dbTables.end(); ++it ) {
-	    TQDataTable *table = (TQDataTable*)widgetFactory->toplevel->child( it.key(), "TQDataTable" );
+	    TQDataTable *table = (TQDataTable*)widgetFactory->toplevel->child( it.key(), TQDATATABLE_OBJECT_NAME_STRING );
 	    if ( !table )
 		continue;
 	    if ( widgetFactory->noDatabaseWidgets.find( table->name() ) != widgetFactory->noDatabaseWidgets.end() )
@@ -289,8 +292,8 @@ TQWidget *KommanderFactory::create( TQIODevice *dev, TQObject *connector, TQWidg
     }
 
     for ( TQMap<TQString, TQString>::Iterator it = widgetFactory->buddies.begin(); it != widgetFactory->buddies.end(); ++it ) {
-	TQLabel *label = (TQLabel*)widgetFactory->toplevel->child( it.key(), "TQLabel" );
-	TQWidget *buddy = (TQWidget*)widgetFactory->toplevel->child( *it, "TQWidget" );
+	TQLabel *label = (TQLabel*)widgetFactory->toplevel->child( it.key(), TQLABEL_OBJECT_NAME_STRING );
+	TQWidget *buddy = (TQWidget*)widgetFactory->toplevel->child( *it, TQWIDGET_OBJECT_NAME_STRING );
 	if ( label && buddy )
 	    label->setBuddy( buddy );
     }
@@ -312,77 +315,77 @@ TQWidget *KommanderFactory::createWidget( const TQString &literalClassName, TQWi
   TQString className = literalClassName;
 
   // create widgets we know
-  if (className == "TQPushButton")
+  if (className == TQPUSHBUTTON_OBJECT_NAME_STRING)
     return new TQPushButton(parent, name);
-  else if (className == "TQToolButton")
+  else if (className == TQTOOLBUTTON_OBJECT_NAME_STRING)
     return new TQToolButton(parent, name);
-  else if (className == "TQCheckBox")
+  else if (className == TQCHECKBOX_OBJECT_NAME_STRING)
     return new TQCheckBox(parent, name);
-  else if (className == "TQRadioButton")
+  else if (className == TQRADIOBUTTON_OBJECT_NAME_STRING)
     return new TQRadioButton(parent, name);
-  else if (className == "TQGroupBox")
+  else if (className == TQGROUPBOX_OBJECT_NAME_STRING)
     return new TQGroupBox(parent, name);
-  else if (className == "TQButtonGroup")
+  else if (className == TQBUTTONGROUP_OBJECT_NAME_STRING)
     return new TQButtonGroup(parent, name);
-  else if (className == "TQIconView")
+  else if (className == TQICONVIEW_OBJECT_NAME_STRING)
   {
-#if !defined(QT_NO_ICONVIEW)
+#if !defined(TQT_NO_ICONVIEW)
     return new TQIconView(parent, name);
 #endif
   }
-  else if (className == "TQTable")
+  else if (className == TQTABLE_OBJECT_NAME_STRING)
   {
-#if !defined(QT_NO_TABLE)
+#if !defined(TQT_NO_TABLE)
     return new TQTable(parent, name);
 #endif
   }
-  else if (className == "TQListBox")
+  else if (className == TQLISTBOX_OBJECT_NAME_STRING)
     return new TQListBox(parent, name);
-  else if (className == "TQListView")
+  else if (className == TQLISTVIEW_OBJECT_NAME_STRING)
     return new TQListView(parent, name);
-  else if (className == "TQLineEdit")
+  else if (className == TQLINEEDIT_OBJECT_NAME_STRING)
     return new TQLineEdit(parent, name);
-  else if (className == "TQSpinBox")
+  else if (className == TQSPINBOX_OBJECT_NAME_STRING)
     return new TQSpinBox(parent, name);
-  else if (className == "TQMultiLineEdit")
+  else if (className == TQMULTILINEEDIT_OBJECT_NAME_STRING)
     return new TQMultiLineEdit(parent, name);
-  else if (className == "TQLabel")
+  else if (className == TQLABEL_OBJECT_NAME_STRING)
     return new TQLabel(parent, name);
-  else if (className == "QLayoutWidget")
+  else if (className == TQLAYOUTWIDGET_OBJECT_NAME_STRING)
     return new TQWidget(parent, name);
-  else if (className == "TQTabWidget")
+  else if (className == TQTABWIDGET_OBJECT_NAME_STRING)
     return new TQTabWidget(parent, name);
-  else if (className == "TQComboBox")
+  else if (className == TQCOMBOBOX_OBJECT_NAME_STRING)
     return new TQComboBox(false, parent, name);
-  else if (className == "TQWidget")
+  else if (className == TQWIDGET_OBJECT_NAME_STRING)
   {
     if (!qwf_stays_on_top)
       return new TQWidget(parent, name);
-    return new TQWidget(parent, name, Qt::WStyle_StaysOnTop);
+    return new TQWidget(parent, name, TQt::WStyle_StaysOnTop);
   }
-  else if (className == "TQDialog")
+  else if (className == TQDIALOG_OBJECT_NAME_STRING)
   {
     if (!qwf_stays_on_top)
       return new TQDialog(parent, name);
-    return new TQDialog(parent, name, false, Qt::WStyle_StaysOnTop);
+    return new TQDialog(parent, name, false, TQt::WStyle_StaysOnTop);
   }
-  else if (className == "TQWizard")
+  else if (className == TQWIZARD_OBJECT_NAME_STRING)
     return new TQWizard(parent, name);
-  else if (className == "TQLCDNumber")
+  else if (className == TQLCDNUMBER_OBJECT_NAME_STRING)
     return new TQLCDNumber(parent, name);
-  else if (className == "TQProgressBar")
+  else if (className == TQPROGRESSBAR_OBJECT_NAME_STRING)
     return new TQProgressBar(parent, name);
-  else if (className == "TQTextView")
+  else if (className == TQTEXTVIEW_OBJECT_NAME_STRING)
     return new TQTextView(parent, name);
-  else if (className == "TQTextBrowser")
+  else if (className == TQTEXTBROWSER_OBJECT_NAME_STRING)
     return new TQTextBrowser(parent, name);
-  else if (className == "TQDial")
+  else if (className == TQDIAL_OBJECT_NAME_STRING)
     return new TQDial(parent, name);
-  else if (className == "TQSlider")
+  else if (className == TQSLIDER_OBJECT_NAME_STRING)
     return new TQSlider(parent, name);
-  else if (className == "TQFrame")
+  else if (className == TQFRAME_OBJECT_NAME_STRING)
     return new TQFrame(parent, name);
-  else if (className == "TQSplitter")
+  else if (className == TQSPLITTER_OBJECT_NAME_STRING)
     return new TQSplitter(parent, name);
   else if (className == "Line")
   {
@@ -390,38 +393,38 @@ TQWidget *KommanderFactory::createWidget( const TQString &literalClassName, TQWi
     f->setFrameStyle(TQFrame::HLine | TQFrame::Sunken);
     return f;
   }
-  else if (className == "TQTextEdit")
+  else if (className == TQTEXTEDIT_OBJECT_NAME_STRING)
     return new TQTextEdit(parent, name);
-  else if (className == "QDateEdit")
-    return new QDateEdit(parent, name);
-  else if (className == "QTimeEdit")
-    return new QTimeEdit(parent, name);
-  else if (className == "QDateTimeEdit")
-    return new QDateTimeEdit(parent, name);
-  else if (className == "TQScrollBar")
+  else if (className == TQDATEEDIT_OBJECT_NAME_STRING)
+    return new TQDateEdit(parent, name);
+  else if (className == TQTIMEEDIT_OBJECT_NAME_STRING)
+    return new TQTimeEdit(parent, name);
+  else if (className == TQDATETIMEEDIT_OBJECT_NAME_STRING)
+    return new TQDateTimeEdit(parent, name);
+  else if (className == TQSCROLLBAR_OBJECT_NAME_STRING)
     return new TQScrollBar(parent, name);
-  else if (className == "TQPopupMenu")
+  else if (className == TQPOPUPMENU_OBJECT_NAME_STRING)
     return new TQPopupMenu(parent, name);
-  else if (className == "TQWidgetStack")
+  else if (className == TQWIDGETSTACK_OBJECT_NAME_STRING)
     return new TQWidgetStack(parent, name);
-  else if (className == "TQMainWindow")
+  else if (className == TQMAINWINDOW_OBJECT_NAME_STRING)
   {
     TQMainWindow *mw = 0;
     if (!qwf_stays_on_top)
       mw = new KmdrMainWindow(parent, name);
     else
-      mw = new KmdrMainWindow(parent, name, Qt::WType_TopLevel | Qt::WStyle_StaysOnTop);
+      mw = new KmdrMainWindow(parent, name, TQt::WType_TopLevel | TQt::WStyle_StaysOnTop);
     mw->setCentralWidget(new TQWidget(mw, "qt_central_widget"));
     mw->centralWidget()->show();
     (void) mw->statusBar();
     return mw;
   }
-#if !defined(QT_NO_SQL)
-  else if (className == "TQDataTable")
+#if !defined(TQT_NO_SQL)
+  else if (className == TQDATATABLE_OBJECT_NAME_STRING)
     return new TQDataTable(parent, name);
-  else if (className == "TQDataBrowser")
+  else if (className == TQDATABROWSER_OBJECT_NAME_STRING)
     return new QDesignerDataBrowser2(parent, name);
-  else if (className == "TQDataView")
+  else if (className == TQDATAVIEW_OBJECT_NAME_STRING)
     return new QDesignerDataView2(parent, name);
 #endif
 
@@ -494,7 +497,7 @@ FeatureList KommanderFactory::featureList()
     //iterate through widgetPlugins, appending KommanderPlugin::widgets() to features
 }
 
-TQWidget *KommanderFactory::createWidgetInternal( const TQDomElement &e, TQWidget *parent, TQLayout* layout, const TQString &classNameArg )
+TQWidget *KommanderFactory::createWidgetInternal( const TQDomElement &e, TQWidget *parent, TQLayout* tqlayout, const TQString &classNameArg )
 {
     lastItem = 0;
     TQDomElement n = e.firstChild().toElement();
@@ -512,13 +515,13 @@ TQWidget *KommanderFactory::createWidgetInternal( const TQDomElement &e, TQWidge
     if ( colspan < 1 )
 	colspan = 1;
     if ( !className.isEmpty() ) {
-	if ( !layout && className  == "QLayoutWidget" )
-	    className = "TQWidget";
-	if ( layout && className == "QLayoutWidget" ) {
-	    // hide layout widgets
+	if ( !tqlayout && className  == TQLAYOUTWIDGET_OBJECT_NAME_STRING )
+	    className = TQWIDGET_OBJECT_NAME_STRING;
+	if ( tqlayout && className == TQLAYOUTWIDGET_OBJECT_NAME_STRING ) {
+	    // hide tqlayout widgets
 	    w = parent;
 	} else {
-	    obj = KommanderFactory::createWidget( className, parent, 0 );
+	    obj = TQT_TQOBJECT(KommanderFactory::createWidget( className, parent, 0 ));
 	    if ( !obj )
 	    {
 		return 0;
@@ -526,18 +529,18 @@ TQWidget *KommanderFactory::createWidgetInternal( const TQDomElement &e, TQWidge
 	    w = (TQWidget*)obj;
 	    if ( !toplevel )
 		toplevel = w;
-	    if ( w->inherits( "TQMainWindow" ) )
+	    if ( w->inherits( TQMAINWINDOW_OBJECT_NAME_STRING ) )
 		w = ( (TQMainWindow*)w )->centralWidget();
-	    if ( layout ) {
-		switch( layoutType( layout ) ) {
+	    if ( tqlayout ) {
+		switch( layoutType( tqlayout ) ) {
 		case HBox:
-		    ( (TQHBoxLayout*)layout )->addWidget( w );
+		    ( (TQHBoxLayout*)tqlayout )->addWidget( w );
 		    break;
 		case VBox:
-		    ( (TQVBoxLayout*)layout )->addWidget( w );
+		    ( (TQVBoxLayout*)tqlayout )->addWidget( w );
 		    break;
 		case Grid:
-		    ( (TQGridLayout*)layout )->addMultiCellWidget( w, row, row + rowspan - 1,
+		    ( (TQGridLayout*)tqlayout )->addMultiCellWidget( w, row, row + rowspan - 1,
 								  col, col + colspan - 1 );
 		    break;
 		default:
@@ -545,7 +548,7 @@ TQWidget *KommanderFactory::createWidgetInternal( const TQDomElement &e, TQWidge
 		}
 	    }
 
-	    layout = 0;
+	    tqlayout = 0;
 	}
     }
     if (className == "Dialog")
@@ -553,57 +556,57 @@ TQWidget *KommanderFactory::createWidgetInternal( const TQDomElement &e, TQWidge
 
     while ( !n.isNull() ) {
 	if ( n.tagName() == "spacer" ) {
-	    createSpacer( n, layout );
+	    createSpacer( n, tqlayout );
 	} else if ( n.tagName() == "widget" ) {
 	    TQMap< TQString, TQString> *oldDbControls = dbControls;
-	    createWidgetInternal( n, w, layout, n.attribute( "class", "TQWidget" ) );
+	    createWidgetInternal( n, w, tqlayout, n.attribute( "class", TQWIDGET_OBJECT_NAME_STRING ) );
 	    dbControls = oldDbControls;
 	} else if ( n.tagName() == "hbox" ) {
-	    TQLayout *parentLayout = layout;
-	    if ( layout && layout->inherits( "TQGridLayout" ) )
-		layout = createLayout( 0, 0, KommanderFactory::HBox );
+	    TQLayout *parentLayout = tqlayout;
+	    if ( tqlayout && tqlayout->inherits( TQGRIDLAYOUT_OBJECT_NAME_STRING ) )
+		tqlayout = createLayout( 0, 0, KommanderFactory::HBox );
 	    else
-		layout = createLayout( w, layout, KommanderFactory::HBox );
-	    obj = layout;
+		tqlayout = createLayout( w, tqlayout, KommanderFactory::HBox );
+	    obj = TQT_TQOBJECT(tqlayout);
 	    n = n.firstChild().toElement();
-	    if ( parentLayout && parentLayout->inherits( "TQGridLayout" ) )
-		( (TQGridLayout*)parentLayout )->addMultiCellLayout( layout, row, row + rowspan - 1, col, col + colspan - 1 );
+	    if ( parentLayout && parentLayout->inherits( TQGRIDLAYOUT_OBJECT_NAME_STRING ) )
+		( (TQGridLayout*)parentLayout )->addMultiCellLayout( tqlayout, row, row + rowspan - 1, col, col + colspan - 1 );
 	    continue;
 	} else if ( n.tagName() == "grid" ) {
-	    TQLayout *parentLayout = layout;
-	    if ( layout && layout->inherits( "TQGridLayout" ) )
-		layout = createLayout( 0, 0, KommanderFactory::Grid );
+	    TQLayout *parentLayout = tqlayout;
+	    if ( tqlayout && tqlayout->inherits( TQGRIDLAYOUT_OBJECT_NAME_STRING ) )
+		tqlayout = createLayout( 0, 0, KommanderFactory::Grid );
 	    else
-		layout = createLayout( w, layout, KommanderFactory::Grid );
-	    obj = layout;
+		tqlayout = createLayout( w, tqlayout, KommanderFactory::Grid );
+	    obj = TQT_TQOBJECT(tqlayout);
 	    n = n.firstChild().toElement();
-	    if ( parentLayout && parentLayout->inherits( "TQGridLayout" ) )
-		( (TQGridLayout*)parentLayout )->addMultiCellLayout( layout, row, row + rowspan - 1, col, col + colspan - 1 );
+	    if ( parentLayout && parentLayout->inherits( TQGRIDLAYOUT_OBJECT_NAME_STRING ) )
+		( (TQGridLayout*)parentLayout )->addMultiCellLayout( tqlayout, row, row + rowspan - 1, col, col + colspan - 1 );
 	    continue;
 	} else if ( n.tagName() == "vbox" ) {
-	    TQLayout *parentLayout = layout;
-	    if ( layout && layout->inherits( "TQGridLayout" ) )
-		layout = createLayout( 0, 0, KommanderFactory::VBox );
+	    TQLayout *parentLayout = tqlayout;
+	    if ( tqlayout && tqlayout->inherits( TQGRIDLAYOUT_OBJECT_NAME_STRING ) )
+		tqlayout = createLayout( 0, 0, KommanderFactory::VBox );
 	    else
-		layout = createLayout( w, layout, KommanderFactory::VBox );
-	    obj = layout;
+		tqlayout = createLayout( w, tqlayout, KommanderFactory::VBox );
+	    obj = TQT_TQOBJECT(tqlayout);
 	    n = n.firstChild().toElement();
-	    if ( parentLayout && parentLayout->inherits( "TQGridLayout" ) )
-		( (TQGridLayout*)parentLayout )->addMultiCellLayout( layout, row, row + rowspan - 1, col, col + colspan - 1 );
+	    if ( parentLayout && parentLayout->inherits( TQGRIDLAYOUT_OBJECT_NAME_STRING ) )
+		( (TQGridLayout*)parentLayout )->addMultiCellLayout( tqlayout, row, row + rowspan - 1, col, col + colspan - 1 );
 	    continue;
 	} else if ( n.tagName() == "property" && obj ) {
 	    setProperty( obj, n.attribute( "name" ), n.firstChild().toElement() );
 	} else if ( n.tagName() == "attribute" && w ) {
 	    TQString attrib = n.attribute( "name" );
 	    TQVariant v = DomTool::elementToVariant( n.firstChild().toElement(), TQVariant() );
-	    if ( parent->inherits( "TQTabWidget" ) ) {
+	    if ( parent->inherits( TQTABWIDGET_OBJECT_NAME_STRING ) ) {
 		if ( attrib == "title" )
 		    ( (TQTabWidget*)parent )->insertTab( w, translate(v.toString()) );
 	    } else
-        if ( parent->inherits( "TQToolBox" ) ) {
+        if ( parent->inherits( TQTOOLBOX_OBJECT_NAME_STRING ) ) {
         if ( attrib == "label" )
             ( (TQToolBox*)parent )->addItem( w, translate(v.toString()) );
-        }else if ( parent->inherits( "TQWizard" ) ) {
+        }else if ( parent->inherits( TQWIZARD_OBJECT_NAME_STRING ) ) {
 		if ( attrib == "title" )
 		    ( (TQWizard*)parent )->addPage( w, translate(v.toString()) );
 	    }
@@ -619,60 +622,60 @@ TQWidget *KommanderFactory::createWidgetInternal( const TQDomElement &e, TQWidge
     return w;
 }
 
-TQLayout *KommanderFactory::createLayout( TQWidget *widget, TQLayout*  layout, LayoutType type )
+TQLayout *KommanderFactory::createLayout( TQWidget *widget, TQLayout*  tqlayout, LayoutType type )
 {
     int spacing = defSpacing;
     int margin = defMargin;
 
-    if ( !layout && widget && widget->inherits( "TQTabWidget" ) )
+    if ( !tqlayout && widget && widget->inherits( TQTABWIDGET_OBJECT_NAME_STRING ) )
 	widget = ((TQTabWidget*)widget)->currentPage();
-    if ( !layout && widget && widget->inherits( "TQToolBox" ) )
+    if ( !tqlayout && widget && widget->inherits( TQTOOLBOX_OBJECT_NAME_STRING ) )
     widget = ((TQToolBox*)widget)->currentItem();
 
-    if ( !layout && widget && widget->inherits( "TQWizard" ) )
+    if ( !tqlayout && widget && widget->inherits( TQWIZARD_OBJECT_NAME_STRING ) )
 	widget = ((TQWizard*)widget)->currentPage();
 
-    if ( !layout && widget && widget->inherits( "TQWidgetStack" ) )
+    if ( !tqlayout && widget && widget->inherits( TQWIDGETSTACK_OBJECT_NAME_STRING ) )
 	widget = ((TQWidgetStack*)widget)->visibleWidget();
 
-    if ( !layout && widget && widget->inherits( "TQGroupBox" ) ) {
+    if ( !tqlayout && widget && widget->inherits( TQGROUPBOX_OBJECT_NAME_STRING ) ) {
 	TQGroupBox *gb = (TQGroupBox*)widget;
 	gb->setColumnLayout( 0, Qt::Vertical );
-	gb->layout()->setMargin( 0 );
-	gb->layout()->setSpacing( 0 );
+	gb->tqlayout()->setMargin( 0 );
+	gb->tqlayout()->setSpacing( 0 );
 	TQLayout *l;
 	switch ( type ) {
 	case HBox:
-	    l = new TQHBoxLayout( gb->layout() );
-	    l->setAlignment( Qt::AlignTop );
+	    l = new TQHBoxLayout( gb->tqlayout() );
+	    l->tqsetAlignment( TQt::AlignTop );
 	    return l;
 	case VBox:
-	    l = new TQVBoxLayout( gb->layout(), spacing );
-	    l->setAlignment( Qt::AlignTop );
+	    l = new TQVBoxLayout( gb->tqlayout(), spacing );
+	    l->tqsetAlignment( TQt::AlignTop );
 	    return l;
 	case Grid:
-	    l = new TQGridLayout( gb->layout() );
-	    l->setAlignment( Qt::AlignTop );
+	    l = new TQGridLayout( gb->tqlayout() );
+	    l->tqsetAlignment( TQt::AlignTop );
 	    return l;
 	default:
 	    return 0;
 	}
     } else {
-	if ( layout ) {
+	if ( tqlayout ) {
 	    TQLayout *l;
 	    switch ( type ) {
 	    case HBox:
-		l = new TQHBoxLayout( layout );
+		l = new TQHBoxLayout( tqlayout );
 		l->setSpacing( spacing );
 		l->setMargin( margin );
 		return l;
 	    case VBox:
-		l = new TQVBoxLayout( layout );
+		l = new TQVBoxLayout( tqlayout );
 		l->setSpacing( spacing );
 		l->setMargin( margin );
 		return l;
 	    case Grid: {
-		l = new TQGridLayout( layout );
+		l = new TQGridLayout( tqlayout );
 		l->setSpacing( spacing );
 		l->setMargin( margin );
 		return l;
@@ -712,24 +715,24 @@ TQLayout *KommanderFactory::createLayout( TQWidget *widget, TQLayout*  layout, L
     }
 }
 
-KommanderFactory::LayoutType KommanderFactory::layoutType( TQLayout *layout ) const
+KommanderFactory::LayoutType KommanderFactory::layoutType( TQLayout *tqlayout ) const
 {
-    if ( layout->inherits( "TQHBoxLayout" ) )
+    if ( tqlayout->inherits( TQHBOXLAYOUT_OBJECT_NAME_STRING ) )
 	return HBox;
-    else if ( layout->inherits( "TQVBoxLayout" ) )
+    else if ( tqlayout->inherits( TQVBOXLAYOUT_OBJECT_NAME_STRING ) )
 	return VBox;
-    else if ( layout->inherits( "TQGridLayout" ) )
+    else if ( tqlayout->inherits( TQGRIDLAYOUT_OBJECT_NAME_STRING ) )
 	return Grid;
     return NoLayout;
 }
 
 void KommanderFactory::setProperty( TQObject* obj, const TQString &prop, const TQDomElement &e )
 {
-    const TQMetaProperty *p = obj->metaObject()->property( obj->metaObject()->findProperty( prop, true ), true );
+    const TQMetaProperty *p = obj->tqmetaObject()->property( obj->tqmetaObject()->findProperty( prop, true ), true );
 
     TQVariant defVariant;
     if ( e.tagName() == "font" ) {
-	TQFont f( qApp->font() );
+	TQFont f( tqApp->font() );
 	if ( obj->isWidgetType() && ( (TQWidget*)obj )->parentWidget() )
 	    f = ( (TQWidget*)obj )->parentWidget()->font();
 	defVariant = TQVariant( f );
@@ -763,9 +766,9 @@ void KommanderFactory::setProperty( TQObject* obj, const TQString &prop, const T
 		if ( !v.toString().isEmpty() )
 		    TQWhatsThis::add( (TQWidget*)obj, translate(v.toString()) );
 	    }
-#ifndef QT_NO_SQL
-	    if ( prop == "database" && !obj->inherits( "TQDataView" )
-		 && !obj->inherits( "TQDataBrowser" ) ) {
+#ifndef TQT_NO_SQL
+	    if ( prop == "database" && !obj->inherits( TQDATAVIEW_OBJECT_NAME_STRING )
+		 && !obj->inherits( TQDATABROWSER_OBJECT_NAME_STRING ) ) {
 		TQStringList lst = DomTool::elementToVariant( e, TQVariant( TQStringList() ) ).toStringList();
 		if ( lst.count() > 2 ) {
 		    if ( dbControls )
@@ -775,7 +778,7 @@ void KommanderFactory::setProperty( TQObject* obj, const TQString &prop, const T
 		}
 	    } else if ( prop == "database" ) {
 		TQStringList lst = DomTool::elementToVariant( e, TQVariant( TQStringList() ) ).toStringList();
-		if ( lst.count() == 2 && obj->inherits( "TQWidget" ) ) {
+		if ( lst.count() == 2 && obj->inherits( TQWIDGET_OBJECT_NAME_STRING ) ) {
 		    SqlWidgetConnection conn( lst[ 0 ], lst[ 1 ] );
 		    sqlWidgetConnections.insert( (TQWidget*)obj, conn );
 		    dbControls = conn.dbControls;
@@ -789,7 +792,7 @@ void KommanderFactory::setProperty( TQObject* obj, const TQString &prop, const T
 		    noDatabaseWidgets << obj->name();
 		}
 	    } else if ( prop == "buttonGroupId" ) {
-		if ( obj->inherits( "TQButton" ) && obj->parent()->inherits( "TQButtonGroup" ) )
+		if ( obj->inherits( TQBUTTON_OBJECT_NAME_STRING ) && obj->parent()->inherits( TQBUTTONGROUP_OBJECT_NAME_STRING ) )
 		    ( (TQButtonGroup*)obj->parent() )->insert( (TQButton*)obj, v.toInt() );
 	    }
 
@@ -828,7 +831,7 @@ void KommanderFactory::setProperty( TQObject* obj, const TQString &prop, const T
     }
 
     if ( prop == "geometry" ) {
-	if ( obj == toplevel ) {
+	if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(toplevel) ) {
 	    toplevel->resize( v.toRect().size() );
 	    return;
 	}
@@ -837,7 +840,7 @@ void KommanderFactory::setProperty( TQObject* obj, const TQString &prop, const T
     obj->setProperty( prop, v );
 }
 
-void KommanderFactory::createSpacer( const TQDomElement &e, TQLayout *layout )
+void KommanderFactory::createSpacer( const TQDomElement &e, TQLayout *tqlayout )
 {
     TQDomElement n = e.firstChild().toElement();
     int row = e.attribute( "row" ).toInt();
@@ -869,7 +872,7 @@ void KommanderFactory::createSpacer( const TQDomElement &e, TQLayout *layout )
 		    sizeType = TQSizePolicy::MinimumExpanding;
 		else if ( n.firstChild().firstChild().toText().data() == "Expanding" )
 		    sizeType = TQSizePolicy::Expanding;
-	    } else if ( prop == "sizeHint" ) {
+	    } else if ( prop == "tqsizeHint" ) {
 		w = n.firstChild().firstChild().firstChild().toText().data().toInt();
 		h = n.firstChild().firstChild().nextSibling().firstChild().toText().data().toInt();
 	    }
@@ -883,12 +886,12 @@ void KommanderFactory::createSpacer( const TQDomElement &e, TQLayout *layout )
 	colspan = 1;
     TQSpacerItem *item = new TQSpacerItem( w, h, orient == Qt::Horizontal ? sizeType : TQSizePolicy::Minimum,
 					 orient == Qt::Vertical ? sizeType : TQSizePolicy::Minimum );
-    if ( layout ) {
-	if ( layout->inherits( "TQBoxLayout" ) )
-	    ( (TQBoxLayout*)layout )->addItem( item );
+    if ( tqlayout ) {
+	if ( tqlayout->inherits( TQBOXLAYOUT_OBJECT_NAME_STRING ) )
+	    ( (TQBoxLayout*)tqlayout )->addItem( item );
 	else
-	    ( (TQGridLayout*)layout )->addMultiCell( item, row, row + rowspan - 1, col, col + colspan - 1,
-						    orient == Qt::Horizontal ? Qt::AlignVCenter : Qt::AlignHCenter );
+	    ( (TQGridLayout*)tqlayout )->addMultiCell( item, row, row + rowspan - 1, col, col + colspan - 1,
+						    orient == Qt::Horizontal ? TQt::AlignVCenter : TQt::AlignHCenter );
     }
 }
 
@@ -1004,7 +1007,7 @@ struct Connection
     }
 };
 
-class NormalizeObject : public QObject
+class NormalizeObject : public TQObject
 {
 public:
     NormalizeObject() : TQObject() {}
@@ -1023,7 +1026,7 @@ void KommanderFactory::loadConnections( const TQDomElement &e, TQObject *connect
 		if ( n2.tagName() == "sender" ) {
 		    TQString name = n2.firstChild().toText().data();
 		    if ( name == "this" || qstrcmp( toplevel->name(), name ) == 0 ) {
-			conn.sender = toplevel;
+			conn.sender = TQT_TQOBJECT(toplevel);
 		    } else {
 			if ( name == "this" )
 			    name = toplevel->name();
@@ -1041,7 +1044,7 @@ void KommanderFactory::loadConnections( const TQDomElement &e, TQObject *connect
 		} else if ( n2.tagName() == "receiver" ) {
 		    TQString name = n2.firstChild().toText().data();
 		    if ( name == "this" || qstrcmp( toplevel->name(), name ) == 0 ) {
-			conn.receiver = toplevel;
+			conn.receiver = TQT_TQOBJECT(toplevel);
 		    } else {
 			TQObjectList *l = toplevel->queryList( 0, name, false );
 			if ( l ) {
@@ -1062,7 +1065,7 @@ void KommanderFactory::loadConnections( const TQDomElement &e, TQObject *connect
 	    TQObject *sender = 0, *receiver = 0;
 	    TQObjectList *l = toplevel->queryList( 0, conn.sender->name(), false );
 	    if ( qstrcmp( conn.sender->name(), toplevel->name() ) == 0 ) {
-		sender = toplevel;
+		sender = TQT_TQOBJECT(toplevel);
 	    } else {
 		if ( !l || !l->first() ) {
 		    delete l;
@@ -1076,7 +1079,7 @@ void KommanderFactory::loadConnections( const TQDomElement &e, TQObject *connect
 		sender = findAction( conn.sender->name() );
 
 	    if ( qstrcmp( conn.receiver->name(), toplevel->name() ) == 0 ) {
-		receiver = toplevel;
+		receiver = TQT_TQOBJECT(toplevel);
 	    } else {
 		l = toplevel->queryList( 0, conn.receiver->name(), false );
 		if ( !l || !l->first() ) {
@@ -1090,16 +1093,16 @@ void KommanderFactory::loadConnections( const TQDomElement &e, TQObject *connect
 
 	    if ( lang == "C++" ) {
 		TQString s = "2""%1";
-		s = s.arg( conn.signal );
+		s = s.tqarg( conn.signal.data() );
 		TQString s2 = "1""%1";
-		s2 = s2.arg( conn.slot );
+		s2 = s2.tqarg( conn.slot.data() );
 
-		TQStrList signalList = sender->metaObject()->signalNames( true );
-		TQStrList slotList = receiver->metaObject()->slotNames( true );
+		TQStrList signalList = sender->tqmetaObject()->signalNames( true );
+		TQStrList slotList = receiver->tqmetaObject()->slotNames( true );
 
 		// if this is a connection to a custom slot and we have a connector, try this as receiver
-		if ( slotList.find( conn.slot ) == -1 && receiver == toplevel && connector ) {
-		    slotList = connector->metaObject()->slotNames( true );
+		if ( slotList.find( conn.slot ) == -1 && TQT_BASE_OBJECT(receiver) == TQT_BASE_OBJECT(toplevel) && connector ) {
+		    slotList = connector->tqmetaObject()->slotNames( true );
 		    receiver = connector;
 		}
 
@@ -1148,7 +1151,7 @@ void KommanderFactory::loadTabOrder( const TQDomElement &e )
 
 void KommanderFactory::createColumn( const TQDomElement &e, TQWidget *widget )
 {
-    if ( widget->inherits( "TQListView" ) && e.tagName() == "column" ) {
+    if ( widget->inherits( TQLISTVIEW_OBJECT_NAME_STRING ) && e.tagName() == "column" ) {
 	TQListView *lv = (TQListView*)widget;
 	TQDomElement n = e.firstChild().toElement();
 	TQPixmap pix;
@@ -1181,17 +1184,17 @@ void KommanderFactory::createColumn( const TQDomElement &e, TQWidget *widget )
 	if ( !resizeable )
 	    lv->header()->setResizeEnabled( resizeable, i );
     }
-#ifndef QT_NO_TABLE
-    else if ( widget->inherits( "TQTable" ) ) {
+#ifndef TQT_NO_TABLE
+    else if ( widget->inherits( TQTABLE_OBJECT_NAME_STRING ) ) {
 	TQTable *table = (TQTable*)widget;
-#ifndef QT_NO_SQL
-	bool isSql = (widget->inherits( "TQDataTable" ));
+#ifndef TQT_NO_SQL
+	bool isSql = (widget->inherits( TQDATATABLE_OBJECT_NAME_STRING ));
 #endif
 	bool isRow;
 	if ( ( isRow = e.tagName() == "row" ) )
 	    table->setNumRows( table->numRows() + 1 );
 	else {
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 	    if ( !isSql )
 #endif
 		table->setNumCols( table->numCols() + 1 );
@@ -1226,14 +1229,14 @@ void KommanderFactory::createColumn( const TQDomElement &e, TQWidget *widget )
 	int i = isRow ? table->numRows() - 1 : table->numCols() - 1;
 	TQHeader *h = !isRow ? table->horizontalHeader() : table->verticalHeader();
 	if ( hasPixmap ) {
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 	    if ( isSql )
 		((TQDataTable*)table)->addColumn( field, txt, -1, pix );
 	    else
 #endif
 		h->setLabel( i, pix, txt );
 	} else {
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
 	    if ( isSql ) {
 		((TQDataTable*)table)->addColumn( field, txt );
 	    }
@@ -1270,14 +1273,14 @@ void KommanderFactory::loadItem( const TQDomElement &e, TQPixmap &pix, TQString
 
 void KommanderFactory::createItem( const TQDomElement &e, TQWidget *widget, TQListViewItem *i )
 {
-    if ( widget->inherits( "TQListBox" ) || widget->inherits( "TQComboBox" ) ) {
+    if ( widget->inherits( TQLISTBOX_OBJECT_NAME_STRING ) || widget->inherits( TQCOMBOBOX_OBJECT_NAME_STRING ) ) {
 	TQDomElement n = e.firstChild().toElement();
 	TQPixmap pix;
 	bool hasPixmap = false;
 	TQString txt;
 	loadItem( n, pix, txt, hasPixmap );
 	TQListBox *lb = 0;
-	if ( widget->inherits( "TQListBox" ) )
+	if ( widget->inherits( TQLISTBOX_OBJECT_NAME_STRING ) )
 	    lb = (TQListBox*)widget;
 	else
 	    lb = ( (TQComboBox*)widget)->listBox();
@@ -1286,8 +1289,8 @@ void KommanderFactory::createItem( const TQDomElement &e, TQWidget *widget, TQLi
 	} else {
 	    new TQListBoxText( lb, txt );
 	}
-#ifndef QT_NO_ICONVIEW
-    } else if ( widget->inherits( "TQIconView" ) ) {
+#ifndef TQT_NO_ICONVIEW
+    } else if ( widget->inherits( TQICONVIEW_OBJECT_NAME_STRING ) ) {
 	TQDomElement n = e.firstChild().toElement();
 	TQPixmap pix;
 	bool hasPixmap = false;
@@ -1297,7 +1300,7 @@ void KommanderFactory::createItem( const TQDomElement &e, TQWidget *widget, TQLi
 	TQIconView *iv = (TQIconView*)widget;
 	new TQIconViewItem( iv, txt, pix );
 #endif
-    } else if ( widget->inherits( "TQListView" ) ) {
+    } else if ( widget->inherits( TQLISTVIEW_OBJECT_NAME_STRING ) ) {
 	TQDomElement n = e.firstChild().toElement();
 	TQPixmap pix;
 	TQValueList<TQPixmap> pixmaps;
@@ -1358,7 +1361,7 @@ void KommanderFactory::loadChildAction( TQObject *parent, const TQDomElement &e
 	    }
 	    n2 = n2.nextSibling().toElement();
 	}
-	if ( !parent->inherits( "TQAction" ) )
+	if ( !parent->inherits( TQACTION_OBJECT_NAME_STRING ) )
 	    actionList.append( a );
     } else if ( n.tagName() == "actiongroup" ) {
 	a = new TQActionGroup( parent );
@@ -1375,7 +1378,7 @@ void KommanderFactory::loadChildAction( TQObject *parent, const TQDomElement &e
 	    }
 	    n2 = n2.nextSibling().toElement();
 	}
-	if ( !parent->inherits( "TQAction" ) )
+	if ( !parent->inherits( TQACTION_OBJECT_NAME_STRING ) )
 	    actionList.append( a );
     }
     if ( a )
@@ -1387,9 +1390,9 @@ void KommanderFactory::loadActions( const TQDomElement &e )
     TQDomElement n = e.firstChild().toElement();
     while ( !n.isNull() ) {
 	if ( n.tagName() == "action" ) {
-	    loadChildAction( toplevel, n );
+	    loadChildAction( TQT_TQOBJECT(toplevel), n );
 	} else if ( n.tagName() == "actiongroup" ) {
-	    loadChildAction( toplevel, n );
+	    loadChildAction( TQT_TQOBJECT(toplevel), n );
 	}
 	n = n.nextSibling().toElement();
     }
@@ -1402,8 +1405,8 @@ void KommanderFactory::loadToolBars( const TQDomElement &e )
     TQToolBar *tb = 0;
     while ( !n.isNull() ) {
 	if ( n.tagName() == "toolbar" ) {
-	    Qt::Dock dock = (Qt::Dock)n.attribute( "dock" ).toInt();
-	    tb = new TQToolBar( TQString::null, mw, dock );
+	    TQt::Dock dock = (TQt::Dock)n.attribute( "dock" ).toInt();
+	    tb = new TQToolBar( TQString(), mw, dock );
 	    tb->setLabel( n.attribute( "label" ) );
 	    tb->setName( n.attribute( "name" ) );
 	    TQDomElement n2 = n.firstChild().toElement();
@@ -1415,9 +1418,9 @@ void KommanderFactory::loadToolBars( const TQDomElement &e )
 		} else if ( n2.tagName() == "separator" ) {
 		    tb->addSeparator();
 		} else if ( n2.tagName() == "widget" ) {
-		    (void)createWidgetInternal( n2, tb, 0, n2.attribute( "class", "TQWidget" ) );
+		    (void)createWidgetInternal( n2, tb, 0, n2.attribute( "class", TQWIDGET_OBJECT_NAME_STRING ) );
 		} else if ( n2.tagName() == "property" ) {
-		    setProperty( tb, n2.attribute( "name" ), n2.firstChild().toElement() );
+		    setProperty( TQT_TQOBJECT(tb), n2.attribute( "name" ), n2.firstChild().toElement() );
 		}
 		n2 = n2.nextSibling().toElement();
 	    }
@@ -1448,7 +1451,7 @@ void KommanderFactory::loadMenuBar( const TQDomElement &e )
 	    }
 	    mb->insertItem( translate( n.attribute( "text" ) ), popup );
 	} else if ( n.tagName() == "property" ) {
-	    setProperty( mb, n.attribute( "name" ), n.firstChild().toElement() );
+	    setProperty( TQT_TQOBJECT(mb), n.attribute( "name" ), n.firstChild().toElement() );
 	}
 	n = n.nextSibling().toElement();
     }
@@ -1460,7 +1463,7 @@ TQAction *KommanderFactory::findAction( const TQString &name )
     for ( TQAction *a = actionList.first(); a; a = actionList.next() ) {
 	if ( TQString( a->name() ) == name )
 	    return a;
-	TQAction *ac = (TQAction*)a->child( name.latin1(), "TQAction" );
+	TQAction *ac = (TQAction*)a->child( name.latin1(), TQACTION_OBJECT_NAME_STRING );
 	if ( ac )
 	    return ac;
     }
