@@ -71,15 +71,15 @@ TQString SpecialFunction::prototype(uint prototypeFlags) const
   TQStringList params;
   for (uint i=start; i<m_types.count(); i++)
     if (prototypeFlags & ShowArgumentNames)
-      params.append(TQString("%1 %2").arg(m_types[i]).arg(m_args[i]));
+      params.append(TQString("%1 %2").tqarg(m_types[i]).tqarg(m_args[i]));
     else
       params.append(m_types[i]);
   if (!params.count())
     return m_function;
   else if (prototypeFlags & NoSpaces)
-    return TQString("%1(%2)").arg(m_function).arg(params.join(","));
+    return TQString("%1(%2)").tqarg(m_function).tqarg(params.join(","));
   else
-    return TQString("%1(%2)").arg(m_function).arg(params.join(", "));
+    return TQString("%1(%2)").tqarg(m_function).tqarg(params.join(", "));
 }
 
 TQString SpecialFunction::argumentName(uint i) const
@@ -291,7 +291,7 @@ void SpecialInformation::registerSpecials()
          i18n("Returns text of a cell in a table."), 3);
   insert(DCOP::checked, "checked(TQString widget)",
          i18n("Returns 1 for checked boxes, 0 for unchecked."), 1);
-  insert(DCOP::children, "children(TQString widget, bool recursive)",
+  insert(DCOP::tqchildren, "tqchildren(TQString widget, bool recursive)",
          i18n("Returns the list of child widgets contained in the parent widget. Set the <i>recursive</i> parameter to <i>true</i> to include widgets contained by child widgets."), 2);
   insert(DCOP::clear, "clear(TQString widget)",
          i18n("Removes all content from the widget."), 1);
@@ -375,8 +375,8 @@ void SpecialInformation::registerSpecials()
      i18n("Returns type(class) of widget."), 1);
   insert(DCOP::setEditable, "setEditable(TQString widget, bool editable)", 
      i18n("Makes the widget editable or read only, depending on the editable argument."), 2);
-  insertInternal(DCOP::geometry, "geometry(TQString widget)", 
-     i18n("Return the widget's geometry as <i>x y w h</i>. This is useful for positioning a created widget."), 1);
+  insertInternal(DCOP::tqgeometry, "tqgeometry(TQString widget)", 
+     i18n("Return the widget's tqgeometry as <i>x y w h</i>. This is useful for positioning a created widget."), 1);
   insertInternal(DCOP::hasFocus, "hasFocus(TQString widget)", 
      i18n("Returns true if the widget has focus."), 1);
   insertInternal(DCOP::getBackgroundColor, "getBackgroundColor(TQString widget)", 
