@@ -129,11 +129,11 @@ static ParseNode f_stringSection(Parser*, const ParameterList& params)
 static ParseNode f_stringArgs(Parser*, const ParameterList& params)
 {
   if (params.count() == 2)
-    return params[0].toString().arg(params[1].toString());
+    return params[0].toString().tqarg(params[1].toString());
   else if (params.count() == 3)
-    return params[0].toString().arg(params[1].toString()).arg(params[2].toString());
+    return params[0].toString().tqarg(params[1].toString()).tqarg(params[2].toString());
   else 
-    return params[0].toString().arg(params[1].toString()).arg(params[2].toString()).arg(params[3].toString());
+    return params[0].toString().tqarg(params[1].toString()).tqarg(params[2].toString()).tqarg(params[3].toString());
 }
 
 static ParseNode f_stringIsNumber(Parser*, const ParameterList& params)    
@@ -250,7 +250,7 @@ static ParseNode f_executeSlot(Parser* parser, const ParameterList& params)
   TQObject *object = widget->object();
   if (!object)
     return ParseNode::error("unknown widget");
-  TQStrList slotSignatures = object->metaObject()->slotNames(true);
+  TQStrList slotSignatures = object->tqmetaObject()->slotNames(true);
   TQStringList slotNames = TQStringList::fromStrList(slotSignatures);
   int slotNum = -1;
   uint i = 0;
@@ -353,7 +353,7 @@ static ParseNode f_dcop(Parser*, const ParameterList& params)
       byteDataStream << params[i++].toDouble();
     else if (*it == "bool")
       byteDataStream << (bool)params[i++].toInt();
-    else if (*it == "TQStringList")
+    else if (*it == TQSTRINGLIST_OBJECT_NAME_STRING)
       if (params[i].toString().find('\n') != -1)
         byteDataStream << TQStringList::split("\n", params[i++].toString(), true);
       else
@@ -361,7 +361,7 @@ static ParseNode f_dcop(Parser*, const ParameterList& params)
     else 
       byteDataStream << params[i++].toString();
   }
-  function.append(TQString("(%1)").arg(items.join(",")));
+  function.append(TQString("(%1)").tqarg(items.join(",")));
   TQCString replyType, byteReply;
   DCOPClient* cl = KApplication::dcopClient();
   if (!cl || !cl->call(appId, object, function.latin1(),
@@ -371,7 +371,7 @@ static ParseNode f_dcop(Parser*, const ParameterList& params)
     return ParseNode();
   }
   TQDataStream byteReplyStream(byteReply, IO_ReadOnly);
-  if (replyType == "TQString")
+  if (replyType == TQSTRING_OBJECT_NAME_STRING)
   {
     TQString text;
     byteReplyStream >> text;
@@ -389,7 +389,7 @@ static ParseNode f_dcop(Parser*, const ParameterList& params)
     byteReplyStream >> b;
     return b;
   }
-  else if (replyType == "TQStringList")
+  else if (replyType == TQSTRINGLIST_OBJECT_NAME_STRING)
   {
     TQStringList text;
     byteReplyStream >> text;
@@ -397,7 +397,7 @@ static ParseNode f_dcop(Parser*, const ParameterList& params)
   }
   else if(replyType != "void")
   {
-     qDebug("%s", TQString("DCOP return type %1 is not yet implemented.").arg(replyType.data()).latin1());
+     qDebug("%s", TQString("DCOP return type %1 is not yet implemented.").tqarg(replyType.data()).latin1());
   }
 
   return ParseNode();
@@ -429,9 +429,9 @@ static ParseNode f_widgetExists(Parser* p, const ParameterList& params)
 static ParseNode f_connect(Parser* p, const ParameterList& params)
 {
   TQString sender = params[0].toString();
-  TQString signal = TQString::number(QSIGNAL_CODE) + params[1].toString();
+  TQString signal = TQString::number(TQSIGNAL_CODE) + params[1].toString();
   TQString receiver = params[2].toString();
-  TQString slot = TQString::number(QSLOT_CODE) + params[3].toString();
+  TQString slot = TQString::number(TQSLOT_CODE) + params[3].toString();
   KommanderWidget *senderW = p->currentWidget()->widgetByName(sender);
   if (!senderW)
     return ParseNode::error("unknown widget");
@@ -445,9 +445,9 @@ static ParseNode f_connect(Parser* p, const ParameterList& params)
 static ParseNode f_disconnect(Parser* p, const ParameterList& params)
 {
   TQString sender = params[0].toString();
-  TQString signal = TQString::number(QSIGNAL_CODE) + params[1].toString();
+  TQString signal = TQString::number(TQSIGNAL_CODE) + params[1].toString();
   TQString receiver = params[2].toString();
-  TQString slot = TQString::number(QSLOT_CODE) + params[3].toString();
+  TQString slot = TQString::number(TQSLOT_CODE) + params[3].toString();
   KommanderWidget *senderW = p->currentWidget()->widgetByName(sender);
   if (!senderW)
     return ParseNode::error("unknown widget");
@@ -499,7 +499,7 @@ static ParseNode f_dialog(Parser* P, const ParameterList& params)
       return TQString();
   }
   TQString cmd = TQString("kmdr-executor %1 %2 _PARENTPID=%3 _PARENTDCOPID=kmdr-executor-%4")
-    .arg(pFileName).arg(a_params).arg(getpid()).arg(getpid());
+    .tqarg(pFileName).tqarg(a_params).tqarg(getpid()).tqarg(getpid());
 
   MyProcess proc(P->currentWidget());
   TQString text;
@@ -571,7 +571,7 @@ static ParseNode f_arrayToString(Parser* P, const ParameterList& params)
   TQValueList<ParseNode>::Iterator itval = values.begin();
   while (*it)
   {
-    array += TQString("%1\t%2\n").arg(*it).arg((*itval).toString());
+    array += TQString("%1\t%2\n").tqarg(*it).tqarg((*itval).toString());
     ++it;
     ++itval;
   }
@@ -704,7 +704,7 @@ static ParseNode f_inputColor(Parser*, const ParameterList& params)
   if (params.count())
     color.setNamedColor(params[0].toString());
   KColorDialog::getColor(color);
-  return color.name();
+  return TQString(color.name());
 }
 
 static ParseNode f_inputText(Parser*, const ParameterList& params)
@@ -721,7 +721,7 @@ static ParseNode f_inputPassword(Parser*, const ParameterList& params)
   if (params.count() > 1)
     value = params[1].toString().local8Bit();
   KPasswordDialog::getPassword(value, params[0].toString());
-  return TQString::fromLocal8Bit(value);
+  return TQString(TQString::fromLocal8Bit(value));
 }
 
 static ParseNode f_inputValue(Parser*, const ParameterList& params)
