@@ -131,7 +131,7 @@ TQString KommanderWidget::evalAssociatedText(const TQString& a_text)
     p.setWidget(this);
     p.setString(a_text);
     if (!p.setString(a_text) || !p.parse())
-      printError(i18n("Line %1: %2.\n").arg(p.errorLine()+1).arg(p.errorMessage()));
+      printError(i18n("Line %1: %2.\n").tqarg(p.errorLine()+1).tqarg(p.errorMessage()));
     return TQString();
   }
   /* Old macro-only parser is implemented below  */
@@ -241,7 +241,7 @@ TQString KommanderWidget::evalAssociatedText(const TQString& a_text)
     }
     else
     {
-      printError(i18n("Unknown special: \'%1\'.").arg(identifier));
+      printError(i18n("Unknown special: \'%1\'.").tqarg(identifier));
       return TQString();
     }
   }
@@ -271,13 +271,13 @@ TQString KommanderWidget::DCOPQuery(const TQStringList& a_query)
   }
   if (!ok)
   {
-    printError(i18n("Unmatched parenthesis in DCOP call \'%1\'.").arg(a_query[2]));
+    printError(i18n("Unmatched parenthesis in DCOP call \'%1\'.").tqarg(a_query[2]));
     return TQString();
   }
   const TQStringList argTypes = parseArgs(pTypes, ok);
   if (!ok || argTypes.count() != a_query.count() - 3)
   {
-    printError(i18n("Incorrect arguments in DCOP call \'%1\'.").arg(a_query[2]));
+    printError(i18n("Incorrect arguments in DCOP call \'%1\'.").tqarg(a_query[2]));
     return TQString();
   }
 
@@ -295,7 +295,7 @@ TQString KommanderWidget::DCOPQuery(const TQStringList& a_query)
       byteDataStream << a_query[i+3].toDouble();
     else if (argTypes[i] == "bool")
       byteDataStream << (bool)(a_query[i+3] != "false" && a_query[i+3] != "false" && a_query[i+3] != "0");
-    else if (argTypes[i] == "TQStringList")
+    else if (argTypes[i] == TQSTRINGLIST_OBJECT_NAME_STRING)
       if (a_query[i+3].find('\n') != -1)
         byteDataStream << TQStringList::split("\n", a_query[i+3], true);
       else
@@ -312,7 +312,7 @@ TQString KommanderWidget::DCOPQuery(const TQStringList& a_query)
   }
 
   TQDataStream byteReplyStream(byteReply, IO_ReadOnly);
-  if (replyType == "TQString")
+  if (replyType == TQSTRING_OBJECT_NAME_STRING)
   {
     TQString text;
     byteReplyStream >> text;
@@ -330,7 +330,7 @@ TQString KommanderWidget::DCOPQuery(const TQStringList& a_query)
     byteReplyStream >> b;
     return TQString::number(b);
   }
-  else if (replyType == "TQStringList")
+  else if (replyType == TQSTRINGLIST_OBJECT_NAME_STRING)
   {
     TQStringList text;
     byteReplyStream >> text;
@@ -338,7 +338,7 @@ TQString KommanderWidget::DCOPQuery(const TQStringList& a_query)
   }
   else if(replyType != "void")
   {
-    printError(i18n("DCOP return type %1 is not yet implemented.").arg(replyType.data()));
+    printError(i18n("DCOP return type %1 is not yet implemented.").tqarg(replyType.data()));
   }
 
   return TQString();
@@ -392,7 +392,7 @@ TQString KommanderWidget::runDialog(const TQString& a_dialog, const TQString& a_
       return TQString();
   }
   TQString cmd = TQString("kmdr-executor %1 %2 _PARENTPID=%3 _PARENTDCOPID=kmdr-executor-%4")
-    .arg(pFileName).arg(a_params).arg(getpid()).arg(getpid());
+    .tqarg(pFileName).tqarg(a_params).tqarg(getpid()).tqarg(getpid());
   return execCommand(cmd);
 }
 
@@ -405,26 +405,26 @@ void KommanderWidget::printError(const TQString& a_error) const
                 KDialogBase::Yes, KDialogBase::No, 0, 0, true, false, 
                 i18n("Continue"), i18n("Continue && Ignore Next Errors"), i18n("Stop"));
     switch (KMessageBox::createKMessageBox(dialog, TQMessageBox::Warning, 
-                i18n("<qt>Error in widget <b>%1</b>:<p><i>%2</i></qt>").arg(TQString(m_thisObject->name()))
-                    .arg(a_error), TQStringList(), TQString(), 0, 0))
+                i18n("<qt>Error in widget <b>%1</b>:<p><i>%2</i></qt>").tqarg(TQString(m_thisObject->name()))
+                    .tqarg(a_error), TQStringList(), TQString(), 0, 0))
     {
       case KDialogBase::No:
         showErrors = false;
       case KDialogBase::Yes:
         break;
       case KDialogBase::Cancel:
-        if (parentDialog()->inherits("TQDialog"))
+        if (parentDialog()->inherits(TQDIALOG_OBJECT_NAME_STRING))
         {
           parentDialog()->close();
           exit(-1);
         }
-        else if (parentDialog()->inherits("TQMainWindow"))
+        else if (parentDialog()->inherits(TQMAINWINDOW_OBJECT_NAME_STRING))
           kapp->quit();
     }
   }
   else 
   {
-    kdError() << i18n("Error in widget %1:\n  %2\n").arg(m_thisObject->name()).arg(a_error);
+    kdError() << i18n("Error in widget %1:\n  %2\n").tqarg(m_thisObject->name()).tqarg(a_error);
   }
 }
 
@@ -579,7 +579,7 @@ TQStringList KommanderWidget::parseFunction(const TQString& group, const TQStrin
   TQString arg = parseBrackets(s, from, ok);
   if (!ok)
   {
-    printError(i18n("Unmatched parenthesis after \'%1\'.").arg(function));
+    printError(i18n("Unmatched parenthesis after \'%1\'.").tqarg(function));
     return TQString();
   }
   const TQStringList args = parseArgs(arg, ok);
@@ -588,23 +588,23 @@ TQStringList KommanderWidget::parseFunction(const TQString& group, const TQStrin
   bool extraArg = gname == Group::DCOP;
 
   if (!ok)
-    printError(i18n("Unmatched quotes in argument of \'%1\'.").arg(function));
+    printError(i18n("Unmatched quotes in argument of \'%1\'.").tqarg(function));
   else if (gname == -1)
-    printError(i18n("Unknown function group: \'%1\'.").arg(group));
+    printError(i18n("Unknown function group: \'%1\'.").tqarg(group));
   else if (fname == -1 && !extraArg)
-    printError(i18n("Unknown function: \'%1\' in group '%2'.").arg(function).arg(group));
+    printError(i18n("Unknown function: \'%1\' in group '%2'.").tqarg(function).tqarg(group));
   else if (fname == -1 && extraArg)
-    printError(i18n("Unknown widget function: \'%1\'.").arg(function));
+    printError(i18n("Unknown widget function: \'%1\'.").tqarg(function));
   else if ((int)args.count() + extraArg < SpecialInformation::minArg(gname, fname))
     printError(i18n("Not enough arguments for \'%1\' (%2 instead of %3).<p>"
        "Correct syntax is: %4")
-        .arg(function).arg(args.count() + extraArg).arg(SpecialInformation::minArg(gname, fname))
-        .arg(SpecialInformation::prototype(gname, fname, SpecialFunction::ShowArgumentNames)));
+        .tqarg(function).tqarg(args.count() + extraArg).tqarg(SpecialInformation::minArg(gname, fname))
+        .tqarg(SpecialInformation::prototype(gname, fname, SpecialFunction::ShowArgumentNames)));
   else if ((int)args.count() + extraArg > SpecialInformation::maxArg(gname, fname))
     printError(i18n("Too many arguments for \'%1\' (%2 instead of %3).<p>"
        "Correct syntax is: %4")
-      .arg(function).arg(args.count() + extraArg).arg(SpecialInformation::maxArg(gname, fname))
-      .arg(SpecialInformation::prototype(gname, fname, SpecialFunction::ShowArgumentNames)));
+      .tqarg(function).tqarg(args.count() + extraArg).tqarg(SpecialInformation::maxArg(gname, fname))
+      .tqarg(SpecialInformation::prototype(gname, fname, SpecialFunction::ShowArgumentNames)));
   else 
     success = true;
   ok = success;
@@ -627,7 +627,7 @@ int KommanderWidget::parseBlockBoundary(const TQString& s, int from, const TQStr
 
 TQString KommanderWidget::substituteVariable(TQString text, TQString variable, TQString value) const
 {
-  TQString var = TQString("@%1").arg(variable);
+  TQString var = TQString("@%1").tqarg(variable);
   TQString newtext;
   int newpos, pos = 0;
   while (true)
@@ -655,7 +655,7 @@ TQWidget* KommanderWidget::parentDialog() const
   while (superParent->parent())
   {
     superParent = superParent->parent();
-    if (superParent->inherits("TQDialog") || superParent->inherits("TQMainWindow"))
+    if (superParent->inherits(TQDIALOG_OBJECT_NAME_STRING) || superParent->inherits(TQMAINWINDOW_OBJECT_NAME_STRING))
       break;
   }
   return (TQWidget*)superParent;
@@ -692,10 +692,10 @@ TQString KommanderWidget::handleDCOP(const int function, const TQStringList& arg
       break;
     case DCOP::type:
       return current->className();
-    case DCOP::children:
+    case DCOP::tqchildren:
     {
       TQStringList matching;
-      TQObjectList* widgets = current->queryList("TQWidget", 0, false, args.count() == 0 || args[0] != "false");
+      TQObjectList* widgets = current->queryList(TQWIDGET_OBJECT_NAME_STRING, 0, false, args.count() == 0 || args[0] != "false");
       for (TQObject* w = widgets->first(); w; w = widgets->next())
         if (w->name() && (dynamic_cast<KommanderWidget*>(w)))
             matching.append(w->name());
@@ -707,12 +707,12 @@ TQString KommanderWidget::handleDCOP(const int function, const TQStringList& arg
 
 bool KommanderWidget::isFunctionSupported(int f)
 {
-  return f == DCOP::setEnabled || f == DCOP::setVisible || f == DCOP::children || f == DCOP::type;
+  return f == DCOP::setEnabled || f == DCOP::setVisible || f == DCOP::tqchildren || f == DCOP::type;
 }
 
 bool KommanderWidget::isCommonFunction(int f)
 {
-  return f == DCOP::setEnabled || f == DCOP::setVisible || f == DCOP::children || f == DCOP::type;
+  return f == DCOP::setEnabled || f == DCOP::setVisible || f == DCOP::tqchildren || f == DCOP::type;
 }
 
 ParserData* KommanderWidget::internalParserData() const
@@ -732,7 +732,7 @@ TQString KommanderWidget::fileName()
 TQString KommanderWidget::widgetName() const
 {
   if (m_thisObject)
-    return TQString::fromLatin1(m_thisObject->name());
+    return TQString::tqfromLatin1(m_thisObject->name());
   else
     return TQString();
 }
