@@ -21,9 +21,10 @@
 class ToolBox : public TQToolBox, public KommanderWidget
 {
   Q_OBJECT
-  Q_PROPERTY(TQString populationText READ populationText WRITE setPopulationText DESIGNABLE false)
-  Q_PROPERTY(TQStringList associations READ associatedText WRITE setAssociatedText DESIGNABLE false)
-  Q_PROPERTY(bool KommanderWidget READ isKommanderWidget)
+  TQ_OBJECT
+  TQ_PROPERTY(TQString populationText READ populationText WRITE setPopulationText DESIGNABLE false)
+  TQ_PROPERTY(TQStringList associations READ associatedText WRITE setAssociatedText DESIGNABLE false)
+  TQ_PROPERTY(bool KommanderWidget READ isKommanderWidget)
 public:
   ToolBox(TQWidget *parent = 0, const char *name = 0);
 
