@@ -38,7 +38,7 @@
 using namespace Diff2;
 
 KompareNavTreePart::KompareNavTreePart( TQWidget* parent, const char* name )
-	: KParts::ReadOnlyPart( parent, name ),
+	: KParts::ReadOnlyPart( TQT_TQOBJECT(parent), name ),
 	m_splitter( 0 ),
 	m_modelList( 0 ),
 	m_srcDirTree( 0 ),
@@ -582,7 +582,7 @@ KDirLVI* KDirLVI::findChild( TQString dir )
 //	kdDebug(8105) << "KDirLVI::findChild called with dir = " << dir << endl;
 	KDirLVI* child;
 	if ( ( child = static_cast<KDirLVI*>(this->firstChild()) ) != 0L )
-	{ // has children, check if dir already exists, if so addModel
+	{ // has tqchildren, check if dir already exists, if so addModel
 		do {
 			if ( dir == child->dirName() )
 				return child;
