@@ -266,7 +266,7 @@ const TQString KomparePart::fetchURL( const KURL& url )
 	{
 		if ( ! KIO::NetAccess::download( url, tempFileName, widget() ) )
 		{
-			slotShowError( i18n( "<qt>The URL <b>%1</b> cannot be downloaded.</qt>" ).arg( url.prettyURL() ) );
+			slotShowError( i18n( "<qt>The URL <b>%1</b> cannot be downloaded.</qt>" ).tqarg( url.prettyURL() ) );
 			tempFileName = "";
 		}
 		return tempFileName;
@@ -278,7 +278,7 @@ const TQString KomparePart::fetchURL( const KURL& url )
 			return url.path();
 		else
 		{
-			slotShowError( i18n( "<qt>The URL <b>%1</b> does not exist on your system.</qt>" ).arg( url.prettyURL() ) );
+			slotShowError( i18n( "<qt>The URL <b>%1</b> does not exist on your system.</qt>" ).tqarg( url.prettyURL() ) );
 			return tempFileName;
 		}
 	}
@@ -543,26 +543,26 @@ void KomparePart::updateStatus()
 	{
 	case Kompare::ComparingFiles :
 		text = i18n( "Comparing file %1 with file %2" )
-		   .arg( source )
-		   .arg( destination );
+		   .tqarg( source )
+		   .tqarg( destination );
 		break;
 	case Kompare::ComparingDirs :
 		text = i18n( "Comparing files in %1 with files in %2" )
-		   .arg( source )
-		   .arg( destination );
+		   .tqarg( source )
+		   .tqarg( destination );
 		break;
 	case Kompare::ShowingDiff :
-		text = i18n( "Viewing diff output from %1" ).arg( source );
+		text = i18n( "Viewing diff output from %1" ).tqarg( source );
 		break;
 	case Kompare::BlendingFile :
 		text = i18n( "Blending diff output from %1 into file %2" )
-		    .arg( source )
-		    .arg( destination );
+		    .tqarg( source )
+		    .tqarg( destination );
 		break;
 	case Kompare::BlendingDir :
 		text = i18n( "Blending diff output from %1 into folder %2" )
-		    .arg( m_info.source.prettyURL() )
-		    .arg( m_info.destination.prettyURL() );
+		    .tqarg( m_info.source.prettyURL() )
+		    .tqarg( m_info.destination.prettyURL() );
 		break;
 	default:
 		break;
@@ -666,7 +666,7 @@ void KomparePart::slotShowDiffstats( void )
 		KMessageBox::information( 0L, i18n(
 		    "No diff file, or no 2 files have been diffed. "
 		    "Therefore no stats are available."),
-		    i18n("Diff Statistics"), TQString::null, false );
+		    i18n("Diff Statistics"), TQString(), false );
 	}
 	else if ( m_modelList->modelCount() == 1 ) { // 1 file in diff, or 2 files compared
 		KMessageBox::information( 0L, i18n(
@@ -678,9 +678,9 @@ void KomparePart::slotShowDiffstats( void )
 		    "Format: %3\n"
 		    "Number of hunks: %4\n"
 		    "Number of differences: %5")
-		    .arg(oldFile).arg(newFile).arg(diffFormat)
-		    .arg(noOfHunks).arg(noOfDiffs),
-		    i18n("Diff Statistics"), TQString::null, false );
+		    .tqarg(oldFile).tqarg(newFile).tqarg(diffFormat)
+		    .tqarg(noOfHunks).tqarg(noOfDiffs),
+		    i18n("Diff Statistics"), TQString(), false );
 	} else { // more than 1 file in diff, or 2 directories compared
 		KMessageBox::information( 0L, i18n(
 		    "Statistics:\n"
@@ -693,9 +693,9 @@ void KomparePart::slotShowDiffstats( void )
 		    "\n"
 		    "Number of hunks: %5\n"
 		    "Number of differences: %6")
-		    .arg(filesInDiff).arg(diffFormat).arg(oldFile)
-		    .arg(newFile).arg(noOfHunks).arg(noOfDiffs),
-		    i18n("Diff Statistics"), TQString::null, false );
+		    .tqarg(filesInDiff).tqarg(diffFormat).tqarg(oldFile)
+		    .tqarg(newFile).tqarg(noOfHunks).tqarg(noOfDiffs),
+		    i18n("Diff Statistics"), TQString(), false );
 	}
 }
 
