@@ -54,12 +54,12 @@ KompareListViewFrame::KompareListViewFrame( bool isSource,
 	m_label ( isSource?"Source":"Dest", this ),
 	m_layout ( this )
 {
-	setSizePolicy ( TQSizePolicy(TQSizePolicy::Ignored, TQSizePolicy::Ignored) );
-	m_label.setSizePolicy ( TQSizePolicy(TQSizePolicy::Ignored, TQSizePolicy::Fixed) );
+	tqsetSizePolicy ( TQSizePolicy(TQSizePolicy::Ignored, TQSizePolicy::Ignored) );
+	m_label.tqsetSizePolicy ( TQSizePolicy(TQSizePolicy::Ignored, TQSizePolicy::Fixed) );
 	TQFrame *bottomLine = new TQFrame(this);
 	bottomLine->setFrameShape(TQFrame::HLine);
 	bottomLine->setFrameShadow ( TQFrame::Plain );
-	bottomLine->setSizePolicy ( TQSizePolicy(TQSizePolicy::Ignored, TQSizePolicy::Fixed) );
+	bottomLine->tqsetSizePolicy ( TQSizePolicy(TQSizePolicy::Ignored, TQSizePolicy::Fixed) );
 	bottomLine->setFixedHeight(1);
 	m_label.setMargin(3);
 	m_layout.setSpacing(0);
@@ -92,7 +92,7 @@ void KompareListViewFrame::slotSetModel( const DiffModel* model )
 				m_label.setText( model->destinationFile() );
 		}
 	} else {
-		m_label.setText( TQString::null );
+		m_label.setText( TQString() );
 	}
 }
 
@@ -122,7 +122,7 @@ KompareListView::KompareListView( bool isSource,
 	setFrameStyle( TQFrame::NoFrame );
 	setVScrollBarMode( TQScrollView::AlwaysOff );
 	setHScrollBarMode( TQScrollView::AlwaysOff );
-	setFocusPolicy( TQWidget::NoFocus );
+	setFocusPolicy( TQ_NoFocus );
 	setFont( m_settings->m_font );
 	setSpaces( m_settings->m_tabToNumberOfSpaces );
 	setFocusProxy( parent->parentWidget() );
@@ -182,7 +182,7 @@ int KompareListView::lastVisibleDifference()
 	return -1;
 }
 
-TQRect KompareListView::itemRect( int i )
+TQRect KompareListView::tqitemRect( int i )
 {
 	TQListViewItem* item = itemAtIndex( i );
 	int x = 0;
@@ -390,7 +390,7 @@ void KompareListView::slotApplyAllDifferences( bool apply )
 	TQPtrDictIterator<KompareListViewDiffItem> it ( m_itemDict );
 	for( ; it.current(); ++it )
 		it.current()->applyDifference( apply );
-	repaint();
+	tqrepaint();
 }
 
 void KompareListView::slotApplyDifference( const Difference* diff, bool apply )
@@ -500,12 +500,12 @@ void KompareListViewDiffItem::applyDifference( bool apply )
 	kdDebug(8104) << "KompareListViewDiffItem::applyDifference( " << apply << " )" << endl;
 	setVisibility();
 	setup();
-	repaint();
+	tqrepaint();
 }
 
 int KompareListViewDiffItem::maxHeight()
 {
-	int lines = QMAX( m_difference->sourceLineCount(), m_difference->destinationLineCount() );
+	int lines = TQMAX( m_difference->sourceLineCount(), m_difference->destinationLineCount() );
 	if( lines == 0 )
 		return BLANK_LINE_HEIGHT;
 	else
@@ -520,7 +520,7 @@ void KompareListViewDiffItem::setSelected( bool b )
 	                      m_sourceItem->firstChild() :
 	                      m_destItem->firstChild();
 	while( item && item->isVisible() ) {
-		item->repaint();
+		item->tqrepaint();
 		item = item->nextSibling();
 	}
 }
@@ -665,7 +665,7 @@ void KompareListViewLineItem::paintText( TQPainter* p, const TQColor& bg, int co
 					TQFont font( p->font() );
 					font.setBold( true );
 					p->setFont( font );
-//					p->setPen( Qt::blue );
+//					p->setPen( TQt::blue );
 					brush = changeBrush;
 				}
 				else
@@ -673,7 +673,7 @@ void KompareListViewLineItem::paintText( TQPainter* p, const TQColor& bg, int co
 					TQFont font( p->font() );
 					font.setBold( false );
 					p->setFont( font );
-//					p->setPen( Qt::black );
+//					p->setPen( TQt::black );
 					brush = normalBrush;
 				}
 				chunkWidth = p->fontMetrics().width( textChunk );
