@@ -36,7 +36,7 @@ using namespace Diff2;
 
 KompareSplitter::KompareSplitter( ViewSettings *settings, TQWidget * parent,
                                   const char *name) :
-	TQSplitter( Horizontal, parent, name ),
+	TQSplitter(Qt::Horizontal, parent, name ),
 	m_settings( settings )
 {
 	TQFrame *scrollFrame = new TQFrame( parent, "scrollFrame" );
@@ -44,27 +44,27 @@ KompareSplitter::KompareSplitter( ViewSettings *settings, TQWidget * parent,
 
 	// Set up the scrollFrame
 	scrollFrame->setFrameStyle( TQFrame::NoFrame | TQFrame::Plain );
-	scrollFrame->setLineWidth(scrollFrame->style().pixelMetric(TQStyle::PM_DefaultFrameWidth));
-	TQGridLayout *pairlayout = new TQGridLayout(scrollFrame, 2, 2, 0);
-	m_vScroll = new TQScrollBar( TQScrollBar::Vertical, scrollFrame );
-	pairlayout->addWidget( m_vScroll, 0, 1 );
-	m_hScroll = new TQScrollBar( TQScrollBar::Horizontal, scrollFrame );
-	pairlayout->addWidget( m_hScroll, 1, 0 );
+	scrollFrame->setLineWidth(scrollFrame->tqstyle().tqpixelMetric(TQStyle::PM_DefaultFrameWidth));
+	TQGridLayout *pairtqlayout = new TQGridLayout(scrollFrame, 2, 2, 0);
+	m_vScroll = new TQScrollBar( Qt::Vertical, scrollFrame );
+	pairtqlayout->addWidget( m_vScroll, 0, 1 );
+	m_hScroll = new TQScrollBar( Qt::Horizontal, scrollFrame );
+	pairtqlayout->addWidget( m_hScroll, 1, 0 );
 
 	new KompareListViewFrame(true, m_settings, this, "source");
 	new KompareListViewFrame(false, m_settings, this, "destination");
-	pairlayout->addWidget( this, 0, 0 );
+	pairtqlayout->addWidget( this, 0, 0 );
 
 	// set up our looks
 	setFrameStyle( TQFrame::StyledPanel | TQFrame::Sunken );
-	setLineWidth( style().pixelMetric( TQStyle::PM_DefaultFrameWidth ) );
+	setLineWidth( tqstyle().tqpixelMetric( TQStyle::PM_DefaultFrameWidth ) );
 
 	setHandleWidth(50);
 	setChildrenCollapsible( false );
 	setFrameStyle( TQFrame::NoFrame );
-	setSizePolicy( TQSizePolicy (TQSizePolicy::Ignored, TQSizePolicy::Ignored ));
+	tqsetSizePolicy( TQSizePolicy (TQSizePolicy::Ignored, TQSizePolicy::Ignored ));
 	setOpaqueResize( true );
-	setFocusPolicy( TQWidget::WheelFocus );
+	setFocusPolicy( TQ_WheelFocus );
 
 	connect( this, TQT_SIGNAL(configChanged()), TQT_SLOT(slotConfigChanged()) );
 	connect( this, TQT_SIGNAL(configChanged()), TQT_SLOT(slotDelayedRepaintHandles()) );
@@ -99,17 +99,17 @@ KompareSplitter::~KompareSplitter(){}
     \a prepend is TRUE, then recalcId() is very probably needed.)
 */
 
-QSplitterLayoutStruct *KompareSplitter::addWidget( KompareListViewFrame *w, bool prepend )
+TQSplitterLayoutStruct *KompareSplitter::addWidget( KompareListViewFrame *w, bool prepend )
 {
 	/* This function is *not* a good place to make connections to and from
 	 * the KompareListView. Make them in the KompareListViewFrame constructor
 	 * instad - that way the connections get made upon creation, not upon the
 	 * next processing of the event queue. */
 
-	QSplitterLayoutStruct *s;
+	TQSplitterLayoutStruct *s;
 	KompareConnectWidgetFrame *newHandle = 0;
 	if ( d->list.count() > 0 ) {
-		s = new QSplitterLayoutStruct;
+		s = new TQSplitterLayoutStruct;
 		s->resizeMode = KeepSize;
 		TQString tmp = "qt_splithandle_";
 		tmp += w->name();
@@ -121,13 +121,13 @@ QSplitterLayoutStruct *KompareSplitter::addWidget( KompareListViewFrame *w, bool
 		s->wid = newHandle;
 		newHandle->setId( d->list.count() );
 		s->isHandle = TRUE;
-		s->sizer = pick( newHandle->sizeHint() );
+		s->sizer = pick( newHandle->tqsizeHint() );
 		if ( prepend )
 		    d->list.prepend( s );
 		else
 		    d->list.append( s );
 	}
-	s = new QSplitterLayoutStruct;
+	s = new TQSplitterLayoutStruct;
 	s->resizeMode = DefaultResizeMode;
 	s->wid = w;
 	s->isHandle = FALSE;
@@ -153,7 +153,7 @@ void KompareSplitter::childEvent( TQChildEvent *c )
 		if ( ((TQWidget*)c->child())->testWFlags( WType_TopLevel ) )
 			return;
 
-		QSplitterLayoutStruct *s = d->list.first();
+		TQSplitterLayoutStruct *s = d->list.first();
 		while ( s ) {
 			if ( s->wid == c->child() )
 				return;
@@ -162,10 +162,10 @@ void KompareSplitter::childEvent( TQChildEvent *c )
 		addWidget( (KompareListViewFrame*)c->child() );
 		recalc( isVisible() );
     } else if ( c->type() == TQEvent::ChildRemoved ) {
-		QSplitterLayoutStruct *prev = 0;
+		TQSplitterLayoutStruct *prev = 0;
 		if ( d->list.count() > 1 )
 			prev = d->list.at( 1 );  // yes, this is correct
-		QSplitterLayoutStruct *curr = d->list.first();
+		TQSplitterLayoutStruct *curr = d->list.first();
 		while ( curr ) {
 			if ( curr->wid == c->child() ) {
 			d->list.removeRef( curr );
@@ -184,7 +184,7 @@ void KompareSplitter::childEvent( TQChildEvent *c )
 	}
 }
 
-// This is from a private qt header (kernel/qlayoutengine_p.h). sorry.
+// This is from a private qt header (kernel/qtqlayoutengine_p.h). sorry.
 TQSize qSmartMinSize( TQWidget *w );
 
 static TQPoint toggle( TQWidget *w, TQPoint pos )
@@ -212,13 +212,13 @@ static TQPoint bottomRight( TQWidget *w )
     if ( isCollapsed(w) ) {
         return toggle( w, w->pos() ) - TQPoint( 1, 1 );
     } else {
-        return w->geometry().bottomRight();
+        return w->tqgeometry().bottomRight();
     }
 }
 
-void KompareSplitter::moveSplitter( QCOORD p, int id )
+void KompareSplitter::moveSplitter( TQCOORD p, int id )
 {
-	QSplitterLayoutStruct *s = d->list.at( id );
+	TQSplitterLayoutStruct *s = d->list.at( id );
 	int farMin;
 	int min;
 	int max;
@@ -229,7 +229,7 @@ void KompareSplitter::moveSplitter( QCOORD p, int id )
 	int* ws = new int[d->list.count()];
 	TQWidget *w = 0;
 	bool upLeft;
-	if ( TQApplication::reverseLayout() && orient == Horizontal ) {
+	if ( TQApplication::reverseLayout() && orient ==Qt::Horizontal ) {
 		int q = p + s->wid->width();
 		doMove( FALSE, q, id - 1, -1, (p > max), poss, ws );
 		doMove( TRUE, q, id, -1, (p < min), poss, ws );
@@ -259,7 +259,7 @@ void KompareSplitter::moveSplitter( QCOORD p, int id )
 void KompareSplitter::doMove( bool backwards, int pos, int id, int delta,
                         bool mayCollapse, int* positions, int* widths )
 {
-	QSplitterLayoutStruct *s;
+	TQSplitterLayoutStruct *s;
 	TQWidget *w;
 	for ( ; id >= 0 && id < (int)d->list.count();
 			id = backwards ? id - delta : id + delta ) {
@@ -278,8 +278,8 @@ void KompareSplitter::doMove( bool backwards, int pos, int id, int delta,
 				int dd = backwards ? pos - pick( topLeft(w) )
 				                   : pick( bottomRight(w) ) - pos + 1;
 				if ( dd > 0 || (!isCollapsed(w) && !mayCollapse) ) {
-					dd = QMAX( pick(qSmartMinSize(w)),
-					           QMIN(dd, pick(w->maximumSize())) );
+					dd = TQMAX( pick(qSmartMinSize(w)),
+					           TQMIN(dd, pick(w->tqmaximumSize())) );
 				} else {
 					dd = 0;
 				}
@@ -294,7 +294,7 @@ void KompareSplitter::doMove( bool backwards, int pos, int id, int delta,
 
 void KompareSplitter::slotSetSelection( const DiffModel* model, const Difference* diff )
 {
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
 	{
 		if ( curr->isHandle )
@@ -314,7 +314,7 @@ void KompareSplitter::slotSetSelection( const DiffModel* model, const Difference
 
 void KompareSplitter::slotSetSelection( const Difference* diff )
 {
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
 		if ( curr->isHandle )
 			((KompareConnectWidgetFrame*)
@@ -328,7 +328,7 @@ void KompareSplitter::slotSetSelection( const Difference* diff )
 
 void KompareSplitter::slotApplyDifference( bool apply )
 {
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
 		if ( !curr->isHandle )
 			((KompareListViewFrame*)
@@ -338,7 +338,7 @@ void KompareSplitter::slotApplyDifference( bool apply )
 
 void KompareSplitter::slotApplyAllDifferences( bool apply )
 {
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
 		if ( !curr->isHandle )
 			((KompareListViewFrame*)
@@ -349,7 +349,7 @@ void KompareSplitter::slotApplyAllDifferences( bool apply )
 
 void KompareSplitter::slotApplyDifference( const Difference* diff, bool apply )
 {
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
 		if ( !curr->isHandle )
 			((KompareListViewFrame*)
@@ -359,7 +359,7 @@ void KompareSplitter::slotApplyDifference( const Difference* diff, bool apply )
 
 void KompareSplitter::slotDifferenceClicked( const Difference* diff )
 {
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
 		if ( !curr->isHandle )
 			((KompareListViewFrame*)
@@ -369,7 +369,7 @@ void KompareSplitter::slotDifferenceClicked( const Difference* diff )
 
 void KompareSplitter::slotConfigChanged()
 {
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	for ( curr = d->list.first(); curr; curr = d->list.next() ) {
 		if ( !curr->isHandle )
 		{
@@ -385,7 +385,7 @@ void KompareSplitter::slotConfigChanged()
 
 void KompareSplitter::slotDelayedRepaintHandles()
 {
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
 		 if ( curr->isHandle )
 			((KompareConnectWidgetFrame*)curr->wid)->wid()->slotDelayedRepaint();
@@ -393,10 +393,10 @@ void KompareSplitter::slotDelayedRepaintHandles()
 
 void KompareSplitter::repaintHandles()
 {
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
 		if ( curr->isHandle )
-			((KompareConnectWidgetFrame*)curr->wid)->wid()->repaint();
+			((KompareConnectWidgetFrame*)curr->wid)->wid()->tqrepaint();
 }
 
 // Scrolling stuff
@@ -410,7 +410,7 @@ void KompareSplitter::wheelEvent( TQWheelEvent* e )
 	// scroll lines...
 	if ( e->orientation() == Qt::Vertical )
 	{
-		if ( e->state() & Qt::ControlButton )
+		if ( e->state() & TQt::ControlButton )
 			if ( e->delta() < 0 ) // scroll down one page
 				m_vScroll->addPage();
 			else // scroll up one page
@@ -423,7 +423,7 @@ void KompareSplitter::wheelEvent( TQWheelEvent* e )
 	}
 	else
 	{
-		if ( e->state() & Qt::ControlButton )
+		if ( e->state() & TQt::ControlButton )
 			if ( e->delta() < 0 ) // scroll right one page
 				m_hScroll->addPage();
 			else // scroll left one page
@@ -557,7 +557,7 @@ void KompareSplitter::slotUpdateVScrollValue()
  
 int KompareSplitter::scrollId()
 {
-	QSplitterLayoutStruct *curr = d->list.first();
+	TQSplitterLayoutStruct *curr = d->list.first();
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
 		if ( !curr->isHandle )
 			return ((KompareListViewFrame*) curr->wid)->view()->scrollId();
@@ -566,7 +566,7 @@ int KompareSplitter::scrollId()
 
 int KompareSplitter::lineSpacing()
 {
-	QSplitterLayoutStruct *curr = d->list.first();
+	TQSplitterLayoutStruct *curr = d->list.first();
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
 		if ( !curr->isHandle )
 			return ((KompareListViewFrame*)
@@ -576,7 +576,7 @@ int KompareSplitter::lineSpacing()
 
 int KompareSplitter::pageSize()
 {
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
 	{
 		if ( !curr->isHandle )
@@ -590,7 +590,7 @@ int KompareSplitter::pageSize()
 
 bool KompareSplitter::needVScrollBar()
 {
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	int pagesize = pageSize();
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
 	{
@@ -607,7 +607,7 @@ bool KompareSplitter::needVScrollBar()
 int KompareSplitter::minVScrollId()
 {
 
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	int min = -1;
 	int mSId;
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
@@ -623,7 +623,7 @@ int KompareSplitter::minVScrollId()
 
 int KompareSplitter::maxVScrollId()
 {
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	int max = 0;
 	int mSId;
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
@@ -640,7 +640,7 @@ int KompareSplitter::maxVScrollId()
 
 bool KompareSplitter::needHScrollBar()
 {
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
 	{
 		if( !curr->isHandle )
@@ -655,7 +655,7 @@ bool KompareSplitter::needHScrollBar()
 
 int KompareSplitter::maxHScrollId()
 {
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	int max = 0;
 	int mHSId;
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
@@ -673,7 +673,7 @@ int KompareSplitter::maxHScrollId()
 
 int KompareSplitter::maxContentsX()
 {
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	int max = 0;
 	int mCX;
 	for ( curr = d->list.first(); curr; curr = d->list.next() )
@@ -695,7 +695,7 @@ int KompareSplitter::minVisibleWidth()
 	// despite the fact that *noone* has a pgright and pgleft key :P
 	// But we do have mousewheels with horizontal scrolling functionality,
 	// pressing shift and scrolling then goes left and right one page at the time
-	QSplitterLayoutStruct *curr;
+	TQSplitterLayoutStruct *curr;
 	int min = -1;
 	int vW;
 	for( curr = d->list.first(); curr; curr = d->list.next() )
