@@ -27,9 +27,10 @@
 class TQWidget;
 class KConfig;
 
-class SettingsBase : public QObject
+class SettingsBase : public TQObject
 {
 Q_OBJECT
+  TQ_OBJECT
 public:
 	SettingsBase( TQWidget* parent );
 	~SettingsBase();
