@@ -58,28 +58,28 @@ KompareModelList::KompareModelList( DiffSettings* diffSettings, struct Kompare::
 	m_info( info ),
 	m_textCodec( 0 )
 {
-	m_applyDifference    = new KAction( i18n("&Apply Difference"), "1rightarrow", Qt::Key_Space,
+	m_applyDifference    = new KAction( i18n("&Apply Difference"), "1rightarrow", TQt::Key_Space,
 	                                 this, TQT_SLOT(slotActionApplyDifference()),
 	                                 (( KomparePart* )parent)->actionCollection(), "difference_apply" );
-	m_unApplyDifference  = new KAction( i18n("Un&apply Difference"), "1leftarrow", Qt::Key_BackSpace,
+	m_unApplyDifference  = new KAction( i18n("Un&apply Difference"), "1leftarrow", TQt::Key_BackSpace,
 	                                 this, TQT_SLOT(slotActionUnApplyDifference()),
 	                                 (( KomparePart* )parent)->actionCollection(), "difference_unapply" );
-	m_applyAll           = new KAction( i18n("App&ly All"), "2rightarrow", Qt::CTRL + Qt::Key_A,
+	m_applyAll           = new KAction( i18n("App&ly All"), "2rightarrow", TQt::CTRL + TQt::Key_A,
 	                                 this, TQT_SLOT(slotActionApplyAllDifferences()),
 	                                 (( KomparePart* )parent)->actionCollection(), "difference_applyall" );
-	m_unapplyAll         = new KAction( i18n("&Unapply All"), "2leftarrow", Qt::CTRL + Qt::Key_U,
+	m_unapplyAll         = new KAction( i18n("&Unapply All"), "2leftarrow", TQt::CTRL + TQt::Key_U,
 	                                 this, TQT_SLOT(slotActionUnapplyAllDifferences()),
 	                                 (( KomparePart* )parent)->actionCollection(), "difference_unapplyall" );
-	m_previousFile       = new KAction( i18n("P&revious File"), "2uparrow", Qt::CTRL + Qt::Key_PageUp,
+	m_previousFile       = new KAction( i18n("P&revious File"), "2uparrow", TQt::CTRL + TQt::Key_PageUp,
 	                                 this, TQT_SLOT(slotPreviousModel()),
 	                                 (( KomparePart* )parent)->actionCollection(), "difference_previousfile" );
-	m_nextFile           = new KAction( i18n("N&ext File"), "2downarrow", Qt::CTRL + Qt::Key_PageDown,
+	m_nextFile           = new KAction( i18n("N&ext File"), "2downarrow", TQt::CTRL + TQt::Key_PageDown,
 	                                 this, TQT_SLOT(slotNextModel()),
 	                                 (( KomparePart* )parent)->actionCollection(), "difference_nextfile" );
-	m_previousDifference = new KAction( i18n("&Previous Difference"), "1uparrow", Qt::CTRL + Qt::Key_Up,
+	m_previousDifference = new KAction( i18n("&Previous Difference"), "1uparrow", TQt::CTRL + TQt::Key_Up,
 	                                 this, TQT_SLOT(slotPreviousDifference()),
 	                                 (( KomparePart* )parent)->actionCollection(), "difference_previous" );
-	m_nextDifference     = new KAction( i18n("&Next Difference"), "1downarrow", Qt::CTRL + Qt::Key_Down,
+	m_nextDifference     = new KAction( i18n("&Next Difference"), "1downarrow", TQt::CTRL + TQt::Key_Down,
 	                                 this, TQT_SLOT(slotNextDifference()),
 	                                 (( KomparePart* )parent)->actionCollection(), "difference_next" );
 	m_previousDifference->setEnabled( false );
@@ -235,7 +235,7 @@ bool KompareModelList::openFileAndDiff( const TQString& file, const TQString& di
 
 	if ( parseDiffOutput( readFile( diff ) ) != 0 )
 	{
-		emit error( i18n( "<qt>No models or no differences, this file: <b>%1</b>, is not a valid diff file.</qt>" ).arg(  diff ) );
+		emit error( i18n( "<qt>No models or no differences, this file: <b>%1</b>, is not a valid diff file.</qt>" ).tqarg(  diff ) );
 		return false;
 	}
 
@@ -243,7 +243,7 @@ bool KompareModelList::openFileAndDiff( const TQString& file, const TQString& di
 	if ( !blendOriginalIntoModelList( file ) )
 	{
 		kdDebug(8101) << "Oops cant blend original file into modellist : " << file << endl;
-		emit( i18n( "<qt>There were problems applying the diff <b>%1</b> to the file <b>%2</b>.</qt>" ).arg( diff ).arg( file ) );
+		emit( i18n( "<qt>There were problems applying the diff <b>%1</b> to the file <b>%2</b>.</qt>" ).tqarg( diff ).tqarg( file ) );
 		return false;
 	}
 
@@ -259,7 +259,7 @@ bool KompareModelList::openDirAndDiff( const TQString& dir, const TQString& diff
 
 	if ( parseDiffOutput( readFile( diff ) ) != 0 )
 	{
-		emit error( i18n( "<qt>No models or no differences, this file: <b>%1</b>, is not a valid diff file.</qt>" ).arg( diff ) );
+		emit error( i18n( "<qt>No models or no differences, this file: <b>%1</b>, is not a valid diff file.</qt>" ).tqarg( diff ) );
 		return false;
 	}
 
@@ -268,7 +268,7 @@ bool KompareModelList::openDirAndDiff( const TQString& dir, const TQString& diff
 	{
 		// Trouble blending the original into the model
 		kdDebug(8101) << "Oops cant blend original dir into modellist : " << dir << endl;
-		emit error( i18n( "<qt>There were problems applying the diff <b>%1</b> to the folder <b>%2</b>.</qt>" ).arg( diff ).arg( dir ) );
+		emit error( i18n( "<qt>There were problems applying the diff <b>%1</b> to the folder <b>%2</b>.</qt>" ).tqarg( diff ).tqarg( dir ) );
 		return false;
 	}
 
@@ -347,7 +347,7 @@ bool KompareModelList::saveDestination( DiffModel* model )
 
 	temp->close();
 	if( temp->status() != 0 ) {
-		emit error( i18n( "<qt>Could not write to the temporary file <b>%1</b>, deleting it.</qt>" ).arg( temp->name() ) );
+		emit error( i18n( "<qt>Could not write to the temporary file <b>%1</b>, deleting it.</qt>" ).tqarg( temp->name() ) );
 		temp->unlink();
 		delete temp;
 		return false;
@@ -380,7 +380,7 @@ bool KompareModelList::saveDestination( DiffModel* model )
 
 	if ( !result )
 	{
-		emit error( i18n( "<qt>Could not upload the temporary file to the destination location <b>%1</b>. The temporary file is still available under: <b>%2</b>. You can manually copy it to the right place.</qt>" ).arg( m_destination ).arg( temp->name() ) );
+		emit error( i18n( "<qt>Could not upload the temporary file to the destination location <b>%1</b>. The temporary file is still available under: <b>%2</b>. You can manually copy it to the right place.</qt>" ).tqarg( m_destination ).tqarg( temp->name() ) );
 	}
 	else
 	{
@@ -489,7 +489,7 @@ TQStringList KompareModelList::split( const TQString& fileContents )
 	int pos = 0;
 	unsigned int oldpos = 0;
 	// split that does not strip the split char
-#ifdef QT_OS_MAC
+#ifdef TQT_OS_MAC
 	const char split = '\r';
 #else
 	const char split = '\n';
@@ -633,7 +633,7 @@ void KompareModelList::slotSelectionChanged( const Diff2::DiffModel* model, cons
 // This method will signal all the other objects about a change in selection,
 // it will emit setSelection( const DiffModel*, const Difference* ) to all who are connected
 	kdDebug(8101) << "KompareModelList::slotSelectionChanged( " << model << ", " << diff << " )" << endl;
-	kdDebug(8101) << "Sender is : " << sender()->className() << endl;
+	kdDebug(8101) << "Sender is : " << TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->className() << endl;
 //	kdDebug(8101) << kdBacktrace() << endl;
 
 	m_selectedModel = const_cast<DiffModel*>(model);
@@ -668,7 +668,7 @@ void KompareModelList::slotSelectionChanged( const Diff2::Difference* diff )
 // This method will emit setSelection( const Difference* ) to whomever is listening
 // when for instance in kompareview the selection has changed
 	kdDebug(8101) << "KompareModelList::slotSelectionChanged( " << diff << " )" << endl;
-	kdDebug(8101) << "Sender is : " << sender()->className() << endl;
+	kdDebug(8101) << "Sender is : " << TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->className() << endl;
 
 	m_selectedDifference = const_cast<Difference*>(diff);
 
@@ -901,7 +901,7 @@ bool KompareModelList::blendOriginalIntoModelList( const TQString& localURL )
 	if ( fi.isDir() )
 	{ // is a dir
 		kdDebug() << "Blend Dir" << endl;
-//		TQDir dir( localURL, TQString::null, TQDir::Name|TQDir::DirsFirst, TQDir::All );
+//		TQDir dir( localURL, TQString(), TQDir::Name|TQDir::DirsFirst, TQDir::All );
 		DiffModelListIterator modelIt = m_models->begin();
 		DiffModelListIterator mEnd    = m_models->end();
 		for ( ; modelIt != mEnd; ++modelIt )
@@ -1086,7 +1086,7 @@ bool KompareModelList::blendFile( DiffModel* model, const TQString& fileContents
 			case Difference::Change:
 				kdDebug(8101) << "Change" << endl;
 
-				//QStringListConstIterator saveIt = linesIt;
+				//TQStringListConstIterator saveIt = linesIt;
 
 				for ( int i = 0; i < diff->sourceLineCount(); i++ )
 				{
