@@ -101,8 +101,8 @@ DOMTreeView::DOMTreeView(TQWidget *parent, const char* name, bool /*allowSaving*
 
   installEventFilter(m_listView);
 
-  ManipulationCommand::connect(TQT_SIGNAL(nodeChanged(const DOM::Node &)), this, TQT_SLOT(slotRefreshNode(const DOM::Node &)));
-  ManipulationCommand::connect(TQT_SIGNAL(structureChanged()), this, TQT_SLOT(refresh()));
+  ManipulationCommand::connect(TQT_SIGNAL(nodeChanged(const DOM::Node &)), TQT_TQOBJECT(this), TQT_SLOT(slotRefreshNode(const DOM::Node &)));
+  ManipulationCommand::connect(TQT_SIGNAL(structureChanged()), TQT_TQOBJECT(this), TQT_SLOT(refresh()));
 
   initDOMNodeInfo();
 
@@ -124,7 +124,7 @@ void DOMTreeView::setHtmlPart(KHTMLPart *_part)
     // nothing here yet
   }
 
-  parentWidget()->setCaption( part ? i18n( "DOM Tree for %1" ).arg(part->url().prettyURL()) : i18n("DOM Tree") );
+  parentWidget()->setCaption( part ? i18n( "DOM Tree for %1" ).tqarg(part->url().prettyURL()) : i18n("DOM Tree") );
 
   TQTimer::singleShot(0, this, TQT_SLOT(slotSetHtmlPartDelayed()));
 }
@@ -137,15 +137,15 @@ DOMTreeWindow *DOMTreeView::mainWindow() const
 bool DOMTreeView::eventFilter(TQObject *o, TQEvent *e)
 {
   if (e->type() == TQEvent::AccelOverride) {
-    TQKeyEvent *ke = static_cast<TQKeyEvent *>(e);
+    TQKeyEvent *ke = TQT_TQKEYEVENT(e);
     kdDebug(90180) << " acceloverride " << ke->key() << " o " << o->name() << endl;
 
-    if (o == m_listView) {	// DOM tree
+    if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_listView)) {	// DOM tree
       KKey ks = mainWindow()->deleteNodeAction()->shortcut().seq(0).key(0);
       if (ke->key() == ks.keyCodeQt())
         return true;
 
-    } else if (o == nodeAttributes) {
+    } else if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(nodeAttributes)) {
       KKey ks = mainWindow()->deleteAttributeAction()->shortcut().seq(0).key(0);
       if (ke->key() == ks.keyCodeQt())
         return true;
@@ -155,14 +155,14 @@ bool DOMTreeView::eventFilter(TQObject *o, TQEvent *e)
   } else if (e->type() == TQEvent::FocusIn) {
 
     kdDebug(90180) << " focusin o " << o->name() << endl;
-    if (o != this) {
+    if (TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(this)) {
       focused_child = o;
     }
 
   } else if (e->type() == TQEvent::FocusOut) {
 
     kdDebug(90180) << " focusout o " << o->name() << endl;
-    if (o != this) {
+    if (TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(this)) {
       focused_child = 0;
     }
 
@@ -343,7 +343,7 @@ void DOMTreeView::highlightHTML(DOMListViewItem *cur_item, const TQString &nodeN
    * think it's worth it.
    */
 
-  TQColor namedColor(palette().active().text());
+  TQColor namedColor(tqpalette().active().text());
   TQString tagName = nodeName.upper();
   if ( tagName == "HTML" ) {
     namedColor = "#0000ff";
@@ -530,7 +530,7 @@ void DOMTreeView::slotSaveClicked()
 
     if (file.exists()) {
       const TQString title = i18n( "File Exists" );
-      const TQString text = i18n( "Do you really want to overwrite: \n%1?" ).arg(url.url());
+      const TQString text = i18n( "Do you really want to overwrite: \n%1?" ).tqarg(url.url());
       if (KMessageBox::Continue != KMessageBox::warningContinueCancel(this, text, title, i18n("Overwrite") ) ) {
 	return;
       }
@@ -545,12 +545,12 @@ void DOMTreeView::slotSaveClicked()
       delete m_textStream;
     } else {
       const TQString title = i18n( "Unable to Open File" );
-      const TQString text = i18n( "Unable to open \n %1 \n for writing" ).arg(url.path());
+      const TQString text = i18n( "Unable to open \n %1 \n for writing" ).tqarg(url.path());
       KMessageBox::sorry( this, text, title );
     }
   } else {
     const TQString title = i18n( "Invalid URL" );
-    const TQString text = i18n( "This URL \n %1 \n is not valid." ).arg(url.url());
+    const TQString text = i18n( "This URL \n %1 \n is not valid." ).tqarg(url.url());
     KMessageBox::sorry( this, text, title );
   }
 }
@@ -943,7 +943,7 @@ static TQString *clickToAdd;
 /**
  * List view item for attribute list.
  */
-class AttributeListItem : public QListViewItem
+class AttributeListItem : public TQListViewItem
 {
   typedef TQListViewItem super;
 
@@ -973,7 +973,7 @@ public:
 
 protected:
   virtual void paintCell( TQPainter *p, const TQColorGroup &cg,
-			  int column, int width, int alignment )
+			  int column, int width, int tqalignment )
   {
     bool updates_enabled = listView()->isUpdatesEnabled();
     listView()->setUpdatesEnabled(false);
@@ -993,7 +993,7 @@ protected:
 
     TQColorGroup _cg( cg );
     _cg.setColor( TQColorGroup::Text, c );
-    super::paintCell( p, _cg, column, width, alignment );
+    super::paintCell( p, _cg, column, width, tqalignment );
 
     if (text_changed) setText(column, oldText);
     listView()->setUpdatesEnabled(updates_enabled);
@@ -1015,7 +1015,7 @@ void DOMTreeView::initDOMNodeInfo()
 
   connect(applyContent, TQT_SIGNAL(clicked()), TQT_SLOT(slotApplyContent()));
 
-  ManipulationCommand::connect(TQT_SIGNAL(nodeChanged(const DOM::Node &)), this, TQT_SLOT(initializeOptionsFromNode(const DOM::Node &)));
+  ManipulationCommand::connect(TQT_SIGNAL(nodeChanged(const DOM::Node &)), TQT_TQOBJECT(this), TQT_SLOT(initializeOptionsFromNode(const DOM::Node &)));
 
   nodeAttributes->setRenameable(0, true);
   nodeAttributes->setRenameable(1, true);
