@@ -38,7 +38,7 @@ void PluginDomtreeviewer::slotShowDOMTree()
     delete m_dialog;
     Q_ASSERT((DOMTreeWindow *)m_dialog == (DOMTreeWindow *)0);
   }
-  if (KHTMLPart *part = ::qt_cast<KHTMLPart *>(parent()))
+  if (KHTMLPart *part = ::tqqt_cast<KHTMLPart *>(parent()))
   {
     m_dialog = new DOMTreeWindow(this);
     connect( m_dialog, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( slotDestroyed() ) );
