@@ -94,7 +94,7 @@ SearchBarPlugin::SearchBarPlugin(TQObject *parent, const char *name,
 
 	configurationChanged();
 
-	KParts::MainWindow *mainWin = static_cast<KParts::MainWindow*>(parent);
+	KParts::MainWindow *mainWin = static_cast<KParts::MainWindow*>(TQT_TQWIDGET(parent));
 
 	//Grab the part manager. Don't know of any other way, and neither does Tronical, so..
 	KParts::PartManager *partMan = static_cast<KParts::PartManager*>(mainWin->child(0, "KParts::PartManager"));
@@ -132,13 +132,13 @@ TQChar delimiter()
 
 bool SearchBarPlugin::eventFilter(TQObject *o, TQEvent *e)
 {
-	if( o==m_searchCombo->lineEdit() && e->type() == TQEvent::KeyPress ) 
+	if( TQT_BASE_OBJECT(o)==TQT_BASE_OBJECT(m_searchCombo->lineEdit()) && e->type() == TQEvent::KeyPress ) 
 	{
 		TQKeyEvent *k = (TQKeyEvent *)e;
 		TQString text = k->text();
 		if(!text.isEmpty())
 		{
-			if(k->key() != Qt::Key_Return && k->key() != Key_Enter && k->key() != Key_Escape)
+			if(k->key() != TQt::Key_Return && k->key() != Key_Enter && k->key() != Key_Escape)
 			{
 				emit gsCompleteDelayed();
 			}
@@ -162,7 +162,7 @@ bool SearchBarPlugin::eventFilter(TQObject *o, TQEvent *e)
 			{
 				if(m_searchCombo->listBox()->isVisible())
 				{
-					qApp->sendEvent(m_searchCombo->listBox(), e);
+					tqApp->sendEvent(m_searchCombo->listBox(), e);
 					return true;
 				}
 			}
@@ -174,7 +174,7 @@ bool SearchBarPlugin::eventFilter(TQObject *o, TQEvent *e)
 			    the listbox was visible.
 			if(m_searchCombo->listBox()->isVisible())
 			{
-				qApp->sendEvent(m_searchCombo->listBox(),e);
+				tqApp->sendEvent(m_searchCombo->listBox(),e);
 			}*/
 		}
 		if (k->key() == Key_Escape)
@@ -273,7 +273,7 @@ void SearchBarPlugin::startSearch(const TQString &_search)
 		TQStringList list;
 		list << "kurisearchfilter" << "kuriikwsfilter";
 
-		service = KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").arg(m_currentEngine));
+		service = KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").tqarg(m_currentEngine));
                 if (service) {
 		    const TQString searchProviderPrefix = *(service->property("Keys").toStringList().begin()) + delimiter();
 		    data.setData( searchProviderPrefix + search );
@@ -281,11 +281,11 @@ void SearchBarPlugin::startSearch(const TQString &_search)
 
 		if(!service || !KURIFilter::self()->filterURI(data, list))
 		{
-			data.setData( TQString::fromLatin1( "google" ) + delimiter() + search );
+			data.setData( TQString::tqfromLatin1( "google" ) + delimiter() + search );
 			KURIFilter::self()->filterURI( data, list );
 		}
 
-		if(KApplication::keyboardMouseState() & Qt::ControlButton) 
+		if(KApplication::keyboardMouseState() & TQt::ControlButton) 
 		{
 			KParts::URLArgs args;
 			args.setNewTab(true);
@@ -329,7 +329,7 @@ void SearchBarPlugin::setIcon()
 		TQStringList list;
 		list << "kurisearchfilter" << "kuriikwsfilter";
 
-		service = KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").arg(m_currentEngine));
+		service = KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").tqarg(m_currentEngine));
                 if (service) {
 		    const TQString searchProviderPrefix = *(service->property("Keys").toStringList().begin()) + delimiter();
 		    data.setData( searchProviderPrefix + "some keyword" );
@@ -353,7 +353,7 @@ void SearchBarPlugin::setIcon()
 			m_searchIcon = SmallIcon("google");
 			providername = "Google";
 		}
-		hinttext = i18n("%1 Search").arg(providername);;
+		hinttext = i18n("%1 Search").tqarg(providername);;
 	}
 	static_cast<KLineEdit*>(m_searchCombo->lineEdit())->setClickMessage(hinttext);
 
@@ -363,8 +363,8 @@ void SearchBarPlugin::setIcon()
 	TQPainter p( &arrowmap );
 	p.drawPixmap(0, 2, m_searchIcon);
 	TQStyle::SFlags arrowFlags = TQStyle::Style_Default;
-	m_searchCombo->style().drawPrimitive(TQStyle::PE_ArrowDown, &p, TQRect(arrowmap.width()-6, 
-	    arrowmap.height()-6, 6, 5), m_searchCombo->colorGroup(), arrowFlags, TQStyleOption() );
+	m_searchCombo->tqstyle().tqdrawPrimitive(TQStyle::PE_ArrowDown, &p, TQRect(arrowmap.width()-6, 
+	    arrowmap.height()-6, 6, 5), m_searchCombo->tqcolorGroup(), arrowFlags, TQStyleOption() );
 	p.end();
 	m_searchIcon = arrowmap;
 
@@ -389,7 +389,7 @@ void SearchBarPlugin::showSelectionMenu()
 		for (TQStringList::ConstIterator it = m_searchEngines.begin(); it != m_searchEngines.end(); ++it )
 		{
 			i++;
-			service = KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").arg(*it));
+			service = KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").tqarg(*it));
 			if(!service)
 			{
 				continue;
@@ -413,7 +413,7 @@ void SearchBarPlugin::showSelectionMenu()
 		}
 
 		m_popupMenu->insertSeparator();
-		m_googleMenu = new KSelectAction(i18n("Use Google Suggest"), SmallIconSet("ktip"), 0, this, TQT_SLOT(selectGoogleSuggestMode()), m_popupMenu);
+		m_googleMenu = new KSelectAction(i18n("Use Google Suggest"), SmallIconSet("ktip"), 0, TQT_TQOBJECT(this), TQT_SLOT(selectGoogleSuggestMode()), TQT_TQOBJECT(m_popupMenu));
 		TQStringList google_modes;
                 google_modes << i18n("For Google Only") << i18n("For All Searches") << i18n("Never");
 		m_googleMenu->setItems(google_modes);
@@ -515,7 +515,7 @@ void SearchBarPlugin::configurationChanged()
 
 void SearchBarPlugin::partChanged(KParts::Part *newPart)
 {
-	m_part = ::qt_cast<KHTMLPart*>(newPart);
+	m_part = ::tqqt_cast<KHTMLPart*>(newPart);
 
 	//Delay since when destroying tabs part 0 gets activated for a bit, before the proper part
 	TQTimer::singleShot(0, this, TQT_SLOT(updateComboVisibility()));
@@ -537,9 +537,13 @@ void SearchBarPlugin::updateComboVisibility()
 
 void SearchBarPlugin::focusSearchbar()
 {
+#ifdef USE_QT4
+	m_searchCombo->setFocus();
+#else // USE_QT4
 	TQFocusEvent::setReason( TQFocusEvent::Shortcut );
 	m_searchCombo->setFocus();
 	TQFocusEvent::resetReason();
+#endif // USE_QT4
 }
 
 SearchBarCombo::SearchBarCombo(TQWidget *parent, const char *name) :
@@ -586,7 +590,7 @@ int SearchBarCombo::findHistoryItem(const TQString &searchText)
 
 void SearchBarCombo::mousePressEvent(TQMouseEvent *e)
 {
-	int x0 = TQStyle::visualRect( style().querySubControlMetrics( TQStyle::CC_ComboBox, this, TQStyle::SC_ComboBoxEditField ), this ).x();
+	int x0 = TQStyle::tqvisualRect( tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this, TQStyle::SC_ComboBoxEditField ), this ).x();
 
 	if(e->x() > x0 + 2 && e->x() < lineEdit()->x())
 	{
