@@ -58,7 +58,7 @@ ActionListItem::ActionListItem(TQListBox *listbox, const TQString &action, const
 
 ConfigDialog::ConfigDialog(TQWidget *parent, const char *name) : TQDialog(parent, name)
 {
-  topWidgetName = parent->topLevelWidget()->name();
+  topWidgetName = parent->tqtopLevelWidget()->name();
   config = new KConfig("metabarrc");
   iconConfig = new KConfig(locate("data", "metabar/iconsrc"));
 
@@ -78,7 +78,7 @@ ConfigDialog::ConfigDialog(TQWidget *parent, const char *name) : TQDialog(parent
   TQWidget *general = new TQWidget;
   
   TQGroupBox *entries_group = new TQGroupBox(2, Qt::Horizontal, i18n("Items"), general);
-  entries_group->setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Preferred);
+  entries_group->tqsetSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Preferred);
   
   TQLabel *entries_label = new TQLabel(i18n("Open with:"), entries_group);
   max_entries = new KIntSpinBox(entries_group);
@@ -98,7 +98,7 @@ ConfigDialog::ConfigDialog(TQWidget *parent, const char *name) : TQDialog(parent
   
   
   TQGroupBox *appearance_group = new TQGroupBox(1, Qt::Horizontal, i18n("Appearance"), general);
-  appearance_group->setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Preferred);
+  appearance_group->tqsetSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Preferred);
   
   animate = new TQCheckBox(i18n("Animate resize"), appearance_group);
   animate->setChecked(config->readBoolEntry("AnimateResize", false));
@@ -110,13 +110,13 @@ ConfigDialog::ConfigDialog(TQWidget *parent, const char *name) : TQDialog(parent
   showframe->setChecked(config->readBoolEntry("ShowFrame", true));
   
   TQGroupBox *theme_group = new TQGroupBox(2, Qt::Horizontal, i18n("Themes"), general);
-  theme_group->setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Preferred);
+  theme_group->tqsetSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Preferred);
   
   themes = new KComboBox(theme_group);
-  themes->setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Preferred);
+  themes->tqsetSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Preferred);
   
   install_theme = new KPushButton(i18n("Install New Theme..."), theme_group);
-  install_theme->setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Preferred);
+  install_theme->tqsetSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Preferred);
   connect(install_theme, TQT_SIGNAL(clicked()), this, TQT_SLOT(installTheme()));
   
   loadThemes();
@@ -144,7 +144,7 @@ ConfigDialog::ConfigDialog(TQWidget *parent, const char *name) : TQDialog(parent
   connect(link_down, TQT_SIGNAL(clicked()), this, TQT_SLOT(moveLinkDown()));
     
   link_list = new KListView(links);
-  link_list->setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding);
+  link_list->tqsetSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding);
   link_list->setSorting(-1);
   link_list->setItemsMovable(TRUE);
   link_list->addColumn(i18n("Name"));
@@ -161,7 +161,7 @@ ConfigDialog::ConfigDialog(TQWidget *parent, const char *name) : TQDialog(parent
   tab->addTab(actionPage, i18n("Actions"));
   tab->addTab(links, i18n("Links"));
   
-  //layout  
+  //tqlayout  
   TQGridLayout *general_layout = new TQGridLayout(general, 2, 2, 5, 5);
   general_layout->addWidget(entries_group, 0, 0);
   general_layout->addWidget(appearance_group, 0, 1);
@@ -222,7 +222,7 @@ ConfigDialog::ConfigDialog(TQWidget *parent, const char *name) : TQDialog(parent
       
         ActionListItem *item = new ActionListItem(actionSelector->selectedListBox(), *it, text, SmallIcon("network"));
         
-        TQListBoxItem *avItem = actionSelector->availableListBox()->findItem(text, Qt::ExactMatch);
+        TQListBoxItem *avItem = actionSelector->availableListBox()->findItem(text, TQt::ExactMatch);
         if(avItem){
           delete avItem;
         }
@@ -236,7 +236,7 @@ ConfigDialog::ConfigDialog(TQWidget *parent, const char *name) : TQDialog(parent
       
       ActionListItem *item = new ActionListItem(actionSelector->selectedListBox(), TQString(*it), text, SmallIcon(icon));
       
-      TQListBoxItem *avItem = actionSelector->availableListBox()->findItem(text, Qt::ExactMatch);
+      TQListBoxItem *avItem = actionSelector->availableListBox()->findItem(text, TQt::ExactMatch);
       if(avItem){
         delete avItem;
       }
@@ -320,7 +320,7 @@ void ConfigDialog::createLink()
   TQLineEdit *url = new TQLineEdit("file:/", main);
   
   KIconButton *icon = new KIconButton(main);
-  icon->setSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Minimum);
+  icon->tqsetSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Minimum);
   icon->setIconType(KIcon::Small, KIcon::Any);
   icon->setStrictIconSize(true);
   icon->setIcon("folder");
@@ -330,19 +330,19 @@ void ConfigDialog::createLink()
   bottom_layout->addWidget(ok);
   bottom_layout->addWidget(cancel);
   
-  TQGridLayout *layout = new TQGridLayout(0, 2, 3, 0, 5);
-  layout->addMultiCellWidget(icon, 0, 1, 0, 0);
-  layout->addWidget(new TQLabel(i18n("Name:"), main), 0, 1);
-  layout->addWidget(name, 0, 2);
-  layout->addWidget(new TQLabel(i18n("URL:"), main), 1, 1);
-  layout->addWidget(url, 1, 2);
+  TQGridLayout *tqlayout = new TQGridLayout(0, 2, 3, 0, 5);
+  tqlayout->addMultiCellWidget(icon, 0, 1, 0, 0);
+  tqlayout->addWidget(new TQLabel(i18n("Name:"), main), 0, 1);
+  tqlayout->addWidget(name, 0, 2);
+  tqlayout->addWidget(new TQLabel(i18n("URL:"), main), 1, 1);
+  tqlayout->addWidget(url, 1, 2);
 
   TQVBoxLayout *main_layout = new TQVBoxLayout(main, 5, 5);
-  main_layout->addLayout(layout);
+  main_layout->addLayout(tqlayout);
   main_layout->addItem(new TQSpacerItem(10, 10, TQSizePolicy::Minimum, TQSizePolicy::Expanding));
   main_layout->addLayout(bottom_layout);
   
-  main->resize(300, main->sizeHint().height());
+  main->resize(300, main->tqsizeHint().height());
   
   if(main->exec() == TQDialog::Accepted){
     TQString name_str = name->text();
@@ -403,7 +403,7 @@ void ConfigDialog::editLink(TQListViewItem *item)
     TQLineEdit *url = new TQLineEdit(linkList[item]->url, main);
     
     KIconButton *icon = new KIconButton(main);
-    icon->setSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Minimum);
+    icon->tqsetSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Minimum);
     icon->setIconType(KIcon::Small, KIcon::Any);
     icon->setStrictIconSize(true);
     icon->setIcon(linkList[item]->icon);
@@ -413,19 +413,19 @@ void ConfigDialog::editLink(TQListViewItem *item)
     bottom_layout->addWidget(ok);
     bottom_layout->addWidget(cancel);
     
-    TQGridLayout *layout = new TQGridLayout(0, 2, 3, 0, 5);
-    layout->addMultiCellWidget(icon, 0, 1, 0, 0);
-    layout->addWidget(new TQLabel(i18n("Name:"), main), 0, 1);
-    layout->addWidget(name, 0, 2);
-    layout->addWidget(new TQLabel(i18n("URL:"), main), 1, 1);
-    layout->addWidget(url, 1, 2);
+    TQGridLayout *tqlayout = new TQGridLayout(0, 2, 3, 0, 5);
+    tqlayout->addMultiCellWidget(icon, 0, 1, 0, 0);
+    tqlayout->addWidget(new TQLabel(i18n("Name:"), main), 0, 1);
+    tqlayout->addWidget(name, 0, 2);
+    tqlayout->addWidget(new TQLabel(i18n("URL:"), main), 1, 1);
+    tqlayout->addWidget(url, 1, 2);
     
     TQVBoxLayout *main_layout = new TQVBoxLayout(main, 5, 5);
-    main_layout->addLayout(layout);
+    main_layout->addLayout(tqlayout);
     main_layout->addItem(new TQSpacerItem(10, 10, TQSizePolicy::Minimum, TQSizePolicy::Expanding));
     main_layout->addLayout(bottom_layout);
     
-    main->resize(300, main->sizeHint().height());
+    main->resize(300, main->tqsizeHint().height());
     
     if(main->exec() == TQDialog::Accepted){
       TQString name_str = name->text();
