@@ -7,7 +7,7 @@
 
 #include "gamecore.h"
 
-class FleetDlgListViewItem : public QListViewItem
+class FleetDlgListViewItem : public TQListViewItem
 {
 	public:
 		FleetDlgListViewItem(TQListView *parent, TQString s1, TQString s2, TQString s3, TQString s4, TQString s5);
