@@ -20,9 +20,10 @@ struct planet_info_buffer {
 typedef TQPtrList<planet_info_buffer> PlanetInfoList;
 typedef TQPtrListIterator<planet_info_buffer> PlanetInfoListIterator;
 
-class PlanetInfo : public QFrame
+class PlanetInfo : public TQFrame
 {
     Q_OBJECT
+  TQ_OBJECT
         
 public:
     PlanetInfo( TQWidget *parent, TQPalette palette );
@@ -30,7 +31,7 @@ public:
 
     void setPlanetList( PlanetList &newPlanets );
     void rescanPlanets();
-    TQSize sizeHint() const;
+    TQSize tqsizeHint() const;
     
 public slots:
     void showPlanet( Planet * );
