@@ -20,8 +20,8 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
  *                                                                             *
  * As a special exception, permission is given to link this program            *
- * with any edition of Qt, and distribute the resulting executable,            *
- * without including the source code for Qt in the source distribution.        *
+ * with any edition of TQt, and distribute the resulting executable,            *
+ * without including the source code for TQt in the source distribution.        *
  *                                                                             *
  ******************************************************************************/
 /**
@@ -204,11 +204,11 @@ int main( int argc, char *argv[] )
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
   // Default values for start date/time (today at 07:00)
-  TQDate startdate = TQDate::currentDate();
+  TQDate startdate = TQDate::tqcurrentDate();
   TQTime starttime( 7, 0 );
 
   // Default values for end date/time (today at 17:00)
-  TQDate enddate = TQDate::currentDate();
+  TQDate enddate = TQDate::tqcurrentDate();
   TQTime endtime( 17, 0 );
 
   // Default values for switches
@@ -241,22 +241,22 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "export-list" ) ) {
     cout << endl;
     cout << i18n( "%1 supports these export formats:" ).
-      arg( progDisplay ).local8Bit()
+      tqarg( progDisplay ).local8Bit().data()
          << endl;
     cout << i18n( "  %1 [Default]" ).
-      arg( "Text" ).local8Bit()
+      tqarg( "Text" ).local8Bit().data()
          << endl;
     cout << i18n( "  %1 (like %2, but more compact)" ).
-      arg( "Short", "Text" ).local8Bit()
+      tqarg( "Short", "Text" ).local8Bit().data()
          << endl;
     cout << i18n( "  %1" ).
-      arg( "HTML" ).local8Bit()
+      tqarg( "HTML" ).local8Bit().data()
          << endl;
     cout << i18n( "  %1 (like %2, but in a month view)" ).
-      arg( "HTMLmonth", "HTML" ).local8Bit()
+      tqarg( "HTMLmonth", "HTML" ).local8Bit().data()
          << endl;
     cout << i18n( "  %1 (Comma-Separated Values)" ).
-      arg( "CSV" ).local8Bit()
+      tqarg( "CSV" ).local8Bit().data()
          << endl;
     cout << endl;
     return 0;
@@ -272,14 +272,14 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "todo" ) ) {
     variables.setUseTodos( true );
     kdDebug() << "main | parse options | use To-dos" << endl;
-    cout << i18n( "Sorry, To-dos are not working yet." ).local8Bit()
+    cout << i18n( "Sorry, To-dos are not working yet." ).local8Bit().data()
          << endl;
     return 1;
   }
   if ( args->isSet( "journal" ) ) {
     variables.setUseJournals( true );
     kdDebug() << "main | parse options | use Journals" << endl;
-    cout << i18n( "Sorry, Journals are not working yet." ).local8Bit()
+    cout << i18n( "Sorry, Journals are not working yet." ).local8Bit().data()
          << endl;
     return 1;
   }
@@ -315,7 +315,7 @@ int main( int argc, char *argv[] )
       variables.setExportType( ExportTypeTextShort );
     } else {
       cout << i18n( "Invalid Export Type Specified: %1" ).
-        arg( option ).local8Bit()
+        tqarg( option ).local8Bit().data()
            << endl;
       return 1;
     }
@@ -475,13 +475,13 @@ int main( int argc, char *argv[] )
     startdate = TQDate::fromString( option, Qt::ISODate );
     if ( !startdate.isValid() ) {
       cout << i18n( "Invalid Start Date Specified: %1" ).
-        arg( option ).local8Bit()
+        tqarg( option ).local8Bit().data()
            << endl;
       return 1;
     }
     kdDebug() << "main | parse options | "
               << "Start date after conversion: "
-              << "(" << startdate.toString() << ")"
+              << "(" << TQString(startdate.toString()) << ")"
               << endl;
   }
 
@@ -500,13 +500,13 @@ int main( int argc, char *argv[] )
       starttime = TQTime::fromString( option, Qt::ISODate );
       if ( !starttime.isValid() ) {
         cout << i18n( "Invalid Start Time Specified: %1" ).
-          arg( option ).local8Bit()
+          tqarg( option ).local8Bit().data()
              << endl;
         return 1;
       }
       kdDebug() << "main | parse options | "
                 << "Start time after conversion: "
-                << "(" << starttime.toString() << ")"
+                << "(" << TQString(starttime.toString()) << ")"
                 << endl;
     } else {
       variables.setFloating( true );
@@ -530,13 +530,13 @@ int main( int argc, char *argv[] )
     enddate = TQDate::fromString( option, Qt::ISODate );
     if ( !enddate.isValid() ) {
       cout << i18n( "Invalid End Date Specified: %1" ).
-        arg( option ).local8Bit()
+        tqarg( option ).local8Bit().data()
            << endl;
       return 1;
     }
     kdDebug() << "main | parse options | "
               << "End date after conversion: "
-              << "(" << enddate.toString() << ")"
+              << "(" << TQString(enddate.toString()) << ")"
               << endl;
   }
 
@@ -554,7 +554,7 @@ int main( int argc, char *argv[] )
 
     if ( !ok ) {
       cout << i18n( "Invalid Date Count Specified: %1" ).
-        arg( option ).local8Bit()
+        tqarg( option ).local8Bit().data()
            << endl;
       return 1;
     }
@@ -563,7 +563,7 @@ int main( int argc, char *argv[] )
     enddate = enddate.addDays( variables.getDaysCount() );
     kdDebug() << "main | parse options | "
               << "End date after conversion: "
-              << "(" << enddate.toString() << ")"
+              << "(" << TQString(enddate.toString()) << ")"
               << endl;
   }
 
@@ -582,14 +582,14 @@ int main( int argc, char *argv[] )
       endtime = TQTime::fromString( option, Qt::ISODate );
       if ( !endtime.isValid() ) {
         cout << i18n( "Invalid End Time Specified: %1" ).
-          arg( option ).local8Bit()
+          tqarg( option ).local8Bit().data()
              << endl;
         return 1;
       }
 
       kdDebug() << "main | parse options | "
                 << "End time after conversion: "
-                << "(" << endtime.toString() << ")"
+                << "(" << TQString(endtime.toString()) << ")"
                 << endl;
     } else {
       variables.setFloating( true );
@@ -682,12 +682,12 @@ int main( int argc, char *argv[] )
 
       if ( remote ) {
         cout << i18n( "Attempting to create a remote file %1" ).
-          arg( variables.getCalendarFile() ).local8Bit() << endl;
+          tqarg( variables.getCalendarFile() ).local8Bit().data() << endl;
         return 1;
       } else {
         if ( exists ) {
           cout << i18n( "Calendar %1 already exists" ).
-            arg( variables.getCalendarFile() ).local8Bit()
+            tqarg( variables.getCalendarFile() ).local8Bit().data()
                << endl;
           return 1;
         }
@@ -695,12 +695,12 @@ int main( int argc, char *argv[] )
 
       if ( konsolekalendar->createCalendar() ) {
         cout << i18n( "Calendar %1 successfully created" ).
-          arg( variables.getCalendarFile() ).local8Bit()
+          tqarg( variables.getCalendarFile() ).local8Bit().data()
              << endl;
         return 0;
       } else {
         cout << i18n( "Unable to create calendar: %1" ).
-          arg( variables.getCalendarFile() ).local8Bit()
+          tqarg( variables.getCalendarFile() ).local8Bit().data()
              << endl;
         return 1;
       }
@@ -708,9 +708,9 @@ int main( int argc, char *argv[] )
 
     if ( !exists ) {
       cout << i18n( "Calendar file not found %1" ).
-        arg( variables.getCalendarFile() ).local8Bit()
+        tqarg( variables.getCalendarFile() ).local8Bit().data()
            << endl;
-      cout << i18n( "Try --create to create new calendar file" ).local8Bit()
+      cout << i18n( "Try --create to create new calendar file" ).local8Bit().data()
            << endl;
       return 1;
     }
@@ -870,7 +870,7 @@ int main( int argc, char *argv[] )
       "Only 1 operation mode "
       "(view, add, change, delete, create) "
       "permitted at any one time"
-      ).local8Bit() << endl;
+      ).local8Bit().data() << endl;
     return 1;
   }
 
@@ -878,7 +878,7 @@ int main( int argc, char *argv[] )
   if ( startdatetime > enddatetime ) {
     cout << i18n(
       "Ending Date/Time occurs before the Starting Date/Time"
-      ).local8Bit() << endl;
+      ).local8Bit().data() << endl;
     return 1;
   }
 
@@ -894,17 +894,17 @@ int main( int argc, char *argv[] )
    */
   TQString prodId = "-//K Desktop Environment//NONSGML %1 %2//EN";
   CalFormat::setApplication( progDisplay,
-                             prodId.arg( progDisplay ).arg( progVersion ) );
+                             prodId.tqarg( progDisplay ).tqarg( progVersion ) );
 
   if ( importFile ) {
     if ( konsolekalendar->importCalendar() ) {
       cout << i18n( "Calendar %1 successfully imported" ).
-        arg( variables.getImportFile() ).local8Bit()
+        tqarg( variables.getImportFile() ).local8Bit().data()
            << endl;
       return 0;
     } else {
       cout << i18n( "Unable to import calendar: %1" ).
-        arg( variables.getImportFile() ).local8Bit()
+        tqarg( variables.getImportFile() ).local8Bit().data()
            << endl;
       return 1;
     }
@@ -920,7 +920,7 @@ int main( int argc, char *argv[] )
     } else {
       cout << i18n(
         "Attempting to insert an event that already exists"
-        ).local8Bit() << endl;
+        ).local8Bit().data() << endl;
       return 1;
     }
   }
@@ -931,12 +931,12 @@ int main( int argc, char *argv[] )
               << endl;
     if ( !variables.isUID() ) {
       cout << i18n( "Missing event UID: "
-                    "use --uid command line option" ).local8Bit()
+                    "use --uid command line option" ).local8Bit().data()
            << endl;
       return 1;
     }
     if ( konsolekalendar->changeEvent() != true ) {
-      cout << i18n( "No such event UID: change event failed" ).local8Bit()
+      cout << i18n( "No such event UID: change event failed" ).local8Bit().data()
            << endl;
       return 1;
     }
@@ -951,12 +951,12 @@ int main( int argc, char *argv[] )
               << endl;
     if ( !variables.isUID() ) {
       cout << i18n( "Missing event UID: "
-                    "use --uid command line option" ).local8Bit()
+                    "use --uid command line option" ).local8Bit().data()
            << endl;
       return 1;
     }
     if ( konsolekalendar->deleteEvent() != true ) {
-      cout << i18n( "No such event UID: delete event failed").local8Bit()
+      cout << i18n( "No such event UID: delete event failed").local8Bit().data()
            << endl;
       return 1;
     }
@@ -971,7 +971,7 @@ int main( int argc, char *argv[] )
               << endl;
     if ( !konsolekalendar->showInstance() ) {
       cout << i18n( "Cannot open specified export file: %1" ).
-        arg( variables.getExportFile() ).local8Bit()
+        tqarg( variables.getExportFile() ).local8Bit().data()
            << endl;
       return 1;
     }
