@@ -96,7 +96,7 @@ class SettingsDialogWrapper : public KSettings::Dialog
     void fixButtonLabel( TQWidget *widget )
     {
       TQObject *object = widget->child( "KJanusWidget::buttonBelowList" );
-      TQPushButton *button = static_cast<TQPushButton*>( object );
+      TQPushButton *button = static_cast<TQPushButton*>( TQT_TQWIDGET(object) );
       if ( button )
         button->setText( i18n( "Select Components ..." ) );
     }
@@ -124,8 +124,8 @@ void MainWindow::initGUI()
            TQT_SLOT( showAboutDialog() ) );
 
   KTrader::OfferList offers = KTrader::self()->query(
-      TQString::fromLatin1( "Kontact/Plugin" ),
-      TQString( "[X-KDE-KontactPluginVersion] == %1" ).arg( KONTACT_PLUGIN_VERSION ) );
+      TQString::tqfromLatin1( "Kontact/Plugin" ),
+      TQString( "[X-KDE-KontactPluginVersion] == %1" ).tqarg( KONTACT_PLUGIN_VERSION ) );
   mPluginInfos = KPluginInfo::fromServices( offers, Prefs::self()->config(), "Plugins" );
 
   KPluginInfo::List::Iterator it;
@@ -133,10 +133,10 @@ void MainWindow::initGUI()
     (*it)->load();
 
     KAction *action = new KAction( (*it)->name(), (*it)->icon(), KShortcut(),
-                                   this, TQT_SLOT(slotActionTriggered()),
+                                   TQT_TQOBJECT(this), TQT_SLOT(slotActionTriggered()),
                                    actionCollection(), (*it)->pluginName().latin1() );
     action->setName( (*it)->pluginName().latin1() );
-    action->setWhatsThis( i18n( "Switch to plugin %1" ).arg( (*it)->name() ) );
+    action->setWhatsThis( i18n( "Switch to plugin %1" ).tqarg( (*it)->name() ) );
 
     TQVariant hasPartProp = (*it)->property( "X-KDE-KontactPluginHasPart" );
     if ( !hasPartProp.isValid() || hasPartProp.toBool() ) {
@@ -144,8 +144,8 @@ void MainWindow::initGUI()
     }
   }
 
-  KStdAction::keyBindings( this, TQT_SLOT( configureShortcuts() ), actionCollection() );
-  KStdAction::configureToolbars( this, TQT_SLOT( configureToolbars() ), actionCollection() );
+  KStdAction::keyBindings( TQT_TQOBJECT(this), TQT_SLOT( configureShortcuts() ), actionCollection() );
+  KStdAction::configureToolbars( TQT_TQOBJECT(this), TQT_SLOT( configureToolbars() ), actionCollection() );
   setXMLFile( "kontactui.rc" );
 
   setStandardToolBarMenuEnabled( true );
@@ -175,7 +175,7 @@ void MainWindow::initObject()
     mSidePane->updatePlugins();
   }
 
-  KSettings::Dispatcher::self()->registerInstance( instance(), this,
+  KSettings::Dispatcher::self()->registerInstance( instance(), TQT_TQOBJECT(this),
                                                    TQT_SLOT( updateConfig() ) );
 
   loadSettings();
@@ -185,7 +185,7 @@ void MainWindow::initObject()
   showTip( false );
 
   // done initializing
-  slotShowStatusMsg( TQString::null );
+  slotShowStatusMsg( TQString() );
 
   connect( KPIM::BroadcastStatus::instance(), TQT_SIGNAL( statusMsg( const TQString& ) ),
            this, TQT_SLOT( slotShowStatusMsg( const TQString&  ) ) );
@@ -244,7 +244,7 @@ void MainWindow::initWidgets()
   mSplitter = new TQSplitter( mTopWidget );
   mBox = new TQHBox( mTopWidget );
   mSidePane = new IconSidePane( this, mSplitter );
-  mSidePane->setSizePolicy( TQSizePolicy( TQSizePolicy::Maximum,
+  mSidePane->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Maximum,
                                          TQSizePolicy::Preferred ) );
   // donÄt occupy screen estate on load
   TQValueList<int> sizes;
@@ -267,7 +267,7 @@ void MainWindow::initWidgets()
   initAboutScreen();
 
   TQString loading = i18n( "<h2 style='text-align:center; margin-top: 0px; margin-bottom: 0px'>%1</h2>" )
-                    .arg( i18n("Loading Kontact...") );
+                    .tqarg( i18n("Loading Kontact...") );
 
   paintAboutScreen( loading );
 
@@ -278,7 +278,7 @@ void MainWindow::initWidgets()
   mLittleProgress = new KPIM::StatusbarProgressWidget( progressDialog, statusBar() );
 
   mStatusMsgLabel = new KRSqueezedTextLabel( i18n( " Initializing..." ), statusBar() );
-  mStatusMsgLabel->setAlignment( AlignLeft | AlignVCenter );
+  mStatusMsgLabel->tqsetAlignment( AlignLeft | AlignVCenter );
 
   statusBar()->addWidget( mStatusMsgLabel, 10 , false );
   statusBar()->addWidget( mLittleProgress, 0 , true );
@@ -290,11 +290,11 @@ void MainWindow::paintAboutScreen( const TQString& msg )
 {
   TQString location = locate( "data", "kontact/about/main.html" );
   TQString content = KPIM::kFileToString( location );
-  content = content.arg( locate( "data", "libkdepim/about/kde_infopage.css" ) );
+  content = content.tqarg( locate( "data", "libkdepim/about/kde_infopage.css" ) );
   if ( kapp->reverseLayout() )
-    content = content.arg( "@import \"%1\";" ).arg( locate( "data", "libkdepim/about/kde_infopage_rtl.css" ) );
+    content = content.tqarg( "@import \"%1\";" ).tqarg( locate( "data", "libkdepim/about/kde_infopage_rtl.css" ) );
   else
-    content = content.arg( "" );
+    content = content.tqarg( "" );
 
   mIntroPart->begin( KURL( location ) );
 
@@ -302,8 +302,8 @@ void MainWindow::paintAboutScreen( const TQString& msg )
   TQString catchPhrase( i18n( "Get Organized!" ) );
   TQString quickDescription( i18n( "The KDE Personal Information Management Suite" ) );
 
-  mIntroPart->write( content.arg( TQFont().pointSize() + 2 ).arg( appName )
-      .arg( catchPhrase ).arg( quickDescription ).arg( msg ) );
+  mIntroPart->write( content.tqarg( TQFont().pointSize() + 2 ).tqarg( appName )
+      .tqarg( catchPhrase ).tqarg( quickDescription ).tqarg( msg ) );
   mIntroPart->end();
 }
 
@@ -313,7 +313,7 @@ void MainWindow::initAboutScreen()
   mPartsStack->addWidget( introbox );
   mPartsStack->raiseWidget( introbox );
   mIntroPart = new KHTMLPart( introbox );
-  mIntroPart->widget()->setFocusPolicy( WheelFocus );
+  mIntroPart->widget()->setFocusPolicy( TQ_WheelFocus );
   // Let's better be paranoid and disable plugins (it defaults to enabled):
   mIntroPart->setPluginsEnabled( false );
   mIntroPart->setJScriptEnabled( false ); // just make this explicit
@@ -333,9 +333,9 @@ void MainWindow::initAboutScreen()
 
 void MainWindow::setupActions()
 {
-  KStdAction::quit( this, TQT_SLOT( slotQuit() ), actionCollection() );
+  KStdAction::quit( TQT_TQOBJECT(this), TQT_SLOT( slotQuit() ), actionCollection() );
   mNewActions = new KToolBarPopupAction( KGuiItem( i18n( "New" ), "" ),
-                                         KStdAccel::shortcut(KStdAccel::New), this, TQT_SLOT( slotNewClicked() ),
+                                         KStdAccel::shortcut(KStdAccel::New), TQT_TQOBJECT(this), TQT_SLOT( slotNewClicked() ),
                                          actionCollection(), "action_new" );
 
   KConfig* const cfg = Prefs::self()->config();
@@ -344,18 +344,18 @@ void MainWindow::setupActions()
 
   if ( mSyncActionsEnabled ) {
     mSyncActions = new KToolBarPopupAction( KGuiItem( i18n( "Synchronize" ), "kitchensync" ),
-                                            KStdAccel::shortcut(KStdAccel::Reload), this, TQT_SLOT( slotSyncClicked() ),
+                                            KStdAccel::shortcut(KStdAccel::Reload), TQT_TQOBJECT(this), TQT_SLOT( slotSyncClicked() ),
                                             actionCollection(), "action_sync" );
   }
-  new KAction( i18n( "Configure Kontact..." ), "configure", 0, this, TQT_SLOT( slotPreferences() ),
+  new KAction( i18n( "Configure Kontact..." ), "configure", 0, TQT_TQOBJECT(this), TQT_SLOT( slotPreferences() ),
                actionCollection(), "settings_configure_kontact" );
 
-  new KAction( i18n( "Configure &Profiles..." ), 0, this, TQT_SLOT( slotConfigureProfiles() ),
+  new KAction( i18n( "Configure &Profiles..." ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotConfigureProfiles() ),
                actionCollection(), "settings_configure_kontact_profiles" );
 
-  new KAction( i18n( "&Kontact Introduction" ), 0, this, TQT_SLOT( slotShowIntroduction() ),
+  new KAction( i18n( "&Kontact Introduction" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotShowIntroduction() ),
                actionCollection(), "help_introduction" );
-  new KAction( i18n( "&Tip of the Day" ), 0, this, TQT_SLOT( slotShowTip() ),
+  new KAction( i18n( "&Tip of the Day" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotShowTip() ),
                actionCollection(), "help_tipofday" );
 
   KWidgetAction* spacerAction = new KWidgetAction( new TQWidget( this ), "SpacerAction", "", 0, 0, actionCollection(), "navigator_spacer_item" );
@@ -543,7 +543,7 @@ void MainWindow::loadPlugins()
     kdDebug(5600) << "Loading Plugin: " << (*it)->name() << endl;
     Kontact::Plugin *plugin =
       KParts::ComponentFactory::createInstanceFromService<Kontact::Plugin>(
-          (*it)->service(), this );
+          (*it)->service(), TQT_TQOBJECT(this) );
 
     if ( !plugin )
       continue;
@@ -629,7 +629,7 @@ void MainWindow::updateShortcuts()
     ++it;
     if ( isPluginLoadedByAction( action ) ) {
       loadedActions.append( action );
-      TQString shortcut = TQString( "CTRL+%1" ).arg( i );
+      TQString shortcut = TQString( "CTRL+%1" ).tqarg( i );
       action->setShortcut( KShortcut( shortcut ) );
       i++;
     } else {
@@ -763,7 +763,7 @@ void MainWindow::slotSyncClicked()
 KToolBar* Kontact::MainWindow::findToolBar(const char* name)
 {
   // like KMainWindow::toolBar, but which doesn't create the toolbar if not found
-  return static_cast<KToolBar *>(child(name, "KToolBar"));
+  return static_cast<KToolBar *>(TQT_TQWIDGET(child(name, "KToolBar")));
 }
 
 void MainWindow::slotActionTriggered()
@@ -787,14 +787,14 @@ void MainWindow::selectPlugin( Kontact::Plugin *plugin )
     return;
   }
 
-  KApplication::setOverrideCursor( TQCursor( Qt::WaitCursor ) );
+  KApplication::setOverrideCursor( TQCursor( TQt::WaitCursor ) );
 
   KParts::Part *part = plugin->part();
 
   if ( !part ) {
     KApplication::restoreOverrideCursor();
     KMessageBox::error( this, i18n( "Cannot load part for %1." )
-                              .arg( plugin->title() )
+                              .tqarg( plugin->title() )
                         + "\n" + lastErrorMessage() );
     plugin->setDisabled( true );
     mSidePane->updatePlugins();
@@ -802,13 +802,13 @@ void MainWindow::selectPlugin( Kontact::Plugin *plugin )
   }
 
   // store old focus widget
-  TQWidget *focusWidget = kapp->focusWidget();
-  if ( mCurrentPlugin && focusWidget ) {
+  TQWidget *tqfocusWidget = kapp->tqfocusWidget();
+  if ( mCurrentPlugin && tqfocusWidget ) {
     // save the focus widget only when it belongs to the activated part
-    TQWidget *parent = focusWidget->parentWidget();
+    TQWidget *parent = tqfocusWidget->parentWidget();
     while ( parent ) {
       if ( parent == mCurrentPlugin->part()->widget() )
-        mFocusWidgets.insert( mCurrentPlugin->identifier(), TQGuardedPtr<TQWidget>( focusWidget ) );
+        mFocusWidgets.insert( mCurrentPlugin->identifier(), TQGuardedPtr<TQWidget>( tqfocusWidget ) );
 
       parent = parent->parentWidget();
     }
@@ -829,9 +829,9 @@ void MainWindow::selectPlugin( Kontact::Plugin *plugin )
     view->show();
 
     if ( mFocusWidgets.contains( plugin->identifier() ) ) {
-      focusWidget = mFocusWidgets[ plugin->identifier() ];
-      if ( focusWidget )
-        focusWidget->setFocus();
+      tqfocusWidget = mFocusWidgets[ plugin->identifier() ];
+      if ( tqfocusWidget )
+        tqfocusWidget->setFocus();
     } else
       view->setFocus();
 
@@ -848,7 +848,7 @@ void MainWindow::selectPlugin( Kontact::Plugin *plugin )
       topDock()->moveDockWindow( navigatorToolBar, -1 );
     }
 
-    setCaption( i18n( "Plugin dependent window title" ,"%1 - Kontact" ).arg( plugin->title() ) );
+    setCaption( i18n( "Plugin dependent window title" ,"%1 - Kontact" ).tqarg( plugin->title() ) );
 
     if ( newAction ) {
       mNewActions->setIcon( newAction->icon() );
@@ -1027,7 +1027,7 @@ void MainWindow::updateConfig()
 
 void MainWindow::showAboutDialog()
 {
-  KApplication::setOverrideCursor( TQCursor( Qt::WaitCursor ) );
+  KApplication::setOverrideCursor( TQCursor( TQt::WaitCursor ) );
 
   if ( !mAboutDialog )
     mAboutDialog = new AboutDialog( this );
@@ -1084,7 +1084,7 @@ void MainWindow::slotOpenUrl( const KURL &url )
       if ( !url.query().isEmpty() ) {
         app = url.query().mid( 1 );
       }
-      kapp->invokeHelp( TQString::null, app );
+      kapp->invokeHelp( TQString(), app );
     }
   } else {
     new KRun( url, this );
@@ -1178,30 +1178,30 @@ TQString MainWindow::introductionString()
       "<td><a href=\"%1\">%1</a><br><span id=\"subtext\"><nobr>%1</td></tr>"
       "</table>"
       "<p style=\"margin-bottom: 0px\"> <a href=\"%1\">Skip this introduction</a></p>" )
-      .arg( kapp->aboutData()->version() )
-      .arg( i18n( "Kontact handles your e-mail, addressbook, calendar, to-do list and more." ) )
-      .arg( "exec:/help?kontact" )
-      .arg( iconSize )
-      .arg( iconSize )
-      .arg( handbook_icon_path )
-      .arg( "exec:/help?kontact" )
-      .arg( i18n( "Read Manual" ) )
-      .arg( i18n( "Learn more about Kontact and its components" ) )
-      .arg( "http://kontact.org" )
-      .arg( iconSize )
-      .arg( iconSize )
-      .arg( html_icon_path )
-      .arg( "http://kontact.org" )
-      .arg( i18n( "Visit Kontact Website" ) )
-      .arg( i18n( "Access online resources and tutorials" ) )
-      .arg( "exec:/gwwizard" )
-      .arg( iconSize )
-      .arg( iconSize )
-      .arg( wizard_icon_path )
-      .arg( "exec:/gwwizard" )
-      .arg( i18n( "Configure Kontact as Groupware Client" ) )
-      .arg( i18n( "Prepare Kontact for use in corporate networks" ) )
-      .arg( "exec:/switch" );
+      .tqarg( kapp->aboutData()->version() )
+      .tqarg( i18n( "Kontact handles your e-mail, addressbook, calendar, to-do list and more." ) )
+      .tqarg( "exec:/help?kontact" )
+      .tqarg( iconSize )
+      .tqarg( iconSize )
+      .tqarg( handbook_icon_path )
+      .tqarg( "exec:/help?kontact" )
+      .tqarg( i18n( "Read Manual" ) )
+      .tqarg( i18n( "Learn more about Kontact and its components" ) )
+      .tqarg( "http://kontact.org" )
+      .tqarg( iconSize )
+      .tqarg( iconSize )
+      .tqarg( html_icon_path )
+      .tqarg( "http://kontact.org" )
+      .tqarg( i18n( "Visit Kontact Website" ) )
+      .tqarg( i18n( "Access online resources and tutorials" ) )
+      .tqarg( "exec:/gwwizard" )
+      .tqarg( iconSize )
+      .tqarg( iconSize )
+      .tqarg( wizard_icon_path )
+      .tqarg( "exec:/gwwizard" )
+      .tqarg( i18n( "Configure Kontact as Groupware Client" ) )
+      .tqarg( i18n( "Prepare Kontact for use in corporate networks" ) )
+      .tqarg( "exec:/switch" );
   return info;
 }
 
