@@ -185,17 +185,17 @@ KopeteChatWindow::KopeteChatWindow( TQWidget *parent, const char* name )
 
 	mainArea = new TQFrame( vBox );
 	mainArea->setLineWidth( 0 );
-	mainArea->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
+	mainArea->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
 	mainLayout = new TQVBoxLayout( mainArea );
 
 	if ( KopetePrefs::prefs()->chatWShowSend() )
 	{
 		//Send Button
 		m_button_send = new KPushButton( i18n("Send"), statusBar() );
-		m_button_send->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
+		m_button_send->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
 		m_button_send->setEnabled( false );
 		m_button_send->setFont( statusBar()->font() );
-		m_button_send->setFixedHeight( statusBar()->sizeHint().height() );
+		m_button_send->setFixedHeight( statusBar()->tqsizeHint().height() );
 		connect( m_button_send, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotSendMessage() ) );
 		statusBar()->addWidget( m_button_send, 0, true );
 	}
@@ -203,20 +203,20 @@ KopeteChatWindow::KopeteChatWindow( TQWidget *parent, const char* name )
 		m_button_send = 0L;
 
 	m_status_text = new KSqueezedTextLabel( i18n("Ready."), statusBar(), "m_status_text" );
-	m_status_text->setAlignment( AlignLeft | AlignVCenter );
+	m_status_text->tqsetAlignment( AlignLeft | AlignVCenter );
 	m_status_text->setFont( statusBar()->font() );
-	m_status_text->setFixedHeight( statusBar()->sizeHint().height() );
+	m_status_text->setFixedHeight( statusBar()->tqsizeHint().height() );
 	statusBar()->addWidget( m_status_text, 1 );
 
 	readOptions();
-	setWFlags( Qt::WDestructiveClose );
+	setWFlags( TQt::WDestructiveClose );
 
 	windows.append( this );
 	windowListChanged();
 
-	KGlobal::config()->setGroup( TQString::fromLatin1("ChatWindowSettings") );
-	m_alwaysShowTabs = KGlobal::config()->readBoolEntry( TQString::fromLatin1("AlwaysShowTabs"), false );
-	m_showFormatToolbar = KGlobal::config()->readBoolEntry( TQString::fromLatin1("Show Format Toolbar"), true );
+	KGlobal::config()->setGroup( TQString::tqfromLatin1("ChatWindowSettings") );
+	m_alwaysShowTabs = KGlobal::config()->readBoolEntry( TQString::tqfromLatin1("AlwaysShowTabs"), false );
+	m_showFormatToolbar = KGlobal::config()->readBoolEntry( TQString::tqfromLatin1("Show Format Toolbar"), true );
 	adjustingFormatToolbar = false;
 //	kdDebug( 14010 ) << k_funcinfo << "Open Windows: " << windows.count() << endl;
 	kapp->ref();
@@ -313,32 +313,32 @@ void KopeteChatWindow::initActions(void)
 
 	createStandardStatusBarAction();
 
-	chatSend = new KAction( i18n( "&Send Message" ), TQString::fromLatin1( "mail_send" ), TQKeySequence(Key_Return) ,
-		this, TQT_SLOT( slotSendMessage() ), coll, "chat_send" );
+	chatSend = new KAction( i18n( "&Send Message" ), TQString::tqfromLatin1( "mail_send" ), TQKeySequence(Key_Return) ,
+		TQT_TQOBJECT(this), TQT_SLOT( slotSendMessage() ), coll, "chat_send" );
 	chatSend->setEnabled( false );
 
- 	KStdAction::save ( this, TQT_SLOT(slotChatSave()), coll );
- 	KStdAction::print ( this, TQT_SLOT(slotChatPrint()), coll );
-	KAction* quitAction = KStdAction::quit ( this, TQT_SLOT(close()), coll );
+ 	KStdAction::save ( TQT_TQOBJECT(this), TQT_SLOT(slotChatSave()), coll );
+ 	KStdAction::print ( TQT_TQOBJECT(this), TQT_SLOT(slotChatPrint()), coll );
+	KAction* quitAction = KStdAction::quit ( TQT_TQOBJECT(this), TQT_SLOT(close()), coll );
 	quitAction->setText( i18n("Close All Chats") );
 
-	tabClose = KStdAction::close ( this, TQT_SLOT(slotChatClosed()), coll, "tabs_close" );
+	tabClose = KStdAction::close ( TQT_TQOBJECT(this), TQT_SLOT(slotChatClosed()), coll, "tabs_close" );
 
 	tabRight=new KAction( i18n( "&Activate Next Tab" ), 0, KStdAccel::tabNext(),
-		this, TQT_SLOT( slotNextTab() ), coll, "tabs_right" );
+		TQT_TQOBJECT(this), TQT_SLOT( slotNextTab() ), coll, "tabs_right" );
 	tabLeft=new KAction( i18n( "&Activate Previous Tab" ), 0, KStdAccel::tabPrev(),
-		this, TQT_SLOT( slotPreviousTab() ), coll, "tabs_left" );
+		TQT_TQOBJECT(this), TQT_SLOT( slotPreviousTab() ), coll, "tabs_left" );
 	tabLeft->setEnabled( false );
 	tabRight->setEnabled( false );
 
-	nickComplete = new KAction( i18n( "Nic&k Completion" ), TQString::null, 0, this, TQT_SLOT( slotNickComplete() ), coll , "nick_compete");
+	nickComplete = new KAction( i18n( "Nic&k Completion" ), TQString(), 0, TQT_TQOBJECT(this), TQT_SLOT( slotNickComplete() ), coll , "nick_compete");
 	nickComplete->setShortcut( TQKeySequence( Key_Tab ) );
 
-	tabDetach = new KAction( i18n( "&Detach Chat" ), TQString::fromLatin1( "tab_breakoff" ), 0,
-		this, TQT_SLOT( slotDetachChat() ), coll, "tabs_detach" );
+	tabDetach = new KAction( i18n( "&Detach Chat" ), TQString::tqfromLatin1( "tab_breakoff" ), 0,
+		TQT_TQOBJECT(this), TQT_SLOT( slotDetachChat() ), coll, "tabs_detach" );
 	tabDetach->setEnabled( false );
 
-	actionDetachMenu = new KActionMenu( i18n( "&Move Tab to Window" ), TQString::fromLatin1( "tab_breakoff" ), coll, "tabs_detachmove" );
+	actionDetachMenu = new KActionMenu( i18n( "&Move Tab to Window" ), TQString::tqfromLatin1( "tab_breakoff" ), coll, "tabs_detachmove" );
 	actionDetachMenu->setDelayed( false );
 
 	connect ( actionDetachMenu->popupMenu(), TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(slotPrepareDetachMenu()) );
@@ -350,36 +350,36 @@ void KopeteChatWindow::initActions(void)
 
 	tabDetach->setShortcut( TQKeySequence(CTRL + SHIFT + Key_B) );
 
-	KStdAction::cut( this, TQT_SLOT(slotCut()), coll);
-	KStdAction::copy( this, TQT_SLOT(slotCopy()), coll);
-	KStdAction::paste( this, TQT_SLOT(slotPaste()), coll);
+	KStdAction::cut( TQT_TQOBJECT(this), TQT_SLOT(slotCut()), coll);
+	KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT(slotCopy()), coll);
+	KStdAction::paste( TQT_TQOBJECT(this), TQT_SLOT(slotPaste()), coll);
 
-	new KAction( i18n( "Set Default &Font..." ), TQString::fromLatin1( "charset" ), 0, this, TQT_SLOT( slotSetFont() ), coll, "format_font" );
-	new KAction( i18n( "Set Default Text &Color..." ), TQString::fromLatin1( "pencil" ), 0, this, TQT_SLOT( slotSetFgColor() ), coll, "format_fgcolor" );
-	new KAction( i18n( "Set &Background Color..." ), TQString::fromLatin1( "fill" ), 0, this, TQT_SLOT( slotSetBgColor() ), coll, "format_bgcolor" );
+	new KAction( i18n( "Set Default &Font..." ), TQString::tqfromLatin1( "charset" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotSetFont() ), coll, "format_font" );
+	new KAction( i18n( "Set Default Text &Color..." ), TQString::tqfromLatin1( "pencil" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotSetFgColor() ), coll, "format_fgcolor" );
+	new KAction( i18n( "Set &Background Color..." ), TQString::tqfromLatin1( "fill" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotSetBgColor() ), coll, "format_bgcolor" );
 
-	historyUp = new KAction( i18n( "Previous History" ), TQString::null, 0,
-		this, TQT_SLOT( slotHistoryUp() ), coll, "history_up" );
+	historyUp = new KAction( i18n( "Previous History" ), TQString(), 0,
+		TQT_TQOBJECT(this), TQT_SLOT( slotHistoryUp() ), coll, "history_up" );
 	historyUp->setShortcut( TQKeySequence(CTRL + Key_Up) );
 
-	historyDown = new KAction( i18n( "Next History" ), TQString::null, 0,
-		this, TQT_SLOT( slotHistoryDown() ), coll, "history_down" );
+	historyDown = new KAction( i18n( "Next History" ), TQString(), 0,
+		TQT_TQOBJECT(this), TQT_SLOT( slotHistoryDown() ), coll, "history_down" );
 	historyDown->setShortcut( TQKeySequence(CTRL + Key_Down) );
 
-	KStdAction::prior( this, TQT_SLOT( slotPageUp() ), coll, "scroll_up" );
-	KStdAction::next( this, TQT_SLOT( slotPageDown() ), coll, "scroll_down" );
+	KStdAction::prior( TQT_TQOBJECT(this), TQT_SLOT( slotPageUp() ), coll, "scroll_up" );
+	KStdAction::next( TQT_TQOBJECT(this), TQT_SLOT( slotPageDown() ), coll, "scroll_down" );
 
-	KStdAction::showMenubar( this, TQT_SLOT(slotViewMenuBar()), coll );
+	KStdAction::showMenubar( TQT_TQOBJECT(this), TQT_SLOT(slotViewMenuBar()), coll );
 
-	membersLeft = new KToggleAction( i18n( "Place to Left of Chat Area" ), TQString::null, 0,
-		this, TQT_SLOT( slotViewMembersLeft() ), coll, "options_membersleft" );
-	membersRight = new KToggleAction( i18n( "Place to Right of Chat Area" ), TQString::null, 0,
-		this, TQT_SLOT( slotViewMembersRight() ), coll, "options_membersright" );
-	toggleMembers = new KToggleAction( i18n( "Show" ), TQString::null, 0,
-		this, TQT_SLOT( slotToggleViewMembers() ), coll, "options_togglemembers" );
+	membersLeft = new KToggleAction( i18n( "Place to Left of Chat Area" ), TQString(), 0,
+		TQT_TQOBJECT(this), TQT_SLOT( slotViewMembersLeft() ), coll, "options_membersleft" );
+	membersRight = new KToggleAction( i18n( "Place to Right of Chat Area" ), TQString(), 0,
+		TQT_TQOBJECT(this), TQT_SLOT( slotViewMembersRight() ), coll, "options_membersright" );
+	toggleMembers = new KToggleAction( i18n( "Show" ), TQString(), 0,
+		TQT_TQOBJECT(this), TQT_SLOT( slotToggleViewMembers() ), coll, "options_togglemembers" );
 	toggleMembers->setCheckedState(i18n("Hide"));
-	toggleAutoSpellCheck = new KToggleAction( i18n( "Automatic Spell Checking" ), TQString::null, 0,
-		this, TQT_SLOT( toggleAutoSpellChecking() ), coll, "enable_auto_spell_check" );
+	toggleAutoSpellCheck = new KToggleAction( i18n( "Automatic Spell Checking" ), TQString(), 0,
+		TQT_TQOBJECT(this), TQT_SLOT( toggleAutoSpellChecking() ), coll, "enable_auto_spell_check" );
 	toggleAutoSpellCheck->setChecked( true );
 
 	actionSmileyMenu = new KopeteEmoticonAction( coll, "format_smiley" );
@@ -393,21 +393,21 @@ void KopeteChatWindow::initActions(void)
 	// add configure key bindings menu item
 	KStdAction::keyBindings( guiFactory(), TQT_SLOT( configureShortcuts() ), coll );
 
-	KStdAction::configureToolbars(this, TQT_SLOT(slotConfToolbar()), coll);
+	KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT(slotConfToolbar()), coll);
 	KopeteStdAction::preferences( coll , "settings_prefs" );
 
 	//The Sending movie
-	normalIcon = TQPixmap( BarIcon( TQString::fromLatin1( "kopete" ) ) );
-	animIcon = KGlobal::iconLoader()->loadMovie( TQString::fromLatin1( "newmessage" ), KIcon::Toolbar);
+	normalIcon = TQPixmap( BarIcon( TQString::tqfromLatin1( "kopete" ) ) );
+	animIcon = KGlobal::iconLoader()->loadMovie( TQString::tqfromLatin1( "newmessage" ), KIcon::Toolbar);
 
 	// Pause the animation because otherwise it's running even when we're not
 	// showing it. This eats resources, and also triggers a pixmap leak in
-	// TQMovie in at least Qt 3.1, Qt 3.2 and the current Qt 3.3 beta
+	// TQMovie in at least TQt 3.1, TQt 3.2 and the current TQt 3.3 beta
 	if( !animIcon.isNull() )  //and another QT bug:  it crash if we pause a null movie
 		animIcon.pause();
 
 	// we can't set the tool bar as parent, if we do, it will be deleted when we configure toolbars
-	anim = new TQLabel( TQString::null, 0L ,"kde toolbar widget" );
+	anim = new TQLabel( TQString(), 0L ,"kde toolbar widget" );
 	anim->setMargin(5);
 	anim->setPixmap( normalIcon );
 
@@ -418,7 +418,7 @@ void KopeteChatWindow::initActions(void)
 	//toolBar()->alignItemRight( 99 );
 	setStandardToolBarMenuEnabled( true );
 
-	setXMLFile( TQString::fromLatin1( "kopetechatwindow.rc" ) );
+	setXMLFile( TQString::tqfromLatin1( "kopetechatwindow.rc" ) );
 	createGUI( 0L );
 
 	// Special handling for remembering whether the format toolbar is visible or not
@@ -581,7 +581,7 @@ void KopeteChatWindow::slotSetBgColor()
 	m_activeView->setBgColor();
 }
 
-void KopeteChatWindow::setStatus(const TQString &text)
+void KopeteChatWindow::settqStatus(const TQString &text)
 {
 	m_status_text->setText(text);
 }
@@ -590,11 +590,11 @@ void KopeteChatWindow::createTabBar()
 {
 	if( !m_tabBar )
 	{
-		KGlobal::config()->setGroup( TQString::fromLatin1("ChatWindowSettings") );
+		KGlobal::config()->setGroup( TQString::tqfromLatin1("ChatWindowSettings") );
 
 		m_tabBar = new KTabWidget( mainArea );
-		m_tabBar->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
-		m_tabBar->setHoverCloseButton(KGlobal::config()->readBoolEntry( TQString::fromLatin1("HoverClose"), false ));
+		m_tabBar->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
+		m_tabBar->setHoverCloseButton(KGlobal::config()->readBoolEntry( TQString::tqfromLatin1("HoverClose"), false ));
 		m_tabBar->setTabReorderingEnabled(true);
 #if KDE_IS_VERSION(3,4,0)
 		m_tabBar->setAutomaticResizeTabs(true);
@@ -621,7 +621,7 @@ void KopeteChatWindow::createTabBar()
 		else
 			setActiveView( chatViewList.first() );
 
-		int tabPosition = KGlobal::config()->readNumEntry( TQString::fromLatin1("Tab Placement") , 0 );
+		int tabPosition = KGlobal::config()->readNumEntry( TQString::tqfromLatin1("Tab Placement") , 0 );
 		slotPlaceTabs( tabPosition );
 	}
 }
@@ -637,7 +637,7 @@ void KopeteChatWindow::addTab( ChatView *view )
 	Kopete::Contact *c=0L;
 	for ( Kopete::Contact *contact = chatMembers.first(); contact; contact = chatMembers.next() )
 	{
-		if(!c || c->onlineStatus() < contact->onlineStatus())
+		if(!c || c->onlinetqStatus() < contact->onlinetqStatus())
 			c=contact;
 	}
 	TQPixmap pluginIcon = c ? view->msgManager()->contactOnlineStatus( c ).iconFor( c) : SmallIcon( view->msgManager()->protocol()->pluginIcon() );
@@ -829,7 +829,7 @@ void KopeteChatWindow::updateBackground( const TQPixmap &pm )
 			backgroundFile->unlink();
 		}
 
-		backgroundFile = new KTempFile( TQString::null, TQString::fromLatin1( ".bmp" ) );
+		backgroundFile = new KTempFile( TQString(), TQString::tqfromLatin1( ".bmp" ) );
 		pm.save( backgroundFile->name(), "BMP" );
 		TQTimer::singleShot( 100, this, TQT_SLOT( slotEnableUpdateBg() ) );
 	}
@@ -892,7 +892,7 @@ void KopeteChatWindow::setActiveView( TQWidget *widget )
 	}
 
 	setCaption( m_activeView->caption() );
-	setStatus( m_activeView->statusText() );
+	settqStatus( m_activeView->statusText() );
 	m_activeView->setFocus();
 	updateSpellCheckAction();
 	slotUpdateSendEnabled();
@@ -909,7 +909,7 @@ void KopeteChatWindow::slotUpdateCaptionIcons( ChatView *view )
 	Kopete::Contact *c=0L;
 	for ( Kopete::Contact *contact = chatMembers.first(); contact; contact = chatMembers.next() )
 	{
-		if(!c || c->onlineStatus() < contact->onlineStatus())
+		if(!c || c->onlinetqStatus() < contact->onlinetqStatus())
 			c=contact;
 	}
 
@@ -986,15 +986,15 @@ void KopeteChatWindow::slotPrepareContactMenu(void)
 			p, TQT_SLOT(deleteLater() ) );
 
 		if( contact->metaContact() )
-			contactsMenu->insertItem( contact->onlineStatus().iconFor( contact ) , contact->metaContact()->displayName(), p );
+			contactsMenu->insertItem( contact->onlinetqStatus().iconFor( contact ) , contact->metaContact()->displayName(), p );
 		else
-			contactsMenu->insertItem( contact->onlineStatus().iconFor( contact ) , contact->contactId(), p );
+			contactsMenu->insertItem( contact->onlinetqStatus().iconFor( contact ) , contact->contactId(), p );
 
 		//FIXME: This number should be a config option
 		if( ++contactCount == 15 && contact != m_them.getLast() )
 		{
 			KActionMenu *moreMenu = new KActionMenu( i18n("More..."),
-				 TQString::fromLatin1("folder_open"), contactsMenu );
+				 TQString::tqfromLatin1("folder_open"), TQT_TQOBJECT(contactsMenu) );
 			connect ( actionContactMenu->popupMenu(), TQT_SIGNAL(aboutToHide()),
 				moreMenu, TQT_SLOT(deleteLater() ) );
 			moreMenu->plug( contactsMenu );
@@ -1032,9 +1032,9 @@ void KopeteChatWindow::readOptions()
 	// load and apply config file settings affecting the appearance of the UI
 //	kdDebug(14010) << k_funcinfo << endl;
 	KConfig *config = KGlobal::config();
-	applyMainWindowSettings( config, TQString::fromLatin1( "KopeteChatWindow" ) );
-	config->setGroup( TQString::fromLatin1("ChatWindowSettings") );
-	m_showFormatToolbar = config->readBoolEntry( TQString::fromLatin1("Show Format Toolbar"), true );
+	applyMainWindowSettings( config, TQString::tqfromLatin1( "KopeteChatWindow" ) );
+	config->setGroup( TQString::tqfromLatin1("ChatWindowSettings") );
+	m_showFormatToolbar = config->readBoolEntry( TQString::tqfromLatin1("Show Format Toolbar"), true );
 }
 
 void KopeteChatWindow::saveOptions()
@@ -1044,12 +1044,12 @@ void KopeteChatWindow::saveOptions()
 	KConfig *config = KGlobal::config();
 
 	// saves menubar,toolbar and statusbar setting
-	saveMainWindowSettings( config, TQString::fromLatin1( "KopeteChatWindow" ) );
-	config->setGroup( TQString::fromLatin1("ChatWindowSettings") );
+	saveMainWindowSettings( config, TQString::tqfromLatin1( "KopeteChatWindow" ) );
+	config->setGroup( TQString::tqfromLatin1("ChatWindowSettings") );
 	if( m_tabBar )
-		config->writeEntry ( TQString::fromLatin1("Tab Placement"), m_tabBar->tabPosition() );
+		config->writeEntry ( TQString::tqfromLatin1("Tab Placement"), m_tabBar->tabPosition() );
 
-	config->writeEntry( TQString::fromLatin1("Show Format Toolbar"), m_showFormatToolbar );
+	config->writeEntry( TQString::tqfromLatin1("Show Format Toolbar"), m_showFormatToolbar );
 	config->sync();
 }
 
@@ -1214,7 +1214,7 @@ void KopeteChatWindow::slotConfKeys()
 
 void KopeteChatWindow::slotConfToolbar()
 {
-	saveMainWindowSettings(KGlobal::config(), TQString::fromLatin1( "KopeteChatWindow" ));
+	saveMainWindowSettings(KGlobal::config(), TQString::tqfromLatin1( "KopeteChatWindow" ));
 	KEditToolbar *dlg = new KEditToolbar(factory(), this );
 	if (dlg->exec())
 	{
@@ -1222,7 +1222,7 @@ void KopeteChatWindow::slotConfToolbar()
 			createGUI( m_activeView->editPart() );
 		else
 			createGUI( 0L );
-		applyMainWindowSettings(KGlobal::config(), TQString::fromLatin1( "KopeteChatWindow" ));
+		applyMainWindowSettings(KGlobal::config(), TQString::tqfromLatin1( "KopeteChatWindow" ));
 	}
 	delete dlg;
 }
@@ -1234,16 +1234,16 @@ void KopeteChatWindow::updateChatState( ChatView* cv, int newState )
 		switch( newState )
 		{
 			case ChatView::Highlighted:
-				m_tabBar->setTabColor( cv, Qt::blue );
+				m_tabBar->setTabColor( cv, TQt::blue );
 				break;
 			case ChatView::Message:
-				m_tabBar->setTabColor( cv, Qt::red );
+				m_tabBar->setTabColor( cv, TQt::red );
 				break;
 			case ChatView::Changed:
-				m_tabBar->setTabColor( cv, Qt::darkRed );
+				m_tabBar->setTabColor( cv, TQt::darkRed );
 				break;
 			case ChatView::Typing:
-				m_tabBar->setTabColor( cv, Qt::darkGreen );
+				m_tabBar->setTabColor( cv, TQt::darkGreen );
 				break;
 			case ChatView::Normal:
 			default:
@@ -1256,7 +1256,7 @@ void KopeteChatWindow::updateChatState( ChatView* cv, int newState )
 void KopeteChatWindow::updateChatTooltip( ChatView* cv )
 {
 	if ( m_tabBar )
-		m_tabBar->setTabToolTip( cv, TQString::fromLatin1("<qt>%1</qt>").arg( cv->caption() ) );
+		m_tabBar->setTabToolTip( cv, TQString::tqfromLatin1("<qt>%1</qt>").tqarg( cv->caption() ) );
 }
 
 void KopeteChatWindow::updateChatLabel()
