@@ -241,8 +241,8 @@ AppearanceConfig::AppearanceConfig(TQWidget *parent, const char* /*name*/, const
 	KHTMLView *htmlWidget = d->preview->view();
 	htmlWidget->setMarginWidth(4);
 	htmlWidget->setMarginHeight(4);
-	htmlWidget->setFocusPolicy(NoFocus);
-	htmlWidget->setSizePolicy(
+	htmlWidget->setFocusPolicy(TQ_NoFocus);
+	htmlWidget->tqsetSizePolicy(
 		TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding));
 	l->addWidget(htmlWidget);
 	// Add the preview message to the ChatMessagePart
@@ -512,18 +512,18 @@ void AppearanceConfig::updateEmoticonlist()
 	// loop adding themes from all dirs into theme-list
 	for(unsigned int x = 0;x < themeDirs.count();x++)
 	{
-		TQDir themeQDir(themeDirs[x]);
-		themeQDir.setFilter( TQDir::Dirs ); // only scan for subdirs
-		themeQDir.setSorting( TQDir::Name ); // I guess name is as good as any
-		for(unsigned int y = 0; y < themeQDir.count(); y++)
+		TQDir themeTQDir(themeDirs[x]);
+		themeTQDir.setFilter( TQDir::Dirs ); // only scan for subdirs
+		themeTQDir.setSorting( TQDir::Name ); // I guess name is as good as any
+		for(unsigned int y = 0; y < themeTQDir.count(); y++)
 		{
-			TQStringList themes = themeQDir.entryList(TQDir::Dirs, TQDir::Name);
+			TQStringList themes = themeTQDir.entryList(TQDir::Dirs, TQDir::Name);
 			// We don't care for '.' and '..'
-			if ( themeQDir[y] != "." && themeQDir[y] != ".." )
+			if ( themeTQDir[y] != "." && themeTQDir[y] != ".." )
 			{
 				// Add ourselves to the list, using our directory name  FIXME:  use the first emoticon of the theme.
-				TQPixmap previewPixmap = TQPixmap(locate("emoticons", themeQDir[y]+"/smile.png"));
-				d->mPrfsEmoticons->icon_theme_list->insertItem(previewPixmap,themeQDir[y]);
+				TQPixmap previewPixmap = TQPixmap(locate("emoticons", themeTQDir[y]+"/smile.png"));
+				d->mPrfsEmoticons->icon_theme_list->insertItem(previewPixmap,themeTQDir[y]);
 			}
 		}
 	}
@@ -548,9 +548,9 @@ void AppearanceConfig::slotSelectedEmoticonsThemeChanged()
 	TQString newContentText = "<qt>";
 
 	for(TQStringList::Iterator it = smileys.begin(); it != smileys.end(); ++it )
-		newContentText += TQString::fromLatin1("<img src=\"%1\"> ").arg(*it);
+		newContentText += TQString::tqfromLatin1("<img src=\"%1\"> ").tqarg(*it);
 
-	newContentText += TQString::fromLatin1("</qt>");
+	newContentText += TQString::tqfromLatin1("</qt>");
 	d->mPrfsEmoticons->icon_theme_preview->setText(newContentText);
 	emitChanged();
 }
@@ -624,7 +624,7 @@ void AppearanceConfig::slotChatStyleVariantSelected(const TQString &variantName)
 
 void AppearanceConfig::slotInstallChatStyle()
 {
-	KURL styleToInstall = KFileDialog::getOpenURL( TQString::null, TQString::fromUtf8("application/x-zip application/x-tgz application/x-tbz"), this, i18n("Choose Chat Window style to install.") );
+	KURL styleToInstall = KFileDialog::getOpenURL( TQString(), TQString::fromUtf8("application/x-zip application/x-tgz application/x-tbz"), this, i18n("Choose Chat Window style to install.") );
 
 	if( !styleToInstall.isEmpty() )
 	{
@@ -673,7 +673,7 @@ void AppearanceConfig::slotDeleteChatStyle()
 	TQString stylePathToDelete = d->styleItemMap[d->mPrfsChatWindow->styleList->selectedItem()];
 	if( ChatWindowStyleManager::self()->removeStyle(stylePathToDelete) )
 	{
-		KMessageBox::queuedMessageBox(this, KMessageBox::Information, i18n("It's the deleted style name", "The style %1 was successfully deleted.").arg(styleName));
+		KMessageBox::queuedMessageBox(this, KMessageBox::Information, i18n("It's the deleted style name", "The style %1 was successfully deleted.").tqarg(styleName));
 
 		// Get the first item in the stye List.
 		TQString stylePath = (*d->styleItemMap.begin());
@@ -682,7 +682,7 @@ void AppearanceConfig::slotDeleteChatStyle()
 	}
 	else
 	{
-		KMessageBox::queuedMessageBox(this, KMessageBox::Information, i18n("It's the deleted style name", "An error occured while trying to delete %1 style.").arg(styleName));
+		KMessageBox::queuedMessageBox(this, KMessageBox::Information, i18n("It's the deleted style name", "An error occured while trying to delete %1 style.").tqarg(styleName));
 	}
 }
 
@@ -728,7 +728,7 @@ FakeAccount(Kopete::Protocol *parent, const TQString &accountID, const char *nam
 ~FakeAccount()
 {}
 bool createContact( const TQString &/*contactId*/, Kopete::MetaContact */*parentContact*/ ){return true;}
-void connect( const Kopete::OnlineStatus& /*initialStatus*/){}
+void connect( const Kopete::OnlineStatus& /*initialtqStatus*/){}
 void disconnect(){}
 void setOnlineStatus( const Kopete::OnlineStatus& /*status*/ , const TQString &/*reason*/){}
 };
@@ -770,7 +770,7 @@ void AppearanceConfig::createPreviewMessages()
 	msgCol.setBg( TQColor( "LightSteelBlue" ) );
 	Kopete::Message msgInt( d->jack, d->myself, i18n( "This is an internal message" ), Kopete::Message::Internal );
 	Kopete::Message msgAct( d->jack, d->myself, i18n( "performed an action" ), Kopete::Message::Inbound,
-				  Kopete::Message::PlainText, TQString::null, Kopete::Message::TypeAction );
+				  Kopete::Message::PlainText, TQString(), Kopete::Message::TypeAction );
 	Kopete::Message msgHigh( d->jack, d->myself, i18n( "This is a highlighted message" ), Kopete::Message::Inbound );
 	msgHigh.setImportance( Kopete::Message::Highlight );
 	// This is a UTF-8 string btw.
@@ -810,7 +810,7 @@ void AppearanceConfig::emitChanged()
 
 void AppearanceConfig::installEmoticonTheme()
 {
-	KURL themeURL = KURLRequesterDlg::getURL(TQString::null, this,
+	KURL themeURL = KURLRequesterDlg::getURL(TQString(), this,
 			i18n("Drag or Type Emoticon Theme URL"));
 	if ( themeURL.isEmpty() )
 		return;
