@@ -17,7 +17,7 @@
 
 #include "kopeteidentityconfig.h"
 
-// Qt includes
+// TQt includes
 #include <tqlayout.h>
 #include <tqimage.h>
 #include <tqlabel.h>
@@ -383,7 +383,7 @@ void KopeteIdentityConfig::slotEnableAndDisableWidgets()
 	}
 
 	if(!photo.isNull())
-		d->m_view->labelPhoto->setPixmap(TQPixmap(photo.smoothScale(64, 92, TQImage::ScaleMin)));
+		d->m_view->labelPhoto->setPixmap(TQPixmap(photo.smoothScale(64, 92, TQ_ScaleMin)));
 	else
 		d->m_view->labelPhoto->setPixmap(TQPixmap());
 
@@ -413,7 +413,7 @@ void KopeteIdentityConfig::slotUpdateCurrentIdentity(const TQString &selectedIde
 void KopeteIdentityConfig::slotNewIdentity()
 {
 	bool ok;
-	TQString newIdentityName = KInputDialog::getText(i18n("New Identity"), i18n("Identity name:") , TQString::null , &ok);
+	TQString newIdentityName = KInputDialog::getText(i18n("New Identity"), i18n("Identity name:") , TQString() , &ok);
 	
 	if(newIdentityName.isEmpty() || !ok)
 		return;
@@ -428,7 +428,7 @@ void KopeteIdentityConfig::slotNewIdentity()
 void KopeteIdentityConfig::slotCopyIdentity()
 {
 	bool ok;
-	TQString copyName = KInputDialog::getText(i18n("Copy Identity"), i18n("Identity name:") , TQString::null, &ok);
+	TQString copyName = KInputDialog::getText(i18n("Copy Identity"), i18n("Identity name:") , TQString(), &ok);
 	
 	if(copyName.isEmpty() || !ok)
 		return;
@@ -528,7 +528,7 @@ void KopeteIdentityConfig::slotChangePhoto(const TQString &photoUrl)
 		if(photo.width() > 96 || photo.height() > 96)
 		{
 			// Scale and crop the picture.
-			photo = photo.smoothScale( 96, 96, TQImage::ScaleMin );
+			photo = photo.smoothScale( 96, 96, TQ_ScaleMin );
 			// crop image if not square
 			if(photo.width() < photo.height()) 
 				photo = photo.copy((photo.width()-photo.height())/2, 0, 96, 96);
@@ -539,7 +539,7 @@ void KopeteIdentityConfig::slotChangePhoto(const TQString &photoUrl)
 		else if (photo.width() < 32 || photo.height() < 32)
 		{
 			// Scale and crop the picture.
-			photo = photo.smoothScale( 32, 32, TQImage::ScaleMin );
+			photo = photo.smoothScale( 32, 32, TQ_ScaleMin );
 			// crop image if not square
 			if(photo.width() < photo.height())
 				photo = photo.copy((photo.width()-photo.height())/2, 0, 32, 32);
@@ -564,12 +564,12 @@ void KopeteIdentityConfig::slotChangePhoto(const TQString &photoUrl)
 		KMD5 context(tempArray);
 		// Save the image to a file.
 		saveLocation = context.hexDigest() + ".png";
-		saveLocation = locateLocal( "appdata", TQString::fromUtf8("globalidentitiespictures/%1").arg( saveLocation ) );
+		saveLocation = locateLocal( "appdata", TQString::fromUtf8("globalidentitiespictures/%1").tqarg( saveLocation ) );
 
 		if(!photo.save(saveLocation, "PNG"))
 		{
 			KMessageBox::sorry(this, 
-					i18n("An error occurred when trying to save the custom photo for %1 identity.").arg(d->selectedIdentity),
+					i18n("An error occurred when trying to save the custom photo for %1 identity.").tqarg(d->selectedIdentity),
 					i18n("Identity Configuration"));
 		}
 		d->m_view->comboPhotoURL->setURL(saveLocation);
@@ -578,14 +578,14 @@ void KopeteIdentityConfig::slotChangePhoto(const TQString &photoUrl)
 	else
 	{
 		KMessageBox::sorry(this, 
-					i18n("An error occurred when trying to save the custom photo for %1 identity.").arg(d->selectedIdentity),
+					i18n("An error occurred when trying to save the custom photo for %1 identity.").tqarg(d->selectedIdentity),
 					i18n("Identity Configuration"));
 	}
 }
 
 void KopeteIdentityConfig::slotClearPhoto()
 {
-	d->m_view->comboPhotoURL->setURL( TQString::null );
+	d->m_view->comboPhotoURL->setURL( TQString() );
 	slotEnableAndDisableWidgets();
 }
 
