@@ -120,7 +120,7 @@ public:
 
 protected:
 	// work around TQListView design stupidity.
-	// GroupViewItem will be QListView-derived, or QListViewItem-derived.
+	// GroupViewItem will be TQListView-derived, or TQListViewItem-derived.
 	template<typename GroupViewItem>
 	void addMetaContactToGroupInner( Kopete::MetaContact *mc, GroupViewItem *gpi )
 	{
@@ -198,7 +198,7 @@ public:
 		{
 			removeMetaContactFromGroupInner( mc, gpi );
 
-			// update the group's display of its number of children.
+			// update the group's display of its number of tqchildren.
 			// TODO: make the KopeteGroupViewItem not need this, by overriding insertItem and takeItem
 			gpi->refreshDisplayName();
 
@@ -288,8 +288,8 @@ private:
 		updateMetaContactInner( mc );
 
 		// FIXME: these items should do this for themselves...
-		m_onlineItem->setText(0,i18n("Online contacts (%1)").arg(m_onlineItem->childCount()));
-		m_offlineItem->setText(0,i18n("Offline contacts (%1)").arg(m_offlineItem->childCount()));
+		m_onlineItem->setText(0,i18n("Online contacts (%1)").tqarg(m_onlineItem->childCount()));
+		m_offlineItem->setText(0,i18n("Offline contacts (%1)").tqarg(m_offlineItem->childCount()));
 	}
 	void updateMetaContactInner( Kopete::MetaContact *mc )
 	{
@@ -375,7 +375,7 @@ void KopeteContactListViewPrivate::updateViewStrategy( KListView *view )
 }
 
 // returns the next item in a depth-first descent of the list view.
-// much like QLVI::itemBelow but does not depend on visibility of items, etc.
+// much like TQLVI::itemBelow but does not depend on visibility of items, etc.
 static TQListViewItem *nextItem( TQListViewItem *item )
 {
 	if ( TQListViewItem *it = item->firstChild() )
@@ -461,49 +461,49 @@ KopeteContactListView::KopeteContactListView( TQWidget *parent, const char *name
 
 void KopeteContactListView::initActions( KActionCollection *ac )
 {
-	actionUndo = KStdAction::undo( this , TQT_SLOT( slotUndo() ) , ac );
-	actionRedo = KStdAction::redo( this , TQT_SLOT( slotRedo() ) , ac );
+	actionUndo = KStdAction::undo( TQT_TQOBJECT(this) , TQT_SLOT( slotUndo() ) , ac );
+	actionRedo = KStdAction::redo( TQT_TQOBJECT(this) , TQT_SLOT( slotRedo() ) , ac );
 	actionUndo->setEnabled(false);
 	actionRedo->setEnabled(false);
 
 
-	new KAction( i18n( "Create New Group..." ), 0, 0, this, TQT_SLOT( addGroup() ),
+	new KAction( i18n( "Create New Group..." ), 0, 0, TQT_TQOBJECT(this), TQT_SLOT( addGroup() ),
 		ac, "AddGroup" );
 
 	actionSendMessage = KopeteStdAction::sendMessage(
-		this, TQT_SLOT( slotSendMessage() ), ac, "contactSendMessage" );
-	actionStartChat = KopeteStdAction::chat( this, TQT_SLOT( slotStartChat() ),
+		TQT_TQOBJECT(this), TQT_SLOT( slotSendMessage() ), ac, "contactSendMessage" );
+	actionStartChat = KopeteStdAction::chat( TQT_TQOBJECT(this), TQT_SLOT( slotStartChat() ),
 		ac, "contactStartChat" );
 
-	actionMove = new KopeteGroupListAction( i18n( "&Move To" ), TQString::fromLatin1( "editcut" ),
-														  0, this, TQT_SLOT( slotMoveToGroup() ), ac, "contactMove" );
-	actionCopy = new KopeteGroupListAction( i18n( "&Copy To" ), TQString::fromLatin1( "editcopy" ), 0,
-														 this, TQT_SLOT( slotCopyToGroup() ), ac, "contactCopy" );
+	actionMove = new KopeteGroupListAction( i18n( "&Move To" ), TQString::tqfromLatin1( "editcut" ),
+														  0, TQT_TQOBJECT(this), TQT_SLOT( slotMoveToGroup() ), ac, "contactMove" );
+	actionCopy = new KopeteGroupListAction( i18n( "&Copy To" ), TQString::tqfromLatin1( "editcopy" ), 0,
+														 TQT_TQOBJECT(this), TQT_SLOT( slotCopyToGroup() ), ac, "contactCopy" );
 
-	actionRemove = KopeteStdAction::deleteContact( this, TQT_SLOT( slotRemove() ),
+	actionRemove = KopeteStdAction::deleteContact( TQT_TQOBJECT(this), TQT_SLOT( slotRemove() ),
 		ac, "contactRemove" );
-	actionSendEmail = new KAction( i18n( "Send Email..." ), TQString::fromLatin1( "mail_generic" ),
-		0, this, TQT_SLOT(  slotSendEmail() ), ac, "contactSendEmail" );
+	actionSendEmail = new KAction( i18n( "Send Email..." ), TQString::tqfromLatin1( "mail_generic" ),
+		0, TQT_TQOBJECT(this), TQT_SLOT(  slotSendEmail() ), ac, "contactSendEmail" );
 	/* this actionRename is buggy, and useless with properties, removed in kopeteui.rc*/
 	actionRename = new KAction( i18n( "Rename" ), "filesaveas", 0,
-		this, TQT_SLOT( slotRename() ), ac, "contactRename" );
-	actionSendFile = KopeteStdAction::sendFile( this, TQT_SLOT( slotSendFile() ),
+		TQT_TQOBJECT(this), TQT_SLOT( slotRename() ), ac, "contactRename" );
+	actionSendFile = KopeteStdAction::sendFile( TQT_TQOBJECT(this), TQT_SLOT( slotSendFile() ),
 		ac, "contactSendFile" );
 
 	actionAddContact = new KActionMenu( i18n( "&Add Contact" ),
-		TQString::fromLatin1( "add_user" ), ac , "contactAddContact" );
+		TQString::tqfromLatin1( "add_user" ), ac , "contactAddContact" );
 	actionAddContact->popupMenu()->insertTitle( i18n("Select Account") );
 
 	actionAddTemporaryContact = new KAction( i18n( "Add to Your Contact List" ), "add_user", 0,
-		this, TQT_SLOT( slotAddTemporaryContact() ), ac, "contactAddTemporaryContact" );
+		TQT_TQOBJECT(this), TQT_SLOT( slotAddTemporaryContact() ), ac, "contactAddTemporaryContact" );
 
 	connect( Kopete::ContactList::self(), TQT_SIGNAL( metaContactSelected( bool ) ), this, TQT_SLOT( slotMetaContactSelected( bool ) ) );
 
 	connect( Kopete::AccountManager::self(), TQT_SIGNAL(accountRegistered( Kopete::Account* )), TQT_SLOT(slotAddSubContactActionNewAccount(Kopete::Account*)));
 	connect( Kopete::AccountManager::self(), TQT_SIGNAL(accountUnregistered( const Kopete::Account* )), TQT_SLOT(slotAddSubContactActionAccountDeleted(const Kopete::Account *)));
 
-	actionProperties = new KAction( i18n( "&Properties" ), "edit_user", Qt::Key_Alt + Qt::Key_Return,
-		this, TQT_SLOT( slotProperties() ), ac, "contactProperties" );
+	actionProperties = new KAction( i18n( "&Properties" ), "edit_user", TQt::Key_Alt + TQt::Key_Return,
+		TQT_TQOBJECT(this), TQT_SLOT( slotProperties() ), ac, "contactProperties" );
 
 	// Update enabled/disabled actions
 	slotViewSelectionChanged();
@@ -516,7 +516,7 @@ KopeteContactListView::~KopeteContactListView()
 
 void KopeteContactListView::slotAddSubContactActionNewAccount(Kopete::Account* account)
 {
-	KAction *action = new KAction( account->accountLabel(), account->accountIcon(), 0 , this, TQT_SLOT(slotAddContact()), account);
+	KAction *action = new KAction( account->accountLabel(), account->accountIcon(), 0 , TQT_TQOBJECT(this), TQT_SLOT(slotAddContact()), account);
 	m_accountAddContactMap.insert( account, action);
 	actionAddContact->insert( action );
 }
@@ -659,7 +659,7 @@ void KopeteContactListView::slotContextMenu( KListView * /*listview*/,
 	int nb = Kopete::ContactList::self()->selectedMetaContacts().count() +
 		Kopete::ContactList::self()->selectedGroups().count();
 
-	KMainWindow *window = dynamic_cast<KMainWindow *>(topLevelWidget());
+	KMainWindow *window = dynamic_cast<KMainWindow *>(tqtopLevelWidget());
 	if ( !window )
 	{
 		kdError( 14000 ) << k_funcinfo << "Main window not found, unable to display context-menu; "
@@ -671,7 +671,7 @@ void KopeteContactListView::slotContextMenu( KListView * /*listview*/,
 	{
 		int px = mapFromGlobal( point ).x() -  ( header()->sectionPos( header()->mapToIndex( 0 ) ) +
 			treeStepSize() * ( item->depth() + ( rootIsDecorated() ? 1 : 0 ) ) + itemMargin() );
-		int py = mapFromGlobal( point ).y() - itemRect( item ).y() - (header()->isVisible() ? header()->height() : 0) ;
+		int py = mapFromGlobal( point ).y() - tqitemRect( item ).y() - (header()->isVisible() ? header()->height() : 0) ;
 
 		//kdDebug( 14000 ) << k_funcinfo << "x: " << px << ", y: " << py << endl;
 		Kopete::Contact *c = metaLVI->contactForPoint( TQPoint( px, py ) ) ;
@@ -691,7 +691,7 @@ void KopeteContactListView::slotContextMenu( KListView * /*listview*/,
 					arg( metaLVI->metaContact()->displayName(), metaLVI->metaContact()->statusString() );
 
 				if ( title.length() > 43 )
-					title = title.left( 40 ) + TQString::fromLatin1( "..." );
+					title = title.left( 40 ) + TQString::tqfromLatin1( "..." );
 
 				if ( popup->title( 0 ).isNull() )
 					popup->insertTitle ( title, 0, 0 );
@@ -716,9 +716,9 @@ void KopeteContactListView::slotContextMenu( KListView * /*listview*/,
 					text=text.replace("&","&&"); // cf BUG 115449
 
 					if ( text.length() > 41 )
-						text = text.left( 38 ) + TQString::fromLatin1( "..." );
+						text = text.left( 38 ) + TQString::tqfromLatin1( "..." );
 
-					popup->insertItem( c->onlineStatus().iconFor( c, 16 ), text , contactMenu );
+					popup->insertItem( c->onlinetqStatus().iconFor( c, 16 ), text , contactMenu );
 				}
 
 				popup->popup( point );
@@ -733,7 +733,7 @@ void KopeteContactListView::slotContextMenu( KListView * /*listview*/,
 		{
 			TQString title = groupvi->group()->displayName();
 			if ( title.length() > 32 )
-				title = title.left( 30 ) + TQString::fromLatin1( "..." );
+				title = title.left( 30 ) + TQString::tqfromLatin1( "..." );
 
 			if( popup->title( 0 ).isNull() )
 				popup->insertTitle( title, 0, 0 );
@@ -814,7 +814,7 @@ void KopeteContactListView::slotExecuted( TQListViewItem *item, const TQPoint &p
 	{
 		// Try if we are clicking a protocol icon. If so, open a direct
 		// connection for that protocol
-		TQRect r = itemRect( item );
+		TQRect r = tqitemRect( item );
 		TQPoint relativePos( pos.x() - r.left() - ( treeStepSize() *
 			( item->depth() + ( rootIsDecorated() ? 1 : 0 ) ) +
 			itemMargin() ), pos.y() - r.top() );
@@ -905,7 +905,7 @@ void KopeteContactListView::slotDropped(TQDropEvent *e, TQListViewItem *, TQList
 	}
 	else if( e->provides("kopete/x-contact") )
 	{
-		TQString contactInfo = TQString::fromUtf8( e->encodedData("kopete/x-contact") );
+		TQString contactInfo = TQString::fromUtf8( e->tqencodedData("kopete/x-contact") );
 		TQString protocolId = contactInfo.section( TQChar( 0xE000 ), 0, 0 );
 		TQString accountId = contactInfo.section( TQChar( 0xE000 ), 1, 1 );
 		TQString contactId = contactInfo.section( TQChar( 0xE000 ), 2 );
@@ -927,7 +927,7 @@ void KopeteContactListView::slotDropped(TQDropEvent *e, TQListViewItem *, TQList
 		for ( KURL::List::Iterator it = urlList.begin(); it != urlList.end(); ++it )
 		{
 			KURL url = (*it);
-			if( url.protocol() == TQString::fromLatin1("kopetemessage") )
+			if( url.protocol() == TQString::tqfromLatin1("kopetemessage") )
 			{
 				//Add a contact
 				addDraggedContactByInfo( url.queryItem("protocolId"),
@@ -938,7 +938,7 @@ void KopeteContactListView::slotDropped(TQDropEvent *e, TQListViewItem *, TQList
 				TQPoint p = contentsToViewport(e->pos());
 				int px = p.x() - ( header()->sectionPos( header()->mapToIndex( 0 ) ) +
 					treeStepSize() * ( dest_metaLVI->depth() + ( rootIsDecorated() ? 1 : 0 ) ) + itemMargin() );
-				int py = p.y() - itemRect( dest_metaLVI ).y();
+				int py = p.y() - tqitemRect( dest_metaLVI ).y();
 
 				Kopete::Contact *c = dest_metaLVI->contactForPoint( TQPoint( px, py ) );
 
@@ -987,7 +987,7 @@ void KopeteContactListView::addDraggedContactToGroup( Kopete::MetaContact *conta
 {
 	int r=KMessageBox::questionYesNo( Kopete::UI::Global::mainWidget(),
 					i18n( "<qt>Would you like to add <b>%1</b> to your contact list as a member of <b>%2</b>?</qt>" )
-					.arg( contact->displayName(), group->displayName() ),
+					.tqarg( contact->displayName(), group->displayName() ),
 					i18n( "Kopete" ), i18n("Add"), i18n("Do Not Add"),
 					"addTemporaryWhenMoving" );
 
@@ -1003,7 +1003,7 @@ void KopeteContactListView::addDraggedContactToMetaContact( Kopete::Contact *con
 {
 	int r = KMessageBox::questionYesNo( Kopete::UI::Global::mainWidget(),
 					i18n( "<qt>Would you like to add <b>%1</b> to your contact list as a child contact of <b>%2</b>?</qt>" )
-					.arg( contact->contactId(), parent->displayName() ),
+					.tqarg( contact->contactId(), parent->displayName() ),
 					i18n( "Kopete" ), i18n("Add"), i18n("Do Not Add"),
 					"addTemporaryWhenMoving" );
 
@@ -1054,7 +1054,7 @@ void KopeteContactListView::addDraggedContactByInfo( const TQString &protocolId,
 			{
 				KMessageBox::sorry( Kopete::UI::Global::mainWidget(),
 					i18n("<qt>This contact is already on your contact list. It is a child contact of <b>%1</b></qt>")
-					.arg( source_contact->metaContact()->displayName() )
+					.tqarg( source_contact->metaContact()->displayName() )
 				);
 			}
 		}
@@ -1146,7 +1146,7 @@ bool KopeteContactListView::acceptDrag(TQDropEvent *e) const
 				TQPoint p=contentsToViewport(e->pos());
 				int px = p.x() - ( header()->sectionPos( header()->mapToIndex( 0 ) ) +
 					treeStepSize() * ( dest_metaLVI->depth() + ( rootIsDecorated() ? 1 : 0 ) ) + itemMargin() );
-				int py = p.y() - itemRect( dest_metaLVI ).y();
+				int py = p.y() - tqitemRect( dest_metaLVI ).y();
 				Kopete::Contact *c = dest_metaLVI->contactForPoint( TQPoint( px, py ) ) ;
 
 				if( c ? !c->isReachable() : !dest_metaLVI->metaContact()->isReachable() )
@@ -1168,7 +1168,7 @@ bool KopeteContactListView::acceptDrag(TQDropEvent *e) const
 
 			for ( KURL::List::Iterator it = urlList.begin(); it != urlList.end(); ++it )
 			{
-				if( (*it).protocol() != TQString::fromLatin1("kopetemessage") && (*it).isLocalFile() )
+				if( (*it).protocol() != TQString::tqfromLatin1("kopetemessage") && (*it).isLocalFile() )
 					return false; //we can't send links if a locale file is in link
 			}
 
@@ -1205,7 +1205,7 @@ void KopeteContactListView::findDrop(const TQPoint &pos, TQListViewItem *&parent
 void KopeteContactListView::contentsMousePressEvent( TQMouseEvent *e )
 {
 	KListView::contentsMousePressEvent( e );
-	if (e->button() == LeftButton )
+	if (e->button() == Qt::LeftButton )
 	{
 		TQPoint p=contentsToViewport(e->pos());
 		TQListViewItem *i=itemAt( p );
@@ -1216,7 +1216,7 @@ void KopeteContactListView::contentsMousePressEvent( TQMouseEvent *e )
 
 			int px = p.x() - ( header()->sectionPos( header()->mapToIndex( 0 ) ) +
 				treeStepSize() * ( i->depth() + ( rootIsDecorated() ? 1 : 0 ) ) + itemMargin() );
-			int py = p.y() - itemRect( i ).y();
+			int py = p.y() - tqitemRect( i ).y();
 
 			m_startDragPos = TQPoint( px , py );
 		}
@@ -1272,7 +1272,7 @@ TQDragObject *KopeteContactListView::dragObject()
 		d->setEncodedData( TQString( c->protocol()->pluginId() +TQChar( 0xE000 )+ c->account()->accountId() +TQChar( 0xE000 )+ c->contactId() ).utf8() );
 		drag->addDragObject( d );
 
-		pm = c->onlineStatus().iconFor( c, 12 ); // FIXME: fixed icon scaling
+		pm = c->onlinetqStatus().iconFor( c, 12 ); // FIXME: fixed icon scaling
 	}
 	else		// dragging a metacontact
 	{
@@ -1443,7 +1443,7 @@ void KopeteContactListView::slotSendFile()
 
 			kdDebug( 14000 ) << "Email: " << emailAddr << "!" << endl;
 			if ( !emailAddr.isEmpty() )
-				kapp->invokeMailer( emailAddr, TQString::null );
+				kapp->invokeMailer( emailAddr, TQString() );
 			else
 				KMessageBox::queuedMessageBox( this, KMessageBox::Sorry, i18n( "There is no email address set for this contact in the KDE address book." ), i18n( "No Email Address in Address Book" ) );
 		}
@@ -1555,13 +1555,13 @@ void KopeteContactListView::slotRemove()
 		{
 			msg = i18n( "<qt>Are you sure you want to remove the contact <b>%1</b>" \
 			            " from your contact list?</qt>" )
-			      .arg( contacts.first()->displayName() ) ;
+			      .tqarg( contacts.first()->displayName() ) ;
 		}
 		else if( !groups.isEmpty() )
 		{
 			msg = i18n( "<qt>Are you sure you want to remove the group <b>%1</b> " \
 			            "and all contacts that are contained within it?</qt>" )
-			      .arg( groups.first()->displayName() );
+			      .tqarg( groups.first()->displayName() );
 		}
 		else
 			return; // this should never happen
@@ -1676,7 +1676,7 @@ void KopeteContactListView::slotAddContact()
 			Kopete::ContactList::self()->selectedMetaContacts().first();
 	Kopete::Group *group =
 			Kopete::ContactList::self()->selectedGroups().first();
-	Kopete::Account *account = dynamic_cast<Kopete::Account*>( sender()->parent() );
+	Kopete::Account *account = dynamic_cast<Kopete::Account*>( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->parent() );
 
 	if ( ( metacontact && metacontact->isTemporary() ) ||
 			  (group && group->type()!=Kopete::Group::Normal ) )
@@ -1772,7 +1772,7 @@ void KopeteContactListView::slotProperties()
 		{
 		}
 		*/
-		metaLVI->repaint();
+		metaLVI->tqrepaint();
 	}
 	else if(groupLVI)
 	{
