@@ -66,7 +66,7 @@ const char MC_UNK[] = "metacontact_unknown";
 
 
 KopeteGVIProps::KopeteGVIProps(KopeteGroupViewItem *gvi, TQWidget *parent, const char *name)
-: KDialogBase(parent, name, true, i18n("Properties of Group %1").arg(gvi->group()->displayName()), Ok|Cancel, Ok, false)
+: KDialogBase(parent, name, true, i18n("Properties of Group %1").tqarg(gvi->group()->displayName()), Ok|Cancel, Ok, false)
 {
 	mainWidget = new KopeteGVIPropsWidget(this, "mainWidget");
 	mainWidget->icnbOpen->setIconSize(KIcon::SizeSmall);
@@ -146,7 +146,7 @@ void KopeteGVIProps::slotIconChanged()
 
 
 KopeteMetaLVIProps::KopeteMetaLVIProps(KopeteMetaContactLVI *lvi, TQWidget *parent, const char *name)
-: KDialogBase(parent, name, true, i18n("Properties of Meta Contact %1").arg(lvi->metaContact()->displayName()), Ok|Cancel, Ok, false)
+: KDialogBase(parent, name, true, i18n("Properties of Meta Contact %1").tqarg(lvi->metaContact()->displayName()), Ok|Cancel, Ok, false)
 {
 	m_countPhotoCapable = 0;
 	mainWidget = new KopeteMetaLVIPropsWidget( this, "mainWidget" );
@@ -157,10 +157,10 @@ KopeteMetaLVIProps::KopeteMetaLVIProps(KopeteMetaContactLVI *lvi, TQWidget *pare
 
 	mNotificationProps = new CustomNotificationProps( this, lvi->metaContact() );
 	// add a button to the notification props to get the sound from KABC
-	// the widget's vert box layout, horiz box layout containing button, spacer, followed by a spacer
-	TQBoxLayout * vb = static_cast<TQVBoxLayout*>( mNotificationProps->widget()->layout() );
+	// the widget's vert box tqlayout, horiz box tqlayout containing button, spacer, followed by a spacer
+	TQBoxLayout * vb = static_cast<TQVBoxLayout*>( mNotificationProps->widget()->tqlayout() );
 
-	TQHBoxLayout* hb = new TQHBoxLayout( vb, -1, "soundFromKABClayout" );
+	TQHBoxLayout* hb = new TQHBoxLayout( vb, -1, "soundFromKABCtqlayout" );
 	mFromKABC = new TQPushButton( i18n( "Sync KABC..." ), mNotificationProps->widget(), "getSoundFromKABC" );
 	hb->addWidget( mFromKABC ); // [ [Button] <-xxxxx-> ]
 	hb->addStretch();
@@ -187,19 +187,19 @@ KopeteMetaLVIProps::KopeteMetaLVIProps(KopeteMetaContactLVI *lvi, TQWidget *pare
 
 	TQString offlineName = item->metaContact()->icon( Kopete::ContactListElement::Offline );
 	if(offlineName.isEmpty())
-		offlineName = TQString::fromLatin1(MC_OFF); // Default
+		offlineName = TQString::tqfromLatin1(MC_OFF); // Default
 
 	TQString onlineName = item->metaContact()->icon( Kopete::ContactListElement::Online );
 	if(onlineName.isEmpty())
-		onlineName = TQString::fromLatin1(MC_ON); // Default
+		onlineName = TQString::tqfromLatin1(MC_ON); // Default
 
 	TQString awayName = item->metaContact()->icon( Kopete::ContactListElement::Away );
 	if(awayName.isEmpty())
-		awayName = TQString::fromLatin1(MC_AW); // Default
+		awayName = TQString::tqfromLatin1(MC_AW); // Default
 
 	TQString unknownName = item->metaContact()->icon( Kopete::ContactListElement::Unknown );
 	if(unknownName.isEmpty())
-		unknownName = TQString::fromLatin1(MC_UNK); // Default
+		unknownName = TQString::tqfromLatin1(MC_UNK); // Default
 
 	mainWidget->icnbOffline->setIcon( offlineName );
 	mainWidget->icnbOnline->setIcon( onlineName );
@@ -372,7 +372,7 @@ void KopeteMetaLVIProps::slotEnableAndDisableWidgets()
 		break;
 	}
 	if( !photo.isNull() )
-		mainWidget->photoLabel->setPixmap(TQPixmap(photo.smoothScale( 64, 92, TQImage::ScaleMin )));
+		mainWidget->photoLabel->setPixmap(TQPixmap(photo.smoothScale( 64, 92, TQ_ScaleMin )));
 	else
 		mainWidget->photoLabel->setPixmap( TQPixmap() );
 }
@@ -489,7 +489,7 @@ void KopeteMetaLVIProps::slotAddresseeChanged( const KABC::Addressee & a )
 	{
 		mainWidget->btnExportKABC->setEnabled( false );
 		mainWidget->btnImportKABC->setEnabled( false );
-		mAddressBookUid = TQString::null;
+		mAddressBookUid = TQString();
 		mainWidget->radioNameContact->setChecked( true );
 		mainWidget->radioPhotoContact->setChecked( true );
 	}
@@ -560,7 +560,7 @@ void KopeteMetaLVIProps::slotClearPhotoClicked()
 #if KDE_IS_VERSION(3,4,0)
 	mainWidget->cmbPhotoUrl->setKURL( KURL() );
 #else
-	mainWidget->cmbPhotoUrl->setURL( TQString::null );
+	mainWidget->cmbPhotoUrl->setURL( TQString() );
 #endif
 	item->metaContact()->setPhoto( KURL() );
 
