@@ -40,7 +40,7 @@ extern "C" {
 #endif
 
 #ifdef HAVE_GL
-class QVideoStreamGLWidget : public QGLWidget
+class QVideoStreamGLWidget : public TQGLWidget
 {
 public:
     QVideoStreamGLWidget(TQWidget* parent = 0, const char* name = 0);
@@ -213,7 +213,7 @@ void QVideoStream::init()
             d->shmh.shmaddr = (char *)shmat(d->shmh.shmid, 0, 0);
             d->xim->data = (char*)d->shmh.shmaddr;
             d->shmh.readOnly = False;
-            Status s = XShmAttach(_w->x11Display(), &(d->shmh));
+            tqStatus s = XShmAttach(_w->x11Display(), &(d->shmh));
             if (s) {
                 XSync(_w->x11Display(), False);
                 shmctl(d->shmh.shmid, IPC_RMID, 0);
@@ -235,7 +235,7 @@ void QVideoStream::init()
         }
         
         d->xim = XCreateImage(_w->x11Display(),
-                              (Visual*)_w->x11Visual(),
+                              (Visual*)TQT_TQPAINTDEVICE(_w)->x11Visual(),
                               _w->x11Depth(),
                               ZPixmap, 0, 0,
                               _inputSize.width(),
@@ -543,7 +543,7 @@ QVideoStreamGLWidget::QVideoStreamGLWidget(TQWidget* parent, const char* name)
     connect(_w, TQT_SIGNAL(resized(int, int)),
             this, TQT_SLOT(resize(int, int)));
 
-    topLevelWidget()->installEventFilter(this);
+    tqtopLevelWidget()->installEventFilter(this);
     _glfunTimer = new TQTimer();
 }
 
@@ -563,10 +563,10 @@ bool QVideoStreamGLWidget::eventFilter(TQObject*, TQEvent* e)
     // For some reason, KeyPress does not work (yields 2), TQEvent::KeyPress is unknown... What the f...????
     // I am too lazy to scan the header files for the reason.
     if(e->type() == 6) {
-        TQKeyEvent* ke = static_cast<TQKeyEvent*>(e);
-        if(ke->key() == Qt::Key_Pause) {
+        TQKeyEvent* ke = TQT_TQKEYEVENT(e);
+        if(ke->key() == TQt::Key_Pause) {
             _glfunTimer->start(500, true);
-        } else if (_glfunTimer->isActive() && (ke->key() == Qt::Key_Escape)) {
+        } else if (_glfunTimer->isActive() && (ke->key() == TQt::Key_Escape)) {
             _glfun = !_glfun;
         }
     }
@@ -594,7 +594,7 @@ void QVideoStreamGLWidget::initializeGL()
     kdDebug() << "    Plane:            " << f.plane()           << endl;
     kdDebug() << "    MAX_TEXTURE_SIZE: " << _maxGL              << endl;
 
-    qglClearColor(Qt::black);
+    qglClearColor(TQt::black);
     glShadeModel(GL_FLAT);
     glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
 
