@@ -71,7 +71,7 @@ void VideoDevice::enumerateMenu (void)
 	{
 		if (0 == xioctl (VIDIOC_QUERYMENU, &querymenu))
 		{
-			kdDebug(14010) <<  k_funcinfo << "  " << TQString::fromLocal8Bit((const char*)querymenu.name) << endl;
+			kdDebug(14010) <<  k_funcinfo << "  " << TQString(TQString::fromLocal8Bit((const char*)querymenu.name)) << endl;
                 }
 		else
 		{
@@ -301,7 +301,7 @@ for (currentid = V4L2_CID_BASE; currentid < V4L2_CID_LASTP1; currentid++)
 			continue;
 
 //kdDebug(14010) <<  k_funcinfo << " Control: " << TQString::fromLocal8Bit((const char*)queryctrl.name) << endl;
-kdDebug(14010) <<  k_funcinfo << " Control: " << TQString::fromLocal8Bit((const char*)queryctrl.name) << " Values from " << queryctrl.minimum << " to " << queryctrl.maximum << " with steps of " << queryctrl.step << ". Default: " << queryctrl.default_value << endl;
+kdDebug(14010) <<  k_funcinfo << " Control: " << TQString(TQString::fromLocal8Bit((const char*)queryctrl.name)) << " Values from " << queryctrl.minimum << " to " << queryctrl.maximum << " with steps of " << queryctrl.step << ". Default: " << queryctrl.default_value << endl;
 
 /*		switch (queryctrl.type)
 		{
@@ -332,7 +332,7 @@ for (currentid = V4L2_CID_PRIVATE_BASE;; currentid++)
 		if (queryctrl.flags & V4L2_CTRL_FLAG_DISABLED)
 			continue;
 
-kdDebug(14010) <<  k_funcinfo << " Control: " << TQString::fromLocal8Bit((const char*)queryctrl.name) << " Values from " << queryctrl.minimum << " to " << queryctrl.maximum << " with steps of " << queryctrl.step << ". Default: " << queryctrl.default_value << endl;
+kdDebug(14010) <<  k_funcinfo << " Control: " << TQString(TQString::fromLocal8Bit((const char*)queryctrl.name)) << " Values from " << queryctrl.minimum << " to " << queryctrl.maximum << " with steps of " << queryctrl.step << ". Default: " << queryctrl.default_value << endl;
 
 		if (queryctrl.type == V4L2_CTRL_TYPE_MENU)
 			enumerateMenu ();
@@ -1336,7 +1336,7 @@ int VideoDevice::getImage(TQImage *qimage)
 					if (b<0) b=0;   if (b>255) b=255;
 
 					uint *p = (uint*)qimage->scanLine(y)+x;
-					*p = qRgba(r,g,b,255);
+					*p = tqRgba(r,g,b,255);
 
 				}
 // Jump to next line
