@@ -86,11 +86,11 @@ public:
   TQAsciiDict<int> ignoreTheseWidgets;
 
   void init(){
-    ignoreTheseWidgets.insert("TQLabel", new int(1));
-    ignoreTheseWidgets.insert("TQFrame", new int(2));
-    ignoreTheseWidgets.insert("TQGroupBox", new int(3));
-    ignoreTheseWidgets.insert("TQButtonGroup", new int(4));
-    ignoreTheseWidgets.insert("TQWidget", new int(5));
+    ignoreTheseWidgets.insert(TQLABEL_OBJECT_NAME_STRING, new int(1));
+    ignoreTheseWidgets.insert(TQFRAME_OBJECT_NAME_STRING, new int(2));
+    ignoreTheseWidgets.insert(TQGROUPBOX_OBJECT_NAME_STRING, new int(3));
+    ignoreTheseWidgets.insert(TQBUTTONGROUP_OBJECT_NAME_STRING, new int(4));
+    ignoreTheseWidgets.insert(TQWIDGET_OBJECT_NAME_STRING, new int(5));
     ignoreTheseWidgets.setAutoDelete(true);
 
     static bool defaultKDEPropertyMapInstalled = false;
@@ -141,49 +141,49 @@ bool KAutoConfig::retrieveSettings(bool trackChanges){
   
   if(trackChanges){
     // QT
-    changedMap.insert(TQString::fromLatin1("TQButton"), TQT_SIGNAL(stateChanged(int)));
-    changedMap.insert(TQString::fromLatin1("TQCheckBox"), TQT_SIGNAL(stateChanged(int)));
-    changedMap.insert(TQString::fromLatin1("TQPushButton"), TQT_SIGNAL(stateChanged(int)));
-    changedMap.insert(TQString::fromLatin1("TQRadioButton"), TQT_SIGNAL(stateChanged(int)));
-    changedMap.insert(TQString::fromLatin1("TQComboBox"), TQT_SIGNAL(activated (int)));
+    changedMap.insert(TQString::tqfromLatin1(TQBUTTON_OBJECT_NAME_STRING), TQT_SIGNAL(stateChanged(int)));
+    changedMap.insert(TQString::tqfromLatin1(TQCHECKBOX_OBJECT_NAME_STRING), TQT_SIGNAL(stateChanged(int)));
+    changedMap.insert(TQString::tqfromLatin1(TQPUSHBUTTON_OBJECT_NAME_STRING), TQT_SIGNAL(stateChanged(int)));
+    changedMap.insert(TQString::tqfromLatin1(TQRADIOBUTTON_OBJECT_NAME_STRING), TQT_SIGNAL(stateChanged(int)));
+    changedMap.insert(TQString::tqfromLatin1(TQCOMBOBOX_OBJECT_NAME_STRING), TQT_SIGNAL(activated (int)));
     //qsqlproperty map doesn't store the text, but the value!
-    //changedMap.insert(TQString::fromLatin1("TQComboBox"), TQT_SIGNAL(textChanged(const TQString &)));
-    changedMap.insert(TQString::fromLatin1("QDateEdit"), TQT_SIGNAL(valueChanged(const TQDate &)));
-    changedMap.insert(TQString::fromLatin1("QDateTimeEdit"), TQT_SIGNAL(valueChanged(const TQDateTime &)));
-    changedMap.insert(TQString::fromLatin1("TQDial"), TQT_SIGNAL(valueChanged (int)));
-    changedMap.insert(TQString::fromLatin1("TQLineEdit"), TQT_SIGNAL(textChanged(const TQString &)));
-    changedMap.insert(TQString::fromLatin1("TQSlider"), TQT_SIGNAL(valueChanged(int)));
-    changedMap.insert(TQString::fromLatin1("TQSpinBox"), TQT_SIGNAL(valueChanged(int)));
-    changedMap.insert(TQString::fromLatin1("QTimeEdit"), TQT_SIGNAL(valueChanged(const TQTime &)));
-    changedMap.insert(TQString::fromLatin1("TQTextEdit"), TQT_SIGNAL(textChanged()));
-    changedMap.insert(TQString::fromLatin1("TQTextBrowser"), TQT_SIGNAL(sourceChanged(const TQString &)));
-    changedMap.insert(TQString::fromLatin1("TQMultiLineEdit"), TQT_SIGNAL(textChanged()));
-    changedMap.insert(TQString::fromLatin1("TQListBox"), TQT_SIGNAL(selectionChanged()));
-    changedMap.insert(TQString::fromLatin1("TQTabWidget"), TQT_SIGNAL(currentChanged(TQWidget *)));
+    //changedMap.insert(TQString::tqfromLatin1(TQCOMBOBOX_OBJECT_NAME_STRING), TQT_SIGNAL(textChanged(const TQString &)));
+    changedMap.insert(TQString::tqfromLatin1(TQDATEEDIT_OBJECT_NAME_STRING), TQT_SIGNAL(valueChanged(const TQDate &)));
+    changedMap.insert(TQString::tqfromLatin1(TQDATETIMEEDIT_OBJECT_NAME_STRING), TQT_SIGNAL(valueChanged(const TQDateTime &)));
+    changedMap.insert(TQString::tqfromLatin1(TQDIAL_OBJECT_NAME_STRING), TQT_SIGNAL(valueChanged (int)));
+    changedMap.insert(TQString::tqfromLatin1(TQLINEEDIT_OBJECT_NAME_STRING), TQT_SIGNAL(textChanged(const TQString &)));
+    changedMap.insert(TQString::tqfromLatin1(TQSLIDER_OBJECT_NAME_STRING), TQT_SIGNAL(valueChanged(int)));
+    changedMap.insert(TQString::tqfromLatin1(TQSPINBOX_OBJECT_NAME_STRING), TQT_SIGNAL(valueChanged(int)));
+    changedMap.insert(TQString::tqfromLatin1(TQTIMEEDIT_OBJECT_NAME_STRING), TQT_SIGNAL(valueChanged(const TQTime &)));
+    changedMap.insert(TQString::tqfromLatin1(TQTEXTEDIT_OBJECT_NAME_STRING), TQT_SIGNAL(textChanged()));
+    changedMap.insert(TQString::tqfromLatin1(TQTEXTBROWSER_OBJECT_NAME_STRING), TQT_SIGNAL(sourceChanged(const TQString &)));
+    changedMap.insert(TQString::tqfromLatin1(TQMULTILINEEDIT_OBJECT_NAME_STRING), TQT_SIGNAL(textChanged()));
+    changedMap.insert(TQString::tqfromLatin1(TQLISTBOX_OBJECT_NAME_STRING), TQT_SIGNAL(selectionChanged()));
+    changedMap.insert(TQString::tqfromLatin1(TQTABWIDGET_OBJECT_NAME_STRING), TQT_SIGNAL(currentChanged(TQWidget *)));
 
     // KDE
-    changedMap.insert( TQString::fromLatin1("KComboBox"), TQT_SIGNAL(activated (int)));
-    changedMap.insert( TQString::fromLatin1("KFontCombo"), TQT_SIGNAL(activated (int)));
-    changedMap.insert( TQString::fromLatin1("KFontRequester"), TQT_SIGNAL(fontSelected(const TQFont &)));
-    changedMap.insert( TQString::fromLatin1("KFontChooser"),  TQT_SIGNAL(fontSelected(const TQFont &)));
-    changedMap.insert( TQString::fromLatin1("KHistoryCombo"), TQT_SIGNAL(activated (int)));
+    changedMap.insert( TQString::tqfromLatin1("KComboBox"), TQT_SIGNAL(activated (int)));
+    changedMap.insert( TQString::tqfromLatin1("KFontCombo"), TQT_SIGNAL(activated (int)));
+    changedMap.insert( TQString::tqfromLatin1("KFontRequester"), TQT_SIGNAL(fontSelected(const TQFont &)));
+    changedMap.insert( TQString::tqfromLatin1("KFontChooser"),  TQT_SIGNAL(fontSelected(const TQFont &)));
+    changedMap.insert( TQString::tqfromLatin1("KHistoryCombo"), TQT_SIGNAL(activated (int)));
 
-    changedMap.insert( TQString::fromLatin1("KColorButton"), TQT_SIGNAL(changed(const TQColor &)));
-    changedMap.insert( TQString::fromLatin1("KDatePicker"), TQT_SIGNAL(dateSelected (TQDate)));
-    changedMap.insert( TQString::fromLatin1("KEditListBox"), TQT_SIGNAL(changed()));
-    changedMap.insert( TQString::fromLatin1("KListBox"), TQT_SIGNAL(selectionChanged()));
-    changedMap.insert( TQString::fromLatin1("KLineEdit"), TQT_SIGNAL(textChanged(const TQString &)));
-    changedMap.insert( TQString::fromLatin1("KPasswordEdit"), TQT_SIGNAL(textChanged(const TQString &)));
-    changedMap.insert( TQString::fromLatin1("KRestrictedLine"), TQT_SIGNAL(textChanged(const TQString &)));
-    changedMap.insert( TQString::fromLatin1("KTextBrowser"), TQT_SIGNAL(sourceChanged(const TQString &)));
-    changedMap.insert( TQString::fromLatin1("KTextEdit"), TQT_SIGNAL(textChanged()));
-    changedMap.insert( TQString::fromLatin1("KURLRequester"),  TQT_SIGNAL(textChanged (const TQString& )));
-    changedMap.insert( TQString::fromLatin1("KIntNumInput"), TQT_SIGNAL(valueChanged (int)));
-    changedMap.insert( TQString::fromLatin1("KIntSpinBox"), TQT_SIGNAL(valueChanged (int)));
-    changedMap.insert( TQString::fromLatin1("KDoubleNumInput"), TQT_SIGNAL(valueChanged (double)));
+    changedMap.insert( TQString::tqfromLatin1("KColorButton"), TQT_SIGNAL(changed(const TQColor &)));
+    changedMap.insert( TQString::tqfromLatin1("KDatePicker"), TQT_SIGNAL(dateSelected (TQDate)));
+    changedMap.insert( TQString::tqfromLatin1("KEditListBox"), TQT_SIGNAL(changed()));
+    changedMap.insert( TQString::tqfromLatin1("KListBox"), TQT_SIGNAL(selectionChanged()));
+    changedMap.insert( TQString::tqfromLatin1("KLineEdit"), TQT_SIGNAL(textChanged(const TQString &)));
+    changedMap.insert( TQString::tqfromLatin1("KPasswordEdit"), TQT_SIGNAL(textChanged(const TQString &)));
+    changedMap.insert( TQString::tqfromLatin1("KRestrictedLine"), TQT_SIGNAL(textChanged(const TQString &)));
+    changedMap.insert( TQString::tqfromLatin1("KTextBrowser"), TQT_SIGNAL(sourceChanged(const TQString &)));
+    changedMap.insert( TQString::tqfromLatin1("KTextEdit"), TQT_SIGNAL(textChanged()));
+    changedMap.insert( TQString::tqfromLatin1("KURLRequester"),  TQT_SIGNAL(textChanged (const TQString& )));
+    changedMap.insert( TQString::tqfromLatin1("KIntNumInput"), TQT_SIGNAL(valueChanged (int)));
+    changedMap.insert( TQString::tqfromLatin1("KIntSpinBox"), TQT_SIGNAL(valueChanged (int)));
+    changedMap.insert( TQString::tqfromLatin1("KDoubleNumInput"), TQT_SIGNAL(valueChanged (double)));
   }
 
-  // Go through all of the children of the widgets and find all known widgets
+  // Go through all of the tqchildren of the widgets and find all known widgets
   TQPtrListIterator<TQWidget> it( d->widgets );
   TQWidget *widget;
   bool usingDefaultValues = false;
@@ -215,8 +215,8 @@ bool KAutoConfig::saveSettings() {
       TQVariant defaultValue = d->defaultValues[groupWidget];
       TQVariant currentValue = propertyMap->property(groupWidget);
 #if KDE_IS_VERSION( 3, 1, 90 )
-      if(!config->hasDefault(TQString::fromLatin1(groupWidget->name())) && currentValue == defaultValue){
-        config->revertToDefault(TQString::fromLatin1(groupWidget->name()));
+      if(!config->hasDefault(TQString::tqfromLatin1(groupWidget->name())) && currentValue == defaultValue){
+        config->revertToDefault(TQString::tqfromLatin1(groupWidget->name()));
         widgetChanged = true;
       }
       else{
@@ -353,12 +353,12 @@ void KAutoConfig::reloadSettings() const {
 bool KAutoConfig::parseChildren(const TQWidget *widget,
     TQPtrList<TQWidget>& currentGroup, bool trackChanges){
   bool valueChanged = false;
-  const TQPtrList<TQObject> *listOfChildren = widget->children();
-  if(!listOfChildren)
+  const TQObjectList listOfChildren = widget->childrenListObject();
+  if(listOfChildren.isEmpty())
     return valueChanged;
 
   TQSqlPropertyMap *propertyMap = TQSqlPropertyMap::defaultMap();
-  TQPtrListIterator<TQObject> it( *listOfChildren );
+  TQPtrListIterator<TQObject> it( listOfChildren );
   TQObject *object;
   while ( (object = it.current()) != 0 )
   {
@@ -390,7 +390,7 @@ bool KAutoConfig::parseChildren(const TQWidget *widget,
       {
         parseTheChildren = false;
         // Disable the widget if it is immutable?
-        if(config->entryIsImmutable( TQString::fromLatin1(childWidget->name())))
+        if(config->entryIsImmutable( TQString::tqfromLatin1(childWidget->name())))
           childWidget->setEnabled(false);
         else
         {
@@ -408,15 +408,15 @@ bool KAutoConfig::parseChildren(const TQWidget *widget,
           propertyMap->setProperty(childWidget, setting);
           valueChanged = true;
         }
-        if(trackChanges && changedMap.find(TQString::fromLatin1(childWidget->className())) !=
+        if(trackChanges && changedMap.find(TQString::tqfromLatin1(childWidget->className())) !=
             changedMap.end())
         {
-          connect(childWidget, changedMap[TQString::fromLatin1(childWidget->className())],
+          connect(childWidget, changedMap[TQString::tqfromLatin1(childWidget->className())],
                   this, TQT_SIGNAL(widgetModified()));
         }
 #ifndef NDEBUG
         else if(trackChanges &&
-          changedMap.find(TQString::fromLatin1(childWidget->className())) == changedMap.end())
+          changedMap.find(TQString::tqfromLatin1(childWidget->className())) == changedMap.end())
         {
           // Without a signal kautoconfigdialog could incorectly 
 	  // enable/disable the buttons
@@ -439,7 +439,7 @@ bool KAutoConfig::parseChildren(const TQWidget *widget,
     if(parseTheChildren)
     {
       // this widget is not known as something we can store.
-      // Maybe we can store one of its children.
+      // Maybe we can store one of its tqchildren.
       valueChanged |= parseChildren(childWidget, currentGroup, trackChanges);
     }
   }
