@@ -63,19 +63,20 @@ class BlackLister;
  *
  * @author Olivier Goffart  <ogoffart@tiscalinet.be>
  */
-class KOPETE_EXPORT Account : public QObject
+class KOPETE_EXPORT Account : public TQObject
 {
 	Q_OBJECT
+  TQ_OBJECT
 
 	Q_ENUMS( AddMode )
-	Q_PROPERTY( TQString accountId READ accountId )
-	Q_PROPERTY( bool excludeConnect READ excludeConnect WRITE setExcludeConnect )
-	Q_PROPERTY( TQColor color READ color WRITE setColor )
-	Q_PROPERTY( TQPixmap accountIcon READ accountIcon )
-	Q_PROPERTY( bool isConnected READ isConnected )
-	Q_PROPERTY( bool isAway READ isAway )
-	Q_PROPERTY( bool suppressStatusNotification READ suppressStatusNotification )
-	Q_PROPERTY( uint priority READ priority WRITE setPriority )
+	TQ_PROPERTY( TQString accountId READ accountId )
+	TQ_PROPERTY( bool excludeConnect READ excludeConnect WRITE setExcludeConnect )
+	TQ_PROPERTY( TQColor color READ color WRITE setColor )
+	TQ_PROPERTY( TQPixmap accountIcon READ accountIcon )
+	TQ_PROPERTY( bool isConnected READ isConnected )
+	TQ_PROPERTY( bool isAway READ isAway )
+	TQ_PROPERTY( bool suppressStatusNotification READ suppressStatusNotification )
+	TQ_PROPERTY( uint priority READ priority WRITE setPriority )
 
 public:
 	/**
@@ -181,7 +182,7 @@ public:
 	/**
 	 * \brief change the account icon.
 	 * by default the icon of an account is the protocol one, but it may be overide it.
-	 * Set TQString::null to go back to the default  (the protocol icon)
+	 * Set TQString() to go back to the default  (the protocol icon)
 	 * 
 	 * this call will emit colorChanged()
 	 */
@@ -264,13 +265,13 @@ public:
 	 * If @p mode is @c DontChangeKABC, no additional action is carried out.
 	 *
 	 * @param contactId the @ref Contact::contactId of the contact to create
-	 * @param displayName the displayname (alias) of the new metacontact. Leave as TQString::null if
+	 * @param displayName the displayname (alias) of the new metacontact. Leave as TQString() if
 	 *                    no alias is known, then by default, the nick will be taken as alias and tracked if changed.
 	 * @param group the group to add the created metacontact to, or 0 for the top-level group.
 	 * @param mode the mode used to add the contact. Use DontChangeKABC when deserializing.
 	 * @return the new created metacontact or 0L if the operation failed
 	 */
-	MetaContact* addContact( const TQString &contactId, const TQString &displayName = TQString::null, Group *group = 0, AddMode mode = DontChangeKABC ) ;
+	MetaContact* addContact( const TQString &contactId, const TQString &displayName = TQString(), Group *group = 0, AddMode mode = DontChangeKABC ) ;
 
 	/**
 	 * @brief Create a new contact, adding it to an existing metacontact
@@ -300,7 +301,7 @@ public:
 	/**
 	 * @brief Indicate whether the account is away.
 	 *
-	 * This is a convenience method that queries @ref Contact::onlineStatus() on @ref myself().
+	 * This is a convenience method that queries @ref Contact::onlinetqStatus() on @ref myself().
 	 * This function is safe to call if @ref setMyself() has not been called yet.
 	 */
 	bool isAway() const;
@@ -408,7 +409,7 @@ protected slots:
 	 *
 	 * @param status the status to set all contacts of this account except @ref myself() to.
 	 */
-	void setAllContactsStatus( const Kopete::OnlineStatus &status );
+	void setAllContactstqStatus( const Kopete::OnlineStatus &status );
 
 signals:
 	/**
@@ -449,10 +450,10 @@ public slots:
 	/**
 	 * @brief Go online for this service.
 	 *
-	 * @param initialStatus is the status to connect with. If it is an invalid status for this
+	 * @param initialtqStatus is the status to connect with. If it is an invalid status for this
 	 * account, the default online for the account should be used.
 	 */
-	virtual void connect( const Kopete::OnlineStatus& initialStatus = OnlineStatus() ) = 0;
+	virtual void connect( const Kopete::OnlineStatus& initialtqStatus = OnlineStatus() ) = 0;
 
 	/**
 	 * @brief Go offline for this service.
@@ -470,7 +471,7 @@ public slots:
 	 *
 	 * @todo change ; make use of setOnlineStatus
 	 */
-	virtual void setAway( bool away, const TQString &reason = TQString::null );
+	virtual void setAway( bool away, const TQString &reason = TQString() );
 
 	/**
 	 * Reimplement this function to set the online status
@@ -478,7 +479,7 @@ public slots:
 	 * @param reason is the away message to set.
 	 * @note If needed, you need to connect.  if the offline status is given, you should disconnect
 	 */
-	virtual void setOnlineStatus( const Kopete::OnlineStatus& status , const TQString &reason = TQString::null ) = 0;
+	virtual void setOnlineStatus( const Kopete::OnlineStatus& status , const TQString &reason = TQString() ) = 0;
 
 	/**
 	 * Display the edit account widget for the account
@@ -515,7 +516,7 @@ private slots:
 	/**
 	 * The @ref myself() contact's online status changed.
 	 */
-	void slotOnlineStatusChanged( Kopete::Contact *contact, const Kopete::OnlineStatus &newStatus, const Kopete::OnlineStatus &oldStatus );
+	void slotOnlineStatusChanged( Kopete::Contact *contact, const Kopete::OnlineStatus &newtqStatus, const Kopete::OnlineStatus &oldtqStatus );
 
 	/**
 	 * The @ref myself() contact's property changed.
