@@ -51,22 +51,23 @@ typedef TQPtrList<Group> GroupList;
  * This class abstracts a generic contact
  * Use it for inserting contacts in the contact list for example.
  */
-class KOPETE_EXPORT Contact : public QObject
+class KOPETE_EXPORT Contact : public TQObject
 {
 	Q_OBJECT
+  TQ_OBJECT
 
 	Q_ENUMS( CanCreateFlags )
-	Q_PROPERTY( TQString formattedName READ formattedName )
-	Q_PROPERTY( TQString formattedIdleTime READ formattedIdleTime )
-	Q_PROPERTY( bool isOnline READ isOnline )
-	Q_PROPERTY( bool fileCapable READ isFileCapable WRITE setFileCapable )
-	Q_PROPERTY( bool canAcceptFiles READ canAcceptFiles )
-	//Q_PROPERTY( bool isReachable READ isReachable )
-	Q_PROPERTY( TQString contactId READ contactId )
-	Q_PROPERTY( TQString icon READ icon WRITE setIcon )
-	Q_PROPERTY( TQString toolTip READ toolTip )
-	Q_PROPERTY( TQString nickName READ nickName WRITE setNickName )
-	//Q_PROPERTY( unsigned long idleTime READ idleTime WRITE setIdleTime )
+	TQ_PROPERTY( TQString formattedName READ formattedName )
+	TQ_PROPERTY( TQString formattedIdleTime READ formattedIdleTime )
+	TQ_PROPERTY( bool isOnline READ isOnline )
+	TQ_PROPERTY( bool fileCapable READ isFileCapable WRITE setFileCapable )
+	TQ_PROPERTY( bool canAcceptFiles READ canAcceptFiles )
+	//TQ_PROPERTY( bool isReachable READ isReachable )
+	TQ_PROPERTY( TQString contactId READ contactId )
+	TQ_PROPERTY( TQString icon READ icon WRITE setIcon )
+	TQ_PROPERTY( TQString toolTip READ toolTip )
+	TQ_PROPERTY( TQString nickName READ nickName WRITE setNickName )
+	//TQ_PROPERTY( unsigned long idleTime READ idleTime WRITE setIdleTime )
 
 public:
 	/**
@@ -87,7 +88,7 @@ public:
 	 * @param icon is an optional icon
 	 */
 	Contact( Account *account, const TQString &id, MetaContact *parent,
-		const TQString &icon = TQString::null );
+		const TQString &icon = TQString() );
 
 	~Contact();
 
@@ -203,7 +204,7 @@ public:
 	 * @brief Get the online status of the contact
 	 * @return the online status of the contact
 	 */
-	OnlineStatus onlineStatus() const;
+	OnlineStatus onlinetqStatus() const;
 
 	/**
 	 * \brief Set the contact's online status
@@ -475,7 +476,7 @@ public slots:
 	 *                file size (such as over  asocket
 	 */
 	virtual void sendFile( const KURL &sourceURL = KURL(),
-			       const TQString &fileName = TQString::null, uint fileSize = 0L );
+			       const TQString &fileName = TQString(), uint fileSize = 0L );
 
 private slots:
 
@@ -509,7 +510,7 @@ signals:
 	 * The contact's online status changed
 	 */
 	void onlineStatusChanged( Kopete::Contact *contact,
-		const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldStatus );
+		const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldtqStatus );
 
 	/**
 	 * The contact is about to be destroyed.
