@@ -58,7 +58,7 @@ class  MetaContact::Private
 	Private() :
 		photoSource(MetaContact::SourceCustom), displayNameSource(MetaContact::SourceCustom),
 		displayNameSourceContact(0L),  photoSourceContact(0L), temporary(false),
-		onlineStatus(Kopete::OnlineStatus::Offline), photoSyncedWithKABC(false)
+		onlinetqStatus(Kopete::OnlineStatus::Offline), photoSyncedWithKABC(false)
 	{}
 
 	~Private()
@@ -85,7 +85,7 @@ class  MetaContact::Private
 	TQMap<TQString, TQMap<TQString, TQString> > addressBook;
 	bool temporary;
 	
-	OnlineStatus::StatusType onlineStatus;
+	OnlineStatus::StatusType onlinetqStatus;
 	bool photoSyncedWithKABC;
 
 	// Used to set contact source at load.
@@ -171,22 +171,22 @@ void MetaContact::addContact( Contact *c )
 
 void MetaContact::updateOnlineStatus()
 {
-	Kopete::OnlineStatus::StatusType newStatus = Kopete::OnlineStatus::Unknown;
-	Kopete::OnlineStatus mostSignificantStatus;
+	Kopete::OnlineStatus::StatusType newtqStatus = Kopete::OnlineStatus::Unknown;
+	Kopete::OnlineStatus mostSignificanttqStatus;
 
 	for ( TQPtrListIterator<Contact> it( d->contacts ); it.current(); ++it )
 	{
 		// find most significant status
-		if ( it.current()->onlineStatus() > mostSignificantStatus )
-			mostSignificantStatus = it.current()->onlineStatus();
+		if ( it.current()->onlinetqStatus() > mostSignificanttqStatus )
+			mostSignificanttqStatus = it.current()->onlinetqStatus();
 	}
 
-	newStatus = mostSignificantStatus.status();
+	newtqStatus = mostSignificanttqStatus.status();
 
-	if( newStatus != d->onlineStatus )
+	if( newtqStatus != d->onlinetqStatus )
 	{
-		d->onlineStatus = newStatus;
-		emit onlineStatusChanged( this, d->onlineStatus );
+		d->onlinetqStatus = newtqStatus;
+		emit onlineStatusChanged( this, d->onlinetqStatus );
 	}
 }
 
@@ -257,7 +257,7 @@ void MetaContact::removeContact(Contact *c, bool deleted)
 		}		
 
 		if(!deleted)
-		{  //If this function is tell by slotContactRemoved, c is maybe just a QObject
+		{  //If this function is tell by slotContactRemoved, c is maybe just a TQObject
 			disconnect( c, TQT_SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
 				this, TQT_SLOT( slotContactStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
 			disconnect( c, TQT_SIGNAL( propertyChanged( Kopete::Contact *, const TQString &, const TQVariant &, const TQVariant & ) ),
@@ -415,14 +415,14 @@ Contact *MetaContact::preferredContact()
 			continue;
 		}
 
-		if( c->onlineStatus().status() > contact->onlineStatus().status()  )
+		if( c->onlinetqStatus().status() > contact->onlinetqStatus().status()  )
 			contact=c; //this contact has a better status
-		else if ( c->onlineStatus().status() == contact->onlineStatus().status() )
+		else if ( c->onlinetqStatus().status() == contact->onlinetqStatus().status() )
 		{
 			if( c->account()->priority() > contact->account()->priority() )
 				contact=c;
 			else if(  c->account()->priority() == contact->account()->priority()
-					&& c->onlineStatus().weight() > contact->onlineStatus().weight() )
+					&& c->onlinetqStatus().weight() > contact->onlinetqStatus().weight() )
 				contact = c;  //the weight is not supposed to follow the same scale for each protocol
 		}
 	}
@@ -513,7 +513,7 @@ TQString MetaContact::statusString() const
 
 OnlineStatus::StatusType MetaContact::status() const
 {
-	return d->onlineStatus;
+	return d->onlinetqStatus;
 }
 
 bool MetaContact::isOnline() const
@@ -566,7 +566,7 @@ void MetaContact::sendFile( const KURL &sourceURL, const TQString &altFileName,
 	Contact *contact = d->contacts.first();
 	for( TQPtrListIterator<Contact> it( d->contacts ) ; it.current(); ++it )
 	{
-		if( ( *it )->onlineStatus() > contact->onlineStatus() && ( *it )->canAcceptFiles() )
+		if( ( *it )->onlinetqStatus() > contact->onlinetqStatus() && ( *it )->canAcceptFiles() )
 			contact = *it;
 	}
 
@@ -653,13 +653,13 @@ TQString nameFromKABC( const TQString &id ) /*const*/
 		}
 	}
 	// no kabc association, return null image
-	return TQString::null;
+	return TQString();
 }
 
 TQString nameFromContact( Kopete::Contact *c) /*const*/
 {
 	if ( !c ) 
-		return TQString::null;
+		return TQString();
 
 	TQString contactName;
 	if ( c->hasProperty( Kopete::Global::Properties::self()->nickName().key() ) )
@@ -690,7 +690,7 @@ TQImage MetaContact::photo() const
   if( picture().image().width() > 96 && picture().image().height() > 96 )
     {
       kdDebug( 14010 )  << k_funcinfo << "Resizing image from " << picture().image().width() << " x " << picture().image().height() << endl;
-      return picture().image().smoothScale(96,96,TQImage::ScaleMin);
+      return picture().image().smoothScale(96,96,TQ_ScaleMin);
     }
   else
     return picture().image();
@@ -1162,8 +1162,8 @@ bool MetaContact::fromXML( const TQDomElement& element )
 		}
 		else if( contactElement.tagName() == TQString::fromUtf8( "address-book-field" ) )
 		{
-			TQString app = contactElement.attribute( TQString::fromUtf8( "app" ), TQString::null );
-			TQString key = contactElement.attribute( TQString::fromUtf8( "key" ), TQString::null );
+			TQString app = contactElement.attribute( TQString::fromUtf8( "app" ), TQString() );
+			TQString key = contactElement.attribute( TQString::fromUtf8( "key" ), TQString() );
 			TQString val = contactElement.text();
 			d->addressBook[ app ][ key ] = val;
 		}
@@ -1338,7 +1338,7 @@ TQString MetaContact::metaContactId() const
 	{
 		Contact *c=d->contacts.first();
 		if(!c)
-			return TQString::null;
+			return TQString();
 		return c->protocol()->pluginId()+TQString::fromUtf8(":")+c->account()->accountId()+TQString::fromUtf8(":") + c->contactId() ;
 	}
 	return d->metaContactId;
@@ -1360,7 +1360,7 @@ void MetaContact::setMetaContactId( const TQString& newMetaContactId )
 	// other programs may have written that data and depend on it
 	d->metaContactId = newMetaContactId;
 	KABCPersistence::self()->write( this );
-	emit onlineStatusChanged( this, d->onlineStatus );
+	emit onlineStatusChanged( this, d->onlinetqStatus );
 	emit persistentDataChanged();
 }
 
