@@ -57,17 +57,18 @@ class Picture;
 class KOPETE_EXPORT MetaContact : public ContactListElement, public NotifyDataObject
 {
 	Q_OBJECT
+  TQ_OBJECT
 
-	Q_PROPERTY( TQString displayName READ displayName WRITE setDisplayName )
-	Q_PROPERTY( TQString statusString READ statusString )
-	Q_PROPERTY( TQString statusIcon READ statusIcon )
-	Q_PROPERTY( bool isOnline READ isOnline )
-	Q_PROPERTY( bool isReachable READ isReachable )
-	Q_PROPERTY( bool isTemporary READ isTemporary )
-	Q_PROPERTY( bool canAcceptFiles READ canAcceptFiles )
-	//Q_PROPERTY( ulong idleTime READ idleTime )
-	Q_PROPERTY( TQString metaContactId READ metaContactId WRITE setMetaContactId )
-	Q_PROPERTY( bool photoSyncedWithKABC READ isPhotoSyncedWithKABC WRITE setPhotoSyncedWithKABC )
+	TQ_PROPERTY( TQString displayName READ displayName WRITE setDisplayName )
+	TQ_PROPERTY( TQString statusString READ statusString )
+	TQ_PROPERTY( TQString statusIcon READ statusIcon )
+	TQ_PROPERTY( bool isOnline READ isOnline )
+	TQ_PROPERTY( bool isReachable READ isReachable )
+	TQ_PROPERTY( bool isTemporary READ isTemporary )
+	TQ_PROPERTY( bool canAcceptFiles READ canAcceptFiles )
+	//TQ_PROPERTY( ulong idleTime READ idleTime )
+	TQ_PROPERTY( TQString metaContactId READ metaContactId WRITE setMetaContactId )
+	TQ_PROPERTY( bool photoSyncedWithKABC READ isPhotoSyncedWithKABC WRITE setPhotoSyncedWithKABC )
 
 public:
 	/** 
@@ -414,7 +415,7 @@ public slots:
 	 *                file size (such as over a socket)
 	 *
 	 */
-	void sendFile( const KURL &sourceURL, const TQString &altFileName = TQString::null,
+	void sendFile( const KURL &sourceURL, const TQString &altFileName = TQString(),
 		unsigned long fileSize = 0L );
 signals:
 	/**
@@ -558,7 +559,7 @@ private slots:
 	/**
 	 * One of the child contact's online status changed
 	 */
-	void slotContactStatusChanged( Kopete::Contact *c, const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldStatus );
+	void slotContactStatusChanged( Kopete::Contact *c, const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldtqStatus );
 
 	/**
 	 * One of the child contact's property changed
