@@ -1,5 +1,5 @@
 /*
-    Contact mock object class
+    Contact tqmock object class
 
     Copyright (c) 2005 by Duncan Mac-Vicar Prett  <duncan@kde.org>
 
@@ -15,8 +15,8 @@
     *************************************************************************
 */
 
-#ifndef _KOPETECONTACT_MOCK_H_
-#define _KOPETECONTACT_MOCK_H_
+#ifndef _KOPETECONTACT_TQMOCK_H_
+#define _KOPETECONTACT_TQMOCK_H_
 
 #include "kopetecontact.h"
 
@@ -35,7 +35,7 @@ namespace Mock
 class Contact : public Kopete::Contact
 {
 public:
-	Contact( Kopete::Account *account, const TQString &id, Kopete::MetaContact *parent, const TQString &icon = TQString::null );
+	Contact( Kopete::Account *account, const TQString &id, Kopete::MetaContact *parent, const TQString &icon = TQString() );
 	~Contact();
 	virtual Kopete::ChatSession* manager( CanCreateFlags canCreate = CannotCreate );
 };
