@@ -95,14 +95,14 @@ int KListViewDateItem::compare(TQListViewItem *i, int col, bool ascending) const
 
 HistoryDialog::HistoryDialog(Kopete::MetaContact *mc, TQWidget* parent,
 	const char* name) : KDialogBase(parent, name, false,
-		i18n("History for %1").arg(mc->displayName()), 0), mSearching(false)
+		i18n("History for %1").tqarg(mc->displayName()), 0), mSearching(false)
 {
 	TQString fontSize;
 	TQString htmlCode;
 	TQString fontStyle;
 
 	kdDebug(14310) << k_funcinfo << "called." << endl;
-	setWFlags(Qt::WDestructiveClose);	// send TQT_SIGNAL(closing()) on quit
+	setWFlags(TQt::WDestructiveClose);	// send TQT_SIGNAL(closing()) on quit
 
 	// FIXME: Allow to show this dialog for only one contact
 	mMetaContact = mc;
@@ -147,8 +147,8 @@ HistoryDialog::HistoryDialog(Kopete::MetaContact *mc, TQWidget* parent,
 	mHtmlView = mHtmlPart->view();
 	mHtmlView->setMarginWidth(4);
 	mHtmlView->setMarginHeight(4);
-	mHtmlView->setFocusPolicy(NoFocus);
-	mHtmlView->setSizePolicy(
+	mHtmlView->setFocusPolicy(TQ_NoFocus);
+	mHtmlView->tqsetSizePolicy(
 	TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding));
 	l->addWidget(mHtmlView);
 
@@ -157,7 +157,7 @@ HistoryDialog::HistoryDialog(Kopete::MetaContact *mc, TQWidget* parent,
 
 	mHtmlPart->begin();
 	htmlCode = "<html><head>" + fontStyle + "</head><body class=\"hf\"></body></html>";
-	mHtmlPart->write( TQString::fromLatin1( htmlCode.latin1() ) );
+	mHtmlPart->write( TQString::tqfromLatin1( htmlCode.latin1() ) );
 	mHtmlPart->end();
 
 	
@@ -174,8 +174,8 @@ HistoryDialog::HistoryDialog(Kopete::MetaContact *mc, TQWidget* parent,
 
 	//initActions
 	KActionCollection* ac = new KActionCollection(this);
-	mCopyAct = KStdAction::copy( this, TQT_SLOT(slotCopy()), ac );
-	mCopyURLAct = new KAction( i18n( "Copy Link Address" ), TQString::fromLatin1( "editcopy" ), 0, this, TQT_SLOT( slotCopyURL() ), ac );
+	mCopyAct = KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT(slotCopy()), ac );
+	mCopyURLAct = new KAction( i18n( "Copy Link Address" ), TQString::tqfromLatin1( "editcopy" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotCopyURL() ), ac );
 
 	resize(650, 700);
 	centerOnScreen(this);
@@ -196,7 +196,7 @@ void HistoryDialog::init()
 {
 	if(mMetaContact)
 	{
-		HistoryLogger logger(mMetaContact, this);
+		HistoryLogger logger(mMetaContact, TQT_TQOBJECT(this));
 		init(mMetaContact);
 	}
 	else
@@ -204,7 +204,7 @@ void HistoryDialog::init()
 		TQPtrListIterator<Kopete::MetaContact> it(mMetaContactList);
 		for(; it.current(); ++it)
 		{
-			HistoryLogger logger(*it, this);
+			HistoryLogger logger(*it, TQT_TQOBJECT(this));
 			init(*it);
 		}
 
@@ -226,7 +226,7 @@ void HistoryDialog::slotLoadDays()
 		
 		DMPair pair(mInit.dateMCList.first());
 		mInit.dateMCList.pop_front();
-		HistoryLogger logger(pair.metaContact(), this);
+		HistoryLogger logger(pair.metaContact(), TQT_TQOBJECT(this));
 		TQValueList<int> dayList = logger.getDaysForMonth(pair.date());
 		for (unsigned int i=0; i<dayList.count(); i++)
 		{
@@ -255,21 +255,21 @@ void HistoryDialog::init(Kopete::Contact *c)
 {
 	// Get year and month list
 	TQRegExp rx( "\\.(\\d\\d\\d\\d)(\\d\\d)" );
-	const TQString contact_in_filename=c->contactId().replace( TQRegExp( TQString::fromLatin1( "[./~?*]" ) ), TQString::fromLatin1( "-" ) );
+	const TQString contact_in_filename=c->contactId().replace( TQRegExp( TQString::tqfromLatin1( "[./~?*]" ) ), TQString::tqfromLatin1( "-" ) );
 	TQFileInfo *fi;
 	
 
 	// BEGIN check if there are Kopete 0.7.x
 	TQDir d1(locateLocal("data",TQString("kopete/logs/")+
-			c->protocol()->pluginId().replace( TQRegExp(TQString::fromLatin1("[./~?*]")),TQString::fromLatin1("-"))
+			c->protocol()->pluginId().replace( TQRegExp(TQString::tqfromLatin1("[./~?*]")),TQString::tqfromLatin1("-"))
 					   ));
 	d1.setFilter( TQDir::Files | TQDir::NoSymLinks );
 	d1.setSorting( TQDir::Name );
 
-	const QFileInfoList *list1 = d1.entryInfoList();
+	const TQFileInfoList *list1 = d1.entryInfoList();
 	if ( list1 != 0 )
 	{
-		QFileInfoListIterator it1( *list1 );
+		TQFileInfoListIterator it1( *list1 );
 		while ( (fi = it1.current()) != 0 )
 		{
 			if(fi->fileName().contains(contact_in_filename))
@@ -288,17 +288,17 @@ void HistoryDialog::init(Kopete::Contact *c)
 	// END of kopete 0.7.x check
 
 	TQString logDir = locateLocal("data",TQString("kopete/logs/")+
-			c->protocol()->pluginId().replace( TQRegExp(TQString::fromLatin1("[./~?*]")),TQString::fromLatin1("-")) +
-					TQString::fromLatin1( "/" ) +
-					c->account()->accountId().replace( TQRegExp( TQString::fromLatin1( "[./~?*]" ) ), TQString::fromLatin1( "-" ) )
+			c->protocol()->pluginId().replace( TQRegExp(TQString::tqfromLatin1("[./~?*]")),TQString::tqfromLatin1("-")) +
+					TQString::tqfromLatin1( "/" ) +
+					c->account()->accountId().replace( TQRegExp( TQString::tqfromLatin1( "[./~?*]" ) ), TQString::tqfromLatin1( "-" ) )
 								);
 	TQDir d(logDir);
 	d.setFilter( TQDir::Files | TQDir::NoSymLinks );
 	d.setSorting( TQDir::Name );
-	const QFileInfoList *list = d.entryInfoList();
+	const TQFileInfoList *list = d.entryInfoList();
 	if ( list != 0 )
 	{
-		QFileInfoListIterator it( *list );
+		TQFileInfoListIterator it( *list );
 		while ( (fi = it.current()) != 0 )
 		{
 			if(fi->fileName().contains(contact_in_filename))
@@ -325,7 +325,7 @@ void HistoryDialog::dateSelected(TQListViewItem* it)
 
 	TQDate chosenDate = item->date();
 
-	HistoryLogger logger(item->metaContact(), this);
+	HistoryLogger logger(item->metaContact(), TQT_TQOBJECT(this));
 	TQValueList<Kopete::Message> msgs=logger.readMessages(chosenDate);
 
 	setMessages(msgs);
@@ -339,16 +339,16 @@ void HistoryDialog::setMessages(TQValueList<Kopete::Message> msgs)
 		htmlBody.removeChild(htmlBody.childNodes().item(htmlBody.childNodes().length() - 1));
 	// ----
 
-	TQString dir = (TQApplication::reverseLayout() ? TQString::fromLatin1("rtl") :
-		TQString::fromLatin1("ltr"));
+	TQString dir = (TQApplication::reverseLayout() ? TQString::tqfromLatin1("rtl") :
+		TQString::tqfromLatin1("ltr"));
 
 	TQValueList<Kopete::Message>::iterator it = msgs.begin();
 
 
 	TQString accountLabel;
 	TQString resultHTML = "<b><font color=\"red\">" + (*it).timestamp().date().toString() + "</font></b><br/>";
-	DOM::HTMLElement newNode = mHtmlPart->document().createElement(TQString::fromLatin1("span"));
-	newNode.setAttribute(TQString::fromLatin1("dir"), dir);
+	DOM::HTMLElement newNode = mHtmlPart->document().createElement(TQString::tqfromLatin1("span"));
+	newNode.setAttribute(TQString::tqfromLatin1("dir"), dir);
 	newNode.setInnerHTML(resultHTML);
 	mHtmlPart->htmlDocument().body().appendChild(newNode);
 
@@ -384,8 +384,8 @@ void HistoryDialog::setMessages(TQValueList<Kopete::Message> msgs)
 									: "<font color=\"" + KopetePrefs::prefs()->textColor().light(200).name() + "\"><b>&lt;</b></font> ")
 					+ body + "<br/>";
 	
-			newNode = mHtmlPart->document().createElement(TQString::fromLatin1("span"));
-			newNode.setAttribute(TQString::fromLatin1("dir"), dir);
+			newNode = mHtmlPart->document().createElement(TQString::tqfromLatin1("span"));
+			newNode.setAttribute(TQString::tqfromLatin1("dir"), dir);
 			newNode.setInnerHTML(resultHTML);
 	
 			mHtmlPart->htmlDocument().body().appendChild(newNode);
@@ -477,7 +477,7 @@ void HistoryDialog::slotSearch()
 		curItem = static_cast<KListViewDateItem *>(curItem->nextSibling())
 	)
 	{
-		qApp->processEvents();
+		tqApp->processEvents();
 		if (!mSearching) return;
 
 		TQDate month(curItem->date().year(),curItem->date().month(),1);
@@ -496,7 +496,7 @@ void HistoryDialog::slotSearch()
 				if (!file.isOpen())
 				{
 					kdWarning(14310) << k_funcinfo << "Error opening " <<
-							file.name() << ": " << file.errorString() << endl;
+							file.name() << ": " << TQString(file.errorString()).ascii() << endl;
 					continue;
 				}
 
@@ -517,7 +517,7 @@ void HistoryDialog::slotSearch()
 						// parsing the files would fix this
 						else { }
 					}
-					qApp->processEvents();
+					tqApp->processEvents();
 					if (!mSearching) return;
 				}
 				file.close();
@@ -553,7 +553,7 @@ void HistoryDialog::slotContactChanged(int index)
 	else
 	{
 		mMetaContact = mMetaContactList.at(index-1);
-        setCaption(i18n("History for %1").arg(mMetaContact->displayName()));
+        setCaption(i18n("History for %1").tqarg(mMetaContact->displayName()));
 		init();
 	}
 }
@@ -597,16 +597,16 @@ void HistoryDialog::slotCopy()
 	if ( qsSelection.isEmpty() ) return;
 	
 	disconnect( kapp->clipboard(), TQT_SIGNAL( selectionChanged()), mHtmlPart, TQT_SLOT(slotClearSelection()));
-	TQApplication::clipboard()->setText(qsSelection, QClipboard::Clipboard);
-	TQApplication::clipboard()->setText(qsSelection, QClipboard::Selection);
+	TQApplication::tqclipboard()->setText(qsSelection, TQClipboard::Clipboard);
+	TQApplication::tqclipboard()->setText(qsSelection, TQClipboard::Selection);
 	connect( kapp->clipboard(), TQT_SIGNAL( selectionChanged()), mHtmlPart, TQT_SLOT(slotClearSelection()));
 }
 
 void HistoryDialog::slotCopyURL()
 {
 	disconnect( kapp->clipboard(), TQT_SIGNAL( selectionChanged()), mHtmlPart, TQT_SLOT(slotClearSelection()));
-	TQApplication::clipboard()->setText( mURL, QClipboard::Clipboard);
-	TQApplication::clipboard()->setText( mURL, QClipboard::Selection);
+	TQApplication::tqclipboard()->setText( mURL, TQClipboard::Clipboard);
+	TQApplication::tqclipboard()->setText( mURL, TQClipboard::Selection);
 	connect( kapp->clipboard(), TQT_SIGNAL( selectionChanged()), mHtmlPart, TQT_SLOT(slotClearSelection()));
 }
 
