@@ -45,7 +45,7 @@ HistoryLogger::HistoryLogger( Kopete::MetaContact *m,  TQObject *parent, const c
 	m_metaContact=m;
 	m_hideOutgoing=false;
 	m_cachedMonth=-1;
-	m_realMonth=TQDate::currentDate().month();
+	m_realMonth=TQDate::tqcurrentDate().month();
 	m_oldSens=Default;
 
 	//the contact may be destroyed, for example, if the contact changes its metacontact
@@ -63,7 +63,7 @@ HistoryLogger::HistoryLogger( Kopete::Contact *c,  TQObject *parent, const char
 	m_cachedMonth=-1;
 	m_metaContact=c->metaContact();
 	m_hideOutgoing=false;
-	m_realMonth=TQDate::currentDate().month();
+	m_realMonth=TQDate::tqcurrentDate().month();
 	m_oldSens=Default;
 
 	//the contact may be destroyed, for example, if the contact changes its metacontact
@@ -107,14 +107,14 @@ void HistoryLogger::setCurrentMonth(int month)
 
 TQDomDocument HistoryLogger::getDocument(const Kopete::Contact *c, unsigned int month , bool canLoad , bool* contain)
 {
-	if(m_realMonth!=TQDate::currentDate().month())
+	if(m_realMonth!=TQDate::tqcurrentDate().month())
 	{ //We changed month, our indice are not correct anymore, clean memory.
 	  // or we will see what i called "the 31 midnight bug"(TM) :-)  -Olivier
 		m_documents.clear();
 		m_cachedMonth=-1;
 		m_currentMonth++; //Not usre it's ok, but should work;
 		m_oldMonth++;     // idem
-		m_realMonth=TQDate::currentDate().month();
+		m_realMonth=TQDate::tqcurrentDate().month();
 	}
 
 	if(!m_metaContact)
@@ -137,7 +137,7 @@ TQDomDocument HistoryLogger::getDocument(const Kopete::Contact *c, unsigned int
 		return documents[month];
 
 
-	TQDomDocument doc =  getDocument(c, TQDate::currentDate().addMonths(0-month), canLoad, contain);
+	TQDomDocument doc =  getDocument(c, TQDate::tqcurrentDate().addMonths(0-month), canLoad, contain);
 
 	documents.insert(month, doc);
 	m_documents[c]=documents;
@@ -170,7 +170,7 @@ TQDomDocument HistoryLogger::getDocument(const Kopete::Contact *c, const TQDate
 		return TQDomDocument();
 	}
 
-	QString	FileName = getFileName(c, date);
+	TQString	FileName = getFileName(c, date);
 
 	TQDomDocument doc( "Kopete-History" );
 
@@ -253,8 +253,8 @@ void HistoryLogger::appendMessage( const Kopete::Message &msg , const Kopete::Co
 		TQDomElement headElem = doc.createElement( "head" );
 		docElem.appendChild( headElem );
 		TQDomElement dateElem = doc.createElement( "date" );
-		dateElem.setAttribute( "year",  TQString::number(TQDate::currentDate().year()) );
-		dateElem.setAttribute( "month", TQString::number(TQDate::currentDate().month()) );
+		dateElem.setAttribute( "year",  TQString::number(TQDate::tqcurrentDate().year()) );
+		dateElem.setAttribute( "month", TQString::number(TQDate::tqcurrentDate().month()) );
 		headElem.appendChild(dateElem);
 		TQDomElement myselfElem = doc.createElement( "contact" );
 		myselfElem.setAttribute( "type",  "myself" );
@@ -280,7 +280,7 @@ void HistoryLogger::appendMessage( const Kopete::Message &msg , const Kopete::Co
 	// On hight-traffic channel, saving can take lots of CPU. (because the file is big)
 	// So i wait a time proportional to the time needed to save..
 
-	const TQString filename=getFileName(c,TQDate::currentDate());
+	const TQString filename=getFileName(c,TQDate::tqcurrentDate());
 	if(!m_toSaveFileName.isEmpty() && m_toSaveFileName != filename)
 	{ //that mean the contact or the month has changed, save it now.
 		saveToDisk();
@@ -316,14 +316,14 @@ void HistoryLogger::saveToDisk()
 		m_toSaveDocument.save( *stream, 1 );
 		file.close();
 
-		m_saveTimerTime=QMIN(t.elapsed()*1000, 300000);
+		m_saveTimerTime=TQMIN(t.elapsed()*1000, 300000);
 		    //a time 1000 times supperior to the time needed to save.  but with a upper limit of 5 minutes
 		//on a my machine, (2.4Ghz, but old HD) it should take about 10 ms to save the file.
 		// So that would mean save every 10 seconds, which seems to be ok.
 		// But it may take 500 ms if the file to save becomes too big (1Mb).
 		kdDebug(14310) << k_funcinfo << m_toSaveFileName << " saved in " << t.elapsed() << " ms " <<endl ;
 
-		m_toSaveFileName=TQString::null;
+		m_toSaveFileName=TQString();
 		m_toSaveDocument=TQDomDocument();
 	}
 	else
@@ -376,8 +376,8 @@ TQValueList<Kopete::Message> HistoryLogger::readMessages(TQDate date)
 					to.append( dir==Kopete::Message::Inbound ? (*it)->account()->myself() : *it );
 
 					Kopete::Message msg(dt, from, to, msgElem2.text(), dir);
-					msg.setBody( TQString::fromLatin1("<span title=\"%1\">%2</span>")
-							.arg( dt.toString(Qt::LocalDate), msg.escapedBody() ),
+					msg.setBody( TQString::tqfromLatin1("<span title=\"%1\">%2</span>")
+							.tqarg( dt.toString(Qt::LocalDate), msg.escapedBody() ),
 							Kopete::Message::RichText);
 				
 
@@ -403,7 +403,7 @@ TQValueList<Kopete::Message> HistoryLogger::readMessages(TQDate date)
 TQValueList<Kopete::Message> HistoryLogger::readMessages(unsigned int lines,
 	const Kopete::Contact *c, Sens sens, bool reverseOrder, bool colorize)
 {
-	//TQDate dd =  TQDate::currentDate().addMonths(0-m_currentMonth);
+	//TQDate dd =  TQDate::tqcurrentDate().addMonths(0-m_currentMonth);
 
 	TQValueList<Kopete::Message> messages;
 
@@ -490,7 +490,7 @@ TQValueList<Kopete::Message> HistoryLogger::readMessages(unsigned int lines,
 					if( !msgElem2.isNull() && msgElem2.tagName()=="msg")
 					{
 						rxTime.search(msgElem2.attribute("time"));
-						TQDate d=TQDate::currentDate().addMonths(0-m_currentMonth);
+						TQDate d=TQDate::tqcurrentDate().addMonths(0-m_currentMonth);
 						TQDateTime dt( TQDate(d.year() , d.month() , rxTime.cap(1).toUInt()), TQTime( rxTime.cap(2).toUInt() , rxTime.cap(3).toUInt(), rxTime.cap(5).toUInt()  ) );
 						if(!timestamp.isValid() || ((sens==Chronological )? dt < timestamp : dt > timestamp) )
 						{
@@ -587,23 +587,23 @@ TQValueList<Kopete::Message> HistoryLogger::readMessages(unsigned int lines,
 					{
 						//parse timestamp only if it was not already parsed
 						rxTime.search(msgElem.attribute("time"));
-						TQDate d=TQDate::currentDate().addMonths(0-m_currentMonth);
+						TQDate d=TQDate::tqcurrentDate().addMonths(0-m_currentMonth);
 						timestamp=TQDateTime( TQDate(d.year() , d.month() , rxTime.cap(1).toUInt()), TQTime( rxTime.cap(2).toUInt() , rxTime.cap(3).toUInt() , rxTime.cap(5).toUInt() ) );
 					}
 
 					Kopete::Message msg(timestamp, from, to, msgElem.text(), dir);
 					if (colorize)
 					{
-						msg.setBody( TQString::fromLatin1("<span style=\"color:%1\" title=\"%2\">%3</span>")
-							.arg( fgColor.name(), timestamp.toString(Qt::LocalDate), msg.escapedBody() ),
+						msg.setBody( TQString::tqfromLatin1("<span style=\"color:%1\" title=\"%2\">%3</span>")
+							.tqarg( fgColor.name(), timestamp.toString(Qt::LocalDate), msg.escapedBody() ),
 							Kopete::Message::RichText
 						);
 						msg.setFg( fgColor );
 					}
 					else
 					{
-						msg.setBody( TQString::fromLatin1("<span title=\"%1\">%2</span>")
-							.arg( timestamp.toString(Qt::LocalDate), msg.escapedBody() ),
+						msg.setBody( TQString::tqfromLatin1("<span title=\"%1\">%2</span>")
+							.tqarg( timestamp.toString(Qt::LocalDate), msg.escapedBody() ),
 							Kopete::Message::RichText
 						);
 					}
@@ -635,7 +635,7 @@ TQValueList<Kopete::Message> HistoryLogger::readMessages(unsigned int lines,
 							TQRegExp rx("(\\d+) (\\d+):(\\d+):(\\d+)");
 							rx.search(msgElem.attribute("time"));
 
-							TQDate d = TQDate::currentDate().addMonths(0-m_currentMonth);
+							TQDate d = TQDate::tqcurrentDate().addMonths(0-m_currentMonth);
 							timestamp = TQDateTime(
 								TQDate(d.year(), d.month(), rx.cap(1).toUInt()),
 								TQTime( rx.cap(2).toUInt(), rx.cap(3).toUInt() ) );
@@ -663,25 +663,25 @@ TQValueList<Kopete::Message> HistoryLogger::readMessages(unsigned int lines,
 TQString HistoryLogger::getFileName(const Kopete::Contact* c, TQDate date)
 {
 	
-	TQString name = c->protocol()->pluginId().replace( TQRegExp( TQString::fromLatin1( "[./~?*]" ) ), TQString::fromLatin1( "-" ) ) +
-		TQString::fromLatin1( "/" ) +
-		c->account()->accountId().replace( TQRegExp( TQString::fromLatin1( "[./~?*]" ) ), TQString::fromLatin1( "-" ) ) +
-		TQString::fromLatin1( "/" ) +
-	c->contactId().replace( TQRegExp( TQString::fromLatin1( "[./~?*]" ) ), TQString::fromLatin1( "-" ) ) +
+	TQString name = c->protocol()->pluginId().replace( TQRegExp( TQString::tqfromLatin1( "[./~?*]" ) ), TQString::tqfromLatin1( "-" ) ) +
+		TQString::tqfromLatin1( "/" ) +
+		c->account()->accountId().replace( TQRegExp( TQString::tqfromLatin1( "[./~?*]" ) ), TQString::tqfromLatin1( "-" ) ) +
+		TQString::tqfromLatin1( "/" ) +
+	c->contactId().replace( TQRegExp( TQString::tqfromLatin1( "[./~?*]" ) ), TQString::tqfromLatin1( "-" ) ) +
 		date.toString(".yyyyMM");
 
-	TQString filename=locateLocal( "data", TQString::fromLatin1( "kopete/logs/" ) + name+ TQString::fromLatin1( ".xml" ) ) ;
+	TQString filename=locateLocal( "data", TQString::tqfromLatin1( "kopete/logs/" ) + name+ TQString::tqfromLatin1( ".xml" ) ) ;
 
 	//Check if there is a kopete 0.7.x file
 	TQFileInfo fi(filename);
 	if(!fi.exists())
 	{
-		name = c->protocol()->pluginId().replace( TQRegExp( TQString::fromLatin1( "[./~?*]" ) ), TQString::fromLatin1( "-" ) ) +
-			TQString::fromLatin1( "/" ) +
-			c->contactId().replace( TQRegExp( TQString::fromLatin1( "[./~?*]" ) ), TQString::fromLatin1( "-" ) ) +
+		name = c->protocol()->pluginId().replace( TQRegExp( TQString::tqfromLatin1( "[./~?*]" ) ), TQString::tqfromLatin1( "-" ) ) +
+			TQString::tqfromLatin1( "/" ) +
+			c->contactId().replace( TQRegExp( TQString::tqfromLatin1( "[./~?*]" ) ), TQString::tqfromLatin1( "-" ) ) +
 			date.toString(".yyyyMM");
 
-		TQString filename2=locateLocal( "data", TQString::fromLatin1( "kopete/logs/" ) + name+ TQString::fromLatin1( ".xml" ) ) ;
+		TQString filename2=locateLocal( "data", TQString::tqfromLatin1( "kopete/logs/" ) + name+ TQString::tqfromLatin1( ".xml" ) ) ;
 
 		TQFileInfo fi2(filename2);
 		if(fi2.exists())
@@ -702,20 +702,20 @@ unsigned int HistoryLogger::getFirstMonth(const Kopete::Contact *c)
 
 	// BEGIN check if there are Kopete 0.7.x
 	TQDir d1(locateLocal("data",TQString("kopete/logs/")+
-		c->protocol()->pluginId().replace( TQRegExp(TQString::fromLatin1("[./~?*]")),TQString::fromLatin1("-"))
+		c->protocol()->pluginId().replace( TQRegExp(TQString::tqfromLatin1("[./~?*]")),TQString::tqfromLatin1("-"))
 		));
 	d1.setFilter( TQDir::Files | TQDir::NoSymLinks );
 	d1.setSorting( TQDir::Name );
 
-	const QFileInfoList *list1 = d1.entryInfoList();
-	QFileInfoListIterator it1( *list1 );
+	const TQFileInfoList *list1 = d1.entryInfoList();
+	TQFileInfoListIterator it1( *list1 );
 
 	while ( (fi = it1.current()) != 0 )
 	{
-		if(fi->fileName().contains(c->contactId().replace( TQRegExp( TQString::fromLatin1( "[./~?*]" ) ), TQString::fromLatin1( "-" ) )))
+		if(fi->fileName().contains(c->contactId().replace( TQRegExp( TQString::tqfromLatin1( "[./~?*]" ) ), TQString::tqfromLatin1( "-" ) )))
 		{
 			rx.search(fi->fileName());
-			int result = 12*(TQDate::currentDate().year() - rx.cap(1).toUInt()) +TQDate::currentDate().month() - rx.cap(2).toUInt();
+			int result = 12*(TQDate::tqcurrentDate().year() - rx.cap(1).toUInt()) +TQDate::tqcurrentDate().month() - rx.cap(2).toUInt();
 
 			if(result < 0)
 			{
@@ -730,22 +730,22 @@ unsigned int HistoryLogger::getFirstMonth(const Kopete::Contact *c)
 
 
 	TQDir d(locateLocal("data",TQString("kopete/logs/")+
-		c->protocol()->pluginId().replace( TQRegExp(TQString::fromLatin1("[./~?*]")),TQString::fromLatin1("-")) +
-		TQString::fromLatin1( "/" ) +
-		c->account()->accountId().replace( TQRegExp( TQString::fromLatin1( "[./~?*]" ) ), TQString::fromLatin1( "-" ) )
+		c->protocol()->pluginId().replace( TQRegExp(TQString::tqfromLatin1("[./~?*]")),TQString::tqfromLatin1("-")) +
+		TQString::tqfromLatin1( "/" ) +
+		c->account()->accountId().replace( TQRegExp( TQString::tqfromLatin1( "[./~?*]" ) ), TQString::tqfromLatin1( "-" ) )
 		));
 
 	d.setFilter( TQDir::Files | TQDir::NoSymLinks );
 	d.setSorting( TQDir::Name );
 
-	const QFileInfoList *list = d.entryInfoList();
-	QFileInfoListIterator it( *list );
+	const TQFileInfoList *list = d.entryInfoList();
+	TQFileInfoListIterator it( *list );
 	while ( (fi = it.current()) != 0 )
 	{
-		if(fi->fileName().contains(c->contactId().replace( TQRegExp( TQString::fromLatin1( "[./~?*]" ) ), TQString::fromLatin1( "-" ) )))
+		if(fi->fileName().contains(c->contactId().replace( TQRegExp( TQString::tqfromLatin1( "[./~?*]" ) ), TQString::tqfromLatin1( "-" ) )))
 		{
 			rx.search(fi->fileName());
-			int result = 12*(TQDate::currentDate().year() - rx.cap(1).toUInt()) +TQDate::currentDate().month() - rx.cap(2).toUInt();
+			int result = 12*(TQDate::tqcurrentDate().year() - rx.cap(1).toUInt()) +TQDate::tqcurrentDate().month() - rx.cap(2).toUInt();
 			if(result < 0)
 			{
 				kdWarning(14310) << k_funcinfo << "Kopete only found log file made in the future. Check your date!" << endl;
