@@ -27,21 +27,22 @@ class ConnectionManager;
 /**
 	@author Heiko Sch&auml;fer <heiko@rangun.de>
 */
-class DetectorNetworkStatus : protected TQObject, public Detector
+class DetectorNetworktqStatus : protected TQObject, public Detector
 {
 	Q_OBJECT
+  TQ_OBJECT
 	
-	DetectorNetworkStatus(const DetectorNetworkStatus&);
-	DetectorNetworkStatus& operator=(const DetectorNetworkStatus&);
+	DetectorNetworktqStatus(const DetectorNetworktqStatus&);
+	DetectorNetworktqStatus& operator=(const DetectorNetworktqStatus&);
 
 public:
-    DetectorNetworkStatus(IConnector* connector);
-    virtual ~DetectorNetworkStatus();
+    DetectorNetworktqStatus(IConnector* connector);
+    virtual ~DetectorNetworktqStatus();
 	
-	virtual void checkStatus() const;
+	virtual void checktqStatus() const;
 
 protected slots:
-	void statusChanged(const TQString& host, NetworkStatus::EnumStatus status);
+	void statusChanged(const TQString& host, NetworktqStatus::EnumtqStatus status);
 	
 private:
 	ConnectionManager * m_connManager;
