@@ -279,7 +279,7 @@ GaduSession::sendMessage( uin_t recipient, const Kopete::Message& msg, int msgCl
 }
 
 int
-GaduSession::changeStatus( int status, bool forFriends )
+GaduSession::changetqStatus( int status, bool forFriends )
 {
 	kdDebug(14101)<<"## Changing to "<<status<<endl;
 	if ( isConnected() ) {
@@ -424,8 +424,8 @@ GaduSession::pubDirSearch(  ResLine& query, int ageFrom, int ageTo, bool onlyAli
 						(const char*)textcodec->fromUnicode( query.city ) );
 		}
 		if ( ageFrom || ageTo ) {
-			TQString yearFrom = TQString::number( TQDate::currentDate().year() - ageFrom );
-			TQString yearTo = TQString::number( TQDate::currentDate().year() - ageTo );
+			TQString yearFrom = TQString::number( TQDate::tqcurrentDate().year() - ageFrom );
+			TQString yearTo = TQString::number( TQDate::tqcurrentDate().year() - ageTo );
 
 			if ( ageFrom && ageTo ) {
 				gg_pubdir50_add( searchRequest, GG_PUBDIR50_BIRTHYEAR,
@@ -490,7 +490,7 @@ GaduSession::sendResult( gg_pubdir50_t result )
 		resultLine.status	= stat.toInt();
 		age = resultLine.age.toInt();
 		if ( age ) {
-			resultLine.age = TQString::number( TQDate::currentDate().year() - age );
+			resultLine.age = TQString::number( TQDate::tqcurrentDate().year() - age );
 		}
 		else {
 			resultLine.age.truncate( 0 );
@@ -566,7 +566,7 @@ GaduSession::handleUserlist( gg_event* event )
 	}
 }
 
-QString
+TQString
 GaduSession::stateDescription( int state )
 {
 	switch( state ) {
@@ -604,7 +604,7 @@ GaduSession::stateDescription( int state )
 			return i18n( "unknown" );
 	}
 }
-QString
+TQString
 GaduSession::errorDescription( int err )
 {
 	switch( err ){
@@ -617,11 +617,11 @@ GaduSession::errorDescription( int err )
 		case GG_ERROR_WRITING:
 			return i18n( "Writing error." );
 		default:
-			return i18n( "Unknown error number %1." ).arg( TQString::number( (unsigned int)err ) );
+			return i18n( "Unknown error number %1." ).tqarg( TQString::number( (unsigned int)err ) );
 	}
 }
 
-QString
+TQString
 GaduSession::failureDescription( gg_failure_t f )
 {
 	switch( f ) {
@@ -642,7 +642,7 @@ GaduSession::failureDescription( gg_failure_t f )
 		case GG_FAILURE_TLS:
 			return i18n( "Unable to connect over encrypted channel.\nTry to turn off encryption support in Gadu account settings and reconnect." );
 		default:
-			return i18n( "Unknown error number %1." ).arg( TQString::number( (unsigned int)f ) );
+			return i18n( "Unknown error number %1." ).tqarg( TQString::number( (unsigned int)f ) );
 	}
 }
 
@@ -730,7 +730,7 @@ GaduSession::checkDescriptor()
 				gaduNotify.description = textcodec->toUnicode( event->event.status.descr );
 			}
 			else {
-				gaduNotify.description = TQString::null;
+				gaduNotify.description = TQString();
 			}
 			gaduNotify.remote_port	= 0;
 			gaduNotify.version	= 0;
@@ -747,7 +747,7 @@ GaduSession::checkDescriptor()
 				gaduNotify.description = textcodec->toUnicode( event->event.status60.descr );
 			}
 			else {
-				gaduNotify.description = TQString::null;
+				gaduNotify.description = TQString();
 			}
 			gaduNotify.remote_ip.setAddress( ntohl( event->event.status60.remote_ip ) );
 			gaduNotify.remote_port	= event->event.status60.remote_port;
