@@ -79,11 +79,11 @@ GroupWiseAccount::GroupWiseAccount( GroupWiseProtocol *parent, const TQString& a
 	TQObject::connect( Kopete::ContactList::self(), TQT_SIGNAL( groupRemoved( Kopete::Group * ) ),
 			TQT_SLOT( slotKopeteGroupRemoved( Kopete::Group * ) ) );
 
-	m_actionAutoReply = new KAction ( i18n( "&Set Auto-Reply..." ), TQString::null, 0, this,
+	m_actionAutoReply = new KAction ( i18n( "&Set Auto-Reply..." ), TQString(), 0, this,
 			TQT_SLOT( slotSetAutoReply() ), this, "actionSetAutoReply");
-	m_actionJoinChatRoom = new KAction ( i18n( "&Join Channel..." ), TQString::null, 0, this,
+	m_actionJoinChatRoom = new KAction ( i18n( "&Join Channel..." ), TQString(), 0, this,
 										 TQT_SLOT( slotJoinChatRoom() ), this, "actionJoinChatRoom");
-	m_actionManagePrivacy = new KAction ( i18n( "&Manage Privacy..." ), TQString::null, 0, this,
+	m_actionManagePrivacy = new KAction ( i18n( "&Manage Privacy..." ), TQString(), 0, this,
 			TQT_SLOT( slotPrivacy() ), this, "actionPrivacy");
 			
 	m_connector = 0;
@@ -112,7 +112,7 @@ KActionMenu* GroupWiseAccount::actionMenu()
 	m_actionMenu->insert( m_actionJoinChatRoom );
 	/* Used for debugging */
 	/*
-	theActionMenu->insert( new KAction ( "Test rtfize()", TQString::null, 0, this,
+	theActionMenu->insert( new KAction ( "Test rtfize()", TQString(), 0, this,
 		TQT_SLOT( slotTestRTFize() ), this,
 		"actionTestRTFize") );
 	*/
@@ -224,7 +224,7 @@ void GroupWiseAccount::setAway( bool away, const TQString & reason )
 	if ( away )
 	{
 		if ( Kopete::Away::getInstance()->idleTime() > 10 ) // don't go AwayIdle unless the user has actually been idle this long
-			setOnlineStatus( protocol()->groupwiseAwayIdle, TQString::null );
+			setOnlineStatus( protocol()->groupwiseAwayIdle, TQString() );
 		else
 			setOnlineStatus( protocol()->groupwiseAway, reason );
 	}
@@ -308,13 +308,13 @@ void GroupWiseAccount::performConnectWithPassword( const TQString &password )
 	// contact details listed
 	TQObject::connect( m_client, TQT_SIGNAL( contactUserDetailsReceived( const GroupWise::ContactDetails & ) ), TQT_SLOT( receiveContactUserDetails( const GroupWise::ContactDetails & ) ) );
 	// contact status changed
-	TQObject::connect( m_client, TQT_SIGNAL( statusReceived( const TQString &, Q_UINT16, const TQString & ) ), TQT_SLOT( receiveStatus( const TQString &, Q_UINT16 , const TQString & ) ) );
+	TQObject::connect( m_client, TQT_SIGNAL( statusReceived( const TQString &, TQ_UINT16, const TQString & ) ), TQT_SLOT( receivetqStatus( const TQString &, TQ_UINT16 , const TQString & ) ) );
 	// incoming message
 	TQObject::connect( m_client, TQT_SIGNAL( messageReceived( const ConferenceEvent & ) ), TQT_SLOT( handleIncomingMessage( const ConferenceEvent & ) ) );
 	// auto reply to one of our messages because the recipient is away
 	TQObject::connect( m_client, TQT_SIGNAL( autoReplyReceived( const ConferenceEvent & ) ), TQT_SLOT( handleIncomingMessage( const ConferenceEvent & ) ) );
 
-	TQObject::connect( m_client, TQT_SIGNAL( ourStatusChanged( GroupWise::Status, const TQString &, const TQString & ) ), TQT_SLOT( changeOurStatus( GroupWise::Status, const TQString &, const TQString & ) ) );
+	TQObject::connect( m_client, TQT_SIGNAL( ourStatusChanged( GroupWise::tqStatus, const TQString &, const TQString & ) ), TQT_SLOT( changeOurtqStatus( GroupWise::tqStatus, const TQString &, const TQString & ) ) );
 	// conference events
 	TQObject::connect( m_client,
 		TQT_SIGNAL( conferenceCreated( const int, const GroupWise::ConferenceGuid & ) ),
@@ -364,7 +364,7 @@ void GroupWiseAccount::performConnectWithPassword( const TQString &password )
 void GroupWiseAccount::slotMessageSendingFailed()
 {
 	KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Sorry,
-				i18n("Message Sending Failed", "Kopete was not able to send the last message sent on account '%1'.\nIf possible, please send the console output from Kopete to <wstephenson@novell.com> for analysis." ).arg( accountId() ) , i18n ("Unable to Send Message on Account '%1'").arg( accountId() ) );
+				i18n("Message Sending Failed", "Kopete was not able to send the last message sent on account '%1'.\nIf possible, please send the console output from Kopete to <wstephenson@novell.com> for analysis." ).tqarg( accountId() ) , i18n ("Unable to Send Message on Account '%1'").tqarg( accountId() ) );
 }
 
 void GroupWiseAccount::setOnlineStatus( const Kopete::OnlineStatus& status, const TQString &reason )
@@ -390,9 +390,9 @@ void GroupWiseAccount::setOnlineStatus( const Kopete::OnlineStatus& status, cons
 		// Appear Offline is achieved by explicitly setting the status to offline, 
 		// rather than disconnecting as when really going offline.
 		if ( status == protocol()->groupwiseAppearOffline )
-			m_client->setStatus( GroupWise::Offline, reason, configGroup()->readEntry( "AutoReply" ) );
+			m_client->settqStatus( GroupWise::Offline, reason, configGroup()->readEntry( "AutoReply" ) );
 		else
-			m_client->setStatus( ( GroupWise::Status )status.internalStatus(), reason, configGroup()->readEntry( "AutoReply" ) );
+			m_client->settqStatus( ( GroupWise::tqStatus )status.internalStatus(), reason, configGroup()->readEntry( "AutoReply" ) );
 	}
 	// going online
 	else
@@ -474,11 +474,11 @@ void GroupWiseAccount::slotLoggedIn()
 	// set local status display
 	myself()->setOnlineStatus( protocol()->groupwiseAvailable );
 	// set status on server
-	if ( initialStatus() != Kopete::OnlineStatus(Kopete::OnlineStatus::Online) &&
-		( ( GroupWise::Status )initialStatus().internalStatus() != GroupWise::Unknown ) )
+	if ( initialtqStatus() != Kopete::OnlineStatus(Kopete::OnlineStatus::Online) &&
+		( ( GroupWise::tqStatus )initialtqStatus().internalStatus() != GroupWise::Unknown ) )
 	{
-		kdDebug( GROUPWISE_DEBUG_GLOBAL ) << "Initial status is not online, setting status to " << initialStatus().internalStatus() << endl;
-		m_client->setStatus( ( GroupWise::Status )initialStatus().internalStatus(), m_initialReason, configGroup()->readEntry( "AutoReply" ) );
+		kdDebug( GROUPWISE_DEBUG_GLOBAL ) << "Initial status is not online, setting status to " << initialtqStatus().internalStatus() << endl;
+		m_client->settqStatus( ( GroupWise::tqStatus )initialtqStatus().internalStatus(), m_initialReason, configGroup()->readEntry( "AutoReply" ) );
 	}
 }
 
@@ -533,7 +533,7 @@ void GroupWiseAccount::reconcileOfflineChanges()
 					else
 						continue;
 
-				GWFolder * folder = ::qt_cast<GWFolder*>( ( *instIt )->parent() );
+				GWFolder * folder = ::tqqt_cast<GWFolder*>( ( *instIt )->parent() );
 				if ( folder->id == ( unsigned int )groupId.toInt() )
 				{
 					found = true;
@@ -566,7 +566,7 @@ void GroupWiseAccount::reconcileOfflineChanges()
 						break;
 					}
 					else
-						kdDebug( GROUPWISE_DEBUG_GLOBAL ) << "metacontact " << c->metaContact()->displayName( ) << "has multiple children and group membership, and contact " << c->dn() << " was removed from one group on the server." << endl;
+						kdDebug( GROUPWISE_DEBUG_GLOBAL ) << "metacontact " << c->metaContact()->displayName( ) << "has multiple tqchildren and group membership, and contact " << c->dn() << " was removed from one group on the server." << endl;
 						conflicts = true;
 				}
 			} // 
@@ -647,7 +647,7 @@ void GroupWiseAccount::slotConnError()
 {
 	kdDebug ( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << endl;
 	KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Sorry,
-				i18n( "Error shown when connecting failed", "Kopete was not able to connect to the GroupWise Messenger server for account '%1'.\nPlease check your server and port settings and try again." ).arg( accountId() ) , i18n ("Unable to Connect '%1'").arg( accountId() ) );
+				i18n( "Error shown when connecting failed", "Kopete was not able to connect to the GroupWise Messenger server for account '%1'.\nPlease check your server and port settings and try again." ).tqarg( accountId() ) , i18n ("Unable to Connect '%1'").tqarg( accountId() ) );
 
 	disconnect();
 }
@@ -664,7 +664,7 @@ void GroupWiseAccount::slotCSDisconnected()
 	TQValueList<GroupWiseChatSession *>::ConstIterator it;
 	for ( it = m_chatSessions.begin() ; it != m_chatSessions.end(); ++it )
 		(*it)->setClosed();
-	setAllContactsStatus( protocol()->groupwiseOffline );
+	setAllContactstqStatus( protocol()->groupwiseOffline );
 	client()->close();
 }
 
@@ -807,8 +807,8 @@ void GroupWiseAccount::handleIncomingMessage( const ConferenceEvent & message )
 
     // if we receive a message from an Offline contact, they are probably blocking us
     // but we have to set their status to Unknown so that we can reply to them.
-    kdDebug( GROUPWISE_DEBUG_GLOBAL) << "sender is: " << sender->onlineStatus().description() << endl;
-    if ( sender->onlineStatus() == protocol()->groupwiseOffline ) {
+    kdDebug( GROUPWISE_DEBUG_GLOBAL) << "sender is: " << sender->onlinetqStatus().description() << endl;
+    if ( sender->onlinetqStatus() == protocol()->groupwiseOffline ) {
         sender->setMessageReceivedOffline( true );
     }
 
@@ -823,19 +823,19 @@ void GroupWiseAccount::handleIncomingMessage( const ConferenceEvent & message )
 	{
 		TQString prefix = i18n("Prefix used for automatically generated auto-reply"
 			" messages when the contact is Away, contains contact's name",
-			"Auto reply from %1: " ).arg( sender->metaContact()->displayName() );
+			"Auto reply from %1: " ).tqarg( sender->metaContact()->displayName() );
 		messageMunged = prefix + message.message;
 	}
 	if ( message.type == GroupWise::ReceivedBroadcast )
 	{
 		TQString prefix = i18n("Prefix used for broadcast messages",
-			"Broadcast message from %1: " ).arg( sender->metaContact()->displayName() );
+			"Broadcast message from %1: " ).tqarg( sender->metaContact()->displayName() );
 		messageMunged = prefix + message.message;
 	}
 	if ( message.type == GroupWise::ReceivedSystemBroadcast )
 	{
 		TQString prefix = i18n("Prefix used for system broadcast messages",
-			"System Broadcast message from %1: " ).arg( sender->metaContact()->displayName() );
+			"System Broadcast message from %1: " ).tqarg( sender->metaContact()->displayName() );
 		messageMunged = prefix + message.message;
 	}
 
@@ -1040,14 +1040,14 @@ GroupWiseContact * GroupWiseAccount::createTemporaryContact( const TQString & dn
 		Kopete::ContactList::self()->addMetaContact( metaContact );
 		// the contact details probably don't contain status - but we can ask for it
 		if ( details.status == GroupWise::Invalid && isConnected() )
-			m_client->requestStatus( details.dn );
+			m_client->requesttqStatus( details.dn );
 	}
 	else
 		kdDebug( GROUPWISE_DEBUG_GLOBAL ) << "Notified of existing temporary contact DN: " << details.dn << endl;
 	return c;
 }
 
-void GroupWiseAccount::receiveStatus( const TQString & contactId, Q_UINT16 status, const TQString &awayMessage )
+void GroupWiseAccount::receivetqStatus( const TQString & contactId, TQ_UINT16 status, const TQString &awayMessage )
 {
 	kdDebug( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << "got status for: " << contactId << ", status: " << status << ", away message: " << awayMessage << endl;
 	GroupWiseContact * c = contactForDN( contactId );
@@ -1062,7 +1062,7 @@ void GroupWiseAccount::receiveStatus( const TQString & contactId, Q_UINT16 statu
 		kdDebug( GROUPWISE_DEBUG_GLOBAL ) << " couldn't find " << contactId << endl;
 }
 
-void GroupWiseAccount::changeOurStatus( GroupWise::Status status, const TQString & awayMessage, const TQString & autoReply )
+void GroupWiseAccount::changeOurtqStatus( GroupWise::tqStatus status, const TQString & awayMessage, const TQString & autoReply )
 {
 	if ( status == GroupWise::Offline )
 		myself()->setOnlineStatus( protocol()->groupwiseAppearOffline );
@@ -1117,7 +1117,7 @@ bool GroupWiseAccount::createContact( const TQString& contactId, Kopete::MetaCon
 		{
 			kdDebug( GROUPWISE_DEBUG_GLOBAL ) << fld->displayName << endl;
 			//FIXME - get rid of FolderItem & co
-			fi.parentId = ::qt_cast<GWFolder*>( fld->parent() )->id;
+			fi.parentId = ::tqqt_cast<GWFolder*>( fld->parent() )->id;
 			fi.id = fld->id;
 			fi.name = fld->displayName;
 		}
@@ -1189,7 +1189,7 @@ void GroupWiseAccount::receiveContactCreated()
 		else
 		{
 			client()->requestDetails( TQStringList( cct->dn() ) );
-			client()->requestStatus( cct->dn() );
+			client()->requesttqStatus( cct->dn() );
 		}
 	}
 	else
@@ -1210,7 +1210,7 @@ void GroupWiseAccount::receiveContactCreated()
 
 		KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget (), KMessageBox::Error,
 							i18n ("The contact %1 could not be added to the contact list, with error message: %2").
-							arg(cct->userId() ).arg( cct->statusString() ),
+							tqarg(cct->userId() ).tqarg( cct->statusString() ),
 							i18n ("Error Adding Contact") );
 	}
 }
@@ -1227,7 +1227,7 @@ void GroupWiseAccount::deleteContact( GroupWiseContact * contact )
 		for ( ; it != instances.end(); ++it )
 		{
 			DeleteItemTask * dit = new DeleteItemTask( client()->rootTask() );
-			dit->item( ::qt_cast<GWFolder*>( (*it)->parent() )->id, (*it)->id );
+			dit->item( ::tqqt_cast<GWFolder*>( (*it)->parent() )->id, (*it)->id );
 			TQObject::connect( dit, TQT_SIGNAL( gotContactDeleted( const ContactItem & ) ), TQT_SLOT( receiveContactDeleted( const ContactItem & ) ) );
 			dit->go( true );
 		}
@@ -1255,8 +1255,8 @@ void GroupWiseAccount::receiveContactDeleted( const ContactItem & instance )
 
 void GroupWiseAccount::slotConnectedElsewhere()
 {
-	KPassivePopup::message( i18n ("Signed in as %1 Elsewhere").arg( accountId() ),
-				i18n( "The parameter is the user's own account id for this protocol", "You have been disconnected from GroupWise Messenger because you signed in as %1 elsewhere" ).arg( accountId() ) , Kopete::UI::Global::mainWidget() );
+	KPassivePopup::message( i18n ("Signed in as %1 Elsewhere").tqarg( accountId() ),
+				i18n( "The parameter is the user's own account id for this protocol", "You have been disconnected from GroupWise Messenger because you signed in as %1 elsewhere" ).tqarg( accountId() ) , Kopete::UI::Global::mainWidget() );
 	disconnect();
 }
 
@@ -1364,7 +1364,7 @@ void GroupWiseAccount::receiveInviteNotify( const ConferenceEvent & event )
 			c = createTemporaryContact( event.user );
 
 		sess->addInvitee( c );
-		Kopete::Message declined = Kopete::Message( myself(), sess->members(), i18n("%1 has been invited to join this conversation.").arg( c->metaContact()->displayName() ), Kopete::Message::Internal, Kopete::Message::PlainText );
+		Kopete::Message declined = Kopete::Message( myself(), sess->members(), i18n("%1 has been invited to join this conversation.").tqarg( c->metaContact()->displayName() ), Kopete::Message::Internal, Kopete::Message::PlainText );
 		sess->appendMessage( declined );
 	}
 	else
@@ -1400,14 +1400,14 @@ void GroupWiseAccount::slotSetAutoReply()
 void GroupWiseAccount::slotTestRTFize()
 {
 /*	bool ok;
-	const TQString query = TQString::fromLatin1("Enter a string to rtfize:");
-	TQString testText = KLineEditDlg::getText( query, TQString::null, &ok, Kopete::UI::Global::mainWidget() );
+	const TQString query = TQString::tqfromLatin1("Enter a string to rtfize:");
+	TQString testText = KLineEditDlg::getText( query, TQString(), &ok, Kopete::UI::Global::mainWidget() );
 	if ( ok )
 		kdDebug( GROUPWISE_DEBUG_GLOBAL ) << "Converted text is: '" << protocol()->rtfizeText( testText ) << "'" << endl;*/
 
 // 	bool ok;
 // 	const TQString query = i18n("Enter a contactId:");
-// 	TQString testText = KInputDialog::getText( query, i18n("This is a test dialog and will not be in the final product!" ), TQString::null, &ok, Kopete::UI::Global::mainWidget() );
+// 	TQString testText = KInputDialog::getText( query, i18n("This is a test dialog and will not be in the final product!" ), TQString(), &ok, Kopete::UI::Global::mainWidget() );
 // 	if ( !ok )
 // 		return;
 // 	kdDebug( GROUPWISE_DEBUG_GLOBAL ) << "Trying to add contact: '" << protocol()->rtfizeText( testText ) << "'" << endl;
@@ -1499,7 +1499,7 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 			{
 				GWContactInstanceList::Iterator candidateInst = instIt;
 				++instIt;
-				GWFolder * folder = ::qt_cast<GWFolder *>( ( *candidateInst )->parent() );
+				GWFolder * folder = ::tqqt_cast<GWFolder *>( ( *candidateInst )->parent() );
 				kdDebug( GROUPWISE_DEBUG_GLOBAL ) << "  - Looking for a match, MC grp '" 
 					<< ( *candidateGrp )->displayName() 
 					<< "', GWFolder '" << folder->displayName << "', objectId is " << folder->id << endl;
@@ -1525,7 +1525,7 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 			candidateGrp = grpIt;
 			++grpIt;
 			GWContactInstanceList::Iterator instIt = instances.begin();
-			GWFolder * sourceFolder =::qt_cast<GWFolder*>( ( *instIt)->parent() );
+			GWFolder * sourceFolder =::tqqt_cast<GWFolder*>( ( *instIt)->parent() );
 			kdDebug( GROUPWISE_DEBUG_GLOBAL ) << "  - moving contact instance from group '" << sourceFolder->displayName << "' to group '" << ( *candidateGrp )->displayName() << "'" << endl;
 
 			// create contactItem parameter
@@ -1604,7 +1604,7 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 		{
 			GWContactInstanceList::Iterator candidateInst = instIt;
 			++instIt;
-			GWFolder * folder =::qt_cast<GWFolder*>( ( *candidateInst )->parent() );
+			GWFolder * folder =::tqqt_cast<GWFolder*>( ( *candidateInst )->parent() );
 			kdDebug( GROUPWISE_DEBUG_GLOBAL ) << "  - remove contact instance '"<< ( *candidateInst )->id << "' in group '" << folder->displayName << "'" << endl;
 
 			DeleteItemTask * dit = new DeleteItemTask( client()->rootTask() );
@@ -1628,7 +1628,7 @@ void GroupWiseAccount::syncContact( GroupWiseContact * contact )
 				TQValueList< ContactItem > instancesToChange;
 				ContactItem instance;
 				instance.id = (*it)->id;
-				instance.parentId = ::qt_cast<GWFolder *>( (*it)->parent() )->id;
+				instance.parentId = ::tqqt_cast<GWFolder *>( (*it)->parent() )->id;
 				instance.sequence = (*it)->sequence;
 				instance.dn = contact->dn();
 				instance.displayName = contact->nickName();
