@@ -116,7 +116,7 @@ bool GroupWiseChatSession::secure()
 void GroupWiseChatSession::setClosed()
 {
 	kdDebug( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << " Conference " << m_guid << " is now Closed " << endl;
-	m_guid = TQString::null;
+	m_guid = TQString();
 	m_flags = m_flags | GroupWise::Closed;
 }
 
@@ -196,7 +196,7 @@ void GroupWiseChatSession::slotCreationFailed( const int failedId, const int sta
 	{
 		kdDebug ( GROUPWISE_DEBUG_GLOBAL ) << k_funcinfo << " couldn't start a chat, no GUID.\n" << endl;
 		//emit creationFailed();
-		Kopete::Message failureNotify = Kopete::Message( myself(), members(), i18n("An error occurred when trying to start a chat: %1").arg( statusCode ), Kopete::Message::Internal, Kopete::Message::PlainText);
+		Kopete::Message failureNotify = Kopete::Message( myself(), members(), i18n("An error occurred when trying to start a chat: %1").tqarg( statusCode ), Kopete::Message::Internal, Kopete::Message::PlainText);
 		appendMessage( failureNotify );
 		setClosed();
 	}
@@ -206,7 +206,7 @@ void GroupWiseChatSession::slotSendTypingNotification( bool typing )
 {
 	// only send a notification if we've got a conference going and we are not Appear Offline
 	if ( !m_guid.isEmpty() && m_memberCount &&
-		  ( account()->myself()->onlineStatus() != GroupWiseProtocol::protocol()->groupwiseAppearOffline ) )
+		  ( account()->myself()->onlinetqStatus() != GroupWiseProtocol::protocol()->groupwiseAppearOffline ) )
 				account()->client()->sendTyping( guid(), typing );
 }
 
@@ -221,7 +221,7 @@ void GroupWiseChatSession::slotMessageSent( Kopete::Message & message, Kopete::C
 			appendMessage( failureNotify );
 			messageSucceeded();
 		}
-		else*/ if ( account()->myself()->onlineStatus() == ( static_cast<GroupWiseProtocol *>( protocol() ) )->groupwiseAppearOffline )
+		else*/ if ( account()->myself()->onlinetqStatus() == ( static_cast<GroupWiseProtocol *>( protocol() ) )->groupwiseAppearOffline )
 		{
 			Kopete::Message failureNotify = Kopete::Message( myself(), members(), i18n("Your message could not be sent. You cannot send messages while your status is Appear Offline. "), Kopete::Message::Internal, Kopete::Message::PlainText);
 			appendMessage( failureNotify );
@@ -330,7 +330,7 @@ void GroupWiseChatSession::slotInviteContact( Kopete::Contact * contact )
 	}
 	else
 	{
-		TQWidget * w = view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) : 0L;
+		TQWidget * w = view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->tqtopLevelWidget() ) : 0L;
 		
 		bool ok;
 		TQRegExp rx( ".*" );
@@ -358,7 +358,7 @@ void GroupWiseChatSession::slotInviteOtherContact()
 	if ( !m_searchDlg )
 	{
 		// show search dialog
-		TQWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) : 
+		TQWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->tqtopLevelWidget() ) : 
 					Kopete::UI::Global::mainWidget() );
 		m_searchDlg = new KDialogBase( w, "invitesearchdialog", false, i18n( "Search for Contact to Invite" ), KDialogBase::Ok|KDialogBase::Cancel );
 		m_search = new GroupWiseContactSearch( account(), TQListView::Single, true, m_searchDlg, "invitesearchwidget" );
@@ -375,7 +375,7 @@ void GroupWiseChatSession::slotSearchedForUsers()
 	TQValueList< ContactDetails > selected = m_search->selectedResults();
 	if ( selected.count() )
 	{
-		TQWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) :
+		TQWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->tqtopLevelWidget() ) :
 				Kopete::UI::Global::mainWidget() ); 
 		ContactDetails cd = selected.first();
 		bool ok;
@@ -399,7 +399,7 @@ void GroupWiseChatSession::addInvitee( const Kopete::Contact * c )
 	Kopete::MetaContact * inviteeMC = new Kopete::MetaContact();
 	inviteeMC->setDisplayName( c->metaContact()->displayName() + pending );
 	GroupWiseContact * invitee = new GroupWiseContact( account(), c->contactId() + " " + pending, inviteeMC, 0, 0, 0 );
-	invitee->setOnlineStatus( c->onlineStatus() );
+	invitee->setOnlineStatus( c->onlinetqStatus() );
 	// TODO: we could set all the placeholder's properties etc here too
 	addContact( invitee, true );
 	m_invitees.append( invitee );
@@ -417,7 +417,7 @@ void GroupWiseChatSession::joined( GroupWiseContact * c )
 	{
 		if ( pending->contactId().startsWith( c->contactId() ) )
 		{
-			removeContact( pending, TQString::null, Kopete::Message::PlainText, true );
+			removeContact( pending, TQString(), Kopete::Message::PlainText, true );
 			break;
 		}
 	}
@@ -459,7 +459,7 @@ void GroupWiseChatSession::inviteDeclined( GroupWiseContact * c )
 	{
 		if ( pending->contactId().startsWith( c->contactId() ) )
 		{
-			removeContact( pending, TQString::null, Kopete::Message::PlainText, true );
+			removeContact( pending, TQString(), Kopete::Message::PlainText, true );
 			break;
 		}
 	}
@@ -468,7 +468,7 @@ void GroupWiseChatSession::inviteDeclined( GroupWiseContact * c )
 	TQString from = c->metaContact()->displayName();
 
 	Kopete::Message declined = Kopete::Message( myself(), members(), 
-				i18n("%1 has rejected an invitation to join this conversation.").arg( from ), 
+				i18n("%1 has rejected an invitation to join this conversation.").tqarg( from ), 
 				Kopete::Message::Internal, Kopete::Message::PlainText );
 	appendMessage( declined );
 }
@@ -501,14 +501,14 @@ void GroupWiseChatSession::updateArchiving()
 
 void GroupWiseChatSession::slotShowSecurity()
 {
-	TQWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) :
+	TQWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->tqtopLevelWidget() ) :
 				Kopete::UI::Global::mainWidget() ); 
 	KMessageBox::queuedMessageBox( w, KMessageBox::Information, i18n( "This conversation is secured with SSL security." ), i18n("Security Status" ) );
 }
 
 void GroupWiseChatSession::slotShowArchiving()
 {
-	TQWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) :
+	TQWidget * w = ( view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->tqtopLevelWidget() ) :
 				Kopete::UI::Global::mainWidget() ); 
 	KMessageBox::queuedMessageBox( w, KMessageBox::Information, i18n( "This conversation is being logged administratively." ), i18n("Archiving Status" ) );
 }
