@@ -1,5 +1,5 @@
 /*
- * qca.cpp - Qt Cryptographic Architecture
+ * qca.cpp - TQt Cryptographic Architecture
  * Copyright (C) 2003  Justin Karneges
  *
  * This library is free software; you can redistribute it and/or
@@ -586,7 +586,7 @@ TQString RSAKey::toPEM(bool publicOnly) const
 	TQCString cs;
 	cs.resize(out.size()+1);
 	memcpy(cs.data(), out.data(), out.size());
-	return TQString::fromLatin1(cs);
+	return TQString::tqfromLatin1(cs);
 }
 
 bool RSAKey::fromPEM(const TQString &str)
@@ -798,7 +798,7 @@ TQString Cert::toPEM() const
 	TQCString cs;
 	cs.resize(out.size()+1);
 	memcpy(cs.data(), out.data(), out.size());
-	return TQString::fromLatin1(cs);
+	return TQString::tqfromLatin1(cs);
 }
 
 bool Cert::fromPEM(const TQString &str)
@@ -1232,13 +1232,13 @@ void SASL::setExternalSSF(int x)
 	d->ext_ssf = x;
 }
 
-void SASL::setLocalAddr(const TQHostAddress &addr, Q_UINT16 port)
+void SASL::setLocalAddr(const TQHostAddress &addr, TQ_UINT16 port)
 {
 	d->localAddr = addr;
 	d->localPort = port;
 }
 
-void SASL::setRemoteAddr(const TQHostAddress &addr, Q_UINT16 port)
+void SASL::setRemoteAddr(const TQHostAddress &addr, TQ_UINT16 port)
 {
 	d->remoteAddr = addr;
 	d->remotePort = port;
