@@ -30,13 +30,14 @@
 class GetStatusTask : public RequestTask
 {
 Q_OBJECT
+  TQ_OBJECT
 public:
 	GetStatusTask(Task* parent);
 	~GetStatusTask();
 	void userDN( const TQString & dn );
 	bool take( Transfer * transfer );
 signals:
-	void gotStatus( const TQString & contactId, Q_UINT16 status, const TQString & statusText );
+	void gottqStatus( const TQString & contactId, TQ_UINT16 status, const TQString & statusText );
 private:
 	TQString m_userDN;
 };
