@@ -30,15 +30,16 @@
 class SetStatusTask : public RequestTask
 {
 Q_OBJECT
+  TQ_OBJECT
 public:
 	SetStatusTask(Task* parent);
 	~SetStatusTask();
-	void status( GroupWise::Status newStatus, const TQString &awayMessage, const TQString &autoReply );
-	GroupWise::Status requestedStatus() const;
+	void status( GroupWise::tqStatus newtqStatus, const TQString &awayMessage, const TQString &autoReply );
+	GroupWise::tqStatus requestedtqStatus() const;
 	TQString awayMessage() const;
 	TQString autoReply() const; 
 private:
-	GroupWise::Status m_status;
+	GroupWise::tqStatus m_status;
 	TQString m_awayMessage;
 	TQString m_autoReply;
 };
