@@ -29,12 +29,13 @@
 class StatusTask : public EventTask
 {
 Q_OBJECT
+  TQ_OBJECT
 public:
 	StatusTask(Task* parent);
 	~StatusTask();
 	bool take( Transfer * transfer );
 signals:
-	void gotStatus( const TQString & contactId, Q_UINT16 status, const TQString & statusText );
+	void gottqStatus( const TQString & contactId, TQ_UINT16 status, const TQString & statusText );
 };
 
 #endif
