@@ -111,7 +111,7 @@ JabberAccount::JabberAccount (JabberProtocol * parent, const TQString & accountI
 
 	TQObject::connect(Kopete::ContactList::self(), TQT_SIGNAL( globalIdentityChanged(const TQString&, const TQVariant& ) ), TQT_SLOT( slotGlobalIdentityChanged(const TQString&, const TQVariant& ) ) );
 
-	m_initialPresence = XMPP::Status ( "", "", 5, true );
+	m_initialPresence = XMPP::tqStatus ( "", "", 5, true );
 
 }
 
@@ -323,8 +323,8 @@ void JabberAccount::connectWithPassword ( const TQString &password )
 				   this, TQT_SLOT ( slotGroupChatJoined ( const XMPP::Jid & ) ) );
 		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( groupChatLeft ( const XMPP::Jid & ) ),
 				   this, TQT_SLOT ( slotGroupChatLeft ( const XMPP::Jid & ) ) );
-		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( groupChatPresence ( const XMPP::Jid &, const XMPP::Status & ) ),
-				   this, TQT_SLOT ( slotGroupChatPresence ( const XMPP::Jid &, const XMPP::Status & ) ) );
+		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( groupChatPresence ( const XMPP::Jid &, const XMPP::tqStatus & ) ),
+				   this, TQT_SLOT ( slotGroupChatPresence ( const XMPP::Jid &, const XMPP::tqStatus & ) ) );
 		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( groupChatError ( const XMPP::Jid &, int, const TQString & ) ),
 				   this, TQT_SLOT ( slotGroupChatError ( const XMPP::Jid &, int, const TQString & ) ) );
 		TQObject::connect ( m_jabberClient, TQT_SIGNAL ( debugMessage ( const TQString & ) ),
@@ -414,7 +414,7 @@ void JabberAccount::connectWithPassword ( const TQString &password )
 
 	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Connecting to Jabber server " << server() << ":" << port() << endl;
 
-	setPresence( XMPP::Status ("connecting", "", 0, true) );
+	setPresence( XMPP::tqStatus ("connecting", "", 0, true) );
 
 	switch ( m_jabberClient->connect ( XMPP::Jid ( accountId () + TQString("/") + resource () ), password ) )
 	{
@@ -609,13 +609,13 @@ void JabberAccount::slotIncomingFileTransfer ()
 
 void JabberAccount::setOnlineStatus( const Kopete::OnlineStatus& status  , const TQString &reason)
 {
-	XMPP::Status xmppStatus = m_protocol->kosToStatus( status, reason);
+	XMPP::tqStatus xmpptqStatus = m_protocol->kosTotqStatus( status, reason);
 
 	if( status.status() == Kopete::OnlineStatus::Offline )
 	{
-			xmppStatus.setIsAvailable( false );
+			xmpptqStatus.setIsAvailable( false );
 			kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "CROSS YOUR FINGERS! THIS IS GONNA BE WILD" << endl;
-            disconnect (Manual, xmppStatus);
+            disconnect (Manual, xmpptqStatus);
             return;
     }
 
@@ -628,12 +628,12 @@ void JabberAccount::setOnlineStatus( const Kopete::OnlineStatus& status  , const
 	if ( !isConnected () )
 	{
 		// we are not connected yet, so connect now
-		m_initialPresence = xmppStatus;
+		m_initialPresence = xmpptqStatus;
 		connect ( status );
 	}
 	else
 	{
-		setPresence ( xmppStatus );
+		setPresence ( xmpptqStatus );
 	}
 }
 
@@ -650,8 +650,8 @@ void JabberAccount::disconnect ( Kopete::Account::DisconnectReason reason )
 
 	// make sure that the connection animation gets stopped if we're still
 	// in the process of connecting
-	setPresence ( XMPP::Status ("", "", 0, false) );
-	m_initialPresence = XMPP::Status ("", "", 5, true);
+	setPresence ( XMPP::tqStatus ("", "", 0, false) );
+	m_initialPresence = XMPP::tqStatus ("", "", 5, true);
 
 	/* FIXME:
 	 * We should delete the JabberClient instance here,
@@ -666,7 +666,7 @@ void JabberAccount::disconnect ( Kopete::Account::DisconnectReason reason )
 	disconnected ( reason );
 }
 
-void JabberAccount::disconnect( Kopete::Account::DisconnectReason reason, XMPP::Status &status )
+void JabberAccount::disconnect( Kopete::Account::DisconnectReason reason, XMPP::tqStatus &status )
 {
     kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "disconnect( reason, status ) called" << endl;
     
@@ -787,7 +787,7 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 					break;
 			}
 
-			errorText = i18n("There was an error in the protocol stream: %1").arg(errorCondition);
+			errorText = i18n("There was an error in the protocol stream: %1").tqarg(errorCondition);
 			break;
 
 		case XMPP::ClientStream::ErrConnection:
@@ -845,7 +845,7 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 					break;
 			}
 			if(!errorCondition.isEmpty())
-				errorText = i18n("There was a connection error: %1").arg(errorCondition);
+				errorText = i18n("There was a connection error: %1").tqarg(errorCondition);
 			break;
 
 		case XMPP::ClientStream::ErrNeg:
@@ -870,7 +870,7 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 					break;
 			}
 
-			errorText = i18n("There was a negotiation error: %1").arg(errorCondition);
+			errorText = i18n("There was a negotiation error: %1").tqarg(errorCondition);
 			break;
 
 		case XMPP::ClientStream::ErrTLS:
@@ -887,7 +887,7 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 					break;
 			}
 
-			errorText = i18n("There was a Transport Layer Security (TLS) error: %1").arg(errorCondition);
+			errorText = i18n("There was a Transport Layer Security (TLS) error: %1").tqarg(errorCondition);
 			break;
 
 		case XMPP::ClientStream::ErrAuth:
@@ -931,7 +931,7 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 					break;
 			}
 
-			errorText = i18n("There was an error authenticating with the server: %1").arg(errorCondition);
+			errorText = i18n("There was an error authenticating with the server: %1").tqarg(errorCondition);
 			break;
 
 		case XMPP::ClientStream::ErrSecurityLayer:
@@ -948,7 +948,7 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 					break;
 			}
 
-			errorText = i18n("There was an error in the security layer: %1").arg(errorCondition);
+			errorText = i18n("There was an error in the security layer: %1").tqarg(errorCondition);
 			break;
 
 		case XMPP::ClientStream::ErrBind:
@@ -965,7 +965,7 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 					break;
 			}
 
-			errorText = i18n("Could not bind a resource: %1").arg(errorCondition);
+			errorText = i18n("Could not bind a resource: %1").tqarg(errorCondition);
 			break;
 
 		default:
@@ -981,7 +981,7 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 	if(!errorText.isEmpty())
 		KMessageBox::error (Kopete::UI::Global::mainWidget (),
 						errorText,
-						i18n("Connection problem with Jabber server %1").arg(server));
+						i18n("Connection problem with Jabber server %1").tqarg(server));
 
 
 }
@@ -1015,27 +1015,27 @@ void JabberAccount::slotCSError ( int error )
 }
 
 /* Set presence (usually called by dialog widget). */
-void JabberAccount::setPresence ( const XMPP::Status &status )
+void JabberAccount::setPresence ( const XMPP::tqStatus &status )
 {
 	kdDebug(JABBER_DEBUG_GLOBAL) << k_funcinfo << "Status: " << status.show () << ", Reason: " << status.status () << endl;
 
 	// fetch input status
-	XMPP::Status newStatus = status;
+	XMPP::tqStatus newtqStatus = status;
 	
 	// TODO: Check if Caps is enabled
 	// Send entity capabilities
 	if( client() )
 	{
-		newStatus.setCapsNode( client()->capsNode() );
-		newStatus.setCapsVersion( client()->capsVersion() );
-		newStatus.setCapsExt( client()->capsExt() );
+		newtqStatus.setCapsNode( client()->capsNode() );
+		newtqStatus.setCapsVersion( client()->capsVersion() );
+		newtqStatus.setCapsExt( client()->capsExt() );
 	}
 
 	// make sure the status gets the correct priority
-	newStatus.setPriority ( configGroup()->readNumEntry ( "Priority", 5 ) );
+	newtqStatus.setPriority ( configGroup()->readNumEntry ( "Priority", 5 ) );
 
 	XMPP::Jid jid ( myself()->contactId () );
-	XMPP::Resource newResource ( resource (), newStatus );
+	XMPP::Resource newResource ( resource (), newtqStatus );
 
 	// update our resource in the resource pool
 	resourcePool()->addResource ( jid, newResource );
@@ -1057,7 +1057,7 @@ void JabberAccount::setPresence ( const XMPP::Status &status )
 
 			XMPP::JT_Presence * task = new XMPP::JT_Presence ( client()->rootTask ());
 
-			task->pres ( newStatus );
+			task->pres ( newtqStatus );
 			task->go ( true );
 		}
 		else
@@ -1103,7 +1103,7 @@ void JabberAccount::slotSubscription (const XMPP::Jid & jid, const TQString & ty
 			hideFlags |= Kopete::UI::ContactAddedNotifyDialog::AddCheckBox | Kopete::UI::ContactAddedNotifyDialog::AddGroupBox ;
 		
 		Kopete::UI::ContactAddedNotifyDialog *dialog=
-				new Kopete::UI::ContactAddedNotifyDialog( jid.full() ,TQString::null,this, hideFlags );
+				new Kopete::UI::ContactAddedNotifyDialog( jid.full() ,TQString(),this, hideFlags );
 		TQObject::connect(dialog,TQT_SIGNAL(applyClicked(const TQString&)),
 						this,TQT_SLOT(slotContactAddedNotifyDialogClosed(const TQString& )));
 		dialog->show();
@@ -1299,11 +1299,11 @@ void JabberAccount::slotContactUpdated (const XMPP::RosterItem & item)
 		*/
 		if ( !item.ask().isEmpty () )
 		{
-			contact->setProperty ( protocol()->propAuthorizationStatus, i18n ( "Waiting for authorization" ) );
+			contact->setProperty ( protocol()->propAuthorizationtqStatus, i18n ( "Waiting for authorization" ) );
 		}
 		else
 		{
-			contact->removeProperty ( protocol()->propAuthorizationStatus );
+			contact->removeProperty ( protocol()->propAuthorizationtqStatus );
 		}
 	}
 	else if(c)  //we don't need to add it, and it is in the contactlist
@@ -1469,7 +1469,7 @@ void JabberAccount::slotGroupChatLeft (const XMPP::Jid & jid)
 	
 }
 
-void JabberAccount::slotGroupChatPresence (const XMPP::Jid & jid, const XMPP::Status & status)
+void JabberAccount::slotGroupChatPresence (const XMPP::Jid & jid, const XMPP::tqStatus & status)
 {
 	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Received groupchat presence for room " << jid.full () << endl;
 
@@ -1512,7 +1512,7 @@ void JabberAccount::slotGroupChatError (const XMPP::Jid &jid, int error, const T
 	case JabberClient::InvalidPasswordForMUC:
 		{
 			TQCString password;
- 			int result = KPasswordDialog::getPassword(password, i18n("A password is required to join the room %1.").arg(jid.node()));
+ 			int result = KPasswordDialog::getPassword(password, i18n("A password is required to join the room %1.").tqarg(jid.node()));
 			if (result == KPasswordDialog::Accepted)
 				m_jabberClient->joinGroupChat(jid.domain(), jid.node(), jid.resource(), password);
 		}
@@ -1521,7 +1521,7 @@ void JabberAccount::slotGroupChatError (const XMPP::Jid &jid, int error, const T
 	case JabberClient::NicknameConflict:
 		{
 			bool ok;
-			TQString nickname = KInputDialog::getText(i18n("Error trying to join %1 : nickname %2 is already in use").arg(jid.node(), jid.resource()),
+			TQString nickname = KInputDialog::getText(i18n("Error trying to join %1 : nickname %2 is already in use").tqarg(jid.node(), jid.resource()),
 									i18n("Give your nickname"),
 									TQString(),
 									&ok);
@@ -1535,14 +1535,14 @@ void JabberAccount::slotGroupChatError (const XMPP::Jid &jid, int error, const T
 	case JabberClient::BannedFromThisMUC:
 		KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (),
 									KMessageBox::Error,
-									i18n ("You can't join the room %1 because you were banned").arg(jid.node()),
+									i18n ("You can't join the room %1 because you were banned").tqarg(jid.node()),
 									i18n ("Jabber Group Chat") );
 		break;
 
 	case JabberClient::MaxUsersReachedForThisMuc:
 		KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (),
 									KMessageBox::Error,
-									i18n ("You can't join the room %1 because the maximum users has been reached").arg(jid.node()),
+									i18n ("You can't join the room %1 because the maximum users has been reached").tqarg(jid.node()),
 									i18n ("Jabber Group Chat") );
 		break;
 
@@ -1659,7 +1659,7 @@ void JabberAccount::slotIncomingVoiceCall( const Jid &jid )
 // 	if(sessionType == "http://www.google.com/session/phone")
 // 	{
 // 		TQString from = ((XMPP::Jid)session->peers().first()).full();
-// 		//KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Information, TQString("Received a voice session invitation from %1.").arg(from) );
+// 		//KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Information, TQString("Received a voice session invitation from %1.").tqarg(from) );
 // 		JingleVoiceSessionDialog *voiceDialog = new JingleVoiceSessionDialog( static_cast<JingleVoiceSession*>(session) );
 // 		voiceDialog->show();
 // 	}
@@ -1687,7 +1687,7 @@ bool JabberAccount::removeAccount( )
 		int result=KMessageBox::warningYesNoCancel( Kopete::UI::Global::mainWidget () ,
 				   i18n( "Do you want to also unregister \"%1\" from the Jabber server ?\n"
 				   			    "If you unregister, all your contact list may be removed on the server,"
-							    "And you will never be able to connect to this account with any client").arg( accountLabel() ),
+							    "And you will never be able to connect to this account with any client").tqarg( accountLabel() ),
 					i18n("Unregister"),
 					KGuiItem(i18n( "Remove and Unregister" ), "editdelete"),
 					KGuiItem(i18n( "Remove from kopete only"), "edittrash"),
@@ -1734,7 +1734,7 @@ void JabberAccount::slotUnregisterFinished( )
 	if ( task && ! task->success ())
 	{
 		KMessageBox::queuedMessageBox ( 0L, KMessageBox::Error,
-			i18n ("An error occured when trying to remove the account:\n%1").arg(task->statusString()),
+			i18n ("An error occured when trying to remove the account:\n%1").tqarg(task->statusString()),
 			i18n ("Jabber Account Unregistration"));
 		m_removing=false;
 		return;
