@@ -129,19 +129,19 @@ void JabberBaseContact::updateContact ( const XMPP::RosterItem & item )
 	switch ( item.subscription().type () )
 	{
 		case XMPP::Subscription::None:
-			setProperty ( protocol()->propSubscriptionStatus,
+			setProperty ( protocol()->propSubscriptiontqStatus,
 						  i18n ( "You cannot see each others' status." ) );
 			break;
 		case XMPP::Subscription::To:
-			setProperty ( protocol()->propSubscriptionStatus,
+			setProperty ( protocol()->propSubscriptiontqStatus,
 						  i18n ( "You can see this contact's status but they cannot see your status." ) );
 			break;
 		case XMPP::Subscription::From:
-			setProperty ( protocol()->propSubscriptionStatus,
+			setProperty ( protocol()->propSubscriptiontqStatus,
 						  i18n ( "This contact can see your status but you cannot see their status." ) );
 			break;
 		case XMPP::Subscription::Both:
-			setProperty ( protocol()->propSubscriptionStatus,
+			setProperty ( protocol()->propSubscriptiontqStatus,
 						  i18n ( "You can see each others' status." ) );
 			break;
 	}
@@ -217,7 +217,7 @@ void JabberBaseContact::updateContact ( const XMPP::RosterItem & item )
 	setDontSync ( false );
 	
 	//can't do it now because it's called from contructor at a point some virtual function are not available
-	TQTimer::singleShot(0, this, TQT_SLOT(reevaluateStatus()));
+	TQTimer::singleShot(0, this, TQT_SLOT(reevaluatetqStatus()));
 
 }
 
@@ -295,7 +295,7 @@ void JabberBaseContact::updateResourceList ()
 	setProperty ( protocol()->propAvailableResources, resourceListStr );
 }
 
-void JabberBaseContact::reevaluateStatus ()
+void JabberBaseContact::reevaluatetqStatus ()
 {
 	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Determining new status for " << contactId () << endl;
 
@@ -390,7 +390,7 @@ void JabberBaseContact::serialize (TQMap < TQString, TQString > &serializedData,
 	// Contact id and display name are already set for us, only add the rest
 	serializedData["JID"] = mRosterItem.jid().full();
 
-	serializedData["groups"] = mRosterItem.groups ().join (TQString::fromLatin1 (","));
+	serializedData["groups"] = mRosterItem.groups ().join (TQString::tqfromLatin1 (","));
 }
 
 void JabberBaseContact::slotUserInfo( )
@@ -414,7 +414,7 @@ void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 	// update vCard cache timestamp if this is not a temporary contact
 	if ( metaContact() && !metaContact()->isTemporary () )
 	{
-		setProperty ( protocol()->propVCardCacheTimeStamp, TQDateTime::currentDateTime().toString ( Qt::ISODate ) );
+		setProperty ( protocol()->propVCardCacheTimeStamp, TQDateTime::tqcurrentDateTime().toString ( Qt::ISODate ) );
 	}
 
 	
@@ -632,7 +632,7 @@ void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 	TQString fullJid =  mRosterItem.jid().full();
 	TQString finalPhotoPath = locateLocal("appdata", "jabberphotos/" + fullJid.replace(TQRegExp("[./~]"),"-")  +".png");
 	
-	// photo() is a QByteArray
+	// photo() is a TQByteArray
 	if ( !vCard.photo().isEmpty() )
 	{
 		kdDebug( JABBER_DEBUG_GLOBAL ) << k_funcinfo << "Contact has a photo embedded into his vCard." << endl;
