@@ -113,7 +113,7 @@ TQStringList JabberCapabilitiesManager::CapabilitiesInformation::jids() const
 {
 	TQStringList jids;
 	
-	TQValueList<QPair<TQString,JabberAccount*> >::ConstIterator it = m_jids.constBegin(), itEnd = m_jids.constEnd();
+	TQValueList<TQPair<TQString,JabberAccount*> >::ConstIterator it = m_jids.constBegin(), itEnd = m_jids.constEnd();
 	for( ; it != itEnd; ++it) 
 	{
 		TQString jid( (*it).first );
@@ -143,12 +143,12 @@ void JabberCapabilitiesManager::CapabilitiesInformation::reset()
 
 void JabberCapabilitiesManager::CapabilitiesInformation::removeAccount(JabberAccount *account)
 {
-	TQValueList<QPair<TQString,JabberAccount*> >::Iterator it = m_jids.begin();
+	TQValueList<TQPair<TQString,JabberAccount*> >::Iterator it = m_jids.begin();
 	while( it != m_jids.end() ) 
 	{
 		if( (*it).second == account) 
 		{
-			TQValueList<QPair<TQString,JabberAccount*> >::Iterator otherIt = it;
+			TQValueList<TQPair<TQString,JabberAccount*> >::Iterator otherIt = it;
 			it++;
 			m_jids.remove(otherIt);
 		}
@@ -161,7 +161,7 @@ void JabberCapabilitiesManager::CapabilitiesInformation::removeAccount(JabberAcc
 
 void JabberCapabilitiesManager::CapabilitiesInformation::addJid(const Jid& jid, JabberAccount* account)
 {
-	QPair<TQString,JabberAccount*> jidAccountPair(jid.full(),account);
+	TQPair<TQString,JabberAccount*> jidAccountPair(jid.full(),account);
 
 	if( !m_jids.contains(jidAccountPair) ) 
 	{
@@ -174,12 +174,12 @@ void JabberCapabilitiesManager::CapabilitiesInformation::removeJid(const Jid& ji
 {
 	kdDebug(JABBER_DEBUG_GLOBAL) << k_funcinfo << "Unregistering " << TQString(jid.full()).replace('%',"%%") << endl;
 
-	TQValueList<QPair<TQString,JabberAccount*> >::Iterator it = m_jids.begin();
+	TQValueList<TQPair<TQString,JabberAccount*> >::Iterator it = m_jids.begin();
 	while( it != m_jids.end() ) 
 	{
 		if( (*it).first == jid.full() ) 
 		{
-			TQValueList<QPair<TQString,JabberAccount*> >::Iterator otherIt = it;
+			TQValueList<TQPair<TQString,JabberAccount*> >::Iterator otherIt = it;
 			it++;
 			m_jids.remove(otherIt);
 		}
@@ -190,11 +190,11 @@ void JabberCapabilitiesManager::CapabilitiesInformation::removeJid(const Jid& ji
 	}
 }
 
-QPair<Jid,JabberAccount*> JabberCapabilitiesManager::CapabilitiesInformation::nextJid(const Jid& jid, const Task* t)
+TQPair<Jid,JabberAccount*> JabberCapabilitiesManager::CapabilitiesInformation::nextJid(const Jid& jid, const Task* t)
 {
 	kdDebug(JABBER_DEBUG_GLOBAL) << k_funcinfo << "Looking for next JID" << endl;
 
-	TQValueList<QPair<TQString,JabberAccount*> >::ConstIterator it = m_jids.constBegin(), itEnd = m_jids.constEnd();
+	TQValueList<TQPair<TQString,JabberAccount*> >::ConstIterator it = m_jids.constBegin(), itEnd = m_jids.constEnd();
 	for( ; it != itEnd; ++it) 
 	{
 		if( (*it).first == jid.full() && (*it).second->client()->rootTask() == t) 
@@ -204,18 +204,18 @@ QPair<Jid,JabberAccount*> JabberCapabilitiesManager::CapabilitiesInformation::ne
 			{
 				kdDebug(JABBER_DEBUG_GLOBAL) << k_funcinfo << "No more JIDs" << endl;
 
-				return QPair<Jid,JabberAccount*>(Jid(),0L);
+				return TQPair<Jid,JabberAccount*>(Jid(),0L);
 			}
 			else if( (*it).second->isConnected() ) 
 			{
 				//qDebug("caps.cpp: Account isn't active");
 				kdDebug(JABBER_DEBUG_GLOBAL) << k_funcinfo << "Account isn't connected." << endl;
 
-				return QPair<Jid,JabberAccount*>( (*it).first,(*it).second );
+				return TQPair<Jid,JabberAccount*>( (*it).first,(*it).second );
 			}
 		}
 	}
-	return QPair<Jid,JabberAccount*>(Jid(),0L);
+	return TQPair<Jid,JabberAccount*>(Jid(),0L);
 }
 
 void JabberCapabilitiesManager::CapabilitiesInformation::setDiscovered(bool value)
@@ -240,7 +240,7 @@ void JabberCapabilitiesManager::CapabilitiesInformation::setFeatures(const TQStr
 	
 void JabberCapabilitiesManager::CapabilitiesInformation::updateLastSeen()
 {
-	m_lastSeen = TQDate::currentDate();
+	m_lastSeen = TQDate::tqcurrentDate();
 }
 
 TQDomElement JabberCapabilitiesManager::CapabilitiesInformation::toXml(TQDomDocument *doc) const
@@ -351,7 +351,7 @@ void JabberCapabilitiesManager::removeAccount(JabberAccount *account)
 	}
 }
 
-void JabberCapabilitiesManager::updateCapabilities(JabberAccount *account, const XMPP::Jid &jid, const XMPP::Status &status )
+void JabberCapabilitiesManager::updateCapabilities(JabberAccount *account, const XMPP::Jid &jid, const XMPP::tqStatus &status )
 {
 	if( !account->client() || !account->client()->rootTask() )
 		return;
@@ -400,7 +400,7 @@ void JabberCapabilitiesManager::updateCapabilities(JabberAccount *account, const
 			{
 				if( !d->capabilitiesInformationMap[*newCapsIt].discovered() && d->capabilitiesInformationMap[*newCapsIt].pendingRequests() == 0 ) 
 				{
-					kdDebug(JABBER_DEBUG_GLOBAL) << k_funcinfo << TQString("Sending disco request to %1, node=%2").arg(TQString(jid.full()).replace('%',"%%")).arg(node + "#" + (*newCapsIt).extensions()) << endl;
+					kdDebug(JABBER_DEBUG_GLOBAL) << k_funcinfo << TQString("Sending disco request to %1, node=%2").tqarg(TQString(jid.full()).replace('%',"%%")).tqarg(node + "#" + (*newCapsIt).extensions()) << endl;
 
 					d->capabilitiesInformationMap[*newCapsIt].setPendingRequests(1);
 					requestDiscoInfo(account, jid, node + "#" + (*newCapsIt).extensions());
@@ -410,7 +410,7 @@ void JabberCapabilitiesManager::updateCapabilities(JabberAccount *account, const
 		else 
 		{
 			// Remove all caps specifications
-			kdDebug(JABBER_DEBUG_GLOBAL) << TQString("Illegal caps info from %1: node=%2, ver=%3").arg(TQString(jid.full()).replace('%',"%%")).arg(node).arg(version) << endl;
+			kdDebug(JABBER_DEBUG_GLOBAL) << TQString("Illegal caps info from %1: node=%2, ver=%3").tqarg(TQString(jid.full()).replace('%',"%%")).tqarg(node).tqarg(version) << endl;
 
 			d->jidCapabilitiesMap.remove( jid.full() );
 		}
@@ -448,7 +448,7 @@ void JabberCapabilitiesManager::discoRequestFinished()
 
 	DiscoItem item = discoInfo->item();
 	Jid jid = discoInfo->jid();
-	kdDebug(JABBER_DEBUG_GLOBAL) << TQString("Disco response from %1, node=%2, success=%3").arg(TQString(jid.full()).replace('%',"%%")).arg(discoInfo->node()).arg(discoInfo->success()) << endl;
+	kdDebug(JABBER_DEBUG_GLOBAL) << TQString("Disco response from %1, node=%2, success=%3").tqarg(TQString(jid.full()).replace('%',"%%")).tqarg(discoInfo->node()).tqarg(discoInfo->success()) << endl;
 
 	TQStringList tokens = TQStringList::split("#",discoInfo->node());
 
@@ -483,10 +483,10 @@ void JabberCapabilitiesManager::discoRequestFinished()
 		}
 		else 
 		{
-			QPair<Jid,JabberAccount*> jidAccountPair = d->capabilitiesInformationMap[capabilities].nextJid(jid,discoInfo->parent());
+			TQPair<Jid,JabberAccount*> jidAccountPair = d->capabilitiesInformationMap[capabilities].nextJid(jid,discoInfo->parent());
 			if( jidAccountPair.second ) 
 			{
-				kdDebug(JABBER_DEBUG_GLOBAL) << TQString("Falling back on %1.").arg(TQString(jidAccountPair.first.full()).replace('%',"%%")) << endl;
+				kdDebug(JABBER_DEBUG_GLOBAL) << TQString("Falling back on %1.").tqarg(TQString(jidAccountPair.first.full()).replace('%',"%%")) << endl;
 				requestDiscoInfo( jidAccountPair.second, jidAccountPair.first, discoInfo->node() );
 			}
 			else 
@@ -497,7 +497,7 @@ void JabberCapabilitiesManager::discoRequestFinished()
 		}
 	}
 	else 
-		kdDebug(JABBER_DEBUG_GLOBAL) << TQString("Current client node '%1' does not match response '%2'").arg(jidCapabilities.node()).arg(node) << endl;
+		kdDebug(JABBER_DEBUG_GLOBAL) << TQString("Current client node '%1' does not match response '%2'").tqarg(jidCapabilities.node()).tqarg(node) << endl;
 
 	//for (unsigned int i = 0; i < item.features().list().count(); i++) 
 	//	printf("    Feature: %s\n",item.features().list()[i].latin1());
@@ -646,7 +646,7 @@ void JabberCapabilitiesManager::saveInformation()
 	}
 
 	TQTextStream textStream;
-	textStream.setDevice(&capsFile);
+	textStream.setDevice(TQT_TQIODEVICE(&capsFile));
 	textStream.setEncoding(TQTextStream::UnicodeUTF8);
 	textStream << doc.toString();
 	textStream.unsetDevice();
