@@ -157,7 +157,7 @@ void JabberClient::cleanUp ()
 	d->currentPenaltyTime = 0;
 
 	d->jid = XMPP::Jid ();
-	d->password = TQString::null;
+	d->password = TQString();
 
 	setForceTLS ( false );
 	setUseSSL ( false );
@@ -171,9 +171,9 @@ void JabberClient::cleanUp ()
 	setFileTransfersEnabled ( false );
 	setS5BServerPort ( 8010 );
 
-	setClientName ( TQString::null );
-	setClientVersion ( TQString::null );
-	setOSName ( TQString::null );
+	setClientName ( TQString() );
+	setClientVersion ( TQString() );
+	setOSName ( TQString() );
 
 	setTimeZone ( "UTC", 0 );
 
@@ -724,8 +724,8 @@ JabberClient::ErrorCode JabberClient::connect ( const XMPP::Jid &jid, const TQSt
 				   this, TQT_SLOT ( slotGroupChatJoined (const Jid &) ) );
 		TQObject::connect ( d->jabberClient, TQT_SIGNAL ( groupChatLeft (const Jid &) ),
 				   this, TQT_SLOT ( slotGroupChatLeft (const Jid &) ) );
-		TQObject::connect ( d->jabberClient, TQT_SIGNAL ( groupChatPresence (const Jid &, const Status &) ),
-				   this, TQT_SLOT ( slotGroupChatPresence (const Jid &, const Status &) ) );
+		TQObject::connect ( d->jabberClient, TQT_SIGNAL ( groupChatPresence (const Jid &, const tqStatus &) ),
+				   this, TQT_SLOT ( slotGroupChatPresence (const Jid &, const tqStatus &) ) );
 		TQObject::connect ( d->jabberClient, TQT_SIGNAL ( groupChatError (const Jid &, int, const TQString &) ),
 				   this, TQT_SLOT ( slotGroupChatError (const Jid &, int, const TQString &) ) );
 		//TQObject::connect ( d->jabberClient, TQT_SIGNAL (debugText (const TQString &) ),
@@ -769,7 +769,7 @@ void JabberClient::disconnect ()
 
 }
 
-void JabberClient::disconnect( XMPP::Status &reason )
+void JabberClient::disconnect( XMPP::tqStatus &reason )
 {
     if ( d->jabberClient )
     {
@@ -823,12 +823,12 @@ void JabberClient::leaveGroupChat ( const TQString &host, const TQString &room )
 
 }
 
-void JabberClient::setGroupChatStatus( const TQString & host, const TQString & room, const XMPP::Status & status )
+void JabberClient::setGroupChattqStatus( const TQString & host, const TQString & room, const XMPP::tqStatus & status )
 {
-	client()->groupChatSetStatus( host, room, status);
+	client()->groupChatSettqStatus( host, room, status);
 }
 
-void JabberClient::changeGroupChatNick( const TQString & host, const TQString & room, const TQString & nick, const XMPP::Status & status )
+void JabberClient::changeGroupChatNick( const TQString & host, const TQString & room, const TQString & nick, const XMPP::tqStatus & status )
 {
 	client()->groupChatChangeNick( host, room, nick, status );
 }
@@ -1112,7 +1112,7 @@ void JabberClient::slotGroupChatLeft ( const Jid &jid )
 
 }
 
-void JabberClient::slotGroupChatPresence ( const Jid &jid, const Status &status)
+void JabberClient::slotGroupChatPresence ( const Jid &jid, const tqStatus &status)
 {
 
 	emit groupChatPresence ( jid, status );
