@@ -21,11 +21,12 @@
 
 /**
  * This task watch for incoming Jingle session and notify manager.
- * It is declared in the header to be "moc"-able.
+ * It is declared in the header to be "tqmoc"-able.
  */
 class JingleWatchSessionTask : public XMPP::Task
 {
 	Q_OBJECT
+  TQ_OBJECT
 public:
 	JingleWatchSessionTask(XMPP::Task *parent);
 	~JingleWatchSessionTask();
