@@ -1,5 +1,5 @@
-#ifndef CS_QRANDOM_H
-#define CS_QRANDOM_H
+#ifndef CS_TQRANDOM_H
+#define CS_TQRANDOM_H
 
 #include<tqcstring.h>
 
