@@ -38,9 +38,10 @@ private:
 	void unlock();
 };
 
-class SafeDeleteLater : public QObject
+class SafeDeleteLater : public TQObject
 {
 	Q_OBJECT
+  TQ_OBJECT
 public:
 	static SafeDeleteLater *ensureExists();
 	void deleteItLater(TQObject *o);
