@@ -136,11 +136,11 @@ namespace XMPP
 		SubType value;
 	};
 
-	class Status
+	class tqStatus
 	{
 	public:
-		Status(const TQString &show="", const TQString &status="", int priority=0, bool available=true);
-		~Status();
+		tqStatus(const TQString &show="", const TQString &status="", int priority=0, bool available=true);
+		~tqStatus();
 
 		int priority() const;
 		const TQString & show() const;
@@ -162,7 +162,7 @@ namespace XMPP
 
 		void setPriority(int);
 		void setShow(const TQString &);
-		void setStatus(const TQString &);
+		void settqStatus(const TQString &);
 		void setTimeStamp(const TQDateTime &);
 		void setKeyID(const TQString &);
 		void setIsAvailable(bool);
@@ -197,19 +197,19 @@ namespace XMPP
 	class Resource
 	{
 	public:
-		Resource(const TQString &name="", const Status &s=Status());
+		Resource(const TQString &name="", const tqStatus &s=tqStatus());
 		~Resource();
 
 		const TQString & name() const;
 		int priority() const;
-		const Status & status() const;
+		const tqStatus & status() const;
 
 		void setName(const TQString &);
-		void setStatus(const Status &);
+		void settqStatus(const tqStatus &);
 
 	private:
 		TQString v_name;
-		Status v_status;
+		tqStatus v_status;
 
 		class ResourcePrivate *d;
 	};
@@ -492,9 +492,10 @@ namespace XMPP
 	class JidLinkManager;
 	class FileTransferManager;
 
-	class Task : public QObject
+	class Task : public TQObject
 	{
 		Q_OBJECT
+  TQ_OBJECT
 	public:
 		enum { ErrDisc };
 		Task(Task *parent);
@@ -539,9 +540,10 @@ namespace XMPP
 		TaskPrivate *d;
 	};
 
-	class Client : public QObject
+	class Client : public TQObject
 	{
 		Q_OBJECT
+  TQ_OBJECT
 
 	public:
 		Client(TQObject *parent=0);
@@ -568,7 +570,7 @@ namespace XMPP
 		void rosterRequest();
 		void sendMessage(const Message &);
 		void sendSubscription(const Jid &, const TQString &);
-		void setPresence(const Status &);
+		void setPresence(const tqStatus &);
 
 		void debug(const TQString &);
 		TQString genUniqueId();
@@ -608,8 +610,8 @@ namespace XMPP
 
 		bool groupChatJoin(const TQString &host, const TQString &room, const TQString &nick);
 		bool groupChatJoin(const TQString &host, const TQString &room, const TQString &nick, const TQString &password);
-		void groupChatSetStatus(const TQString &host, const TQString &room, const Status &);
-		void groupChatChangeNick(const TQString &host, const TQString &room, const TQString &nick, const Status &);
+		void groupChatSettqStatus(const TQString &host, const TQString &room, const tqStatus &);
+		void groupChatChangeNick(const TQString &host, const TQString &room, const TQString &nick, const tqStatus &);
 		void groupChatLeave(const TQString &host, const TQString &room);
 
 	signals:
@@ -630,7 +632,7 @@ namespace XMPP
 		void xmlOutgoing(const TQString &);
 		void groupChatJoined(const Jid &);
 		void groupChatLeft(const Jid &);
-		void groupChatPresence(const Jid &, const Status &);
+		void groupChatPresence(const Jid &, const tqStatus &);
 		void groupChatError(const Jid &, int, const TQString &);
 
 		void incomingJidLink();
@@ -639,7 +641,7 @@ namespace XMPP
 		//void streamConnected();
 		//void streamHandshaken();
 		//void streamError(const StreamError &);
-		//void streamSSLCertificateReady(const QSSLCert &);
+		//void streamSSLCertificateReady(const TQSSLCert &);
 		//void streamCloseFinished();
 		void streamError(int);
 		void streamReadyRead();
@@ -650,7 +652,7 @@ namespace XMPP
 
 		// basic daemons
 		void ppSubscription(const Jid &, const TQString &);
-		void ppPresence(const Jid &, const Status &);
+		void ppPresence(const Jid &, const tqStatus &);
 		void pmMessage(const Message &);
 		void prRoster(const Roster &);
 
@@ -664,8 +666,8 @@ namespace XMPP
 		void distribute(const TQDomElement &);
 		void importRoster(const Roster &);
 		void importRosterItem(const RosterItem &);
-		void updateSelfPresence(const Jid &, const Status &);
-		void updatePresence(LiveRosterItem *, const Jid &, const Status &);
+		void updateSelfPresence(const Jid &, const tqStatus &);
+		void updatePresence(LiveRosterItem *, const Jid &, const tqStatus &);
 
 		class ClientPrivate;
 		ClientPrivate *d;
@@ -687,15 +689,15 @@ namespace XMPP
 		ResourceList::ConstIterator priority() const;
 
 		bool isAvailable() const;
-		const Status & lastUnavailableStatus() const;
+		const tqStatus & lastUnavailabletqStatus() const;
 		bool flagForDelete() const;
 
-		void setLastUnavailableStatus(const Status &);
+		void setLastUnavailabletqStatus(const tqStatus &);
 		void setFlagForDelete(bool);
 
 	private:
 		ResourceList v_resourceList;
-		Status v_lastUnavailableStatus;
+		tqStatus v_lastUnavailabletqStatus;
 		bool v_flagForDelete;
 
 		class LiveRosterItemPrivate;
