@@ -61,9 +61,10 @@ static bool haveHost(const StreamHostList &list, const Jid &j)
 	return false;
 }
 
-class S5BManager::Item : public QObject
+class S5BManager::Item : public TQObject
 {
 	Q_OBJECT
+  TQ_OBJECT
 public:
 	enum { Idle, Initiator, Target, Active };
 	enum { ErrRefused, ErrConnect, ErrWrongHost, ErrProxy };
@@ -1745,9 +1746,10 @@ void S5BManager::Item::finished()
 //----------------------------------------------------------------------------
 // S5BConnector
 //----------------------------------------------------------------------------
-class S5BConnector::Item : public QObject
+class S5BConnector::Item : public TQObject
 {
 	Q_OBJECT
+  TQ_OBJECT
 public:
 	SocksClient *client;
 	SocksUDP *client_udp;
@@ -1976,9 +1978,10 @@ void S5BConnector::man_udpSuccess(const Jid &streamHost)
 //----------------------------------------------------------------------------
 // S5BServer
 //----------------------------------------------------------------------------
-class S5BServer::Item : public QObject
+class S5BServer::Item : public TQObject
 {
 	Q_OBJECT
+  TQ_OBJECT
 public:
 	SocksClient *client;
 	TQString host;
