@@ -39,7 +39,7 @@ using namespace XMPP;
 //
 // This function prints out an array of bytes as latin characters, converting
 // non-printable bytes into hex values as necessary.  Useful for displaying
-// QByteArrays for debugging purposes.
+// TQByteArrays for debugging purposes.
 static TQString printArray(const TQByteArray &a)
 {
 	TQString s;
@@ -1109,7 +1109,7 @@ bool CoreProtocol::normalStep(const TQDomElement &e)
 		e.setAttribute("mechanism", sasl_mech);
 		if(!sasl_step.isEmpty()) {
 #ifdef XMPP_TEST
-			TD::msg(TQString("SASL OUT: [%1]").arg(printArray(sasl_step)));
+			TD::msg(TQString("SASL OUT: [%1]").tqarg(printArray(sasl_step)));
 #endif
 			e.appendChild(doc.createTextNode(Base64::arrayToString(sasl_step)));
 		}
@@ -1143,7 +1143,7 @@ bool CoreProtocol::normalStep(const TQDomElement &e)
 		else {
 			TQByteArray stepData = sasl_step;
 #ifdef XMPP_TEST
-			TD::msg(TQString("SASL OUT: [%1]").arg(printArray(sasl_step)));
+			TD::msg(TQString("SASL OUT: [%1]").tqarg(printArray(sasl_step)));
 #endif
 			TQDomElement e = doc.createElementNS(NS_SASL, "response");
 			if(!stepData.isEmpty())
@@ -1289,7 +1289,7 @@ bool CoreProtocol::normalStep(const TQDomElement &e)
 #ifdef XMPP_TEST
 				TQString s = "SASL mechs:";
 				for(TQStringList::ConstIterator it = f.sasl_mechs.begin(); it != f.sasl_mechs.end(); ++it)
-					s += TQString(" [%1]").arg((*it));
+					s += TQString(" [%1]").tqarg((*it));
 				TD::msg(s);
 #endif
 			}
@@ -1341,7 +1341,7 @@ bool CoreProtocol::normalStep(const TQDomElement &e)
 			if(e.tagName() == "challenge") {
 				TQByteArray a = Base64::stringToArray(e.text());
 #ifdef XMPP_TEST
-				TD::msg(TQString("SASL IN: [%1]").arg(printArray(a)));
+				TD::msg(TQString("SASL IN: [%1]").tqarg(printArray(a)));
 #endif
 				sasl_step = a;
 				need = NSASLNext;
