@@ -574,7 +574,7 @@ public:
 	bool allowPlain, mutualAuth;
 	bool haveLocalAddr;
 	TQHostAddress localAddr;
-	Q_UINT16 localPort;
+	TQ_UINT16 localPort;
 	int minimumSSF, maximumSSF;
 	TQString sasl_mech;
 	bool doBinding;
@@ -832,7 +832,7 @@ void ClientStream::setSASLMechanism(const TQString &s)
 	d->sasl_mech = s;
 }
 
-void ClientStream::setLocalAddr(const TQHostAddress &addr, Q_UINT16 port)
+void ClientStream::setLocalAddr(const TQHostAddress &addr, TQ_UINT16 port)
 {
 	d->haveLocalAddr = true;
 	d->localAddr = addr;
@@ -1241,7 +1241,7 @@ void ClientStream::srvProcessNext()
 				printf("Break (RecvOpen)\n");
 
 				// calculate key
-				TQCString str = QCA::SHA1::hashToString("secret").utf8();
+				TQCString str = QCA::SHA1::hashToString(TQCString("secret")).utf8();
 				str = QCA::SHA1::hashToString(str + "im.pyxa.org").utf8();
 				str = QCA::SHA1::hashToString(str + d->srv.id.utf8()).utf8();
 				d->srv.setDialbackKey(str);
@@ -1358,9 +1358,9 @@ void ClientStream::processNext()
 #endif
 
 #ifdef XMPP_TEST
-				TQString s = TQString("handshake success (lang=[%1]").arg(d->client.lang);
+				TQString s = TQString("handshake success (lang=[%1]").tqarg(d->client.lang);
 				if(!d->client.from.isEmpty())
-					s += TQString(", from=[%1]").arg(d->client.from);
+					s += TQString(", from=[%1]").tqarg(d->client.from);
 				s += ')';
 				TD::msg(s);
 #endif
