@@ -485,7 +485,7 @@ JT_Presence::~JT_Presence()
 {
 }
 
-void JT_Presence::pres(const Status &s)
+void JT_Presence::pres(const tqStatus &s)
 {
 	type = 0;
 
@@ -504,7 +504,7 @@ void JT_Presence::pres(const Status &s)
 		if(!s.status().isEmpty())
 			tag.appendChild(textTag(doc(), "status", s.status()));
 
-		tag.appendChild( textTag(doc(), "priority", TQString("%1").arg(s.priority()) ) );
+		tag.appendChild( textTag(doc(), "priority", TQString("%1").tqarg(s.priority()) ) );
 
 		if(!s.keyID().isEmpty()) {
 			TQDomElement x = textTag(doc(), "x", s.keyID());
@@ -529,7 +529,7 @@ void JT_Presence::pres(const Status &s)
 	}
 }
 
-void JT_Presence::pres(const Jid &to, const Status &s)
+void JT_Presence::pres(const Jid &to, const tqStatus &s)
 {
 	pres(s);
 	tag.setAttribute("to", to.full());
@@ -569,7 +569,7 @@ bool JT_PushPresence::take(const TQDomElement &e)
 		return false;
 
 	Jid j(e.attribute("from"));
-	Status p;
+	tqStatus p;
 
 	if(e.hasAttribute("type")) {
 		TQString type = e.attribute("type");
@@ -593,7 +593,7 @@ bool JT_PushPresence::take(const TQDomElement &e)
 
 	tag = findSubTag(e, "status", &found);
 	if(found)
-		p.setStatus(tagContent(tag));
+		p.settqStatus(tagContent(tag));
 	tag = findSubTag(e, "show", &found);
 	if(found)
 		p.setShow(tagContent(tag));
@@ -676,7 +676,7 @@ static TQDomElement oldStyleNS(const TQDomElement &e)
 	if(!noShowNS)
 		i.setAttribute("xmlns", e.namespaceURI());
 
-	// copy children
+	// copy tqchildren
 	TQDomNodeList nl = e.childNodes();
 	for(x = 0; x < nl.count(); ++x) {
 		TQDomNode n = nl.item(x);
@@ -742,7 +742,7 @@ static TQDomElement addCorrectNS(const TQDomElement &e)
 			i.setAttributeNodeNS(al.item(x).cloneNode().toAttr());
 	}
 
-	// copy children
+	// copy tqchildren
 	TQDomNodeList nl = e.childNodes();
 	for(x = 0; x < nl.count(); ++x) {
 		TQDomNode n = nl.item(x);
@@ -1338,12 +1338,12 @@ bool JT_ServInfo::take(const TQDomElement &e)
 	//	TQDomElement query = doc()->createElement("query");
 	//	query.setAttribute("xmlns", "jabber:iq:time");
 	//	iq.appendChild(query);
-	//	TQDateTime local = TQDateTime::currentDateTime();
+	//	TQDateTime local = TQDateTime::tqcurrentDateTime();
 	//	TQDateTime utc = local.addSecs(-getTZOffset() * 3600);
 	//	TQString str = getTZString();
 	//	query.appendChild(textTag("utc", TS2stamp(utc)));
 	//	query.appendChild(textTag("tz", str));
-	//	query.appendChild(textTag("display", TQString("%1 %2").arg(local.toString()).arg(str)));
+	//	query.appendChild(textTag("display", TQString("%1 %2").tqarg(local.toString()).tqarg(str)));
 	//	send(iq);
 	//	return TRUE;
 	//}
@@ -1969,7 +1969,7 @@ JT_MucPresence::~JT_MucPresence()
 {
 }
 
-void JT_MucPresence::pres(const Status &s)
+void JT_MucPresence::pres(const tqStatus &s)
 {
 	type = 0;
 
@@ -1988,7 +1988,7 @@ void JT_MucPresence::pres(const Status &s)
 		if(!s.status().isEmpty())
 			tag.appendChild(textTag(doc(), "status", s.status()));
 
-		tag.appendChild( textTag(doc(), "priority", TQString("%1").arg(s.priority()) ) );
+		tag.appendChild( textTag(doc(), "priority", TQString("%1").tqarg(s.priority()) ) );
 
 		if(!s.keyID().isEmpty()) {
 			TQDomElement x = textTag(doc(), "x", s.keyID());
@@ -2013,7 +2013,7 @@ void JT_MucPresence::pres(const Status &s)
 	}
 }
 
-void JT_MucPresence::pres(const Jid &to, const Status &s, const TQString &password)
+void JT_MucPresence::pres(const Jid &to, const tqStatus &s, const TQString &password)
 {
 	pres(s);
 	tag.setAttribute("to", to.full());
@@ -2118,3 +2118,34 @@ TQDomElement JT_PrivateStorage::element( )
 	return d->elem;
 }
 
+//----------------------------------------------------------------------------
+// PongServer
+//----------------------------------------------------------------------------
+/**
+ * \class PongServer
+ * \brief Answers XMPP Pings
+ */
+
+PongServer::PongServer(Task *parent)
+:Task(parent)
+{
+}
+
+PongServer::~PongServer()
+{
+}
+
+bool PongServer::take(const TQDomElement &e)
+{
+	if (e.tagName() != "iq" || e.attribute("type") != "get")
+		return false;
+
+	bool found = false;
+	TQDomElement ping = findSubTag(e, "ping", &found);
+	if (found && ping.attribute("xmlns") == "urn:xmpp:ping") {
+		TQDomElement iq = createIQ(doc(), "result", e.attribute("from"), e.attribute("id"));
+		send(iq);
+		return true;
+	}
+	return false;
+}
