@@ -22,7 +22,7 @@
 
 #include "dlgjabbervcard.h"
 
-// Qt includes
+// TQt includes
 #include <tqtextedit.h>
 #include <tqwidgetstack.h>
 #include <tqregexp.h>
@@ -92,7 +92,7 @@ dlgJabberVCard::dlgJabberVCard (JabberAccount *account, JabberBaseContact *conta
  */
 dlgJabberVCard::~dlgJabberVCard ()
 {
-	// no need to delete child widgets, Qt does it all for us
+	// no need to delete child widgets, TQt does it all for us
 }
 
 /*
@@ -296,7 +296,7 @@ void dlgJabberVCard::setEnabled(bool state)
 void dlgJabberVCard::slotSaveVCard()
 {
 	setEnabled(false);
-	m_mainWidget->lblStatus->setText( i18n("Saving vCard to server...") );
+	m_mainWidget->lbltqStatus->setText( i18n("Saving vCard to server...") );
 
 	XMPP::VCard vCard;
 	XMPP::VCard::AddressList addressList;
@@ -418,12 +418,12 @@ void dlgJabberVCard::slotVCardSaved()
 	
 	if( vCard->success() )
 	{
-		m_mainWidget->lblStatus->setText( i18n("vCard save sucessful.") );
+		m_mainWidget->lbltqStatus->setText( i18n("vCard save sucessful.") );
 		m_contact->setPropertiesFromVCard( vCard->vcard() );
 	}
 	else
 	{
-		m_mainWidget->lblStatus->setText( i18n("Error: Unable to save vCard.") );
+		m_mainWidget->lbltqStatus->setText( i18n("Error: Unable to save vCard.") );
 	}
 
 	setEnabled(true);
@@ -431,7 +431,7 @@ void dlgJabberVCard::slotVCardSaved()
 
 void dlgJabberVCard::slotGetVCard()
 {
-	m_mainWidget->lblStatus->setText( i18n("Fetching contact vCard...") );
+	m_mainWidget->lbltqStatus->setText( i18n("Fetching contact vCard...") );
 
 	setReadOnly(true);
 	setEnabled(false);
@@ -454,11 +454,11 @@ void dlgJabberVCard::slotGotVCard()
 
 		assignContactProperties();		
 
-		m_mainWidget->lblStatus->setText( i18n("vCard fetching Done.") );
+		m_mainWidget->lbltqStatus->setText( i18n("vCard fetching Done.") );
 	}
 	else
 	{
-		m_mainWidget->lblStatus->setText( i18n("Error: vCard could not be fetched correctly. Check connectivity with the Jabber server.") );
+		m_mainWidget->lbltqStatus->setText( i18n("Error: vCard could not be fetched correctly. Check connectivity with the Jabber server.") );
 		//it is maybe possible to anyway edit our own vCard (if it is new
 		if(m_account->myself() == m_contact)
 			setEnabled( true );
@@ -469,7 +469,7 @@ void dlgJabberVCard::slotSelectPhoto()
 {
 	TQString path;
 	bool remoteFile = false;
-	KURL filePath = KFileDialog::getImageOpenURL( TQString::null, this, i18n( "Jabber Photo" ) );
+	KURL filePath = KFileDialog::getImageOpenURL( TQString(), this, i18n( "Jabber Photo" ) );
 	if( filePath.isEmpty() )
 		return;
 
@@ -493,7 +493,7 @@ void dlgJabberVCard::slotSelectPhoto()
 		if(img.width() > 96 || img.height() > 96)
 		{
 			// Scale and crop the picture.
-			img = img.smoothScale( 96, 96, TQImage::ScaleMin );
+			img = img.smoothScale( 96, 96, TQ_ScaleMin );
 			// crop image if not square
 			if(img.width() < img.height()) 
 				img = img.copy((img.width()-img.height())/2, 0, 96, 96);
@@ -504,7 +504,7 @@ void dlgJabberVCard::slotSelectPhoto()
 		else if (img.width() < 32 || img.height() < 32)
 		{
 			// Scale and crop the picture.
-			img = img.smoothScale( 32, 32, TQImage::ScaleMin );
+			img = img.smoothScale( 32, 32, TQ_ScaleMin );
 			// crop image if not square
 			if(img.width() < img.height())
 				img = img.copy((img.width()-img.height())/2, 0, 32, 32);
@@ -527,7 +527,7 @@ void dlgJabberVCard::slotSelectPhoto()
 		}
 		else
 		{
-			m_photoPath = TQString::null;
+			m_photoPath = TQString();
 		}
 	}
 	else
@@ -542,12 +542,12 @@ void dlgJabberVCard::slotSelectPhoto()
 void dlgJabberVCard::slotClearPhoto()
 {
 	m_mainWidget->lblPhoto->setPixmap( TQPixmap() );
-	m_photoPath = TQString::null;
+	m_photoPath = TQString();
 }
 
 void dlgJabberVCard::slotOpenURL(const TQString &url)
 {
-	if ( !url.isEmpty () || (url == TQString::fromLatin1("mailto:") ) )
+	if ( !url.isEmpty () || (url == TQString::tqfromLatin1("mailto:") ) )
 		new KRun(KURL( url ) );
 }
 
