@@ -81,7 +81,7 @@ MSNAccount::MSNAccount( MSNProtocol *parent, const TQString& AccountID, const ch
 	TQObject::connect( Kopete::ContactList::self(), TQT_SIGNAL( globalIdentityChanged(const TQString&, const TQVariant& ) ), TQT_SLOT( slotGlobalIdentityChanged(const TQString&, const TQVariant& ) ));
 
 	m_openInboxAction = new KAction( i18n( "Open Inbo&x..." ), "mail_generic", 0, this, TQT_SLOT( slotOpenInbox() ), this, "m_openInboxAction" );
-	m_changeDNAction = new KAction( i18n( "&Change Display Name..." ), TQString::null, 0, this, TQT_SLOT( slotChangePublicName() ), this, "renameAction" );
+	m_changeDNAction = new KAction( i18n( "&Change Display Name..." ), TQString(), 0, this, TQT_SLOT( slotChangePublicName() ), this, "renameAction" );
 	m_startChatAction = new KAction( i18n( "&Start Chat..." ), "mail_generic", 0, this, TQT_SLOT( slotStartChat() ), this, "startChatAction" );
 
 
@@ -231,7 +231,7 @@ void MSNAccount::createNotificationServer( const TQString &host, uint port )
 	TQObject::connect( m_notifySocket, TQT_SIGNAL( errorMessage(int, const TQString& ) ), 
 		TQT_SLOT( slotErrorMessageReceived(int, const TQString& ) ) );
 
-	m_notifySocket->setStatus( m_connectstatus );
+	m_notifySocket->settqStatus( m_connectstatus );
 	m_notifySocket->connect(host, port);
 }
 
@@ -314,7 +314,7 @@ void MSNAccount::setOnlineStatus( const Kopete::OnlineStatus &status , const TQS
 		disconnect();
 	else if ( m_notifySocket )
 	{
-		m_notifySocket->setStatus( status );
+		m_notifySocket->settqStatus( status );
 	}
 	else
 	{
@@ -330,7 +330,7 @@ void MSNAccount::slotStartChat()
 
 	bool ok;
 	TQString handle = KInputDialog::getText( i18n( "Start Chat - MSN Plugin" ),
-		i18n( "Please enter the email address of the person with whom you want to chat:" ), TQString::null, &ok ).lower();
+		i18n( "Please enter the email address of the person with whom you want to chat:" ), TQString(), &ok ).lower();
 	if ( ok )
 	{
 		if ( MSNProtocol::validContactId( handle ) )
@@ -409,7 +409,7 @@ void MSNAccount::slotNotifySocketClosed()
 	m_notifySocket->deleteLater();
 	m_notifySocket = 0l;
 	myself()->setOnlineStatus( MSNProtocol::protocol()->FLN );
-	setAllContactsStatus( MSNProtocol::protocol()->FLN );
+	setAllContactstqStatus( MSNProtocol::protocol()->FLN );
 	disconnected(reason);
 
 	
@@ -484,7 +484,7 @@ void MSNAccount::setPublicName( const TQString &publicName )
 {
 	if ( m_notifySocket )
 	{
-		m_notifySocket->changePublicName( publicName, TQString::null );
+		m_notifySocket->changePublicName( publicName, TQString() );
 	}
 }
 
@@ -596,7 +596,7 @@ void MSNAccount::slotGroupAdded( const TQString& groupName, const TQString &grou
 			kdDebug( 14140 ) << k_funcinfo << "Adding to new group: " << contactId <<  endl;
 			MSNContact *c = static_cast<MSNContact *>(contacts()[contactId]);
 			if(c && c->hasProperty(MSNProtocol::protocol()->propGuid.key()) )
-				notifySocket()->addContact( contactId, MSNProtocol::FL, TQString::null, c->guid(), groupGuid );
+				notifySocket()->addContact( contactId, MSNProtocol::FL, TQString(), c->guid(), groupGuid );
 			else
 			{
 				// If we get to here, we're currently adding a new contact, add the groupGUID to the groupList
@@ -703,7 +703,7 @@ void MSNAccount::slotKopeteGroupRemoved( Kopete::Group *g )
 
 			Kopete::Group::topLevel()->setPluginData( protocol(), accountId() + " id", "" );
 			Kopete::Group::topLevel()->setPluginData( protocol(), accountId() + " displayName", g->pluginData( protocol(), accountId() + " displayName" ) );
-			g->setPluginData( protocol(), accountId() + " id", TQString::null ); // the group should be soon deleted, but make sure
+			g->setPluginData( protocol(), accountId() + " id", TQString() ); // the group should be soon deleted, but make sure
 
 			return;
 		}
@@ -737,7 +737,7 @@ void MSNAccount::slotNewContactList()
 		for(TQMap<TQString, Kopete::Group*>::Iterator it=m_oldGroupList.begin() ; it != m_oldGroupList.end() ; ++it )
 		{	//they are about to be changed
 			if(it.data())
-				it.data()->setPluginData( protocol(), accountId() + " id", TQString::null );
+				it.data()->setPluginData( protocol(), accountId() + " id", TQString() );
 		}
 
 		m_allowList.clear();
@@ -745,9 +745,9 @@ void MSNAccount::slotNewContactList()
 		m_reverseList.clear();
 		m_groupList.clear();
 		KConfigGroup *config=configGroup();
-		config->writeEntry( "blockList" , TQString::null ) ;
-		config->writeEntry( "allowList" , TQString::null );
-		config->writeEntry( "reverseList" , TQString::null );
+		config->writeEntry( "blockList" , TQString() ) ;
+		config->writeEntry( "allowList" , TQString() );
+		config->writeEntry( "reverseList" , TQString() );
 
 		// clear all date information which will be received.
 		// if the information is not anymore on the server, it will not be received
@@ -759,9 +759,9 @@ void MSNAccount::slotNewContactList()
 			c->setAllowed( false );
 			c->setReversed( false );
 			c->setDeleted( true );
-			c->setInfo( "PHH", TQString::null );
-			c->setInfo( "PHW", TQString::null );
-			c->setInfo( "PHM", TQString::null );
+			c->setInfo( "PHH", TQString() );
+			c->setInfo( "PHW", TQString() );
+			c->setInfo( "PHM", TQString() );
 			c->removeProperty( MSNProtocol::protocol()->propGuid );
 		}
 		m_newContactList=true;
@@ -874,21 +874,21 @@ void MSNAccount::slotContactListed( const TQString& handle, const TQString& publ
 		}
 	}
 	if ( lists & 2 )
-		slotContactAdded( handle, "AL", publicName, TQString::null, TQString::null );
+		slotContactAdded( handle, "AL", publicName, TQString(), TQString() );
 	else if(c)
 		c->setAllowed(false);
 	if ( lists & 4 )
-		slotContactAdded( handle, "BL", publicName, TQString::null, TQString::null );
+		slotContactAdded( handle, "BL", publicName, TQString(), TQString() );
 	else if(c)
 		c->setBlocked(false);
 	if ( lists & 8 )
-		slotContactAdded( handle, "RL", publicName, TQString::null, TQString::null );
+		slotContactAdded( handle, "RL", publicName, TQString(), TQString() );
 	else if(c)
 		c->setReversed(false);
 	if ( lists & 16 ) // This contact is on the pending list. Add to the reverse list and delete from the pending list
 	{
-		notifySocket()->addContact( handle, MSNProtocol::RL, TQString::null, TQString::null, TQString::null );
-		notifySocket()->removeContact( handle, MSNProtocol::PL, TQString::null, TQString::null );
+		notifySocket()->addContact( handle, MSNProtocol::RL, TQString(), TQString(), TQString() );
+		notifySocket()->removeContact( handle, MSNProtocol::PL, TQString(), TQString() );
 	}
 }
 
@@ -922,7 +922,7 @@ void MSNAccount::slotContactAdded( const TQString& handle, const TQString& list,
 					if( m_groupList.contains(groupGuid) )
 					{
 						kdDebug( 14140 ) << k_funcinfo << "Adding " << handle << " to group: " << groupGuid <<  endl;
-						notifySocket()->addContact( handle, MSNProtocol::FL, TQString::null, contactGuid, groupGuid );
+						notifySocket()->addContact( handle, MSNProtocol::FL, TQString(), contactGuid, groupGuid );
 						
 						c->contactAddedToGroup( groupGuid, m_groupList[ groupGuid ] );
 						
@@ -951,7 +951,7 @@ void MSNAccount::slotContactAdded( const TQString& handle, const TQString& list,
 				if( !c->hasProperty(MSNProtocol::protocol()->propGuid.key()) )
 					c->setProperty( MSNProtocol::protocol()->propGuid, contactGuid );
 
-				if ( c->onlineStatus() == MSNProtocol::protocol()->UNK )
+				if ( c->onlinetqStatus() == MSNProtocol::protocol()->UNK )
 					c->setOnlineStatus( MSNProtocol::protocol()->FLN );
 	
 				if ( c->metaContact() && c->metaContact()->isTemporary() )
@@ -971,7 +971,7 @@ void MSNAccount::slotContactAdded( const TQString& handle, const TQString& list,
 		if ( !handle.isEmpty() && !m_allowList.contains( handle ) && !m_blockList.contains( handle ) )
 		{
 			kdDebug(14140) << k_funcinfo << "Trying to add contact to AL. " << endl;
-			notifySocket()->addContact(handle, MSNProtocol::AL, TQString::null, TQString::null, TQString::null );
+			notifySocket()->addContact(handle, MSNProtocol::AL, TQString(), TQString(), TQString() );
 		}
 	}
 	else if ( list == "BL" )
@@ -1035,7 +1035,7 @@ void MSNAccount::slotContactRemoved( const TQString& handle, const TQString& lis
 		m_blockList.remove( handle );
 		configGroup()->writeEntry( "blockList" , m_blockList ) ;
 		if ( !m_allowList.contains( handle ) )
-			notifySocket()->addContact( handle, MSNProtocol::AL, TQString::null, TQString::null, TQString::null );
+			notifySocket()->addContact( handle, MSNProtocol::AL, TQString(), TQString(), TQString() );
 
 		if(c)
 			c->setBlocked( false );
@@ -1045,7 +1045,7 @@ void MSNAccount::slotContactRemoved( const TQString& handle, const TQString& lis
 		m_allowList.remove( handle );
 		configGroup()->writeEntry( "allowList" , m_allowList ) ;
 		if ( !m_blockList.contains( handle ) )
-			notifySocket()->addContact( handle, MSNProtocol::BL, TQString::null, TQString::null, TQString::null );
+			notifySocket()->addContact( handle, MSNProtocol::BL, TQString(), TQString(), TQString() );
 
 		if(c)
 			c->setAllowed( false );
@@ -1189,7 +1189,7 @@ void MSNAccount::slotCreateChat( const TQString& ID, const TQString& address, co
 		if ( !ID.isEmpty() && notifyNewChat )
 		{
 			// this temporary message should open the window if they not exist
-			TQString body = i18n( "%1 has started a chat with you" ).arg( c->metaContact()->displayName() );
+			TQString body = i18n( "%1 has started a chat with you" ).tqarg( c->metaContact()->displayName() );
 			Kopete::Message tmpMsg = Kopete::Message( c, manager->members(), body, Kopete::Message::Internal, Kopete::Message::PlainText );
 			manager->appendMessage( tmpMsg );
 		}
@@ -1242,16 +1242,16 @@ void MSNAccount::slotContactAddedNotifyDialogClosed(const TQString& handle)
 	if ( !dialog->authorized() )
 	{
 		if ( m_allowList.contains( handle ) )
-			m_notifySocket->removeContact( handle, MSNProtocol::AL, TQString::null, TQString::null );
+			m_notifySocket->removeContact( handle, MSNProtocol::AL, TQString(), TQString() );
 		else if ( !m_blockList.contains( handle ) )
-			m_notifySocket->addContact( handle, MSNProtocol::BL, TQString::null, TQString::null, TQString::null );
+			m_notifySocket->addContact( handle, MSNProtocol::BL, TQString(), TQString(), TQString() );
 	}
 	else
 	{
 		if ( m_blockList.contains( handle ) )
-			m_notifySocket->removeContact( handle, MSNProtocol::BL, TQString::null, TQString::null );
+			m_notifySocket->removeContact( handle, MSNProtocol::BL, TQString(), TQString() );
 		else if ( !m_allowList.contains( handle ) )
-			m_notifySocket->addContact( handle, MSNProtocol::AL, TQString::null, TQString::null, TQString::null );
+			m_notifySocket->addContact( handle, MSNProtocol::AL, TQString(), TQString(), TQString() );
 	}
 
 	
@@ -1354,8 +1354,8 @@ void MSNAccount::addContactServerside(const TQString &contactId, TQPtrList<Kopet
 			if( !m_groupList.contains(groupId) )
 			{
 				// Clear the group plugin data.
-				group->setPluginData( protocol() , accountId() + " id" , TQString::null);
-				group->setPluginData( protocol() , accountId() + " displayName" , TQString::null);
+				group->setPluginData( protocol() , accountId() + " id" , TQString());
+				group->setPluginData( protocol() , accountId() + " displayName" , TQString());
 				kdDebug( 14140 ) << k_funcinfo << " Group " << group->displayName() << " marked with id #" << groupId << " does not seems to be anymore on the server" << endl;
 
 				// Add the group on MSN server, will fix the corruption.
@@ -1383,7 +1383,7 @@ void MSNAccount::addContactServerside(const TQString &contactId, TQPtrList<Kopet
 
 	// After add the contact to the top-level, it will be moved to required groups later.
 	kdDebug( 14140 ) << k_funcinfo << "Add the contact on the server " << endl;
-	m_notifySocket->addContact( contactId, MSNProtocol::FL, contactId, TQString::null, TQString::null );
+	m_notifySocket->addContact( contactId, MSNProtocol::FL, contactId, TQString(), TQString() );
 }
 
 MSNContact *MSNAccount::findContactByGuid(const TQString &contactGuid)
@@ -1488,7 +1488,7 @@ void MSNAccount::resetPictureObject(bool silent, bool force)
 	if(old!=m_pictureObj && isConnected() && m_notifySocket && !silent)
 	{
 		//update the msn pict
-		m_notifySocket->setStatus( myself()->onlineStatus() );
+		m_notifySocket->settqStatus( myself()->onlinetqStatus() );
 	}
 }
 
