@@ -202,7 +202,7 @@ void MSNChatSession::slotUserJoined( const TQString &handle, const TQString &pub
 	m_timeoutTimer=0L;
 	
 	if( !account()->contacts()[ handle ] )
-		account()->addContact( handle, TQString::null, 0L, Kopete::Account::Temporary);
+		account()->addContact( handle, TQString(), 0L, Kopete::Account::Temporary);
 
 	MSNContact *c = static_cast<MSNContact*>( account()->contacts()[ handle ] );
 
@@ -355,7 +355,7 @@ void MSNChatSession::slotInviteOtherContact()
 	bool ok;
 	TQString handle = KInputDialog::getText(i18n( "MSN Plugin" ),
 			i18n( "Please enter the email address of the person you want to invite:" ),
-			TQString::null, &ok );
+			TQString(), &ok );
 	if( !ok )
 		return;
 
@@ -408,7 +408,7 @@ void MSNChatSession::slotAcknowledgement(unsigned int id, bool ack)
 	if ( !ack )
 	{
 		Kopete::Message m = m_messagesSent[ id ];
-		TQString body = i18n( "The following message has not been sent correctly:\n%1" ).arg( m.plainBody() );
+		TQString body = i18n( "The following message has not been sent correctly:\n%1" ).tqarg( m.plainBody() );
 		Kopete::Message msg = Kopete::Message( m.to().first(), members(), body, Kopete::Message::Internal, Kopete::Message::PlainText );
 		appendMessage( msg );
 		//stop the stupid animation
@@ -467,7 +467,7 @@ void MSNChatSession::slotInvitation(const TQString &handle, const TQString &msg)
 				TQString body = i18n(
 					"%1 has sent an unimplemented invitation, the invitation was rejected.\n"
 					"The invitation was: %2" )
-						.arg( c->property( Kopete::Global::Properties::self()->nickName()).value().toString(), inviteName );
+						.tqarg( c->property( Kopete::Global::Properties::self()->nickName()).value().toString(), inviteName );
 				Kopete::Message tmpMsg = Kopete::Message( c , members() , body , Kopete::Message::Internal, Kopete::Message::PlainText);
 				appendMessage(tmpMsg);
 
@@ -493,7 +493,7 @@ void MSNChatSession::sendFile(const TQString &fileLocation, const TQString &/*fi
 	// TODO create a switchboard to send the file is one is not available.
 	if(m_chatService && members().getFirst())
 	{
-		m_chatService->PeerDispatcher()->sendFile(fileLocation, (Q_INT64)fileSize, members().getFirst()->contactId());
+		m_chatService->PeerDispatcher()->sendFile(fileLocation, (TQ_INT64)fileSize, members().getFirst()->contactId());
 	}
 }
 
@@ -527,7 +527,7 @@ void MSNChatSession::slotRequestPicture()
 			if( !c->object().isEmpty() )
 				m_chatService->requestDisplayPicture();
 		}
-		else if(myself()->onlineStatus().isDefinitelyOnline()  && myself()->onlineStatus().status() != Kopete::OnlineStatus::Invisible )
+		else if(myself()->onlinetqStatus().isDefinitelyOnline()  && myself()->onlinetqStatus().status() != Kopete::OnlineStatus::Invisible )
 			startChatSession();
 	}
 	else
@@ -548,7 +548,7 @@ void MSNChatSession::slotDisplayPictureChanged()
 			int sz=22;
 			// get the size of the toolbar were the aciton is plugged.
 			//  if you know a better way to get the toolbar, let me know
-			KMainWindow *w= view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) : 0L;
+			KMainWindow *w= view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->tqtopLevelWidget() ) : 0L;
 			if(w)
 			{
 				//We connected that in the constructor.  we don't need to keep this slot active.
@@ -621,7 +621,7 @@ void MSNChatSession::receivedTypingMsg( const TQString &contactId, bool b )
 		if (  notifyNewChat  )
 		{
 			// this internal message should open the window if they not exist
-			TQString body = i18n( "%1 has started a chat with you" ).arg( c->metaContact()->displayName() );
+			TQString body = i18n( "%1 has started a chat with you" ).tqarg( c->metaContact()->displayName() );
 			Kopete::Message tmpMsg = Kopete::Message( c, members(), body, Kopete::Message::Internal, Kopete::Message::PlainText );
 			appendMessage( tmpMsg );
 		}
@@ -715,14 +715,14 @@ void MSNChatSession::cleanMessageQueue( const TQString & reason )
 		else
 			m=m_messagesSent.begin().data();
 		
-		TQString body=i18n("The following message has not been sent correctly  (%1): \n%2").arg(reason, m.plainBody());
+		TQString body=i18n("The following message has not been sent correctly  (%1): \n%2").tqarg(reason, m.plainBody());
 		Kopete::Message msg = Kopete::Message(m.to().first() , members() , body , Kopete::Message::Internal, Kopete::Message::PlainText);
 		appendMessage(msg);
 	}
 	else
 	{
 		Kopete::Message m;
-		TQString body=i18n("These messages have not been sent correctly (%1): <br /><ul>").arg(reason);
+		TQString body=i18n("These messages have not been sent correctly (%1): <br /><ul>").tqarg(reason);
 		for ( TQMap<unsigned int , Kopete::Message>::iterator it = m_messagesSent.begin(); it!=m_messagesSent.end(); it = m_messagesSent.begin() )
 		{
 			m=it.data();
