@@ -90,14 +90,14 @@ void MSNNotifySocket::disconnect()
 	m_isLogged = false;
 	if(	m_disconnectReason==Kopete::Account::Unknown )
 		m_disconnectReason=Kopete::Account::Manual;
-	if( onlineStatus() == Connected )
-		sendCommand( "OUT", TQString::null, false );
+	if( onlinetqStatus() == Connected )
+		sendCommand( "OUT", TQString(), false );
 
 	if( m_keepaliveTimer )
 		m_keepaliveTimer->stop();
 
 	// the socket is not connected yet, so I should force the signals
-	if ( onlineStatus() == Disconnected || onlineStatus() == Connecting )
+	if ( onlinetqStatus() == Disconnected || onlinetqStatus() == Connecting )
 		emit socketClosed();
 	else
 		MSNSocket::disconnect();
@@ -122,7 +122,7 @@ void MSNNotifySocket::handleError( uint code, uint id )
 		case 205:
 		case 208:
 		{
-			msg = i18n( "<qt>The MSN user '%1' does not exist.<br>Please check the MSN ID.</qt>" ).arg( handle );
+			msg = i18n( "<qt>The MSN user '%1' does not exist.<br>Please check the MSN ID.</qt>" ).tqarg( handle );
 			type = MSNSocket::ErrorServerError;
 			break;
 		}
@@ -134,7 +134,7 @@ void MSNNotifySocket::handleError( uint code, uint id )
 						"MSN Error: %1<br>"
 						"please send us a detailed bug report "
 						"at kopete-devel@kde.org containing the raw debug output on the "
-						"console (in gzipped format, as it is probably a lot of output.)" ).arg(code);
+						"console (in gzipped format, as it is probably a lot of output.)" ).tqarg(code);
 			type = MSNSocket::ErrorServerError;
 			break;
 		}
@@ -166,7 +166,7 @@ void MSNNotifySocket::handleError( uint code, uint id )
 			msg = i18n( "<qt>The user '%1' already exists in this group on the MSN server;<br>"
 				"if Kopete does not show the user, please send us a detailed bug report "
 				"at kopete-devel@kde.org containing the raw debug output on the "
-				"console (in gzipped format, as it is probably a lot of output.)</qt>" ).arg(handle);
+				"console (in gzipped format, as it is probably a lot of output.)</qt>" ).tqarg(handle);
 			type = MSNSocket::ErrorInformation;
 			break;
 		}
@@ -180,7 +180,7 @@ void MSNNotifySocket::handleError( uint code, uint id )
 		}	
 		case 219:
 		{
-			msg = i18n( "The user '%1' seems to already be blocked or allowed on the server." ).arg(handle);
+			msg = i18n( "The user '%1' seems to already be blocked or allowed on the server." ).tqarg(handle);
 			type = MSNSocket::ErrorServerError;
 			break;
 		}
@@ -563,7 +563,7 @@ void MSNNotifySocket::parseCommand( const TQString &cmd, uint id, const TQString
 			kdDebug(14140) << k_funcinfo << "Contact list up-to-date." << endl;
 
 		// set the status
-		setStatus( m_newstatus );
+		settqStatus( m_newstatus );
 	}
 	else if( cmd == "BPR" )
 	{
@@ -641,7 +641,7 @@ void MSNNotifySocket::parseCommand( const TQString &cmd, uint id, const TQString
 					"<input type=\"hidden\" name=\"sl\" value=\"" + sl +"\">\n"
 					"<input type=\"hidden\" name=\"rru\" value=\"" + rru + "\">\n"
 					"<input type=\"hidden\" name=\"auth\" value=\"" + m_MSPAuth + "\">\n"
-					"<input type=\"hidden\" name=\"creds\" value=\"" + TQString::fromLatin1( md5.hexDigest() ) + "\">\n"
+					"<input type=\"hidden\" name=\"creds\" value=\"" + TQString::tqfromLatin1( md5.hexDigest() ) + "\">\n"
 					"<input type=\"hidden\" name=\"svc\" value=\"mail\">\n"
 					"<input type=\"hidden\" name=\"js\" value=\"yes\">\n"
 				"</form></body>\n</html>\n";
@@ -737,7 +737,7 @@ void MSNNotifySocket::slotReadMessage( const TQByteArray &bytes )
 
 	if(msg.contains("text/x-msmsgsinitialmdatanotification"))
 	{
-		//Mail-Data: <MD><E><I>301</I><IU>1</IU><O>4</O><OU>2</OU></E><Q><QTM>409600</QTM><QNM>204800</QNM></Q></MD>
+		//Mail-Data: <MD><E><I>301</I><IU>1</IU><O>4</O><OU>2</OU></E><Q><TQTM>409600</TQTM><TQNM>204800</TQNM></Q></MD>
 		// MD - Mail Data
 		// E  - email
 		// I  - initial mail
@@ -775,7 +775,7 @@ void MSNNotifySocket::slotReadMessage( const TQByteArray &bytes )
 		mailCount++;
 
 		//TODO:  it is also possible to get the subject  (but warning about the encoding)
-		TQObject::connect(KNotification::event( "msn_mail",i18n( "You have one new email from %1 in your MSN inbox." ).arg(m),
+		TQObject::connect(KNotification::event( "msn_mail",i18n( "You have one new email from %1 in your MSN inbox." ).tqarg(m),
 										0 , 0 , i18n( "Open Inbox..." ) ),
 				TQT_SIGNAL(activated(unsigned int ) ) , this, TQT_SLOT( slotOpenInbox() ) );
 	}
@@ -909,7 +909,7 @@ void MSNNotifySocket::slotReadMessage( const TQByteArray &bytes )
 			m_msnAlertURLs.append(subscString);
 
 			// Don't do any MSN alerts notification for new blog updates
-			if( subscString != TQString::fromLatin1("s.htm") && actionString != TQString::fromLatin1("a.htm") )
+			if( subscString != TQString::tqfromLatin1("s.htm") && actionString != TQString::tqfromLatin1("a.htm") )
 			{
 				KNotification* notification = KNotification::event("msn_alert", textString, 0L, 0L, actions);
 				TQObject::connect(notification, TQT_SIGNAL(activated(unsigned int)), this, TQT_SLOT(slotMSNAlertLink(unsigned int)));
@@ -956,7 +956,7 @@ void MSNNotifySocket::slotReadMessage( const TQByteArray &bytes )
 				contact->setProperty(MSNProtocol::protocol()->propPersonalMessage, currentMedia.isEmpty() ? personalMessage : currentMedia);
 			}
 		}
-		m_tmpLastHandle = TQString::null;
+		m_tmpLastHandle = TQString();
 	}
 }
 
@@ -1008,13 +1008,13 @@ TQString MSNNotifySocket::processCurrentMedia( const TQString &mediaXmlElement )
 	currentMedia = format;
 	for(uint i=0; i<formatterStrings.size(); i++)
 	{
-		currentMedia = currentMedia.replace(TQString("{%1}").arg(i), formatterStrings[i]);
+		currentMedia = currentMedia.replace(TQString("{%1}").tqarg(i), formatterStrings[i]);
 	}
 
 	if( type == TQString::fromUtf8("Music") )
 	{
 		// the  "♫" is encoded in utf8 (and should be in utf8)
-		currentMedia = i18n("Now Listening: ♫ %1 ♫").arg(currentMedia);
+		currentMedia = i18n("Now Listening: ♫ %1 ♫").tqarg(currentMedia);
 	}
 
 	kdDebug(1414) << "Current Media received: " << currentMedia << endl;
@@ -1049,25 +1049,25 @@ void MSNNotifySocket::addContact( const TQString &handle, int list, const TQStri
 			// Adding the contact to a group
 			if( !contactGuid.isEmpty() )
 			{
-				args = TQString("FL C=%1 %2").arg( contactGuid ).arg( groupGuid );
+				args = TQString("FL C=%1 %2").tqarg( contactGuid ).tqarg( groupGuid );
 				kdDebug(14140) << k_funcinfo << "In adding contact to a group" << endl;
 			}
 			// Adding a new contact
 			else
 			{
-				args = TQString("FL N=%1 F=%2").arg( handle ).arg( escape( publicName ) );
+				args = TQString("FL N=%1 F=%2").tqarg( handle ).tqarg( escape( publicName ) );
 				kdDebug(14140) << k_funcinfo << "In adding contact to a new contact" << endl;
 			}
 			break;
 		}
 		case MSNProtocol::AL:
-			args = TQString("AL N=%1").arg( handle );
+			args = TQString("AL N=%1").tqarg( handle );
 			break;
 		case MSNProtocol::BL:
-			args = TQString("BL N=%1").arg( handle );
+			args = TQString("BL N=%1").tqarg( handle );
 			break;
 		case MSNProtocol::RL:
-			args = TQString("RL N=%1").arg( handle );
+			args = TQString("RL N=%1").tqarg( handle );
 			break;
 		default:
 			kdDebug(14140) << k_funcinfo <<"WARNING! Unknown list " << list << "!" << endl;
@@ -1105,11 +1105,11 @@ void MSNNotifySocket::removeContact( const TQString &handle, int list, const TQS
 	m_tmpHandles[id]=handle;
 }
 
-void MSNNotifySocket::setStatus( const Kopete::OnlineStatus &status )
+void MSNNotifySocket::settqStatus( const Kopete::OnlineStatus &status )
 {
 //	kdDebug( 14140 ) << k_funcinfo << statusToString( status ) << endl;
 
-	if( onlineStatus() == Disconnected )
+	if( onlinetqStatus() == Disconnected )
 		m_newstatus = status;
 	else
 		sendCommand( "CHG", statusToString( status ) + " " + m_account->myselfClientId() + " " + escape(m_account->pictureObject()) );
@@ -1185,17 +1185,17 @@ void MSNNotifySocket::changePersonalMessage( MSNProtocol::PersonalMessageType ty
 			if( !mediaList[0].isEmpty() ) // Current Track
 			{
 				xmlCurrentMedia += "{0}";
-				formatterArguments += TQString("%1\\0").arg(mediaList[0]);
+				formatterArguments += TQString("%1\\0").tqarg(mediaList[0]);
 			}
 			if( !mediaList[1].isEmpty() ) // Current Artist
 			{
 				xmlCurrentMedia += " - {1}";
-				formatterArguments += TQString("%1\\0").arg(mediaList[1]);
+				formatterArguments += TQString("%1\\0").tqarg(mediaList[1]);
 			}
 			if( !mediaList[2].isEmpty() ) // Current Album
 			{
 				xmlCurrentMedia += " ({2})";
-				formatterArguments += TQString("%1\\0").arg(mediaList[2]);
+				formatterArguments += TQString("%1\\0").tqarg(mediaList[2]);
 			}
 			xmlCurrentMedia += "\\0" + formatterArguments + "\\0";
 			break;
@@ -1256,7 +1256,7 @@ TQString MSNNotifySocket::statusToString( const Kopete::OnlineStatus &status ) c
 
 void MSNNotifySocket::slotSendKeepAlive()
 {
-	//we did not received the previous QNG
+	//we did not received the previous TQNG
 	if(m_ping)
 	{
 		m_disconnectReason=Kopete::Account::ConnectionReset;
@@ -1269,7 +1269,7 @@ void MSNNotifySocket::slotSendKeepAlive()
 	{
 		// Send a dummy command to fake activity. This makes sure MSN doesn't
 		// disconnect you when the notify socket is idle.
-		sendCommand( "PNG" , TQString::null , false );
+		sendCommand( "PNG" , TQString() , false );
 		m_ping=true;
 	}
 
