@@ -56,7 +56,7 @@ class MimeMessage
 
 MSNSocket::MSNSocket(TQObject* parent)  : TQObject (parent)
 {
-	m_onlineStatus = Disconnected;
+	m_onlinetqStatus = Disconnected;
 	m_socket = 0L;
 	m_useHttp = false;
 	m_timer  = 0L;
@@ -64,7 +64,7 @@ MSNSocket::MSNSocket(TQObject* parent)  : TQObject (parent)
 
 MSNSocket::~MSNSocket()
 {
-	//if ( m_onlineStatus != Disconnected )
+	//if ( m_onlinetqStatus != Disconnected )
 	//	disconnect();
 	delete m_timer;
 	m_timer = 0L;
@@ -75,13 +75,13 @@ MSNSocket::~MSNSocket()
 
 void MSNSocket::connect( const TQString &server, uint port )
 {
-	if ( m_onlineStatus == Connected || m_onlineStatus == Connecting )
+	if ( m_onlinetqStatus == Connected || m_onlinetqStatus == Connecting )
 	{
 		kdWarning( 14140 ) << k_funcinfo << "Already connected or connecting! Not connecting again." << endl;
 		return;
 	}
 
-	if( m_onlineStatus == Disconnecting )
+	if( m_onlinetqStatus == Disconnecting )
 	{
 		// Cleanup first.
 		// FIXME: More generic!!!
@@ -166,16 +166,16 @@ void MSNSocket::doneDisconnect()
 
 void MSNSocket::setOnlineStatus( MSNSocket::OnlineStatus status )
 {
-	if ( m_onlineStatus == status )
+	if ( m_onlinetqStatus == status )
 		return;
 
-	m_onlineStatus = status;
+	m_onlinetqStatus = status;
 	emit onlineStatusChanged( status );
 }
 
 void MSNSocket::slotSocketError( int error )
 {
-	kdWarning( 14140 ) << k_funcinfo << "Error: " << error << " (" << m_socket->errorString() << ")" << endl;
+	kdWarning( 14140 ) << k_funcinfo << "Error: " << error << " (" << m_socket->KSocketBase::errorString() << ")" << endl;
 
 	if(!KSocketBase::isFatalError(error))
 		return;
@@ -183,9 +183,9 @@ void MSNSocket::slotSocketError( int error )
 
 	TQString errormsg = i18n( "There was an error while connecting to the MSN server.\nError message:\n" );
 	if ( error == KSocketBase::LookupFailure )
-		errormsg += i18n( "Unable to lookup %1" ).arg( m_socket->peerResolver().nodeName() );
+		errormsg += i18n( "Unable to lookup %1" ).tqarg( m_socket->peerResolver().nodeName() );
 	else
-		errormsg +=  m_socket->errorString() ;
+		errormsg +=  m_socket->KSocketBase::errorString() ;
 
 	//delete m_socket;
 	m_socket->deleteLater();
@@ -594,7 +594,7 @@ void MSNSocket::handleError( uint code, uint /* id */ )
 	default:
 		// FIXME: if the error causes a disconnect, it will crash, but we can't disconnect every time
 		msg = i18n( "Unhandled MSN error code %1 \n"
-			"Please fill a bug report with a detailed description and if possible the last console debug output." ).arg( code );
+			"Please fill a bug report with a detailed description and if possible the last console debug output." ).tqarg( code );
 			// "See http://www.hypothetic.org/docs/msn/basics.php for a description of all error codes."
 		break;
 	}
@@ -757,12 +757,12 @@ TQString MSNSocket::escape( const TQString &str )
 	//If we encode more, the size can be longer than excepted.
 
 	int old_length= str.length();
-	TQChar *new_segment = new QChar[ old_length * 3 + 1 ];
+	TQChar *new_segment = new TQChar[ old_length * 3 + 1 ];
 	int new_length = 0;
 
 	for	( int i = 0; i < old_length; i++ )
 	{
-		unsigned short character = str[i].unicode();
+		unsigned short character = str[i].tqunicode();
 
 		if( character <= 32 || character == '%' )
 		{
@@ -823,7 +823,7 @@ void MSNSocket::slotSocketClosed()
 {
     kdDebug( 14140 ) << k_funcinfo << "Socket closed. " << endl;
 
-	if ( !m_socket ||  m_onlineStatus == Disconnected )
+	if ( !m_socket ||  m_onlinetqStatus == Disconnected )
 	{
 		kdDebug( 14140 ) << k_funcinfo << "Socket already deleted or already disconnected" << endl;
 		return;
@@ -885,7 +885,7 @@ bool MSNSocket::setUseHttpMethod( bool useHttp )
 		else if( s == "msnswitchboardsocket" )
 			m_type = "SB";
 		else
-			m_type = TQString::null;
+			m_type = TQString();
 
 		if( m_type.isNull() )
 			return false;
@@ -897,7 +897,7 @@ bool MSNSocket::setUseHttpMethod( bool useHttp )
 		m_gateway = "gateway.messenger.hotmail.com";
 	}
 
-	if ( m_onlineStatus != Disconnected )
+	if ( m_onlinetqStatus != Disconnected )
 		disconnect();
 
 	m_useHttp = useHttp;
@@ -950,7 +950,7 @@ bool MSNSocket::accept( KServerSocket *server )
 TQString MSNSocket::getLocalIP()
 {
 	if ( !m_socket )
-		return TQString::null;
+		return TQString();
 
 	const KSocketAddress address = m_socket->localAddress();
 
