@@ -54,7 +54,7 @@
 #include "kopetemessage.h"
 #include "kopetecontact.h"
 #include "kopeteuiglobal.h"
-#include "private/kopeteemoticons.h"
+#include "kopeteemoticons.h"
 //#include "kopeteaccountmanager.h"
 //#include "kopeteprotocol.h"
 
@@ -80,7 +80,7 @@ MSNSwitchBoardSocket::~MSNSwitchBoardSocket()
 {
 	kdDebug(14140) << k_funcinfo << endl;
 
-	TQMap<TQString , QPair<TQString , KTempFile*> >::Iterator it;
+	TQMap<TQString , TQPair<TQString , KTempFile*> >::Iterator it;
 	for ( it = m_emoticons.begin(); it != m_emoticons.end(); ++it )
 	{
 		delete it.data().second;
@@ -128,7 +128,7 @@ void MSNSwitchBoardSocket::handleError( uint code, uint id )
 		}
 		case 215:
 		{
-			msg = i18n( "The user %1 is already in this chat." ).arg( m_msgHandle );
+			msg = i18n( "The user %1 is already in this chat." ).tqarg( m_msgHandle );
 			type = MSNSocket::ErrorServerError;
 
 			//userLeftChat(m_msgHandle , i18n("user was twice in this chat") ); //(the user shouln't join there
@@ -136,7 +136,7 @@ void MSNSwitchBoardSocket::handleError( uint code, uint id )
 		}
 		case 216:
 		{
-			msg = i18n( "The user %1 is online but has blocked you:\nyou can not talk to this user." ).arg( m_msgHandle );
+			msg = i18n( "The user %1 is online but has blocked you:\nyou can not talk to this user." ).tqarg( m_msgHandle );
 			type = MSNSocket::ErrorInformation;
 
 			userLeftChat(m_msgHandle, i18n("user blocked you"));
@@ -145,7 +145,7 @@ void MSNSwitchBoardSocket::handleError( uint code, uint id )
 		case 217:
 		{
 			// TODO: we need to know the nickname instead of the handle.
-			msg = i18n( "The user %1 is currently not signed in.\n" "Messages will not be delivered." ).arg( m_msgHandle );
+			msg = i18n( "The user %1 is currently not signed in.\n" "Messages will not be delivered." ).tqarg( m_msgHandle );
 			type = MSNSocket::ErrorServerError;
 
 			userLeftChat(m_msgHandle, i18n("user disconnected"));
@@ -153,7 +153,7 @@ void MSNSwitchBoardSocket::handleError( uint code, uint id )
 		}
 		case 713:
 		{
-			TQString msg = i18n( "You are trying to invite too many contacts to this chat at the same time" ).arg( m_msgHandle );
+			TQString msg = i18n( "You are trying to invite too many contacts to this chat at the same time" ).tqarg( m_msgHandle );
 			type = MSNSocket::ErrorInformation;
 
 			userLeftChat(m_msgHandle, i18n("user blocked you"));
@@ -215,7 +215,7 @@ void MSNSwitchBoardSocket::parseCommand( const TQString &cmd, uint  id ,
 		cleanQueue(); //in case some message are waiting their emoticons, never mind, send them
 
 		TQString handle = data.section( ' ', 0, 0 ).replace( "\r\n" , "" );
-		userLeftChat( handle,  (data.section( ' ', 1, 1 ) == "1" ) ? i18n("timeout") : TQString::null   );
+		userLeftChat( handle,  (data.section( ' ', 1, 1 ) == "1" ) ? i18n("timeout") : TQString()   );
 	}
 	else if( cmd == "MSG" )
 	{
@@ -434,7 +434,7 @@ void MSNSwitchBoardSocket::slotReadMessage( const TQByteArray &bytes )
 
 				if( !m_emoticons.contains(msnobj) || !m_emoticons[msnobj].second )
 				{
-					m_emoticons.insert(msnobj, qMakePair(txt,(KTempFile*)0L));
+					m_emoticons.insert(msnobj, tqMakePair(txt,(KTempFile*)0L));
 					MSNContact *c=static_cast<MSNContact*>(m_account->contacts()[m_msgHandle]);
 					if(!c)
 						return;
@@ -510,7 +510,7 @@ void MSNSwitchBoardSocket::slotReadMessage( const TQByteArray &bytes )
 		{
 			bool valid = true;
 			// Retrieve the nmber of data chunks.
-			Q_UINT32 numberOfChunks = chunks.toUInt(&valid);
+			TQ_UINT32 numberOfChunks = chunks.toUInt(&valid);
 			if(valid && (numberOfChunks > 1))
 			{
 				regex = TQRegExp("base64:([0-9a-zA-Z+/=]+)");
@@ -577,7 +577,7 @@ void MSNSwitchBoardSocket::sendTypingMsg( bool isTyping )
 	if( !isTyping )
 		return;
 
-	if ( onlineStatus() != Connected || m_chatMembers.empty())
+	if ( onlinetqStatus() != Connected || m_chatMembers.empty())
 	{
 		//we are not yet in a chat.
 		//if we send that command now, we may get disconnected.
@@ -653,7 +653,7 @@ int MSNSwitchBoardSocket::sendCustomEmoticon(const TQString &name, const TQStrin
 // this sends a short message to the server
 int MSNSwitchBoardSocket::sendMsg( const Kopete::Message &msg )
 {
-	if ( onlineStatus() != Connected || m_chatMembers.empty())
+	if ( onlinetqStatus() != Connected || m_chatMembers.empty())
 	{
 //		m_messagesQueue.append(msg);
 		return -1;
@@ -768,7 +768,7 @@ int MSNSwitchBoardSocket::sendMsg( const Kopete::Message &msg )
 		int nb=(int)ceil((float)(len_M)/(float)(futurmessages_size));
 
 		if(KMessageBox::warningContinueCancel(0L /* FIXME: we should try to find a parent somewere*/ ,
-			i18n("The message you are trying to send is too long; it will be split into %1 messages.").arg(nb) ,
+			i18n("The message you are trying to send is too long; it will be split into %1 messages.").tqarg(nb) ,
 			i18n("Message too big - MSN Plugin" ), KStdGuiItem::cont() , "SendLongMessages" )
 				== KMessageBox::Continue )
 		{
@@ -850,7 +850,7 @@ void MSNSwitchBoardSocket::slotSocketClosed( )
 
 void MSNSwitchBoardSocket::slotCloseSession()
 {
-	sendCommand( "OUT", TQString::null, false );
+	sendCommand( "OUT", TQString(), false );
 	disconnect();
 }
 
@@ -920,7 +920,7 @@ void  MSNSwitchBoardSocket::slotEmoticonReceived( KTempFile *file, const TQStrin
 	}
 	else if(msnObj == "inkformatgif")
 	{
-		TQString msg=i18n("<img src=\"%1\" alt=\"Typewrited message\" />" ).arg( file->name() );
+		TQString msg=i18n("<img src=\"%1\" alt=\"Typewrited message\" />" ).tqarg( file->name() );
 
 		kdDebug(14140) << k_funcinfo << file->name()  <<endl;
 
@@ -961,7 +961,7 @@ void  MSNSwitchBoardSocket::slotEmoticonReceived( KTempFile *file, const TQStrin
 	}
 }
 
-void MSNSwitchBoardSocket::slotIncomingFileTransfer(const TQString& from, const TQString& /*fileName*/, Q_INT64 /*fileSize*/)
+void MSNSwitchBoardSocket::slotIncomingFileTransfer(const TQString& from, const TQString& /*fileName*/, TQ_INT64 /*fileSize*/)
 {
 	TQPtrList<Kopete::Contact> others;
 	others.append( m_account->myself() );
@@ -1008,7 +1008,7 @@ void MSNSwitchBoardSocket::cleanQueue()
 Kopete::Message &MSNSwitchBoardSocket::parseCustomEmoticons(Kopete::Message &kmsg)
 {
 	TQString message=kmsg.escapedBody();
-	TQMap<TQString , QPair<TQString , KTempFile*> >::Iterator it;
+	TQMap<TQString , TQPair<TQString , KTempFile*> >::Iterator it;
 	for ( it = m_emoticons.begin(); it != m_emoticons.end(); ++it )
 	{
 		TQString es=TQStyleSheet::escape(it.data().first);
@@ -1021,19 +1021,19 @@ Kopete::Message &MSNSwitchBoardSocket::parseCustomEmoticons(Kopete::Message &kms
 		     * emoticons like that. So, in that case, we show like the MSN client */
 			#if 0
 			TQString em = TQRegExp::escape( es );
-			message.replace( TQRegExp(TQString::fromLatin1( "(^|[\\W\\s]|%1)(%2)(?!\\w)" ).arg(em).arg(em)),
-								TQString::fromLatin1("\\1<img align=\"center\" width=\"") +
+			message.replace( TQRegExp(TQString::tqfromLatin1( "(^|[\\W\\s]|%1)(%2)(?!\\w)" ).tqarg(em).tqarg(em)),
+								TQString::tqfromLatin1("\\1<img align=\"center\" width=\"") +
 			#endif
 			//match any occurence which is not in a html tag.
-			message.replace( TQRegExp(TQString::fromLatin1("%1(?![^><]*>)").arg(TQRegExp::escape(es))),
-						TQString::fromLatin1("<img align=\"center\" width=\"") +
+			message.replace( TQRegExp(TQString::tqfromLatin1("%1(?![^><]*>)").tqarg(TQRegExp::escape(es))),
+						TQString::tqfromLatin1("<img align=\"center\" width=\"") +
 						TQString::number(iconImage.width()) +
-						TQString::fromLatin1("\" height=\"") +
+						TQString::tqfromLatin1("\" height=\"") +
 						TQString::number(iconImage.height()) +
-						TQString::fromLatin1("\" src=\"") + imgPath +
-						TQString::fromLatin1("\" title=\"") + es +
-						TQString::fromLatin1("\" alt=\"") + es +
-						TQString::fromLatin1( "\"/>" ) );
+						TQString::tqfromLatin1("\" src=\"") + imgPath +
+						TQString::tqfromLatin1("\" title=\"") + es +
+						TQString::tqfromLatin1("\" alt=\"") + es +
+						TQString::tqfromLatin1( "\"/>" ) );
 			kmsg.setBody(message, Kopete::Message::RichText);
 		}
 	}
@@ -1092,7 +1092,7 @@ Dispatcher* MSNSwitchBoardSocket::PeerDispatcher()
 
 // 		TQObject::connect(this, TQT_SIGNAL(blockRead(const TQByteArray&)), m_dispatcher, TQT_SLOT(slotReadMessage(const TQByteArray&)));
 // 		TQObject::connect(m_dispatcher, TQT_SIGNAL(sendCommand(const TQString&, const TQString&, bool, const TQByteArray&, bool)), this, TQT_SLOT(sendCommand(const TQString&, const TQString&, bool, const TQByteArray&, bool)));
-		TQObject::connect(m_dispatcher, TQT_SIGNAL(incomingTransfer(const TQString&, const TQString&, Q_INT64)), this, TQT_SLOT(slotIncomingFileTransfer(const TQString&, const TQString&, Q_INT64)));
+		TQObject::connect(m_dispatcher, TQT_SIGNAL(incomingTransfer(const TQString&, const TQString&, TQ_INT64)), this, TQT_SLOT(slotIncomingFileTransfer(const TQString&, const TQString&, TQ_INT64)));
 		TQObject::connect(m_dispatcher, TQT_SIGNAL(displayIconReceived(KTempFile *, const TQString&)), this, TQT_SLOT(slotEmoticonReceived( KTempFile *, const TQString&)));
 		TQObject::connect(this, TQT_SIGNAL(msgAcknowledgement(unsigned int, bool)), m_dispatcher, TQT_SLOT(messageAcknowledged(unsigned int, bool)));
 		m_dispatcher->m_pictureUrl = m_account->pictureUrl();
@@ -1112,7 +1112,7 @@ void MSNSwitchBoardSocket::slotKeepAliveTimer( )
 	the bad side effect:  some switchboard connection may be maintained for really long time!
 	 */
 	
-	if ( onlineStatus() != Connected || m_chatMembers.empty())
+	if ( onlinetqStatus() != Connected || m_chatMembers.empty())
 	{
 		//we are not yet in a chat.
 		//if we send that command now, we may get disconnected.
