@@ -118,7 +118,7 @@ void AIMMyselfContact::sendMessage( Kopete::Message& message, Kopete::ChatSessio
         return;
     //okay, now we need to change the message.escapedBody from real HTML to aimhtml.
     //looking right now for docs on that "format".
-    //looks like everything except for alignment codes comes in the format of spans
+    //looks like everything except for tqalignment codes comes in the format of spans
 
     //font-style:italic -> <i>
     //font-weight:600 -> <b> (anything > 400 should be <b>, 400 is not bold)
@@ -127,53 +127,53 @@ void AIMMyselfContact::sendMessage( Kopete::Message& message, Kopete::ChatSessio
     //font-size:xxpt -> <font ptsize=xx>
 
     s=message.escapedBody();
-    s.replace ( TQRegExp( TQString::fromLatin1("<span style=\"([^\"]*)\">([^<]*)</span>")),
-            TQString::fromLatin1("<style>\\1;\"\\2</style>"));
+    s.replace ( TQRegExp( TQString::tqfromLatin1("<span style=\"([^\"]*)\">([^<]*)</span>")),
+            TQString::tqfromLatin1("<style>\\1;\"\\2</style>"));
 
-    s.replace ( TQRegExp( TQString::fromLatin1("<style>([^\"]*)font-style:italic;([^\"]*)\"([^<]*)</style>")),
-                TQString::fromLatin1("<i><style>\\1\\2\"\\3</style></i>"));
+    s.replace ( TQRegExp( TQString::tqfromLatin1("<style>([^\"]*)font-style:italic;([^\"]*)\"([^<]*)</style>")),
+                TQString::tqfromLatin1("<i><style>\\1\\2\"\\3</style></i>"));
 
-    s.replace ( TQRegExp( TQString::fromLatin1("<style>([^\"]*)font-weight:600;([^\"]*)\"([^<]*)</style>")),
-                TQString::fromLatin1("<b><style>\\1\\2\"\\3</style></b>"));
+    s.replace ( TQRegExp( TQString::tqfromLatin1("<style>([^\"]*)font-weight:600;([^\"]*)\"([^<]*)</style>")),
+                TQString::tqfromLatin1("<b><style>\\1\\2\"\\3</style></b>"));
 
-    s.replace ( TQRegExp( TQString::fromLatin1("<style>([^\"]*)text-decoration:underline;([^\"]*)\"([^<]*)</style>")),
-                TQString::fromLatin1("<u><style>\\1\\2\"\\3</style></u>"));
+    s.replace ( TQRegExp( TQString::tqfromLatin1("<style>([^\"]*)text-decoration:underline;([^\"]*)\"([^<]*)</style>")),
+                TQString::tqfromLatin1("<u><style>\\1\\2\"\\3</style></u>"));
 
-    s.replace ( TQRegExp( TQString::fromLatin1("<style>([^\"]*)font-family:([^;]*);([^\"]*)\"([^<]*)</style>")),
-                TQString::fromLatin1("<font face=\"\\2\"><style>\\1\\3\"\\4</style></font>"));
+    s.replace ( TQRegExp( TQString::tqfromLatin1("<style>([^\"]*)font-family:([^;]*);([^\"]*)\"([^<]*)</style>")),
+                TQString::tqfromLatin1("<font face=\"\\2\"><style>\\1\\3\"\\4</style></font>"));
 
-    s.replace ( TQRegExp( TQString::fromLatin1("<style>([^\"]*)font-size:([^p]*)pt;([^\"]*)\"([^<]*)</style>")),
-                TQString::fromLatin1("<font ptsize=\"\\2\"><style>\\1\\3\"\\4</style></font>"));
+    s.replace ( TQRegExp( TQString::tqfromLatin1("<style>([^\"]*)font-size:([^p]*)pt;([^\"]*)\"([^<]*)</style>")),
+                TQString::tqfromLatin1("<font ptsize=\"\\2\"><style>\\1\\3\"\\4</style></font>"));
 
-    s.replace ( TQRegExp( TQString::fromLatin1("<style>([^\"]*)color:([^;]*);([^\"]*)\"([^<]*)</style>")),
-                TQString::fromLatin1("<font color=\"\\2\"><style>\\1\\3\"\\4</style></font>"));
+    s.replace ( TQRegExp( TQString::tqfromLatin1("<style>([^\"]*)color:([^;]*);([^\"]*)\"([^<]*)</style>")),
+                TQString::tqfromLatin1("<font color=\"\\2\"><style>\\1\\3\"\\4</style></font>"));
 
-    s.replace ( TQRegExp( TQString::fromLatin1("<style>([^\"]*)\"([^<]*)</style>")),
-                TQString::fromLatin1("\\2"));
+    s.replace ( TQRegExp( TQString::tqfromLatin1("<style>([^\"]*)\"([^<]*)</style>")),
+                TQString::tqfromLatin1("\\2"));
 
     //okay now change the <font ptsize="xx"> to <font size="xx">
 
     //0-9 are size 1
-    s.replace ( TQRegExp ( TQString::fromLatin1("<font ptsize=\"\\d\">")),
-                TQString::fromLatin1("<font size=\"1\">"));
+    s.replace ( TQRegExp ( TQString::tqfromLatin1("<font ptsize=\"\\d\">")),
+                TQString::tqfromLatin1("<font size=\"1\">"));
     //10-11 are size 2
-    s.replace ( TQRegExp ( TQString::fromLatin1("<font ptsize=\"1[01]\">")),
-                TQString::fromLatin1("<font size=\"2\">"));
+    s.replace ( TQRegExp ( TQString::tqfromLatin1("<font ptsize=\"1[01]\">")),
+                TQString::tqfromLatin1("<font size=\"2\">"));
     //12-13 are size 3
-    s.replace ( TQRegExp ( TQString::fromLatin1("<font ptsize=\"1[23]\">")),
-                TQString::fromLatin1("<font size=\"3\">"));
+    s.replace ( TQRegExp ( TQString::tqfromLatin1("<font ptsize=\"1[23]\">")),
+                TQString::tqfromLatin1("<font size=\"3\">"));
     //14-16 are size 4
-    s.replace ( TQRegExp ( TQString::fromLatin1("<font ptsize=\"1[456]\">")),
-                TQString::fromLatin1("<font size=\"4\">"));
+    s.replace ( TQRegExp ( TQString::tqfromLatin1("<font ptsize=\"1[456]\">")),
+                TQString::tqfromLatin1("<font size=\"4\">"));
     //17-22 are size 5
-    s.replace ( TQRegExp ( TQString::fromLatin1("<font ptsize=\"(?:1[789]|2[012])\">")),
-                TQString::fromLatin1("<font size=\"5\">"));
+    s.replace ( TQRegExp ( TQString::tqfromLatin1("<font ptsize=\"(?:1[789]|2[012])\">")),
+                TQString::tqfromLatin1("<font size=\"5\">"));
     //23-29 are size 6
-    s.replace ( TQRegExp ( TQString::fromLatin1("<font ptsize=\"2[3456789]\">")),TQString::fromLatin1("<font size=\"6\">"));
+    s.replace ( TQRegExp ( TQString::tqfromLatin1("<font ptsize=\"2[3456789]\">")),TQString::tqfromLatin1("<font size=\"6\">"));
     //30- (and any I missed) are size 7
-    s.replace ( TQRegExp ( TQString::fromLatin1("<font ptsize=\"[^\"]*\">")),TQString::fromLatin1("<font size=\"7\">"));
+    s.replace ( TQRegExp ( TQString::tqfromLatin1("<font ptsize=\"[^\"]*\">")),TQString::tqfromLatin1("<font size=\"7\">"));
 
-    s.replace ( TQRegExp ( TQString::fromLatin1("<br[ /]*>")), TQString::fromLatin1("<br>") );
+    s.replace ( TQRegExp ( TQString::tqfromLatin1("<br[ /]*>")), TQString::tqfromLatin1("<br>") );
 
     kdDebug(14190) << k_funcinfo << "sending "
         << s << endl;
@@ -237,7 +237,7 @@ AIMAccount::~AIMAccount()
 
 OscarContact *AIMAccount::createNewContact( const TQString &contactId, Kopete::MetaContact *parentContact, const SSI& ssiItem )
 {
-	AIMContact* contact = new AIMContact( this, contactId, parentContact, TQString::null, ssiItem );
+	AIMContact* contact = new AIMContact( this, contactId, parentContact, TQString(), ssiItem );
 	if ( !ssiItem.alias().isEmpty() )
 		contact->setProperty( Kopete::Global::Properties::self()->nickName(), ssiItem.alias() );
 
@@ -300,13 +300,13 @@ KActionMenu* AIMAccount::actionMenu()
 	// mActionMenu is managed by Kopete::Account.  It is deleted when
 	// it is no longer shown, so we can (safely) just make a new one here.
 	KActionMenu *mActionMenu = new KActionMenu(accountId(),
-		myself()->onlineStatus().iconFor( this ), this, "AIMAccount::mActionMenu");
+		myself()->onlinetqStatus().iconFor( this ), this, "AIMAccount::mActionMenu");
 
 	AIMProtocol *p = AIMProtocol::protocol();
 
 	TQString accountNick = myself()->property( Kopete::Global::Properties::self()->nickName() ).value().toString();
-	mActionMenu->popupMenu()->insertTitle( myself()->onlineStatus().iconFor( myself() ),
-			i18n( "%2 <%1>" ).arg( accountId(), accountNick ));
+	mActionMenu->popupMenu()->insertTitle( myself()->onlinetqStatus().iconFor( myself() ),
+			i18n( "%2 <%1>" ).tqarg( accountId(), accountNick ));
 
 	mActionMenu->insert( new KAction( i18n("Online"), p->statusOnline.iconFor( this ), 0, this,
 	             TQT_SLOT( slotGoOnline() ), mActionMenu, "AIMAccount::mActionOnline") );
@@ -322,7 +322,7 @@ KActionMenu* AIMAccount::actionMenu()
 	mActionMenu->insert( mActionOffline );
 	mActionMenu->popupMenu()->insertSeparator();
 
-    KAction* m_joinChatAction = new KAction( i18n( "Join Chat..." ), TQString::null,  0,  this,
+    KAction* m_joinChatAction = new KAction( i18n( "Join Chat..." ), TQString(),  0,  this,
                                              TQT_SLOT( slotJoinChat() ), mActionMenu, "join_a_chat" );
 
 	mActionMenu->insert( new KToggleAction( i18n( "Set Visibility..." ), 0, 0,
@@ -344,16 +344,16 @@ void AIMAccount::setAway(bool away, const TQString &awayReason)
 // 	kdDebug(14152) << k_funcinfo << accountId() << "reason is " << awayReason << endl;
 	if ( away )
 	{
-		engine()->setStatus( Client::Away, awayReason );
+		engine()->settqStatus( Client::Away, awayReason );
 		AIMMyselfContact* me = static_cast<AIMMyselfContact *> ( myself() );
 		me->setLastAwayMessage(awayReason);
 		me->setProperty( Kopete::Global::Properties::self()->awayMessage(), awayReason );
 	}
 	else
 	{
-		engine()->setStatus( Client::Online );
+		engine()->settqStatus( Client::Online );
 		AIMMyselfContact* me = static_cast<AIMMyselfContact *> ( myself() );
-		me->setLastAwayMessage(TQString::null);
+		me->setLastAwayMessage(TQString());
 		me->removeProperty( Kopete::Global::Properties::self()->awayMessage() );
 	}
 }
@@ -374,7 +374,7 @@ void AIMAccount::setUserProfile(const TQString &profile)
 	AIMMyselfContact* aimmc = dynamic_cast<AIMMyselfContact*>( myself() );
 	if ( aimmc )
 		aimmc->setOwnProfile( profile );
-	configGroup()->writeEntry( TQString::fromLatin1( "Profile" ), profile );
+	configGroup()->writeEntry( TQString::tqfromLatin1( "Profile" ), profile );
 }
 
 void AIMAccount::slotEditInfo()
@@ -451,7 +451,7 @@ void AIMAccount::slotBuddyIconChanged()
 		iconFile.open( IO_ReadOnly );
 		
 		KMD5 iconHash;
-		iconHash.update( iconFile );
+		iconHash.update( *TQT_TQIODEVICE(&iconFile) );
 		kdDebug(OSCAR_AIM_DEBUG) << k_funcinfo  << "hash is :" << iconHash.hexDigest() << endl;
 			
 		//find old item, create updated item
@@ -532,13 +532,13 @@ void AIMAccount::slotJoinChat()
 
 void AIMAccount::slotGoOnline()
 {
-	if ( myself()->onlineStatus().status() == Kopete::OnlineStatus::Away )
+	if ( myself()->onlinetqStatus().status() == Kopete::OnlineStatus::Away )
 	{
 		kdDebug(14152) << k_funcinfo << accountId() << " was away. welcome back." << endl;
-		engine()->setStatus( Client::Online );
+		engine()->settqStatus( Client::Online );
 		myself()->removeProperty( Kopete::Global::Properties::self()->awayMessage() );
 	}
-	else if ( myself()->onlineStatus().status() == Kopete::OnlineStatus::Offline )
+	else if ( myself()->onlinetqStatus().status() == Kopete::OnlineStatus::Offline )
 	{
 		kdDebug(14152) << k_funcinfo << accountId() << " was offline. time to connect" << endl;
 		OscarAccount::connect();
@@ -606,7 +606,7 @@ void AIMAccount::messageReceived( const Oscar::Message& message )
         // Might be duplicate code from the parent class to get some needed information
         // Perhaps a refactoring is needed.
         kdDebug(14152) << k_funcinfo << "Checking to see if I'm online.." << endl;
-        if( myself()->onlineStatus().status() == Kopete::OnlineStatus::Away )
+        if( myself()->onlinetqStatus().status() == Kopete::OnlineStatus::Away )
         {
             TQString sender = Oscar::normalize( message.sender() );
             AIMContact* aimSender = static_cast<AIMContact *> ( contacts()[sender] ); //should exist now
@@ -759,7 +759,7 @@ void AIMAccount::connectWithPassword( const TQString & )
 
 	// Get the screen name for this account
 	TQString screenName = accountId();
-	TQString server = configGroup()->readEntry( "Server", TQString::fromLatin1( "login.oscar.aol.com" ) );
+	TQString server = configGroup()->readEntry( "Server", TQString::tqfromLatin1( "login.oscar.aol.com" ) );
 	uint port = configGroup()->readNumEntry( "Port", 5190 );
 
 	Connection* c = setupConnection( server, port );
@@ -771,7 +771,7 @@ void AIMAccount::connectWithPassword( const TQString & )
 			<< "AIM network because no password was specified in the "
 			<< "preferences." << endl;
 	}
-	else if ( myself()->onlineStatus() == static_cast<AIMProtocol*>( protocol() )->statusOffline )
+	else if ( myself()->onlinetqStatus() == static_cast<AIMProtocol*>( protocol() )->statusOffline )
 	{
 		kdDebug(14152) << k_funcinfo << "Logging in as " << accountId() << endl ;
 		updateVersionUpdaterStamp();
@@ -895,7 +895,7 @@ void AIMAccount::setPrivacySettings( int privacy )
 void AIMAccount::setPrivacyTLVs( BYTE privacy, DWORD userClasses )
 {
 	SSIManager* ssi = engine()->ssiManager();
-	Oscar::SSI item = ssi->findItem( TQString::null, ROSTER_VISIBILITY );
+	Oscar::SSI item = ssi->findItem( TQString(), ROSTER_VISIBILITY );
 
 	TQValueList<Oscar::TLV> tList;
 
@@ -905,7 +905,7 @@ void AIMAccount::setPrivacyTLVs( BYTE privacy, DWORD userClasses )
 	if ( !item )
 	{
 		kdDebug(OSCAR_AIM_DEBUG) << k_funcinfo << "Adding new privacy TLV item" << endl;
-		Oscar::SSI s( TQString::null, 0, ssi->nextContactId(), ROSTER_VISIBILITY, tList );
+		Oscar::SSI s( TQString(), 0, ssi->nextContactId(), ROSTER_VISIBILITY, tList );
 		engine()->modifySSIItem( item, s );
 	}
 	else
