@@ -56,7 +56,7 @@ AIMContact::AIMContact( Kopete::Account* account, const TQString& name, Kopete::
 	m_haveAwayMessage = false;
 	m_mobile = false;
 	// Set the last autoresponse time to the current time yesterday
-	m_lastAutoresponseTime = TQDateTime::currentDateTime().addDays(-1);
+	m_lastAutoresponseTime = TQDateTime::tqcurrentDateTime().addDays(-1);
 
 	TQObject::connect( mAccount->engine(), TQT_SIGNAL( receivedUserInfo( const TQString&, const UserDetails& ) ),
 	                  this, TQT_SLOT( userInfoUpdated( const TQString&, const UserDetails& ) ) );
@@ -66,8 +66,8 @@ AIMContact::AIMContact( Kopete::Account* account, const TQString& name, Kopete::
 	                  this, TQT_SLOT( updateAwayMessage( const TQString&, const TQString& ) ) );
 	TQObject::connect( mAccount->engine(), TQT_SIGNAL( receivedProfile( const TQString&, const TQString& ) ),
 	                  this, TQT_SLOT( updateProfile( const TQString&, const TQString& ) ) );
-	TQObject::connect( mAccount->engine(), TQT_SIGNAL( userWarned( const TQString&, Q_UINT16, Q_UINT16 ) ),
-	                  this, TQT_SLOT( gotWarning( const TQString&, Q_UINT16, Q_UINT16 ) ) );
+	TQObject::connect( mAccount->engine(), TQT_SIGNAL( userWarned( const TQString&, TQ_UINT16, TQ_UINT16 ) ),
+	                  this, TQT_SLOT( gotWarning( const TQString&, TQ_UINT16, TQ_UINT16 ) ) );
 	TQObject::connect( mAccount->engine(), TQT_SIGNAL( haveIconForContact( const TQString&, TQByteArray ) ),
 	                  this, TQT_SLOT( haveIcon( const TQString&, TQByteArray ) ) );
 	TQObject::connect( mAccount->engine(), TQT_SIGNAL( iconServerConnected() ),
@@ -128,15 +128,15 @@ void AIMContact::setAwayMessage(const TQString &message)
 		"Called for '" << contactId() << "', away msg='" << message << "'" << endl;
 	TQString filteredMessage = message;
 	filteredMessage.replace(
-		TQRegExp(TQString::fromLatin1("<[hH][tT][mM][lL].*>(.*)</[hH][tT][mM][lL]>")),
-		TQString::fromLatin1("\\1"));
+		TQRegExp(TQString::tqfromLatin1("<[hH][tT][mM][lL].*>(.*)</[hH][tT][mM][lL]>")),
+		TQString::tqfromLatin1("\\1"));
 	filteredMessage.replace(
-		TQRegExp(TQString::fromLatin1("<[bB][oO][dD][yY].*>(.*)</[bB][oO][dD][yY]>")),
-		TQString::fromLatin1("\\1") );
-	TQRegExp fontRemover( TQString::fromLatin1("<[fF][oO][nN][tT].*>(.*)</[fF][oO][nN][tT]>") );
+		TQRegExp(TQString::tqfromLatin1("<[bB][oO][dD][yY].*>(.*)</[bB][oO][dD][yY]>")),
+		TQString::tqfromLatin1("\\1") );
+	TQRegExp fontRemover( TQString::tqfromLatin1("<[fF][oO][nN][tT].*>(.*)</[fF][oO][nN][tT]>") );
 	fontRemover.setMinimal(true);
 	while ( filteredMessage.find( fontRemover ) != -1 )
-		filteredMessage.replace( fontRemover, TQString::fromLatin1("\\1") );
+		filteredMessage.replace( fontRemover, TQString::tqfromLatin1("\\1") );
 	setProperty(mProtocol->awayMessage, filteredMessage);
 }
 
@@ -148,7 +148,7 @@ int AIMContact::warningLevel() const
 void AIMContact::updateSSIItem()
 {
 	if ( m_ssiItem.type() != 0xFFFF && m_ssiItem.waitingAuth() == false &&
-	     onlineStatus() == Kopete::OnlineStatus::Unknown )
+	     onlinetqStatus() == Kopete::OnlineStatus::Unknown )
 	{
 		//make sure they're offline
 		setOnlineStatus( static_cast<AIMProtocol*>( protocol() )->statusOffline );
@@ -302,7 +302,7 @@ void AIMContact::updateProfile( const TQString& contact, const TQString& profile
 	emit updatedProfile();
 }
 
-void AIMContact::gotWarning( const TQString& contact, Q_UINT16 increase, Q_UINT16 newLevel )
+void AIMContact::gotWarning( const TQString& contact, TQ_UINT16 increase, TQ_UINT16 newLevel )
 {
 	//somebody just got bitchslapped! :O
 	Q_UNUSED( increase );
@@ -351,11 +351,11 @@ void AIMContact::warnUser()
 	                        "(Warning a user on AIM will result in a \"Warning Level\"" \
 	                        " increasing for the user you warn. Once this level has reached a" \
 	                        " certain point, they will not be able to sign on. Please do not abuse" \
-	                        " this function, it is meant for legitimate practices.)</qt>" ).arg( nick );
+	                        " this function, it is meant for legitimate practices.)</qt>" ).tqarg( nick );
 
 
 	int result = KMessageBox::questionYesNoCancel( Kopete::UI::Global::mainWidget(), message,
-	                                               i18n( "Warn User %1?" ).arg( nick ),
+	                                               i18n( "Warn User %1?" ).tqarg( nick ),
 	                                               i18n( "Warn Anonymously" ), i18n( "Warn" ) );
 
 	if ( result == KMessageBox::Yes )
@@ -383,7 +383,7 @@ void AIMContact::slotSendMsg(Kopete::Message& message, Kopete::ChatSession *)
 		return;
 	//okay, now we need to change the message.escapedBody from real HTML to aimhtml.
 	//looking right now for docs on that "format".
-	//looks like everything except for alignment codes comes in the format of spans
+	//looks like everything except for tqalignment codes comes in the format of spans
 
 	//font-style:italic -> <i>
 	//font-weight:600 -> <b> (anything > 400 should be <b>, 400 is not bold)
@@ -392,59 +392,59 @@ void AIMContact::slotSendMsg(Kopete::Message& message, Kopete::ChatSession *)
 	//font-size:xxpt -> <font ptsize=xx>
 
 	s=message.escapedBody();
-	s.replace ( TQRegExp( TQString::fromLatin1("<span style=\"([^\"]*)\">([^<]*)</span>")),
-			TQString::fromLatin1("<style>\\1;\"\\2</style>"));
+	s.replace ( TQRegExp( TQString::tqfromLatin1("<span style=\"([^\"]*)\">([^<]*)</span>")),
+			TQString::tqfromLatin1("<style>\\1;\"\\2</style>"));
 
-	s.replace ( TQRegExp( TQString::fromLatin1("<style>([^\"]*)font-style:italic;([^\"]*)\"([^<]*)</style>")),
-	            TQString::fromLatin1("<i><style>\\1\\2\"\\3</style></i>"));
+	s.replace ( TQRegExp( TQString::tqfromLatin1("<style>([^\"]*)font-style:italic;([^\"]*)\"([^<]*)</style>")),
+	            TQString::tqfromLatin1("<i><style>\\1\\2\"\\3</style></i>"));
 
-	s.replace ( TQRegExp( TQString::fromLatin1("<style>([^\"]*)font-weight:600;([^\"]*)\"([^<]*)</style>")),
-	            TQString::fromLatin1("<b><style>\\1\\2\"\\3</style></b>"));
+	s.replace ( TQRegExp( TQString::tqfromLatin1("<style>([^\"]*)font-weight:600;([^\"]*)\"([^<]*)</style>")),
+	            TQString::tqfromLatin1("<b><style>\\1\\2\"\\3</style></b>"));
 
-	s.replace ( TQRegExp( TQString::fromLatin1("<style>([^\"]*)text-decoration:underline;([^\"]*)\"([^<]*)</style>")),
-	            TQString::fromLatin1("<u><style>\\1\\2\"\\3</style></u>"));
+	s.replace ( TQRegExp( TQString::tqfromLatin1("<style>([^\"]*)text-decoration:underline;([^\"]*)\"([^<]*)</style>")),
+	            TQString::tqfromLatin1("<u><style>\\1\\2\"\\3</style></u>"));
 
-	s.replace ( TQRegExp( TQString::fromLatin1("<style>([^\"]*)font-family:([^;]*);([^\"]*)\"([^<]*)</style>")),
-	            TQString::fromLatin1("<font face=\"\\2\"><style>\\1\\3\"\\4</style></font>"));
+	s.replace ( TQRegExp( TQString::tqfromLatin1("<style>([^\"]*)font-family:([^;]*);([^\"]*)\"([^<]*)</style>")),
+	            TQString::tqfromLatin1("<font face=\"\\2\"><style>\\1\\3\"\\4</style></font>"));
 
-	s.replace ( TQRegExp( TQString::fromLatin1("<style>([^\"]*)font-size:([^p]*)pt;([^\"]*)\"([^<]*)</style>")),
-				TQString::fromLatin1("<font ptsize=\"\\2\"><style>\\1\\3\"\\4</style></font>"));
+	s.replace ( TQRegExp( TQString::tqfromLatin1("<style>([^\"]*)font-size:([^p]*)pt;([^\"]*)\"([^<]*)</style>")),
+				TQString::tqfromLatin1("<font ptsize=\"\\2\"><style>\\1\\3\"\\4</style></font>"));
 
-	s.replace ( TQRegExp( TQString::fromLatin1("<style>([^\"]*)color:([^;]*);([^\"]*)\"([^<]*)</style>")),
-	            TQString::fromLatin1("<font color=\"\\2\"><style>\\1\\3\"\\4</style></font>"));
+	s.replace ( TQRegExp( TQString::tqfromLatin1("<style>([^\"]*)color:([^;]*);([^\"]*)\"([^<]*)</style>")),
+	            TQString::tqfromLatin1("<font color=\"\\2\"><style>\\1\\3\"\\4</style></font>"));
 
-	s.replace ( TQRegExp( TQString::fromLatin1("<style>([^\"]*)\"([^<]*)</style>")),
-	            TQString::fromLatin1("\\2"));
+	s.replace ( TQRegExp( TQString::tqfromLatin1("<style>([^\"]*)\"([^<]*)</style>")),
+	            TQString::tqfromLatin1("\\2"));
 
 	//okay now change the <font ptsize="xx"> to <font size="xx">
 
 	//0-9 are size 1
-	s.replace ( TQRegExp ( TQString::fromLatin1("<font ptsize=\"\\d\">")),
-	            TQString::fromLatin1("<font size=\"1\">"));
+	s.replace ( TQRegExp ( TQString::tqfromLatin1("<font ptsize=\"\\d\">")),
+	            TQString::tqfromLatin1("<font size=\"1\">"));
 	//10-11 are size 2
-	s.replace ( TQRegExp ( TQString::fromLatin1("<font ptsize=\"1[01]\">")),
-	            TQString::fromLatin1("<font size=\"2\">"));
+	s.replace ( TQRegExp ( TQString::tqfromLatin1("<font ptsize=\"1[01]\">")),
+	            TQString::tqfromLatin1("<font size=\"2\">"));
 	//12-13 are size 3
-	s.replace ( TQRegExp ( TQString::fromLatin1("<font ptsize=\"1[23]\">")),
-	            TQString::fromLatin1("<font size=\"3\">"));
+	s.replace ( TQRegExp ( TQString::tqfromLatin1("<font ptsize=\"1[23]\">")),
+	            TQString::tqfromLatin1("<font size=\"3\">"));
 	//14-16 are size 4
-	s.replace ( TQRegExp ( TQString::fromLatin1("<font ptsize=\"1[456]\">")),
-	            TQString::fromLatin1("<font size=\"4\">"));
+	s.replace ( TQRegExp ( TQString::tqfromLatin1("<font ptsize=\"1[456]\">")),
+	            TQString::tqfromLatin1("<font size=\"4\">"));
 	//17-22 are size 5
-	s.replace ( TQRegExp ( TQString::fromLatin1("<font ptsize=\"(?:1[789]|2[012])\">")),
-	            TQString::fromLatin1("<font size=\"5\">"));
+	s.replace ( TQRegExp ( TQString::tqfromLatin1("<font ptsize=\"(?:1[789]|2[012])\">")),
+	            TQString::tqfromLatin1("<font size=\"5\">"));
 	//23-29 are size 6
-	s.replace ( TQRegExp ( TQString::fromLatin1("<font ptsize=\"2[3456789]\">")),TQString::fromLatin1("<font size=\"6\">"));
+	s.replace ( TQRegExp ( TQString::tqfromLatin1("<font ptsize=\"2[3456789]\">")),TQString::tqfromLatin1("<font size=\"6\">"));
 	//30- (and any I missed) are size 7
-	s.replace ( TQRegExp ( TQString::fromLatin1("<font ptsize=\"[^\"]*\">")),TQString::fromLatin1("<font size=\"7\">"));
+	s.replace ( TQRegExp ( TQString::tqfromLatin1("<font ptsize=\"[^\"]*\">")),TQString::tqfromLatin1("<font size=\"7\">"));
 
 	// strip left over line break
-	s.remove(TQRegExp(TQString::fromLatin1("<br\b[^>]*>$")));
+	s.remove(TQRegExp(TQString::tqfromLatin1("<br\b[^>]*>$")));
 
-	s.replace ( TQRegExp ( TQString::fromLatin1("<br[ /]*>")), TQString::fromLatin1("<br>") );
+	s.replace ( TQRegExp ( TQString::tqfromLatin1("<br[ /]*>")), TQString::tqfromLatin1("<br>") );
 
 	// strip left over line break
-	s.remove( TQRegExp( TQString::fromLatin1( "<br>$" ) ) );
+	s.remove( TQRegExp( TQString::tqfromLatin1( "<br>$" ) ) );
 
 	kdDebug(14190) << k_funcinfo << "sending "
 		<< s << endl;
@@ -475,9 +475,9 @@ void AIMContact::updateFeatures()
 void AIMContact::sendAutoResponse(Kopete::Message& msg)
 {
 	// The target time is 2 minutes later than the last message
-	int delta = m_lastAutoresponseTime.secsTo( TQDateTime::currentDateTime() );
+	int delta = m_lastAutoresponseTime.secsTo( TQDateTime::tqcurrentDateTime() );
 	kdDebug(14152) << k_funcinfo << "Last autoresponse time: " << m_lastAutoresponseTime << endl;
-	kdDebug(14152) << k_funcinfo << "Current time: " << TQDateTime::currentDateTime() << endl;
+	kdDebug(14152) << k_funcinfo << "Current time: " << TQDateTime::tqcurrentDateTime() << endl;
 	kdDebug(14152) << k_funcinfo << "Difference: " << delta << endl;
 	// Check to see if we're past that time
 	if(delta > 120)
@@ -509,7 +509,7 @@ void AIMContact::sendAutoResponse(Kopete::Message& msg)
 		manager(Kopete::Contact::CanCreate)->appendMessage(msg);
 		manager(Kopete::Contact::CanCreate)->messageSucceeded();
 		// Update the last autoresponse time
-		m_lastAutoresponseTime = TQDateTime::currentDateTime();
+		m_lastAutoresponseTime = TQDateTime::tqcurrentDateTime();
 	}
 	else
 	{
