@@ -66,7 +66,7 @@ K_EXPORT_COMPONENT_FACTORY( kopete_icq, ICQProtocolFactory( "kopete_icq" ) )
 
 ICQProtocolHandler::ICQProtocolHandler() : Kopete::MimeTypeHandler(false)
 {
-	registerAsMimeHandler(TQString::fromLatin1("application/x-icq"));
+	registerAsMimeHandler(TQString::tqfromLatin1("application/x-icq"));
 }
 
 void ICQProtocolHandler::handleURL(const TQString &mimeType, const KURL & url) const
@@ -141,11 +141,11 @@ void ICQProtocolHandler::handleURL(const TQString &mimeType, const KURL & url) c
 	}
 
 	TQString nickuin = nick.isEmpty() ?
-		i18n("'%1'").arg(uin) :
-		i18n("'%1' (%2)").arg(nick, uin);
+		i18n("'%1'").tqarg(uin) :
+		i18n("'%1' (%2)").tqarg(nick, uin);
 
 	if (KMessageBox::questionYesNo(Kopete::UI::Global::mainWidget(),
-	                               i18n("Do you want to add %1 to your contact list?").arg(nickuin), TQString::null, i18n("Add"), i18n("Do Not Add"))
+	                               i18n("Do you want to add %1 to your contact list?").tqarg(nickuin), TQString(), i18n("Add"), i18n("Do Not Add"))
 	    != KMessageBox::Yes)
 	{
 		kdDebug(14153) << k_funcinfo << "Cancelled" << endl;
@@ -181,8 +181,8 @@ ICQProtocol::ICQProtocol(TQObject *parent, const char *name, const TQStringList&
 	emailAddress(Kopete::Global::Properties::self()->emailAddress()),
 	ipAddress("ipAddress", i18n("IP Address") ),
 	clientFeatures("clientFeatures", i18n("Client Features"), 0, false),
-	buddyIconHash("iconHash", i18n("Buddy Icon MD5 Hash"), TQString::null, true, false, true),
-    contactEncoding( "contactEncoding", i18n( "Contact Encoding" ), TQString::null, true, false, true )
+	buddyIconHash("iconHash", i18n("Buddy Icon MD5 Hash"), TQString(), true, false, true),
+    contactEncoding( "contactEncoding", i18n( "Contact Encoding" ), TQString(), true, false, true )
 
 {
 	if (protocolStatic_)
@@ -219,7 +219,7 @@ void ICQProtocol::initGenders()
 void ICQProtocol::initCountries()
 {
 	mCountries.insert(0, ""); // unspecified
-	KLocale *kl = KGlobal::locale(); //KLocale(TQString::fromLatin1("kopete"));
+	KLocale *kl = KGlobal::locale(); //KLocale(TQString::tqfromLatin1("kopete"));
 
 	mCountries.insert(93, kl->twoAlphaToCountryName("af"));
 	mCountries.insert(355, kl->twoAlphaToCountryName("al"));
@@ -468,7 +468,7 @@ void ICQProtocol::initCountries()
 void ICQProtocol::initLang()
 {
 
-	KLocale *kl = KGlobal::locale(); //KLocale(TQString::fromLatin1("kopete"));
+	KLocale *kl = KGlobal::locale(); //KLocale(TQString::tqfromLatin1("kopete"));
 
 	mLanguages.insert(0 , "");
 	mLanguages.insert(1 , kl->twoAlphaToLanguageName("ar") /*i18n("Arabic")*/);
@@ -775,8 +775,8 @@ Kopete::Contact *ICQProtocol::deserializeContact( Kopete::MetaContact *metaConta
 
     if ( serializedData.contains( "ssi_waitingAuth" ) )
     {
-	TQString authStatus = serializedData["ssi_waitingAuth"];
-	if ( authStatus == "true" )
+	TQString authtqStatus = serializedData["ssi_waitingAuth"];
+	if ( authtqStatus == "true" )
 		ssiWaitingAuth = true;
     }
 
@@ -789,7 +789,7 @@ Kopete::Contact *ICQProtocol::deserializeContact( Kopete::MetaContact *metaConta
 
 	Oscar::SSI item( ssiName, ssiGid, ssiBid, ssiType, TQValueList<TLV>(), 0 );
 	item.setWaitingAuth( ssiWaitingAuth );
-	ICQContact *c = new ICQContact( account, contactId, metaContact, TQString::null, item );
+	ICQContact *c = new ICQContact( account, contactId, metaContact, TQString(), item );
 	return c;
 }
 
