@@ -19,11 +19,12 @@
 
 #include "coreprotocol.h"
 
-#define QT_FATAL_ASSERT 1
+#define TQT_FATAL_ASSERT 1
 
-class ClientStreamTest : public QApplication
+class ClientStreamTest : public TQApplication
 {
 Q_OBJECT
+  TQ_OBJECT
 public:
 	ClientStreamTest(int argc, char ** argv);
 	
