@@ -29,7 +29,7 @@ LoginTest::~LoginTest()
 
 void LoginTest::slotDoTest()
 {
-	TQString server = TQString::fromLatin1("login.oscar.aol.com");
+	TQString server = TQString::tqfromLatin1("login.oscar.aol.com");
 	// connect to server
 	qDebug( "connecting to server ");
 
