@@ -16,11 +16,12 @@
 
 #include "ssimanager.h"
 
-#define QT_FATAL_ASSERT 1
+#define TQT_FATAL_ASSERT 1
 
-class SSITest : public QApplication
+class SSITest : public TQApplication
 {
 Q_OBJECT
+  TQ_OBJECT
 public:
 	SSITest(int argc, char ** argv);
 	
