@@ -20,11 +20,12 @@
 #include "connection.h"
 #include "coreprotocol.h"
 
-#define QT_FATAL_ASSERT 1
+#define TQT_FATAL_ASSERT 1
 
-class LoginTest : public QApplication
+class LoginTest : public TQApplication
 {
 Q_OBJECT
+  TQ_OBJECT
 public:
 	LoginTest(int argc, char ** argv);
 	
