@@ -69,7 +69,7 @@ public:
 	//The liboscar hook for the account
 	Client* engine;
 
-	Q_UINT32 ssiLastModTime;
+	TQ_UINT32 ssiLastModTime;
 
 	//contacts waiting on SSI add ack and their metacontact
 	TQMap<TQString, Kopete::MetaContact*> addContactMap;
@@ -245,7 +245,7 @@ void OscarAccount::processSSIList()
 			oc->setSSIItem( item );
 		}
 		else
-			addContact( ( *bit ).name(), TQString::null, group, Kopete::Account::DontChangeKABC );
+			addContact( ( *bit ).name(), TQString(), group, Kopete::Account::DontChangeKABC );
 	}
 
 	TQObject::connect( kcl, TQT_SIGNAL( groupRenamed( Kopete::Group*,  const TQString& ) ),
@@ -276,7 +276,7 @@ void OscarAccount::processSSIList()
     }
     kdDebug(OSCAR_GEN_DEBUG) << k_funcinfo << "the following contacts are not on the server side list"
                              << nonServerContactList << endl;
-	bool showMissingContactsDialog = configGroup()->readBoolEntry(TQString::fromLatin1("ShowMissingContactsDialog"), true);
+	bool showMissingContactsDialog = configGroup()->readBoolEntry(TQString::tqfromLatin1("ShowMissingContactsDialog"), true);
     if ( !nonServerContactList.isEmpty() && showMissingContactsDialog )
     {
         d->olnscDialog = new OscarListNonServerContacts( Kopete::UI::Global::mainWidget() );
@@ -334,7 +334,7 @@ void OscarAccount::nonServerAddContactDialogClosed()
     }
 
 	bool showOnce = d->olnscDialog->onlyShowOnce();
-	configGroup()->writeEntry( TQString::fromLatin1("ShowMissingContactsDialog") , !showOnce);
+	configGroup()->writeEntry( TQString::tqfromLatin1("ShowMissingContactsDialog") , !showOnce);
 	configGroup()->sync();
 	
     d->olnscDialog->delayedDestruct();
@@ -389,7 +389,7 @@ void OscarAccount::messageReceived( const Oscar::Message& message )
 	if ( !contacts()[sender] )
 	{
 		kdDebug(OSCAR_RAW_DEBUG) << "Adding '" << sender << "' as temporary contact" << endl;
-		addContact( sender, TQString::null, 0,  Kopete::Account::Temporary );
+		addContact( sender, TQString(), 0,  Kopete::Account::Temporary );
 	}
 
 	OscarContact* ocSender = static_cast<OscarContact *> ( contacts()[sender] ); //should exist now
@@ -429,15 +429,15 @@ void OscarAccount::messageReceived( const Oscar::Message& message )
 
 void OscarAccount::setServerAddress(const TQString &server)
 {
-	configGroup()->writeEntry( TQString::fromLatin1( "Server" ), server );
+	configGroup()->writeEntry( TQString::tqfromLatin1( "Server" ), server );
 }
 
 void OscarAccount::setServerPort(int port)
 {
 	if ( port > 0 )
-		configGroup()->writeEntry( TQString::fromLatin1( "Port" ), port );
+		configGroup()->writeEntry( TQString::tqfromLatin1( "Port" ), port );
 	else //set to default 5190
-		configGroup()->writeEntry( TQString::fromLatin1( "Port" ), 5190 );
+		configGroup()->writeEntry( TQString::tqfromLatin1( "Port" ), 5190 );
 }
 
 TQTextCodec* OscarAccount::defaultCodec() const
@@ -475,7 +475,7 @@ void OscarAccount::setBuddyIcon( KURL url )
 		
 		const TQSize size = ( d->engine->isIcq() ) ? TQSize( 52, 64 ) : TQSize( 48, 48 );
 		
-		image = image.smoothScale( size, TQImage::ScaleMax );
+		image = image.smoothScale( size, TQ_ScaleMax );
 		if( image.width() > size.width())
 			image = image.copy( ( image.width() - size.width() ) / 2, 0, size.width(), image.height() );
 		
@@ -727,9 +727,9 @@ void OscarAccount::userStoppedTyping( const TQString & contact )
 void OscarAccount::slotSocketError( int errCode, const TQString& errString )
 {
 	Q_UNUSED( errCode );
-	KPassivePopup::message( i18n( "account has been disconnected", "%1 disconnected" ).arg( accountId() ),
+	KPassivePopup::message( i18n( "account has been disconnected", "%1 disconnected" ).tqarg( accountId() ),
 	                        errString,
-	                        myself()->onlineStatus().protocolIcon(),
+	                        myself()->onlinetqStatus().protocolIcon(),
 	                        Kopete::UI::Global::mainWidget() );
 	logOff( Kopete::Account::ConnectionReset );
 }
@@ -744,8 +744,8 @@ void OscarAccount::slotTaskError( const Oscar::SNAC& s, int code, bool fatal )
 	if ( s.family == 0 && s.subtype == 0 )
 	{
 		message = getFLAPErrorMessage( code );
-		KPassivePopup::message( i18n( "account has been disconnected", "%1 disconnected" ).arg( accountId() ),
-		                        message, myself()->onlineStatus().protocolIcon(),
+		KPassivePopup::message( i18n( "account has been disconnected", "%1 disconnected" ).tqarg( accountId() ),
+		                        message, myself()->onlinetqStatus().protocolIcon(),
 		                        Kopete::UI::Global::mainWidget() );
 		switch ( code )
 		{
@@ -772,7 +772,7 @@ void OscarAccount::slotTaskError( const Oscar::SNAC& s, int code, bool fatal )
 	else
 		message = i18n("There was an error in the protocol handling; automatic reconnection occurring.");
 
-	KPassivePopup::message( i18n("OSCAR Protocol error"), message, myself()->onlineStatus().protocolIcon(),
+	KPassivePopup::message( i18n("OSCAR Protocol error"), message, myself()->onlinetqStatus().protocolIcon(),
 	                        Kopete::UI::Global::mainWidget() );
 	if ( fatal )
 		logOff( Kopete::Account::ConnectionReset );
@@ -819,44 +819,44 @@ TQString OscarAccount::getFLAPErrorMessage( int code )
 		{
 			reason = i18n( "You have logged in more than once with the same %1," \
 			               " account %2 is now disconnected.")
-				.arg( acctDescription ).arg( accountId() );
+				.tqarg( acctDescription ).tqarg( accountId() );
 		}
 		else // error while logging in
 		{
 			reason = i18n( "Sign on failed because either your %1 or " \
 			               "password are invalid. Please check your settings for account %2.")
-				.arg( acctDescription ).arg( accountId() );
+				.tqarg( acctDescription ).tqarg( accountId() );
 
 		}
 		break;
 	case 0x0002: // Service temporarily unavailable
 	case 0x0014: // Reservation map error
 		reason = i18n("The %1 service is temporarily unavailable. Please try again later.")
-			.arg( acctType );
+			.tqarg( acctType );
 		break;
 	case 0x0004: // Incorrect nick or password, re-enter
 	case 0x0005: // Mismatch nick or password, re-enter
 		reason = i18n("Could not sign on to %1 with account %2 because the " \
-		              "password was incorrect.").arg( acctType ).arg( accountId() );
+		              "password was incorrect.").tqarg( acctType ).tqarg( accountId() );
 		break;
 	case 0x0007: // non-existant ICQ#
 	case 0x0008: // non-existant ICQ#
 		reason = i18n("Could not sign on to %1 with nonexistent account %2.")
-			.arg( acctType ).arg( accountId() );
+			.tqarg( acctType ).tqarg( accountId() );
 		break;
 	case 0x0009: // Expired account
 		reason = i18n("Sign on to %1 failed because your account %2 expired.")
-			.arg( acctType ).arg( accountId() );
+			.tqarg( acctType ).tqarg( accountId() );
 		break;
 	case 0x0011: // Suspended account
 		reason = i18n("Sign on to %1 failed because your account %2 is " \
-		              "currently suspended.").arg( acctType ).arg( accountId() );
+		              "currently suspended.").tqarg( acctType ).tqarg( accountId() );
 		break;
 	case 0x0015: // too many clients from same IP
 	case 0x0016: // too many clients from same IP
 	case 0x0017: // too many clients from same IP (reservation)
 		reason = i18n("Could not sign on to %1 as there are too many clients" \
-		              " from the same computer.").arg( acctType );
+		              " from the same computer.").tqarg( acctType );
 		break;
 	case 0x0018: // rate exceeded (turboing)
 		if ( isConnected() )
@@ -866,7 +866,7 @@ TQString OscarAccount::getFLAPErrorMessage( int code )
 							" Wait ten minutes and try again." \
 							" If you continue to try, you will" \
 							" need to wait even longer.")
-				.arg( accountId() ).arg( acctType );
+				.tqarg( accountId() ).tqarg( acctType );
 		}
 		else
 		{
@@ -875,7 +875,7 @@ TQString OscarAccount::getFLAPErrorMessage( int code )
 							" Wait ten minutes and try again." \
 							" If you continue to try, you will" \
 							" need to wait even longer.")
-				.arg( accountId() ).arg( acctType) ;
+				.tqarg( accountId() ).tqarg( acctType) ;
 		}
 		break;
 	case 0x001C:
@@ -883,7 +883,7 @@ TQString OscarAccount::getFLAPErrorMessage( int code )
 		if ( !d->versionAlreadyUpdated )
 		{
 			reason = i18n("Sign on to %1 with your account %2 failed.")
-				.arg( acctType ).arg( accountId() );
+				.tqarg( acctType ).tqarg( accountId() );
 			
 			d->versionAlreadyUpdated = true;
 		}
@@ -891,19 +891,19 @@ TQString OscarAccount::getFLAPErrorMessage( int code )
 		{
 			reason = i18n("The %1 server thinks the client you are using is " \
 						  "too old. Please report this as a bug at http://bugs.kde.org")
-				.arg( acctType );
+				.tqarg( acctType );
 		}
 		break;
 	case 0x0022: // Account suspended because of your age (age < 13)
 		reason = i18n("Account %1 was disabled on the %2 server because " \
 		              "of your age (less than 13).")
-			.arg( accountId() ).arg( acctType );
+			.tqarg( accountId() ).tqarg( acctType );
 		break;
 	default:
 		if ( !isConnected() )
 		{
 			reason = i18n("Sign on to %1 with your account %2 failed.")
-				.arg( acctType ).arg( accountId() );
+				.tqarg( acctType ).tqarg( accountId() );
 		}
 		break;
 	}
