@@ -40,9 +40,10 @@ class Task;
 class KTemporaryFile;
 struct YABEntry;
 
-class Client : public QObject
+class Client : public TQObject
 {
 Q_OBJECT
+  TQ_OBJECT
 
 	public:
 
@@ -99,7 +100,7 @@ Q_OBJECT
 		 * If status is any other status the Client connects into Online state and changes into the specified state after the login.
 		 * @param status the status to connect with
 		 */
-		void setStatusOnConnect( Yahoo::Status status );
+		void setStatusOnConnect( Yahoo::tqStatus status );
 
 		/**
 		 * Specifies the status message we connect with.
@@ -146,7 +147,7 @@ Q_OBJECT
 		 * @param message the status message that will be set
 		 * @param type Yahoo::StatusTypeAvailable means that the user is available, Yahoo::StatusTypeAway means that the user is away from the keyboard
 		 */
-		void changeStatus(Yahoo::Status status, const TQString &message, Yahoo::StatusType type);
+		void changetqStatus(Yahoo::tqStatus status, const TQString &message, Yahoo::StatusType type);
 
 		/**
 		 * Set the verification word that is needed for a account verification after
@@ -161,7 +162,7 @@ Q_OBJECT
 		 * @param group the group where the buddy will be placed
 		 * @param message the message that will be sent to the buddy along the authorization request
 		 */
-		void addBuddy( const TQString &userId, const TQString &group, const TQString &message = TQString::fromLatin1("Please add me")  );
+		void addBuddy( const TQString &userId, const TQString &group, const TQString &message = TQString::tqfromLatin1("Please add me")  );
 
 		/**
 		 * Remove a buddy from the contact list
@@ -184,7 +185,7 @@ Q_OBJECT
 		 * @param mode defines the Stealth mode that is changed. That can be "Appear Offline", "Appear Online" or "Apper permanently offline"
 		 * @param state the status of the specified Stealth mode. Active, Not Active or Clear
 		 */
-		void stealthContact( TQString const &userId, Yahoo::StealthMode mode, Yahoo::StealthStatus state );
+		void stealthContact( TQString const &userId, Yahoo::StealthMode mode, Yahoo::StealthtqStatus state );
 
 		/**
 		 * Request the buddy's picture
@@ -225,7 +226,7 @@ Q_OBJECT
 		 * Notify the buddies about our new status
 		 * @param flag the type of our picture (0=none, 1=avatar, 2=picture)
 		 */
-		void setPictureStatus( Yahoo::PictureStatus flag );
+		void setPicturetqStatus( Yahoo::PicturetqStatus flag );
 
 		/**
 		 * Send a response to the webcam invite ( Accept / Decline )
@@ -431,13 +432,13 @@ Q_OBJECT
 		int pictureChecksum();
 
 		/** Get our status */
-		Yahoo::Status status();
+		Yahoo::tqStatus status();
 
 		/**
 		 * Set our status
 		 * @param status the new status
 		 */
-		void setStatus( Yahoo::Status status );
+		void settqStatus( Yahoo::tqStatus status );
 
 		/** Access the root Task for this client, so tasks may be added to it. */
 		Task* rootTask();
@@ -502,7 +503,7 @@ Q_OBJECT
 		/**
 		 * Notifies about the stealth status of buddies
 		 */
-		void stealthStatusChanged( const TQString &, Yahoo::StealthStatus );
+		void stealthStatusChanged( const TQString &, Yahoo::StealthtqStatus );
 		/**
 		 * Notifies about mails
 		 */
