@@ -28,6 +28,7 @@ class YMSGTransfer;
 class ListTask : public Task
 {
 Q_OBJECT
+  TQ_OBJECT
 public:
 	ListTask(Task *parent);
 	~ListTask();
@@ -40,7 +41,7 @@ protected:
 	void parseStealthList( YMSGTransfer *transfer );
 signals:
 	void gotBuddy(const TQString&, const TQString&, const TQString&);
-	void stealthStatusChanged( const TQString&, Yahoo::StealthStatus );
+	void stealthStatusChanged( const TQString&, Yahoo::StealthtqStatus );
 };
 
 #endif
