@@ -114,7 +114,7 @@ void YahooContact::setOnlineStatus(const Kopete::OnlineStatus &status)
 			protocol() ,
 			status.internalStatus()+1000 ,
 			status.overlayIcons() + TQStringList("yahoo_stealthed") ,
-			i18n("%1|Stealthed").arg( status.description() ) ) );
+			i18n("%1|Stealthed").tqarg( status.description() ) ) );
 	}
 	else if( !m_stealthed && status.internalStatus() > 999 )// Stealthed -> Not Stealthed
 		Contact::setOnlineStatus( static_cast< YahooProtocol *>( protocol() )->statusFromYahoo( status.internalStatus() - 1000 ) );
@@ -128,7 +128,7 @@ void YahooContact::setOnlineStatus(const Kopete::OnlineStatus &status)
 void YahooContact::setStealthed( bool stealthed )
 {
 	m_stealthed = stealthed;
-	setOnlineStatus( onlineStatus() );
+	setOnlineStatus( onlinetqStatus() );
 }
 
 bool YahooContact::stealthed()
@@ -187,7 +187,7 @@ void YahooContact::sync(unsigned int flags)
 bool YahooContact::isOnline() const
 {
 	//kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
-	return onlineStatus().status() != Kopete::OnlineStatus::Offline && onlineStatus().status() != Kopete::OnlineStatus::Unknown;
+	return onlinetqStatus().status() != Kopete::OnlineStatus::Offline && onlinetqStatus().status() != Kopete::OnlineStatus::Unknown;
 }
 
 bool YahooContact::isReachable()
@@ -232,7 +232,7 @@ TQString YahooContact::prepareMessage( const TQString &messageText )
 		pos = regExp.search( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-		newMsg.replace( regExp, TQString::fromLatin1("<span\\1font-weight:600\\2>\033[1m\\3\033[x1m</span>" ) );
+		newMsg.replace( regExp, TQString::tqfromLatin1("<span\\1font-weight:600\\2>\033[1m\\3\033[x1m</span>" ) );
 		}
 	}
 
@@ -243,7 +243,7 @@ TQString YahooContact::prepareMessage( const TQString &messageText )
 		pos = regExp.search( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-		newMsg.replace( regExp, TQString::fromLatin1("<span\\1text-decoration:underline\\2>\033[4m\\3\033[x4m</span>" ) );
+		newMsg.replace( regExp, TQString::tqfromLatin1("<span\\1text-decoration:underline\\2>\033[4m\\3\033[x4m</span>" ) );
 		}
 	}
 
@@ -254,7 +254,7 @@ TQString YahooContact::prepareMessage( const TQString &messageText )
 		pos = regExp.search( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-		newMsg.replace( regExp, TQString::fromLatin1("<span\\1font-style:italic\\2>\033[2m\\3\033[x2m</span>" ) );
+		newMsg.replace( regExp, TQString::tqfromLatin1("<span\\1font-style:italic\\2>\033[2m\\3\033[x2m</span>" ) );
 		}
 	}
 
@@ -265,7 +265,7 @@ TQString YahooContact::prepareMessage( const TQString &messageText )
 		pos = regExp.search( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, TQString::fromLatin1("<span\\1\\3>\033[#\\2m\\4\033[#000000m</span>" ) );
+			newMsg.replace( regExp, TQString::tqfromLatin1("<span\\1\\3>\033[#\\2m\\4\033[#000000m</span>" ) );
 		}
 	}
 
@@ -276,7 +276,7 @@ TQString YahooContact::prepareMessage( const TQString &messageText )
 		pos = regExp.search( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, TQString::fromLatin1("<span\\1\\3><font face=\"\\2\">\\4</span>" ) );
+			newMsg.replace( regExp, TQString::tqfromLatin1("<span\\1\\3><font face=\"\\2\">\\4</span>" ) );
 		}
 	}
 
@@ -287,7 +287,7 @@ TQString YahooContact::prepareMessage( const TQString &messageText )
 		pos = regExp.search( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, TQString::fromLatin1("<span\\1\\3><font size=\"\\2\">\\4</span>" ) );
+			newMsg.replace( regExp, TQString::tqfromLatin1("<span\\1\\3><font size=\"\\2\">\\4</span>" ) );
 		}
 	}
 
@@ -298,18 +298,18 @@ TQString YahooContact::prepareMessage( const TQString &messageText )
 		pos = regExp.search( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, TQString::fromLatin1("\\2") );
+			newMsg.replace( regExp, TQString::tqfromLatin1("\\2") );
 		}
 	}
 
 	// convert escaped chars
-	newMsg.replace( TQString::fromLatin1( "&gt;" ), TQString::fromLatin1( ">" ) );
-	newMsg.replace( TQString::fromLatin1( "&lt;" ), TQString::fromLatin1( "<" ) );
-	newMsg.replace( TQString::fromLatin1( "&quot;" ), TQString::fromLatin1( "\"" ) );
-	newMsg.replace( TQString::fromLatin1( "&nbsp;" ), TQString::fromLatin1( " " ) );
-	newMsg.replace( TQString::fromLatin1( "&amp;" ), TQString::fromLatin1( "&" ) );
-	newMsg.replace( TQString::fromLatin1( "<br />" ), TQString::fromLatin1( "\r" ) );
-	newMsg.replace( TQString::fromLatin1( "<br/>" ), TQString::fromLatin1( "\r" ) );
+	newMsg.replace( TQString::tqfromLatin1( "&gt;" ), TQString::tqfromLatin1( ">" ) );
+	newMsg.replace( TQString::tqfromLatin1( "&lt;" ), TQString::tqfromLatin1( "<" ) );
+	newMsg.replace( TQString::tqfromLatin1( "&quot;" ), TQString::tqfromLatin1( "\"" ) );
+	newMsg.replace( TQString::tqfromLatin1( "&nbsp;" ), TQString::tqfromLatin1( " " ) );
+	newMsg.replace( TQString::tqfromLatin1( "&amp;" ), TQString::tqfromLatin1( "&" ) );
+	newMsg.replace( TQString::tqfromLatin1( "<br />" ), TQString::tqfromLatin1( "\r" ) );
+	newMsg.replace( TQString::tqfromLatin1( "<br/>" ), TQString::tqfromLatin1( "\r" ) );
 
 	return newMsg;
 }
@@ -447,7 +447,7 @@ void YahooContact::slotUserProfile()
 {
 	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
 
-	TQString profileSiteString = TQString::fromLatin1("http://profiles.yahoo.com/") + userId();
+	TQString profileSiteString = TQString::tqfromLatin1("http://profiles.yahoo.com/") + userId();
 	KRun::runURL( KURL( profileSiteString ) , "text/html" );
 }
 
@@ -467,7 +467,7 @@ void YahooContact::stealthContact()
 	stealthSettingDialog->setMainWidget( stealthWidget );
 
 	// Prepare dialog
-	if( m_account->myself()->onlineStatus() == YahooProtocol::protocol()->Invisible )
+	if( m_account->myself()->onlinetqStatus() == YahooProtocol::protocol()->Invisible )
 	{
 		stealthWidget->radioOffline->setEnabled( true );
 		stealthWidget->radioOffline->setChecked( true );
@@ -490,7 +490,7 @@ void YahooContact::stealthContact()
 		m_account->yahooSession()->stealthContact( m_userId, Yahoo::StealthPermOffline, Yahoo::StealthActive );
 
 	// Apply temporary setting
-	if( m_account->myself()->onlineStatus() == YahooProtocol::protocol()->Invisible )
+	if( m_account->myself()->onlinetqStatus() == YahooProtocol::protocol()->Invisible )
 	{
 		if( stealthWidget->radioOnline->isChecked() )
 		{
@@ -518,7 +518,7 @@ void YahooContact::buzzContact()
 		Kopete::Message msg = Kopete::Message( manager(Kopete::Contact::CannotCreate)->myself() ,
 					manager(Kopete::Contact::CannotCreate)->members(), i18n("Buzzz!!!"),
 					Kopete::Message::Outbound, Kopete::Message::PlainText,
-					TQString::null , Kopete::Message::TypeAction);
+					TQString() , Kopete::Message::TypeAction);
 		view->appendMessage( msg );
 	}
 }
@@ -591,7 +591,7 @@ void YahooContact::slotEmitDisplayPictureChanged()
 {
 	kdDebug(YAHOO_GEN_DEBUG) << k_funcinfo << endl;
 	TQString newlocation=locateLocal( "appdata", "yahoopictures/"+ contactId().lower().replace(TQRegExp("[./~]"),"-")  +".png"  ) ;
-	setProperty( Kopete::Global::Properties::self()->photo(), TQString::null );
+	setProperty( Kopete::Global::Properties::self()->photo(), TQString() );
 	setProperty( Kopete::Global::Properties::self()->photo() , newlocation );
 	emit displayPictureChanged();
 }
@@ -607,7 +607,7 @@ void YahooContact::inviteWebcam()
 	{
 		KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error,
 			i18n("I cannot find the jasper image convert program.\njasper is required to render the yahoo webcam images."
-			"\nPlease see %1 for further information.").arg("http://wiki.kde.org/tiki-index.php?page=Kopete%20Webcam%20Support") );
+			"\nPlease see %1 for further information.").tqarg("http://wiki.kde.org/tiki-index.php?page=Kopete%20Webcam%20Support") );
 		return;
 	}
 	m_account->yahooSession()->sendWebcamInvite( m_userId );
@@ -662,7 +662,7 @@ void YahooContact::requestWebcam()
 	{
 		KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error,
 			i18n("I cannot find the jasper image convert program.\njasper is required to render the yahoo webcam images."
-			"\nPlease see %1 for further information.").arg("http://wiki.kde.org/tiki-index.php?page=Kopete%20Webcam%20Support") );
+			"\nPlease see %1 for further information.").tqarg("http://wiki.kde.org/tiki-index.php?page=Kopete%20Webcam%20Support") );
 		return;
 	}
 
@@ -763,8 +763,8 @@ void YahooContact::writeYABEntry()
 	setProperty( YahooProtocol::protocol()->propWorkURL, m_YABEntry->workURL );
 
 		// Miscellanous
-	setProperty( YahooProtocol::protocol()->propBirthday, m_YABEntry->birthday.toString( Qt::ISODate ) );
-	setProperty( YahooProtocol::protocol()->propAnniversary, m_YABEntry->anniversary.toString( Qt::ISODate ) );
+	setProperty( YahooProtocol::protocol()->propBirthday, TQString(m_YABEntry->birthday.toString( Qt::ISODate )) );
+	setProperty( YahooProtocol::protocol()->propAnniversary, TQString(m_YABEntry->anniversary.toString( Qt::ISODate )) );
 	setProperty( YahooProtocol::protocol()->propNotes, m_YABEntry->notes );
 	setProperty( YahooProtocol::protocol()->propAdditional1, m_YABEntry->additional1 );
 	setProperty( YahooProtocol::protocol()->propAdditional2, m_YABEntry->additional2 );
