@@ -26,8 +26,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #include "calendarview.h"
@@ -131,18 +131,18 @@ CalendarView::CalendarView( TQWidget *parent, const char *name )
 
   mExtensions.setAutoDelete( true );
 
-  mDateNavigator = new DateNavigator( this );
-  mDateChecker = new DateChecker( this );
+  mDateNavigator = new DateNavigator( TQT_TQOBJECT(this) );
+  mDateChecker = new DateChecker( TQT_TQOBJECT(this) );
 
   TQBoxLayout *topLayout = new TQVBoxLayout( this );
 
 #ifndef KORG_NOSPLITTER
-  // create the main layout frames.
-  mPanner = new TQSplitter( TQSplitter::Horizontal, this,
+  // create the main tqlayout frames.
+  mPanner = new TQSplitter( Qt::Horizontal, this,
                            "CalendarView::Panner" );
   topLayout->addWidget( mPanner );
 
-  mLeftSplitter = new TQSplitter( TQSplitter::Vertical, mPanner,
+  mLeftSplitter = new TQSplitter( Qt::Vertical, mPanner,
                                  "CalendarView::LeftFrame" );
 //  mPanner->setResizeMode( mLeftSplitter, TQSplitter::Stretch );
 
@@ -177,7 +177,7 @@ CalendarView::CalendarView( TQWidget *parent, const char *name )
 
   mDateNavigatorContainer = new KDateNavigator( leftFrame, true,
                                        "CalendarView::DateNavigator",
-                                       TQDate::currentDate() );
+                                       TQDate::tqcurrentDate() );
   mTodoList = new KOTodoView( CalendarNull::self(), leftFrame, "todolist" );
 
   mEventViewer = new KOEventViewer ( CalendarNull::self(), leftFrame, "EventViewer" );
@@ -185,7 +185,7 @@ CalendarView::CalendarView( TQWidget *parent, const char *name )
   TQWidget *rightBox = new TQWidget( mainBox );
   TQBoxLayout *rightLayout = new TQVBoxLayout( rightBox );
 
-  mNavigatorBar = new NavigatorBar( TQDate::currentDate(), rightBox );
+  mNavigatorBar = new NavigatorBar( TQDate::tqcurrentDate(), rightBox );
   rightLayout->addWidget( mNavigatorBar );
 
   mRightFrame = new TQWidgetStack( rightBox );
@@ -195,7 +195,7 @@ CalendarView::CalendarView( TQWidget *parent, const char *name )
 
   if ( KOPrefs::instance()->mVerticalScreen ) {
     // mTodoList->setFixedHeight( 60 );
-    mTodoList->setFixedHeight( mDateNavigatorContainer->sizeHint().height() );
+    mTodoList->setFixedHeight( mDateNavigatorContainer->tqsizeHint().height() );
   }
 #endif
 
@@ -277,7 +277,7 @@ CalendarView::CalendarView( TQWidget *parent, const char *name )
   KOGlobals::self()->
       setHolidays( new KHolidays( KOPrefs::instance()->mHolidays ) );
 
-  connect( TQApplication::clipboard(), TQT_SIGNAL( dataChanged() ),
+  connect( TQApplication::tqclipboard(), TQT_SIGNAL( dataChanged() ),
            TQT_SLOT( checkClipboard() ) );
 
   connect( mTodoList, TQT_SIGNAL( incidenceSelected( Incidence *,const TQDate & ) ),
@@ -311,7 +311,7 @@ void CalendarView::setCalendar( Calendar *cal )
   connect( mHistory, TQT_SIGNAL( redone() ), TQT_SLOT( updateView() ) );
 
   if ( mChanger ) delete mChanger;
-  setIncidenceChanger( new IncidenceChanger( mCalendar, this ) );
+  setIncidenceChanger( new IncidenceChanger( mCalendar, TQT_TQOBJECT(this) ) );
 
   mCalendar->registerObserver( this );
 
@@ -349,15 +349,15 @@ Calendar *CalendarView::calendar()
   else return CalendarNull::self();
 }
 
-QPair<ResourceCalendar *, TQString> CalendarView::viewSubResourceCalendar()
+TQPair<ResourceCalendar *, TQString> CalendarView::viewSubResourceCalendar()
 {
-  QPair<ResourceCalendar *, TQString> p( 0, TQString() );
+  TQPair<ResourceCalendar *, TQString> p( 0, TQString() );
   KOrg::BaseView *cV = mViewManager->currentView();
   if ( cV && cV == mViewManager->multiAgendaView() ) {
     cV = mViewManager->multiAgendaView()->selectedAgendaView();
   }
   if ( cV ) {
-    p = qMakePair( cV->resourceCalendar(), cV->subResourceCalendar() );
+    p = tqMakePair( cV->resourceCalendar(), cV->subResourceCalendar() );
   }
   return p;
 }
@@ -387,7 +387,7 @@ TQDate CalendarView::activeDate( bool fallbackToToday )
 
   // When all else fails, use the navigator start date, or today.
   if ( fallbackToToday ) {
-    return TQDate::currentDate();
+    return TQDate::tqcurrentDate();
   } else {
     return mDateNavigator->selectedDates().first();
   }
@@ -487,7 +487,7 @@ bool CalendarView::openCalendar(const TQString& filename, bool merge)
     // have become partially populated.  Clear it out.
     if ( !merge ) mCalendar->close();
 
-    KMessageBox::error(this,i18n("Could not load calendar '%1'.").arg(filename));
+    KMessageBox::error(this,i18n("Could not load calendar '%1'.").tqarg(filename));
 
     return false;
   }
@@ -547,7 +547,7 @@ void CalendarView::readSettings()
 
   TQValueList<int> sizes = config->readIntListEntry( "Separator1" );
   if ( sizes.count() != 2 ) {
-    sizes << mDateNavigatorContainer->minimumSizeHint().width();
+    sizes << mDateNavigatorContainer->tqminimumSizeHint().width();
     sizes << 300;
   }
   mPanner->setSizes( sizes );
@@ -660,7 +660,7 @@ void CalendarView::writeFilterSettings( KConfig *config )
   if ( mCurrentFilter ) {
     config->writeEntry( "Current Filter", mCurrentFilter->name() );
   } else {
-    config->writeEntry( "Current Filter", TQString::null );
+    config->writeEntry( "Current Filter", TQString() );
   }
 }
 
@@ -776,18 +776,18 @@ void CalendarView::incidenceChanged( Incidence *oldIncidence,
       if ( todo->isCompleted() ||
            modification == KOGlobals::COMPLETION_MODIFIED_WITH_RECURRENCE ) {
         TQString timeStr = KGlobal::locale()->formatTime( TQTime::currentTime() );
-        TQString description = i18n( "To-do completed: %1 (%2)" ).arg(
-          newIncidence->summary() ).arg( timeStr );
+        TQString description = i18n( "To-do completed: %1 (%2)" ).tqarg(
+          newIncidence->summary() ).tqarg( timeStr );
 
-        Journal::List journals = calendar()->journals( TQDate::currentDate() );
+        Journal::List journals = calendar()->journals( TQDate::tqcurrentDate() );
         Journal *journal;
 
         if ( journals.isEmpty() ) {
           journal = new Journal();
-          journal->setDtStart( TQDateTime::currentDateTime() );
+          journal->setDtStart( TQDateTime::tqcurrentDateTime() );
 
-          TQString dateStr = KGlobal::locale()->formatDate( TQDate::currentDate() );
-          journal->setSummary( i18n("Journal of %1").arg( dateStr ) );
+          TQString dateStr = KGlobal::locale()->formatDate( TQDate::tqcurrentDate() );
+          journal->setSummary( i18n("Journal of %1").tqarg( dateStr ) );
           journal->setDescription( description );
 
           //TODO: recorded to-dos should save into the standard resource always
@@ -844,7 +844,7 @@ void CalendarView::checkForFilteredChange( Incidence *incidence )
     // user so that he isn't surprised if his new event doesn't show up
     KMessageBox::information( this, i18n("The item \"%1\" is filtered by "
                  "your current filter rules, so it will be hidden and not "
-                 "appear in the view.").arg( incidence->summary() ),
+                 "appear in the view.").tqarg( incidence->summary() ),
                  i18n("Filter Applied"), "ChangedIncidenceFiltered" );
   }
 }
@@ -901,7 +901,7 @@ void CalendarView::updateUnmanagedViews()
 int CalendarView::msgItemDelete( Incidence *incidence )
 {
   return KMessageBox::warningContinueCancel(this,
-      i18n("The item \"%1\" will be permanently deleted.").arg( incidence->summary() ),
+      i18n("The item \"%1\" will be permanently deleted.").tqarg( incidence->summary() ),
       i18n("KOrganizer Confirmation"), KGuiItem(i18n("&Delete"),"editdelete"));
 }
 
@@ -925,7 +925,7 @@ void CalendarView::edit_cut()
                                                 "Do you want to cut just this item and "
                                                 "make all its sub-to-dos independent, or "
                                                 "cut the to-do with all its sub-to-dos?"
-                                             ).arg( incidence->summary() ),
+                                             ).tqarg( incidence->summary() ),
                                            i18n("KOrganizer Confirmation"),
                                            i18n("Cut Only This"),
                                            i18n("Cut All"));
@@ -935,7 +935,7 @@ void CalendarView::edit_cut()
     incidences.append( incidence );
     makeChildrenIndependent( incidence );
   } else if ( km == KMessageBox::No ) { // all
-    // load incidence + children + grandchildren...
+    // load incidence + tqchildren + grandtqchildren...
     getIncidenceHierarchy( incidence, incidences );
   }
 
@@ -962,7 +962,7 @@ void CalendarView::edit_copy()
                                            i18n("The item \"%1\" has sub-to-dos. "
                                                 "Do you want to copy just this item or "
                                                 "copy the to-do with all its sub-to-dos?"
-                                             ).arg( incidence->summary() ),
+                                             ).tqarg( incidence->summary() ),
                                            i18n("KOrganizer Confirmation"),
                                            i18n("Copy Only This"),
                                            i18n("Copy All"));
@@ -971,7 +971,7 @@ void CalendarView::edit_copy()
   if ( km == KMessageBox::Yes ) { // only one
     incidences.append( incidence );
   } else if ( km == KMessageBox::No ) { // all
-    // load incidence + children + grandchildren...
+    // load incidence + tqchildren + grandtqchildren...
     getIncidenceHierarchy( incidence, incidences );
   }
 
@@ -1075,7 +1075,7 @@ void CalendarView::edit_paste()
 
   Incidence::List::Iterator it;
   for ( it = pastedIncidences.begin(); it != pastedIncidences.end(); ++it ) {
-    QPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
+    TQPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
 
     // FIXME: use a visitor here
     if ( ( *it )->type() == "Event" ) {
@@ -1248,7 +1248,7 @@ void CalendarView::newTodo( ResourceCalendar *res, const TQString &subRes )
   todoEditor->setResource( res, subRes );
   if ( mViewManager->currentView()->isEventView() ) {
     dtDue.setDate( mDateNavigator->selectedDates().first() );
-    TQDateTime dtDummy = TQDateTime::currentDateTime();
+    TQDateTime dtDummy = TQDateTime::tqcurrentDateTime();
     mViewManager->currentView()->eventDurationHint( dtDue, dtDummy, allday );
     todoEditor->setDates( dtDue, allday );
   }
@@ -1283,13 +1283,13 @@ void CalendarView::newJournal()
 void CalendarView::newJournal( ResourceCalendar *res, const TQString &subRes )
 {
   kdDebug(5850) << "CalendarView::newJournal()" << endl;
-  newJournal( res, subRes, TQString::null, TQDate() );
+  newJournal( res, subRes, TQString(), TQDate() );
 }
 
 void CalendarView::newJournal( ResourceCalendar *res, const TQString &subRes,
                                const TQDate &date)
 {
-  newJournal( res, subRes, TQString::null, date );
+  newJournal( res, subRes, TQString(), date );
 }
 
 void CalendarView::newJournal( ResourceCalendar *res, const TQString &subRes,
@@ -1494,7 +1494,7 @@ void CalendarView::dissociateOccurrence( Incidence *incidence, const TQDate &dat
     return;
   }
 
-  QPair<ResourceCalendar *, TQString>p =
+  TQPair<ResourceCalendar *, TQString>p =
     CalHelper::incSubResourceCalendar( calendar(), incidence );
 
   if ( !mChanger->beginChange( incidence, p.first, p.second ) ) {
@@ -1528,7 +1528,7 @@ void CalendarView::dissociateFutureOccurrence( Incidence *incidence, const TQDat
     return;
   }
 
-  QPair<ResourceCalendar *, TQString>p =
+  TQPair<ResourceCalendar *, TQString>p =
     CalHelper::incSubResourceCalendar( calendar(), incidence );
 
   if ( !mChanger->beginChange( incidence, p.first, p.second ) ) {
@@ -1585,7 +1585,7 @@ void CalendarView::schedule_publish(Incidence *incidence)
       KMessageBox::information( this, i18n("The item information was successfully sent."),
                                 i18n("Publishing"), "IncidencePublishSuccess" );
     } else {
-      KMessageBox::error( this, i18n("Unable to publish the item '%1'").arg( incidence->summary() ) );
+      KMessageBox::error( this, i18n("Unable to publish the item '%1'").tqarg( incidence->summary() ) );
     }
   }
   delete publishdlg;
@@ -1661,7 +1661,7 @@ void CalendarView::schedule_forward( Incidence *incidence )
     } else {
       KMessageBox::error(
         this,
-        i18n( "Unable to forward the item '%1'" ).arg( incidence->summary() ),
+        i18n( "Unable to forward the item '%1'" ).tqarg( incidence->summary() ),
         i18n( "Forwarding Error" ) );
     }
   }
@@ -1669,7 +1669,7 @@ void CalendarView::schedule_forward( Incidence *incidence )
 
 void CalendarView::mailFreeBusy( int daysToPublish )
 {
-  TQDateTime start = TQDateTime::currentDateTime();
+  TQDateTime start = TQDateTime::tqcurrentDateTime();
   TQDateTime end = start.addDays(daysToPublish);
 
   FreeBusy *freebusy = new FreeBusy(mCalendar, start, end);
@@ -1727,16 +1727,16 @@ void CalendarView::schedule(Scheduler::Method method, Incidence *incidence)
   if ( scheduler.performTransaction( incidence, method ) ) {
     KMessageBox::information( this, i18n("The groupware message for item '%1'"
                                 "was successfully sent.\nMethod: %2")
-                                .arg( incidence->summary() )
-                                .arg( Scheduler::methodName( method ) ),
+                                .tqarg( incidence->summary() )
+                                .tqarg( Scheduler::methodName( method ) ),
                               i18n("Sending Free/Busy"),
                               "FreeBusyPublishSuccess" );
   } else {
     KMessageBox::error( this, i18n("Groupware message sending failed. "
                         "%2 is request/reply/add/cancel/counter/etc.",
                         "Unable to send the item '%1'.\nMethod: %2")
-                        .arg( incidence->summary() )
-                        .arg( Scheduler::methodName( method ) ) );
+                        .tqarg( incidence->summary() )
+                        .tqarg( Scheduler::methodName( method ) ) );
   }
 }
 
@@ -1817,7 +1817,7 @@ void CalendarView::exportICalendar()
     if ( TQFile( filename ).exists() ) {
       if ( KMessageBox::No == KMessageBox::warningYesNo(
              this,
-             i18n( "Do you want to overwrite %1?").arg(filename) ) ) {
+             i18n( "Do you want to overwrite %1?").tqarg(filename) ) ) {
 	      return;
       }
     }
@@ -1845,7 +1845,7 @@ void CalendarView::exportVCalendar()
     if ( TQFile( filename ).exists() ) {
       if ( KMessageBox::No == KMessageBox::warningYesNo(
              this,
-             i18n( "Do you want to overwrite %1?").arg(filename ) ) ) {
+             i18n( "Do you want to overwrite %1?").tqarg(filename ) ) ) {
              return;
       }
     }
@@ -1865,7 +1865,7 @@ void CalendarView::eventUpdated(Incidence *)
 void CalendarView::adaptNavigationUnits()
 {
   if (mViewManager->currentView()->isEventView()) {
-    int days = mViewManager->currentView()->currentDateCount();
+    int days = mViewManager->currentView()->tqcurrentDateCount();
     if (days == 1) {
       emit changeNavStringPrev(i18n("&Previous Day"));
       emit changeNavStringNext(i18n("&Next Day"));
@@ -1934,7 +1934,7 @@ void CalendarView::processIncidenceSelection( Incidence *incidence, const TQDate
 void CalendarView::checkClipboard()
 {
 #ifndef KORG_NODND
-  if (ICalDrag::canDecode(TQApplication::clipboard()->data())) {
+  if (ICalDrag::canDecode(TQApplication::tqclipboard()->data())) {
     kdDebug(5850) << "CalendarView::checkClipboard() true" << endl;
     emit pasteEnabled(true);
   } else {
@@ -2252,7 +2252,7 @@ bool CalendarView::editIncidence( Incidence *incidence, const TQDate &date, bool
     return true;
   }
 
-  QPair<ResourceCalendar *, TQString>p =
+  TQPair<ResourceCalendar *, TQString>p =
     CalHelper::incSubResourceCalendar( calendar(), incidence );
 
   Incidence *savedIncidence = incidence->clone();
@@ -2334,7 +2334,7 @@ void CalendarView::deleteTodoIncidence ( Todo *todo, bool force )
            "Do you want to delete just this item and "
            "make all its sub-to-dos independent, or "
            "delete the to-do with all its sub-to-dos?"
-        ).arg( todo->summary() ),
+        ).tqarg( todo->summary() ),
       i18n("KOrganizer Confirmation"),
       i18n("Delete Only This"),
       i18n("Delete All"));
@@ -2367,7 +2367,7 @@ void CalendarView::deleteIncidence(Incidence *incidence, bool force)
       KMessageBox::information( this, i18n("The item \"%1\" is marked read-only "
                                 "and cannot be deleted; it probably belongs to "
                                 "a read-only calendar resource.")
-                                .arg(incidence->summary()),
+                                .tqarg(incidence->summary()),
                                 i18n("Removing not possible"),
                                 "deleteReadOnlyIncidence" );
     }
@@ -2377,7 +2377,7 @@ void CalendarView::deleteIncidence(Incidence *incidence, bool force)
   CanDeleteIncidenceVisitor v;
 
   // Let the visitor do special things for special incidence types.
-  // e.g. todos with children cannot be deleted, so act(..) returns false
+  // e.g. todos with tqchildren cannot be deleted, so act(..) returns false
   if ( !v.act( incidence, this ) )
     return;
   //If it is a todo, there are specific delete function
@@ -2389,7 +2389,7 @@ void CalendarView::deleteIncidence(Incidence *incidence, bool force)
 
   if ( incidence->doesRecur() ) {
     TQDate itemDate = mViewManager->currentSelectionDate();
-    kdDebug(5850) << "Recurrence-Date: " << itemDate.toString() << endl;
+    kdDebug(5850) << "Recurrence-Date: " << TQString(itemDate.toString()) << endl;
     int km = KMessageBox::Ok;
     if ( !force ) {
       if ( !itemDate.isValid() ) {
@@ -2397,22 +2397,22 @@ void CalendarView::deleteIncidence(Incidence *incidence, bool force)
         km = KMessageBox::warningContinueCancel(this,
           i18n("The calendar item \"%1\" recurs over multiple dates; "
                "are you sure you want to delete it "
-               "and all its recurrences?").arg( incidence->summary() ),
+               "and all its recurrences?").tqarg( incidence->summary() ),
                i18n("KOrganizer Confirmation"), i18n("Delete All") );
       } else {
         km = KOMessageBox::fourBtnMsgBox( this, TQMessageBox::Warning,
           i18n("The calendar item \"%1\" recurs over multiple dates. "
                "Do you want to delete only the current one on %2, only all "
                "future recurrences, or all its recurrences?" )
-               .arg( incidence->summary() )
-               .arg( KGlobal::locale()->formatDate(itemDate)),
+               .tqarg( incidence->summary() )
+               .tqarg( KGlobal::locale()->formatDate(itemDate)),
                i18n("KOrganizer Confirmation"), i18n("Delete C&urrent"),
                i18n("Delete &Future"),
                i18n("Delete &All"));
       }
     }
 
-    QPair<ResourceCalendar *, TQString>p =
+    TQPair<ResourceCalendar *, TQString>p =
       CalHelper::incSubResourceCalendar( calendar(), incidence );
 
     switch(km) {
@@ -2428,8 +2428,8 @@ void CalendarView::deleteIncidence(Incidence *incidence, bool force)
               // Moving the first in a series...don't bother with the nonstandard exclusion list
               Recurrence *recur = incidence->recurrence();
               Event* thisevent = static_cast<Event*>(incidence);
-              QDateTime newEnd;
-              QDateTime newRecurEnd;
+              TQDateTime newEnd;
+              TQDateTime newRecurEnd;
               newRecurEnd = recur->endDateTime();
               newEnd.setTime_t( incidence->dtEnd().toTime_t() + ( recur->getNextDateTime( recur->startDateTime() ).toTime_t() - recur->startDateTime().toTime_t()  ) );
               thisevent->setDtEnd( newEnd  );
@@ -2524,14 +2524,14 @@ void CalendarView::purgeCompleted()
       if ( aTodo && !aTodo->relatedTo() )
         rootTodos.append( aTodo );
     }
-    // now that we have a list of all root todos, check them and their children
+    // now that we have a list of all root todos, check them and their tqchildren
     for ( it = rootTodos.begin(); it != rootTodos.end(); ++it ) {
       purgeCompletedSubTodos( *it, allDeleted );
     }
     endMultiModify();
     if ( !allDeleted ) {
       KMessageBox::information( this, i18n("Unable to purge to-dos with "
-                                "uncompleted children."), i18n("Delete To-do"),
+                                "uncompleted tqchildren."), i18n("Delete To-do"),
                                 "UncompletedChildrenPurgeTodos" );
     }
   }
@@ -2577,7 +2577,7 @@ void CalendarView::addIncidenceOn( Incidence *incadd, const TQDate &dt )
 {
   if ( !incadd || !mChanger ) {
     KMessageBox::sorry(this, i18n("Unable to copy the item to %1.")
-                       .arg( dt.toString() ), i18n("Copying Failed") );
+                       .tqarg( dt.toString() ), i18n("Copying Failed") );
     return;
   }
   Incidence *incidence = mCalendar->incidence( incadd->uid() );
@@ -2609,7 +2609,7 @@ void CalendarView::addIncidenceOn( Incidence *incadd, const TQDate &dt )
     todo->setHasDueDate( true );
   }
 
-  QPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
+  TQPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
 
   if ( !mChanger->addIncidence( incidence, p.first, p.second, this ) ) {
     KODialogManager::errorSaveIncidence( this, incidence );
@@ -2621,7 +2621,7 @@ void CalendarView::moveIncidenceTo( Incidence *incmove, const TQDate &dt )
 {
   if ( !incmove || !mChanger ) {
     KMessageBox::sorry( this, i18n("Unable to move the item to %1.")
-                        .arg( dt.toString() ), i18n("Moving Failed") );
+                        .tqarg( dt.toString() ), i18n("Moving Failed") );
     return;
   }
   Incidence *incidence = mCalendar->incidence( incmove->uid() );
@@ -2631,7 +2631,7 @@ void CalendarView::moveIncidenceTo( Incidence *incmove, const TQDate &dt )
   }
 
   Incidence *oldIncidence = incidence->clone();
-  QPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
+  TQPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
 
   if ( !mChanger->beginChange( incidence, p.first, p.second ) ) {
     delete oldIncidence;
@@ -2774,7 +2774,7 @@ Incidence* CalendarView::singleOccurrenceOrAll( Incidence *inc,
   }
 
   if ( dissociationOccurred && commitToCalendar ) {
-    QPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
+    TQPair<ResourceCalendar *, TQString>p = viewSubResourceCalendar();
     mChanger->addIncidence( incToReturn, p.first, p.second, this );
     mChanger->changeIncidence( incSaved, inc, whatChanged, this );
   }
@@ -2794,16 +2794,16 @@ void CalendarView::selectWeek( const TQDate &date )
 }
 
 void CalendarView::getIncidenceHierarchy( Incidence *inc,
-                                          Incidence::List &children )
+                                          Incidence::List &tqchildren )
 {
   // protecion against looping hierarchies
-  if ( inc && !children.contains( inc ) ) {
+  if ( inc && !tqchildren.contains( inc ) ) {
     Incidence::List::ConstIterator it;
     Incidence::List immediateChildren = inc->relations();
     for ( it = immediateChildren.constBegin(); it != immediateChildren.constEnd(); ++it ) {
-      getIncidenceHierarchy( *it, children );
+      getIncidenceHierarchy( *it, tqchildren );
     }
-    children.append( inc );
+    tqchildren.append( inc );
   }
 }
 
