@@ -19,8 +19,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 #ifndef CALENDARVIEW_H
 #define CALENDARVIEW_H
@@ -56,7 +56,7 @@ class HTMLExportSettings;
 using namespace KOrg;
 using namespace KCal;
 
-class CalendarViewExtension : public QWidget
+class CalendarViewExtension : public TQWidget
 {
   public:
     CalendarViewExtension( TQWidget *parent, const char *name = 0 )
@@ -81,12 +81,13 @@ class CalendarViewExtension : public QWidget
 class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::Observer
 {
     Q_OBJECT
+  TQ_OBJECT
   public:
     /**
       Constructs a new calendar view widget.
 
       @param parent   parent window
-      @param name     Qt internal widget object name
+      @param name     TQt internal widget object name
     */
     CalendarView( TQWidget *parent = 0, const char *name = 0 );
     virtual ~CalendarView();
@@ -115,7 +116,7 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
     void setCalendar( Calendar * );
     Calendar *calendar();
 
-    QPair<ResourceCalendar *, TQString> viewSubResourceCalendar();
+    TQPair<ResourceCalendar *, TQString> viewSubResourceCalendar();
 
     KOrg::History *history() const { return mHistory; }
 
@@ -288,7 +289,7 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
     */
     void newEvent( ResourceCalendar *res, const TQString &subRes,
                    const TQString &summary,
-                   const TQString &description = TQString::null,
+                   const TQString &description = TQString(),
                    const TQStringList &attachment = TQStringList(),
                    const TQStringList &attendees = TQStringList(),
                    const TQStringList &attachmentMimetypes = TQStringList(),
@@ -352,7 +353,7 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
 
     void newTodo( ResourceCalendar *res, const TQString &subRes,
                   const TQString &summary,
-                  const TQString &description = TQString::null,
+                  const TQString &description = TQString(),
                   const TQStringList &attachments = TQStringList(),
                   const TQStringList &attendees = TQStringList(),
                   const TQStringList &attachmentMimetypes = TQStringList(),
@@ -453,10 +454,10 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
      */
     void appointment_delete();
 
-    /* frees the selected to-do's children from it's relation, update the view */
+    /* frees the selected to-do's tqchildren from it's relation, update the view */
     void todo_unsub();
 
-    /* frees an incidence's children from it's relation, without update the view
+    /* frees an incidence's tqchildren from it's relation, without update the view
        Works with any incidence type, although currently we only pass to-dos
     */
     bool incidence_unsub( Incidence *inc );
@@ -464,7 +465,7 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
     /** Make all sub-to-dos of the selected todo independent, update the view */
     bool makeSubTodosIndependent ( );
 
-    /** Make all children of incidence independent, not update the view
+    /** Make all tqchildren of incidence independent, not update the view
         Works with any incidence type, although currently we only pass to-dos
     */
     bool makeChildrenIndependent( Incidence *inc );
