@@ -19,8 +19,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #include <tqtooltip.h>
@@ -75,7 +75,7 @@ KOAgendaItem::KOAgendaItem( Calendar *calendar, Incidence *incidence,
   mItemPos( itemPos ), mItemCount( itemCount ),
   mMultiItemInfo( 0 ), mStartMoveInfo( 0 )
 {
-  setBackgroundMode( Qt::NoBackground );
+  setBackgroundMode( TQt::NoBackground );
 
   setCellXY( 0, 0, 1 );
   setCellXRight( 0 );
@@ -562,7 +562,7 @@ void KOAgendaItem::addAttendee( const TQString &newAttendee )
   KPIM::getNameAndMail( newAttendee, name, email );
   if ( !( name.isEmpty() && email.isEmpty() ) ) {
     mIncidence->addAttendee(new Attendee(name,email));
-    KMessageBox::information( this, i18n("Attendee \"%1\" added to the calendar item \"%2\"").arg(KPIM::normalizedAddress(name, email, TQString())).arg(text()), i18n("Attendee added"), "AttendeeDroppedAdded" );
+    KMessageBox::information( this, i18n("Attendee \"%1\" added to the calendar item \"%2\"").tqarg(KPIM::normalizedAddress(name, email, TQString())).tqarg(text()), i18n("Attendee added"), "AttendeeDroppedAdded" );
   }
 
 }
@@ -739,14 +739,14 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
   TQRect visRect = visibleRect();
   // when scrolling horizontally in the side-by-side view, the repainted area is clipped
   // to the newly visible area, which is a problem since the content changes when visRect
-  // changes, so repaint the full item in that case
+  // changes, so tqrepaint the full item in that case
   if ( ev->rect() != visRect && visRect.isValid() && ev->rect().isValid() ) {
-    repaint( visRect );
+    tqrepaint( visRect );
     return;
   }
 
   TQPainter p( this );
-  const int ft = 2; // frame thickness for layout, see paintFrame()
+  const int ft = 2; // frame thickness for tqlayout, see paintFrame()
   const int margin = 1 + ft; // frame + space between frame and content
 
   // General idea is to always show the icons (even in the all-day events).
@@ -769,7 +769,7 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
     if ( static_cast<Todo*>(mIncidence)->isOverdue() )
       bgColor = KOPrefs::instance()->todoOverdueColor();
     else if ( static_cast<Todo*>(mIncidence)->dtDue().date() ==
-              TQDateTime::currentDateTime().date() )
+              TQDateTime::tqcurrentDateTime().date() )
       bgColor = KOPrefs::instance()->todoDueTodayColor();
   }
 
@@ -838,8 +838,8 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
   if ( !isMultiItem() ) {
     shortH = KGlobal::locale()->formatTime(mIncidence->dtStart().time());
     if (mIncidence->type() != "Todo")
-      longH = i18n("%1 - %2").arg(shortH)
-               .arg(KGlobal::locale()->formatTime(mIncidence->dtEnd().time()));
+      longH = i18n("%1 - %2").tqarg(shortH)
+               .tqarg(KGlobal::locale()->formatTime(mIncidence->dtEnd().time()));
     else
       longH = shortH;
   } else if ( !mMultiItemInfo->mFirstMultiItem ) {
@@ -847,7 +847,7 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
     longH = shortH;
   } else {
     shortH = KGlobal::locale()->formatTime(mIncidence->dtEnd().time());
-    longH = i18n("- %1").arg(shortH);
+    longH = i18n("- %1").tqarg(shortH);
   }
 
   KWordWrap *ww = KWordWrap::formatText( fm,
@@ -857,10 +857,10 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
   int th = ww->boundingRect().height();
   delete ww;
 
-  int hlHeight = QMAX(fm.boundingRect(longH).height(),
-     QMAX(alarmPxmp->height(), QMAX(recurPxmp->height(),
-     QMAX(readonlyPxmp->height(), QMAX(replyPxmp->height(),
-     QMAX(groupPxmp->height(), organizerPxmp->height()))))));
+  int hlHeight = TQMAX(fm.boundingRect(longH).height(),
+     TQMAX(alarmPxmp->height(), TQMAX(recurPxmp->height(),
+     TQMAX(readonlyPxmp->height(), TQMAX(replyPxmp->height(),
+     TQMAX(groupPxmp->height(), organizerPxmp->height()))))));
 
   bool completelyRenderable = th < (height() - 2 * ft - 2 - hlHeight);
 
@@ -917,7 +917,7 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
                                 mLabelText );
 
     //kdDebug() << "SIZES for " << mLabelText <<  ": " << width() << " :: " << txtWidth << endl;
-    ww->drawText( &p, x, margin, Qt::AlignHCenter | KWordWrap::FadeOut );
+    ww->drawText( &p, x, margin, TQt::AlignHCenter | KWordWrap::FadeOut );
     delete ww;
     return;
   }
@@ -937,8 +937,8 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
          (mIncidence->dtStart() != mIncidence->dtEnd()) ) { // multi days
       shortH = longH =
         i18n("%1 - %2")
-             .arg(KGlobal::locale()->formatDate(mIncidence->dtStart().date()))
-             .arg(KGlobal::locale()->formatDate(mIncidence->dtEnd().date()));
+             .tqarg(KGlobal::locale()->formatDate(mIncidence->dtStart().date()))
+             .tqarg(KGlobal::locale()->formatDate(mIncidence->dtEnd().date()));
 
       // paint headline
       p.fillRect( 0, 0, width(), (ft/2) + margin + hlHeight,
@@ -988,10 +988,10 @@ void KOAgendaItem::paintEvent( TQPaintEvent *ev )
   TQString ws = ww->wrappedString();
   if ( ws.left( ws.length()-1 ).find( '\n' ) >= 0 )
     ww->drawText( &p, eventX, y,
-                  Qt::AlignAuto | KWordWrap::FadeOut );
+                  TQt::AlignAuto | KWordWrap::FadeOut );
   else
     ww->drawText( &p, eventX + (txtWidth-ww->boundingRect().width()-2*margin)/2,
-                  y, Qt::AlignHCenter | KWordWrap::FadeOut );
+                  y, TQt::AlignHCenter | KWordWrap::FadeOut );
   delete ww;
 }
 
