@@ -18,8 +18,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #include <tqhbox.h>
@@ -137,7 +137,7 @@ KOAlternateLabel::KOAlternateLabel(const TQString &shortlabel, const TQString &l
   : TQLabel(parent, name), mTextTypeFixed(false), mShortText(shortlabel),
     mLongText(longlabel), mExtensiveText(extensivelabel)
 {
-  setSizePolicy(TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
+  tqsetSizePolicy(TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
   if (mExtensiveText.isEmpty()) mExtensiveText = mLongText;
   squeezeTextToLabel();
 }
@@ -235,9 +235,9 @@ void KOAlternateLabel::resizeEvent( TQResizeEvent * )
   squeezeTextToLabel();
 }
 
-TQSize KOAlternateLabel::minimumSizeHint() const
+TQSize KOAlternateLabel::tqminimumSizeHint() const
 {
-  TQSize sh = TQLabel::minimumSizeHint();
+  TQSize sh = TQLabel::tqminimumSizeHint();
   sh.setWidth(-1);
   return sh;
 }
@@ -258,7 +258,7 @@ KOAgendaView::KOAgendaView( Calendar *cal,
   mPendingChanges( true ),
   mAreDatesInitialized( false )
 {
-  mSelectedDates.append(TQDate::currentDate());
+  mSelectedDates.append(TQDate::tqcurrentDate());
 
   mLayoutDayLabels = 0;
   mDayLabelsFrame = 0;
@@ -284,7 +284,7 @@ KOAgendaView::KOAgendaView( Calendar *cal,
 
   // Create agenda splitter
 #ifndef KORG_NOSPLITTER
-  mSplitterAgenda = new TQSplitter(Vertical,this);
+  mSplitterAgenda = new TQSplitter(Qt::Vertical,this);
   topLayout->addWidget(mSplitterAgenda);
 
 #if KDE_IS_VERSION( 3, 1, 93 )
@@ -313,12 +313,12 @@ KOAgendaView::KOAgendaView( Calendar *cal,
   if ( KOPrefs::instance()->compactDialogs() ) {
     mExpandButton = new TQPushButton(mDummyAllDayLeft);
     mExpandButton->setPixmap( mNotExpandedPixmap );
-    mExpandButton->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed,
+    mExpandButton->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Fixed,
                                   TQSizePolicy::Fixed ) );
     connect( mExpandButton, TQT_SIGNAL( clicked() ), TQT_SIGNAL( toggleExpand() ) );
   } else {
     TQLabel *label = new TQLabel( i18n("All Day"), mDummyAllDayLeft );
-    label->setAlignment( Qt::AlignRight | Qt::AlignVCenter | Qt::WordBreak );
+    label->tqsetAlignment( TQt::AlignRight | TQt::AlignVCenter | TQt::WordBreak );
   }
 
   mAllDayAgenda = new KOAgenda( 1, calendarView, mAllDayFrame );
@@ -476,7 +476,7 @@ void KOAgendaView::zoomInVertically( )
 
   mTimeLabels->updateConfig();
   mTimeLabels->positionChanged();
-  mTimeLabels->repaint();
+  mTimeLabels->tqrepaint();
 
   updateView();
 }
@@ -493,7 +493,7 @@ void KOAgendaView::zoomOutVertically( )
 
     mTimeLabels->updateConfig();
     mTimeLabels->positionChanged();
-    mTimeLabels->repaint();
+    mTimeLabels->tqrepaint();
 
     updateView();
   }
@@ -584,7 +584,7 @@ void KOAgendaView::zoomView( const int delta, const TQPoint &pos,
     else
       zoomInHorizontally( zoomDate );
   } else {
-    // Vertical zoom
+    // Qt::Vertical zoom
     TQPoint posConstentsOld = mAgenda->gridToContents(pos);
     if ( delta > 0 ) {
       zoomOutVertically();
@@ -627,16 +627,16 @@ void KOAgendaView::createDayLabels( bool force )
     int dW = calsys->dayOfWeek(date);
     TQString veryLongStr = KGlobal::locale()->formatDate( date );
     TQString longstr = i18n( "short_weekday date (e.g. Mon 13)","%1 %2" )
-        .arg( calsys->weekDayName( dW, true ) )
-        .arg( calsys->day(date) );
+        .tqarg( calsys->weekDayName( dW, true ) )
+        .tqarg( calsys->day(date) );
     TQString shortstr = TQString::number(calsys->day(date));
 
     KOAlternateLabel *dayLabel = new KOAlternateLabel(shortstr,
                                                       longstr, veryLongStr, mDayLabels);
     dayLabel->useShortText(); // will be recalculated in updateDayLabelSizes() anyway
     dayLabel->setMinimumWidth(1);
-    dayLabel->setAlignment(TQLabel::AlignHCenter);
-    if (date == TQDate::currentDate()) {
+    dayLabel->tqsetAlignment(TQLabel::AlignHCenter);
+    if (date == TQDate::tqcurrentDate()) {
       TQFont font = dayLabel->font();
       font.setBold(true);
       dayLabel->setFont(font);
@@ -649,9 +649,9 @@ void KOAgendaView::createDayLabels( bool force )
     TQStringList::ConstIterator textit = texts.begin();
     for ( ; textit != texts.end(); ++textit ) {
       // use a KOAlternateLabel so when the text doesn't fit any more a tooltip is used
-      KOAlternateLabel*label = new KOAlternateLabel( (*textit), (*textit), TQString::null, mDayLabels );
+      KOAlternateLabel*label = new KOAlternateLabel( (*textit), (*textit), TQString(), mDayLabels );
       label->setMinimumWidth(1);
-      label->setAlignment(AlignCenter);
+      label->tqsetAlignment(AlignCenter);
       dayLayout->addWidget(label);
     }
 
@@ -662,9 +662,9 @@ void KOAgendaView::createDayLabels( bool force )
       TQString text = it->shortText( date );
       if ( !text.isEmpty() ) {
         // use a KOAlternateLabel so when the text doesn't fit any more a tooltip is used
-        KOAlternateLabel*label = new KOAlternateLabel( text, text, TQString::null, mDayLabels );
+        KOAlternateLabel*label = new KOAlternateLabel( text, text, TQString(), mDayLabels );
         label->setMinimumWidth(1);
-        label->setAlignment(AlignCenter);
+        label->tqsetAlignment(AlignCenter);
         dayLayout->addWidget(label);
       }
     }
@@ -696,7 +696,7 @@ int KOAgendaView::maxDatesHint()
   return 0;
 }
 
-int KOAgendaView::currentDateCount()
+int KOAgendaView::tqcurrentDateCount()
 {
   return mSelectedDates.count();
 }
@@ -783,7 +783,7 @@ void KOAgendaView::updateConfig()
 {
 //  kdDebug(5850) << "KOAgendaView::updateConfig()" << endl;
 
-  // update config for children
+  // update config for tqchildren
   mTimeLabels->updateConfig();
   mAgenda->updateConfig();
   mAllDayAgenda->updateConfig();
@@ -793,7 +793,7 @@ void KOAgendaView::updateConfig()
   mTimeLabels->positionChanged();
 
   // for some reason, this needs to be called explicitly
-  mTimeLabels->repaint();
+  mTimeLabels->tqrepaint();
 
   updateTimeBarWidth();
 
@@ -813,7 +813,7 @@ void KOAgendaView::updateTimeBarWidth()
   int width;
 
   width = mDummyAllDayLeft->fontMetrics().width( i18n("All Day") );
-  width = QMAX( width, mTimeLabels->width() );
+  width = TQMAX( width, mTimeLabels->width() );
 
   mDummyAllDayLeft->setFixedWidth( width );
   mTimeLabels->setFixedWidth( width );
@@ -1343,7 +1343,7 @@ void KOAgendaView::changeIncidenceDisplay( Incidence *incidence, int mode )
   }
 
   // HACK: Update the view if the all-day agenda has been modified.
-  // Do this because there are some layout problems in the
+  // Do this because there are some tqlayout problems in the
   // all-day agenda that are not easily solved, but clearing
   // and redrawing works ok.
   if ( incidence->doesFloat() ) {
@@ -1420,7 +1420,7 @@ void KOAgendaView::fillAgenda()
 
 void KOAgendaView::displayIncidence( Incidence *incidence )
 {
-  TQDate today = TQDate::currentDate();
+  TQDate today = TQDate::tqcurrentDate();
   DateTimeList::iterator t;
 
   // FIXME: use a visitor here
@@ -1523,7 +1523,7 @@ void KOAgendaView::clearView()
 
 CalPrinterBase::PrintType KOAgendaView::printType()
 {
-  if ( currentDateCount() == 1 ) return CalPrinterBase::Day;
+  if ( tqcurrentDateCount() == 1 ) return CalPrinterBase::Day;
   else return CalPrinterBase::Week;
 }
 
