@@ -19,8 +19,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #include "koeditorattachments.h"
@@ -189,7 +189,7 @@ AttachmentEditDialog::AttachmentEditDialog( AttachmentListItem *item,
                    i18n( "Type any string you desire here for the name of the attachment" ) );
   grid->addMultiCellWidget( mLabelEdit, 0, 0, 1, 2 );
 
-  KSeparator *sep = new KSeparator( TQt::Horizontal, topFrame );
+  KSeparator *sep = new KSeparator( Qt::Horizontal, topFrame );
   grid->addMultiCellWidget( sep, 1, 1, 0, 2 );
 
   TQLabel *label = new TQLabel( i18n( "Type:" ), topFrame );
@@ -232,7 +232,7 @@ AttachmentEditDialog::AttachmentEditDialog( AttachmentListItem *item,
   } else {
     uint size = item->attachment()->size();
     grid->addWidget( new TQLabel( i18n( "Size:" ), topFrame ), 4, 0 );
-    grid->addWidget( new TQLabel( TQString::fromLatin1( "%1 (%2)" ).
+    grid->addWidget( new TQLabel( TQString::tqfromLatin1( "%1 (%2)" ).
                                  arg( KIO::convertSize( size ) ).
                                  arg( KGlobal::locale()->formatNumber(
                                         size, 0 ) ), topFrame ), 4, 2 );
@@ -321,8 +321,8 @@ AttachmentIconView::AttachmentIconView( KOEditorAttachments* parent )
   setMode( KIconView::Select );
   setItemTextPos( TQIconView::Right );
   setArrangement( TQIconView::LeftToRight );
-  setMaxItemWidth( QMAX(maxItemWidth(), 250) );
-  setMinimumHeight( QMAX(fontMetrics().height(), 16) + 12 );
+  setMaxItemWidth( TQMAX(maxItemWidth(), 250) );
+  setMinimumHeight( TQMAX(fontMetrics().height(), 16) + 12 );
 
   connect( this, TQT_SIGNAL( dropped ( TQDropEvent *, const TQValueList<TQIconDragItem> & ) ),
            this, TQT_SLOT( handleDrop( TQDropEvent *, const TQValueList<TQIconDragItem> & ) ) );
@@ -337,10 +337,10 @@ KURL AttachmentIconView::tempFileForAttachment( KCal::Attachment *attachment )
 
   KTempFile *file;
   if ( !patterns.empty() ) {
-    file = new KTempFile( TQString::null,
+    file = new KTempFile( TQString(),
                           TQString( patterns.first() ).remove( '*' ),0600 );
   } else {
-    file = new KTempFile( TQString::null, TQString::null, 0600 );
+    file = new KTempFile( TQString(), TQString(), 0600 );
   }
   file->setAutoDelete( true );
   file->file()->open( IO_WriteOnly );
@@ -490,29 +490,29 @@ KOEditorAttachments::KOEditorAttachments( int spacing, TQWidget *parent,
 
   mContextMenu = new KPopupMenu( this );
 
-  KActionCollection* ac = new KActionCollection( this, this );
+  KActionCollection* ac = new KActionCollection( TQT_TQWIDGET(this), TQT_TQOBJECT(this) );
 
-  mOpenAction = new KAction( i18n("Open"), 0, this, TQT_SLOT(slotShow()), ac );
+  mOpenAction = new KAction( i18n("Open"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotShow()), ac );
   mOpenAction->plug( mContextMenu );
 
-  mSaveAsAction = new KAction( i18n( "Save As..." ), 0, this, TQT_SLOT(slotSaveAs()), ac );
+  mSaveAsAction = new KAction( i18n( "Save As..." ), 0, TQT_TQOBJECT(this), TQT_SLOT(slotSaveAs()), ac );
   mSaveAsAction->plug( mContextMenu );
   mContextMenu->insertSeparator();
 
-  mCopyAction = KStdAction::copy(this, TQT_SLOT(slotCopy()), ac );
+  mCopyAction = KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(slotCopy()), ac );
   mCopyAction->plug( mContextMenu );
-  mCutAction = KStdAction::cut(this, TQT_SLOT(slotCut()), ac );
+  mCutAction = KStdAction::cut(TQT_TQOBJECT(this), TQT_SLOT(slotCut()), ac );
   mCutAction->plug( mContextMenu );
-  KAction *action = KStdAction::paste(this, TQT_SLOT(slotPaste()), ac );
+  KAction *action = KStdAction::paste(TQT_TQOBJECT(this), TQT_SLOT(slotPaste()), ac );
   action->plug( mContextMenu );
   mContextMenu->insertSeparator();
 
-  mDeleteAction = new KAction( i18n( "&Remove" ), 0, this, TQT_SLOT(slotRemove()),  ac );
+  mDeleteAction = new KAction( i18n( "&Remove" ), 0, TQT_TQOBJECT(this), TQT_SLOT(slotRemove()),  ac );
   mDeleteAction->plug( mContextMenu );
   mDeleteAction->setShortcut( Key_Delete );
   mContextMenu->insertSeparator();
 
-  mEditAction = new KAction( i18n( "&Properties..." ), 0, this, TQT_SLOT(slotEdit()), ac );
+  mEditAction = new KAction( i18n( "&Properties..." ), 0, TQT_TQOBJECT(this), TQT_SLOT(slotEdit()), ac );
   mEditAction->plug( mContextMenu );
 
   selectionChanged();
@@ -574,7 +574,7 @@ void KOEditorAttachments::handlePasteOrDrop( TQMimeSource* source )
     TQStringList lst = TQStringList::split( '\n', text, FALSE );
     for ( TQStringList::ConstIterator it = lst.constBegin(); it != lst.constEnd(); ++it ) {
       urls.append( *it );
-      labels.append( TQString::null );
+      labels.append( TQString() );
     }
     probablyWeHaveUris = true;
   }
@@ -609,7 +609,7 @@ void KOEditorAttachments::handlePasteOrDrop( TQMimeSource* source )
       if ( mAttachments->findItem( label ) ) {
         label += '~' + randomString( 3 );
       }
-      addUriAttachment( (*it).url(), TQString::null, label, true );
+      addUriAttachment( (*it).url(), TQString(), label, true );
     }
   } else if ( action != DRAG_CANCEL ) {
     if ( probablyWeHaveUris ) {
@@ -622,10 +622,10 @@ void KOEditorAttachments::handlePasteOrDrop( TQMimeSource* source )
         if ( mAttachments->findItem( label ) ) {
           label += '~' + randomString( 3 );
         }
-        addUriAttachment( (*it).url(), TQString::null, label, true );
+        addUriAttachment( (*it).url(), TQString(), label, true );
       }
     } else { // we take anything
-      addDataAttachment( source->encodedData( source->format() ),
+      addDataAttachment( source->tqencodedData( source->format() ),
                          source->format(),
                          KMimeType::mimeType( source->format() )->name() );
     }
@@ -675,7 +675,7 @@ void KOEditorAttachments::slotAddData()
     if ( label.isEmpty() ) {
       label = uri.prettyURL();
     }
-    addUriAttachment( uri.url(), TQString::null, label, true );
+    addUriAttachment( uri.url(), TQString(), label, true );
   }
 }
 
@@ -718,7 +718,7 @@ void KOEditorAttachments::slotRemove()
 
   if ( KMessageBox::questionYesNo(
          this,
-         i18n( "<qt>Do you really want to remove these attachments?<p>%1</qt>" ).arg( labelsStr ),
+         i18n( "<qt>Do you really want to remove these attachments?<p>%1</qt>" ).tqarg( labelsStr ),
          i18n( "Remove Attachment?" ),
          KStdGuiItem::yes(), KStdGuiItem::no(),
          "calendarRemoveAttachments" ) != KMessageBox::Yes ) {
@@ -874,7 +874,7 @@ void KOEditorAttachments::writeIncidence( KCal::Incidence *i )
 
 void KOEditorAttachments::slotCopy()
 {
-    TQApplication::clipboard()->setData( mAttachments->mimeData(), QClipboard::Clipboard );
+    TQApplication::tqclipboard()->setData( mAttachments->mimeData(), TQClipboard::Clipboard );
 }
 
 void KOEditorAttachments::slotCut()
@@ -885,7 +885,7 @@ void KOEditorAttachments::slotCut()
 
 void KOEditorAttachments::slotPaste()
 {
-    handlePasteOrDrop( TQApplication::clipboard()->data() );
+    handlePasteOrDrop( TQApplication::tqclipboard()->data() );
 }
 
 void KOEditorAttachments::selectionChanged()
