@@ -18,8 +18,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 
@@ -426,7 +426,7 @@ void KOEditorGeneral::updateAlarmWidgets( Incidence *incidence )
         remStr = remStr.left( maxLen );
         remStr += etc;
       }
-      mAlarmInfoLabel->setText( i18n( "Triggers %1" ).arg( remStr ) );
+      mAlarmInfoLabel->setText( i18n( "Triggers %1" ).tqarg( remStr ) );
     }
   } else {  // alarm count is 1
     Alarm *alarm = mAlarmList.first();
@@ -465,7 +465,7 @@ void KOEditorGeneral::updateAlarmWidgets( Incidence *incidence )
       mSimpleAlarmBox->hide();
       if ( incidence ) {
         TQString remStr = IncidenceFormatter::reminderStringList( incidence ).first();
-        mAlarmInfoLabel->setText( i18n( "Triggers %1" ).arg( remStr ) );
+        mAlarmInfoLabel->setText( i18n( "Triggers %1" ).tqarg( remStr ) );
       }
     }
   }
@@ -497,7 +497,7 @@ void KOEditorGeneral::readIncidence( Incidence *incidence, Calendar *calendar )
 
   TQString resLabel = IncidenceFormatter::resourceString( calendar, incidence );
   if ( !resLabel.isEmpty() ) {
-    mResourceLabel->setText( i18n( "Calendar: %1" ).arg( resLabel ) );
+    mResourceLabel->setText( i18n( "Calendar: %1" ).tqarg( resLabel ) );
     mResourceLabel->show();
   }
 }
@@ -573,7 +573,7 @@ void KOEditorGeneral::setDescription( const TQString &text )
 
 TQObject *KOEditorGeneral::typeAheadReceiver() const
 {
-  return mSummaryEdit;
+  return TQT_TQOBJECT(mSummaryEdit);
 }
 
 void KOEditorGeneral::updateAttendeeSummary(int count)
