@@ -18,8 +18,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #include <tqtooltip.h>
@@ -135,10 +135,10 @@ TQComboBox *RecurBase::createMonthNameCombo( TQWidget *parent, const char *name
   return combo;
 }
 
-TQBoxLayout *RecurBase::createFrequencySpinBar( TQWidget *parent, TQLayout *layout,
+TQBoxLayout *RecurBase::createFrequencySpinBar( TQWidget *parent, TQLayout *tqlayout,
     TQString everyText, TQString unitText )
 {
-  TQBoxLayout *freqLayout = new TQHBoxLayout( layout );
+  TQBoxLayout *freqLayout = new TQHBoxLayout( tqlayout );
 
   TQString whatsThis = i18n("Sets how often this event or to-do should recur.");
   TQLabel *preLabel = new TQLabel( everyText, parent );
@@ -578,7 +578,7 @@ ExceptionsWidget::ExceptionsWidget( TQWidget *parent, const char *name ) :
 {
   TQBoxLayout *topLayout = new TQVBoxLayout( this );
 
-  TQGroupBox *groupBox = new TQGroupBox( 1, Horizontal, i18n("E&xceptions"),
+  TQGroupBox *groupBox = new TQGroupBox( 1, Qt::Horizontal, i18n("E&xceptions"),
                                        this );
   topLayout->addWidget( groupBox );
 
@@ -590,7 +590,7 @@ ExceptionsWidget::ExceptionsWidget( TQWidget *parent, const char *name ) :
   TQWhatsThis::add( mExceptionDateEdit,
        i18n("A date that should be considered an exception "
       "to the recurrence rules for this event or to-do.") );
-  mExceptionDateEdit->setDate( TQDate::currentDate() );
+  mExceptionDateEdit->setDate( TQDate::tqcurrentDate() );
   boxLayout->addWidget( mExceptionDateEdit, 0, 0 );
 
   TQPushButton *addExceptionButton = new TQPushButton(
@@ -700,7 +700,7 @@ RecurrenceRangeWidget::RecurrenceRangeWidget( TQWidget *parent,
 {
   TQBoxLayout *topLayout = new TQVBoxLayout( this );
 
-  mRangeGroupBox = new TQGroupBox( 1, Horizontal, i18n("Recurrence Range"),
+  mRangeGroupBox = new TQGroupBox( 1, Qt::Horizontal, i18n("Recurrence Range"),
                                   this );
   TQWhatsThis::add( mRangeGroupBox,
        i18n("Sets a range for which these recurrence rules will "
@@ -824,7 +824,7 @@ void RecurrenceRangeWidget::setDateTimes( const TQDateTime &start,
                                           const TQDateTime & )
 {
   mStartDateLabel->setText( i18n("Begins on: %1")
-      .arg( KGlobal::locale()->formatDate( start.date() ) ) );
+      .tqarg( KGlobal::locale()->formatDate( start.date() ) ) );
 }
 
 ///////////////////////// RecurrenceRangeDialog ///////////////////////////
@@ -891,7 +891,7 @@ RecurrenceChooser::RecurrenceChooser( TQWidget *parent, const char *name ) :
   } else {
     mTypeCombo = 0;
 
-    TQButtonGroup *ruleButtonGroup = new TQButtonGroup( 1, Horizontal, this );
+    TQButtonGroup *ruleButtonGroup = new TQButtonGroup( 1, Qt::Horizontal, this );
     ruleButtonGroup->setFrameStyle( TQFrame::NoFrame );
     topLayout->addWidget( ruleButtonGroup );
 
@@ -980,7 +980,7 @@ KOEditorRecurrence::KOEditorRecurrence( TQWidget* parent, const char *name ) :
   topLayout->addMultiCellWidget( mEnabledCheck, 0, 0, 0, 1 );
 
 
-  mTimeGroupBox = new TQGroupBox( 1, Horizontal, i18n("Appointment Time "),
+  mTimeGroupBox = new TQGroupBox( 1, Qt::Horizontal, i18n("Appointment Time "),
                                  this );
   TQWhatsThis::add( mTimeGroupBox,
                    i18n("Displays appointment time information.") );
@@ -999,8 +999,8 @@ KOEditorRecurrence::KOEditorRecurrence( TQWidget* parent, const char *name ) :
 //  layoutTimeFrame->addWidget( mDateTimeLabel );
 
   Qt::Orientation orientation;
-  if ( KOPrefs::instance()->mCompactDialogs ) orientation = Horizontal;
-  else orientation = Vertical;
+  if ( KOPrefs::instance()->mCompactDialogs ) orientation = Qt::Horizontal;
+  else orientation = Qt::Vertical;
 
   mRuleBox = new TQGroupBox( 1, orientation, i18n("Recurrence Rule"), this );
   TQWhatsThis::add( mRuleBox,
@@ -1394,8 +1394,8 @@ bool KOEditorRecurrence::validateInput()
        mEventStartDt.isValid() && ((mRecurrenceRange->endDate())<mEventStartDt.date()) ) {
     KMessageBox::sorry( 0,
       i18n("The end date '%1' of the recurrence must be after the start date '%2' of the event.")
-      .arg( KGlobal::locale()->formatDate( mRecurrenceRange->endDate() ) )
-      .arg( KGlobal::locale()->formatDate( mEventStartDt.date() ) ) );
+      .tqarg( KGlobal::locale()->formatDate( mRecurrenceRange->endDate() ) )
+      .tqarg( KGlobal::locale()->formatDate( mEventStartDt.date() ) ) );
     return false;
   }
   int recurrenceType = mRecurrenceChooser->type();
