@@ -19,8 +19,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #include <tqlayout.h>
@@ -84,7 +84,7 @@ void KOTodoListViewToolTip::maybeTip( const TQPoint & pos)
   {
 
     /* Calculate the rectangle. */
-    r=todolist->itemRect(i);
+    r=todolist->tqitemRect(i);
     headerPos = todolist->header()->sectionPos(col)-todolist->contentsX();
     r.setLeft( (headerPos < 0 ? 0 : headerPos) );
     r.setRight(headerPos + todolist->header()->sectionSize(col));
@@ -797,7 +797,7 @@ void KOTodoView::popupMenu( TQListViewItem *item, const TQPoint &, int column )
       if ( mActiveItem->todo()->hasDueDate () ) {
         mMovePopupMenu->datePicker()->setDate( date );
       } else {
-        mMovePopupMenu->datePicker()->setDate( TQDate::currentDate() );
+        mMovePopupMenu->datePicker()->setDate( TQDate::tqcurrentDate() );
       }
       switch ( column ) {
         case ePriorityColumn:
@@ -815,7 +815,7 @@ void KOTodoView::popupMenu( TQListViewItem *item, const TQPoint &, int column )
           break;
         default:
           mCopyPopupMenu->datePicker()->setDate( date );
-          mCopyPopupMenu->datePicker()->setDate( TQDate::currentDate() );
+          mCopyPopupMenu->datePicker()->setDate( TQDate::tqcurrentDate() );
           mItemPopupMenu->setItemEnabled( ePopupUnSubTodo,
                                           mActiveItem->todo()->relatedTo() );
           mItemPopupMenu->setItemEnabled( ePopupUnAllSubTodo,
@@ -832,7 +832,7 @@ void KOTodoView::newTodo()
 {
   kdDebug() << k_funcinfo << endl;
   emit newTodoSignal( 0/*ResourceCalendar*/, TQString()/*subResource*/,
-                      TQDate::currentDate().addDays(7) );
+                      TQDate::tqcurrentDate().addDays(7) );
 }
 
 void KOTodoView::newSubTodo()
@@ -917,7 +917,7 @@ void KOTodoView::setNewPercentage( KOTodoViewItem *item, int percentage )
       myChild = myChild->nextSibling();
     }*/
     if ( percentage == 100 ) {
-      todo->setCompleted( TQDateTime::currentDateTime() );
+      todo->setCompleted( TQDateTime::tqcurrentDateTime() );
       // If the todo does recur, it doesn't get set as completed. However, the
       // item is still checked. Uncheck it again.
       if ( !todo->isCompleted() ) {
@@ -992,7 +992,7 @@ void KOTodoView::copyTodoToDate( TQDate date )
     newTodo->setDtDue( dt );
     newTodo->setPercentComplete( 0 );
 
-    QPair<ResourceCalendar *, TQString>p =
+    TQPair<ResourceCalendar *, TQString>p =
       CalHelper::incSubResourceCalendar( calendar(), mActiveItem->todo() );
 
     mChanger->addIncidence( newTodo, p.first, p.second, this );
@@ -1065,14 +1065,14 @@ void KOTodoView::itemStateChanged( TQListViewItem *item )
 
 void KOTodoView::setNewPercentageDelayed( KOTodoViewItem *item, int percentage )
 {
-  mPercentChangedMap.append( qMakePair( item, percentage ) );
+  mPercentChangedMap.append( tqMakePair( item, percentage ) );
 
   TQTimer::singleShot( 0, this, TQT_SLOT( processDelayedNewPercentage() ) );
 }
 
 void KOTodoView::processDelayedNewPercentage()
 {
-  TQValueList< QPair< KOTodoViewItem *, int> >::Iterator it;
+  TQValueList< TQPair< KOTodoViewItem *, int> >::Iterator it;
   for ( it = mPercentChangedMap.begin(); it != mPercentChangedMap.end(); ++it )
     setNewPercentage( (*it).first, (*it).second );
 
@@ -1128,7 +1128,7 @@ void KOTodoView::addQuickTodo()
       delete todo;
       return;
     }
-    mQuickAdd->setText( TQString::null );
+    mQuickAdd->setText( TQString() );
   }
 }
 
