@@ -60,7 +60,7 @@ MultiAgendaView::MultiAgendaView( Calendar * cal, CalendarView *calendarView,
   mLeftSplitter = new TQSplitter( Qt::Vertical, topSideBox );
   mLeftSplitter->setOpaqueResize( KGlobalSettings::opaqueResize() );
   TQLabel *label = new TQLabel( i18n("All Day"), mLeftSplitter );
-  label->setAlignment( Qt::AlignRight | Qt::AlignVCenter | Qt::WordBreak );
+  label->tqsetAlignment( TQt::AlignRight | TQt::AlignVCenter | TQt::WordBreak );
   TQVBox *sideBox = new TQVBox( mLeftSplitter );
   EventIndicator *eiSpacer = new EventIndicator( EventIndicator::Top, sideBox );
   eiSpacer->changeColumns( 0 );
@@ -265,7 +265,7 @@ void MultiAgendaView::setupViews()
 
   int minWidth = 0;
   for ( TQValueList<TQWidget*>::ConstIterator it = mAgendaWidgets.constBegin(); it != mAgendaWidgets.constEnd(); ++it )
-    minWidth = QMAX( minWidth, (*it)->minimumSizeHint().width() );
+    minWidth = TQMAX( minWidth, (*it)->tqminimumSizeHint().width() );
   for ( TQValueList<TQWidget*>::ConstIterator it = mAgendaWidgets.constBegin(); it != mAgendaWidgets.constEnd(); ++it )
     (*it)->setMinimumWidth( minWidth );
 }
@@ -292,10 +292,10 @@ DateList MultiAgendaView::selectedIncidenceDates()
   return list;
 }
 
-int MultiAgendaView::currentDateCount()
+int MultiAgendaView::tqcurrentDateCount()
 {
   FOREACH_VIEW( agendaView )
-    return agendaView->currentDateCount();
+    return agendaView->tqcurrentDateCount();
   return 0;
 }
 
@@ -427,7 +427,7 @@ void MultiAgendaView::resizeEvent(TQResizeEvent * ev)
 void MultiAgendaView::resizeScrollView(const TQSize & size)
 {
   const int widgetWidth = size.width() - mTimeLabels->width() - mScrollBar->width();
-  int width = QMAX( mTopBox->sizeHint().width(), widgetWidth );
+  int width = TQMAX( mTopBox->tqsizeHint().width(), widgetWidth );
   int height = size.height();
   if ( width > widgetWidth ) {
     const int sbHeight = mScrollView->horizontalScrollBar()->height();
@@ -459,17 +459,17 @@ void MultiAgendaView::updateConfig()
 
 bool MultiAgendaView::eventFilter(TQObject * obj, TQEvent * event)
 {
-  if ( obj->className() == TQCString("QSplitterHandle") ) {
+  if ( obj->className() == TQCString(TQSPLITTERHANDLE_OBJECT_NAME_STRING) ) {
     // KDE4: not needed anymore, TQSplitter has a moved signal there
     if ( (event->type() == TQEvent::MouseMove && KGlobalSettings::opaqueResize())
            || event->type() == TQEvent::MouseButtonRelease ) {
       FOREACH_VIEW( agenda ) {
-        if ( agenda->splitter() == obj->parent() )
+        if ( TQT_BASE_OBJECT(agenda->splitter()) == TQT_BASE_OBJECT(obj->parent()) )
           mLastMovedSplitter = agenda->splitter();
       }
-      if ( mLeftSplitter == obj->parent() )
+      if ( TQT_BASE_OBJECT(mLeftSplitter )== TQT_BASE_OBJECT(obj->parent()) )
         mLastMovedSplitter = mLeftSplitter;
-      else if ( mRightSplitter == obj->parent() )
+      else if ( TQT_BASE_OBJECT(mRightSplitter) == TQT_BASE_OBJECT(obj->parent()) )
         mLastMovedSplitter = mRightSplitter;
       TQTimer::singleShot( 0, this, TQT_SLOT(resizeSplitters()) );
     }
@@ -536,13 +536,13 @@ void MultiAgendaView::zoomView( const int delta, const TQPoint & pos, const Qt::
 
   mTimeLabels->updateConfig();
   mTimeLabels->positionChanged();
-  mTimeLabels->repaint();
+  mTimeLabels->tqrepaint();
 }
 
 // KDE4: not needed, use existing TQSplitter signals instead
 void MultiAgendaView::installSplitterEventFilter(TQSplitter * splitter)
 {
-  TQObjectList *objlist = splitter->queryList( "QSplitterHandle" );
+  TQObjectList *objlist = splitter->queryList( TQSPLITTERHANDLE_OBJECT_NAME_STRING );
   // HACK: when not being visible, the splitter handle is sometimes not found
   // for unknown reasons, so trigger an update when we are shown again
   if ( objlist->count() == 0 && !isVisible() )
