@@ -27,7 +27,10 @@
 */
 class ConfigDialog:public KDialogBase
 {
-Q_OBJECT public:
+  Q_OBJECT
+  TQ_OBJECT
+
+public:
 
   ConfigDialog(TQWidget * parent = 0);
   virtual ~ ConfigDialog();
