@@ -21,8 +21,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #ifndef KORG_NOPRINTER
@@ -144,7 +144,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
           event->dtStart(), event->doesFloat(), false );
       } else {
         mStartCaption = i18n( "No start date" );
-        mStartString = TQString::null;
+        mStartString = TQString();
       }
 
       if ( event->hasEndDate() ) {
@@ -162,7 +162,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
         }
       } else {
         mEndCaption = i18n("No end date");
-        mEndString = TQString::null;
+        mEndString = TQString();
       }
       return true;
     }
@@ -173,7 +173,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
           todo->dtStart(), todo->doesFloat(), false );
       } else {
         mStartCaption = i18n( "No start date" );
-        mStartString = TQString::null;
+        mStartString = TQString();
       }
 
       if ( todo->hasDueDate() ) {
@@ -182,7 +182,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
           todo->dtDue(), todo->doesFloat(), false );
       } else {
         mEndCaption = i18n("No due date");
-        mEndString = TQString::null;
+        mEndString = TQString();
       }
       return true;
     }
@@ -190,8 +190,8 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
       mStartCaption = i18n( "Start date: " );
       mStartString = IncidenceFormatter::dateTimeToString(
         journal->dtStart(), journal->doesFloat(), false );
-      mEndCaption = TQString::null;
-      mEndString = TQString::null;
+      mEndCaption = TQString();
+      mEndString = TQString();
       return true;
     }
 };
@@ -204,12 +204,12 @@ int CalPrintIncidence::printCaptionAndText( TQPainter &p, const TQRect &box, con
 
   TQFont oldFont( p.font() );
   p.setFont( captionFont );
-  p.drawText( box, Qt::AlignLeft|Qt::AlignTop|Qt::SingleLine, caption );
+  p.drawText( box, TQt::AlignLeft|TQt::AlignTop|TQt::SingleLine, caption );
 
   if ( !text.isEmpty() ) {
     textRect.setLeft( textRect.left() + textWd );
     p.setFont( textFont );
-    p.drawText( textRect, Qt::AlignLeft|Qt::AlignTop|Qt::SingleLine, text );
+    p.drawText( textRect, TQt::AlignLeft|TQt::AlignTop|TQt::SingleLine, text );
   }
   p.setFont( oldFont );
   return textRect.bottom();
@@ -283,7 +283,7 @@ void CalPrintIncidence::print( TQPainter &p, int width, int height )
 
       textRect.setLeft( textRect.right() );
       textRect.setRight( timesBox.right() - padding() );
-      h = QMAX( printCaptionAndText( p, textRect, stringVis.mEndCaption, stringVis.mEndString, captionFont, textFont ), h );
+      h = TQMAX( printCaptionAndText( p, textRect, stringVis.mEndCaption, stringVis.mEndString, captionFont, textFont ), h );
     }
 
     // Convert recurrence to a string
@@ -303,7 +303,7 @@ void CalPrintIncidence::print( TQPainter &p, int width, int height )
         }
       }
       displayString.append(exceptString);
-      h = QMAX( printCaptionAndText( p, recurBox, i18n( "Repeats: "), displayString, captionFont, textFont ), h );
+      h = TQMAX( printCaptionAndText( p, recurBox, i18n( "Repeats: "), displayString, captionFont, textFont ), h );
     }
 
     // Alarms Printing
@@ -346,27 +346,27 @@ void CalPrintIncidence::print( TQPainter &p, int width, int height )
 
         if ( offset % (24*60) == 0 && offset>0 ) { // divides evenly into days?
           useoffset = offset / (24*60);
-          offsetstr = offsetstr.arg( i18n("1 day", "%n days", useoffset ) );
+          offsetstr = offsetstr.tqarg( i18n("1 day", "%n days", useoffset ) );
         } else if (offset % 60 == 0 && offset>0 ) { // divides evenly into hours?
           useoffset = offset / 60;
-          offsetstr = offsetstr.arg( i18n("1 hour", "%n hours", useoffset ) );
+          offsetstr = offsetstr.tqarg( i18n("1 hour", "%n hours", useoffset ) );
         } else {
           useoffset = offset;
-          offsetstr = offsetstr.arg( i18n("1 minute", "%n minutes", useoffset ) );
+          offsetstr = offsetstr.tqarg( i18n("1 minute", "%n minutes", useoffset ) );
         }
         alarmStrings << offsetstr;
       }
       txt = alarmStrings.join( i18n("Spacer for the joined list of categories", ", ") );
 
     }
-    h = QMAX( printCaptionAndText( p, alarmBox, cap, txt, captionFont, textFont ), h );
+    h = TQMAX( printCaptionAndText( p, alarmBox, cap, txt, captionFont, textFont ), h );
 
 
     TQRect organizerBox( timesBox.left()+padding(), h+padding(), timesBox.right()-padding(), lineHeight );
-    h = QMAX( printCaptionAndText( p, organizerBox, i18n("Organizer: "), (*it)->organizer().fullName(), captionFont, textFont ), h );
+    h = TQMAX( printCaptionAndText( p, organizerBox, i18n("Organizer: "), (*it)->organizer().fullName(), captionFont, textFont ), h );
 
     // Finally, draw the frame around the time information...
-    timesBox.setBottom( QMAX( timesBox.bottom(), h+padding() ) );
+    timesBox.setBottom( TQMAX( timesBox.bottom(), h+padding() ) );
     drawBox( p, BOX_BORDER_WIDTH, timesBox );
 
 
@@ -439,10 +439,10 @@ void CalPrintIncidence::print( TQPainter &p, int width, int height )
     if ( mShowSubitemsNotes ) {
       if ( (*it)->relations().isEmpty() || (*it)->type() != "Todo" ) {
         int notesPosition = drawBoxWithCaption( p, notesBox, i18n("Notes:"),
-                         TQString::null, /*sameLine=*/false, /*expand=*/false,
+                         TQString(), /*sameLine=*/false, /*expand=*/false,
                          captionFont, textFont );
         TQPen oldPen( p.pen() );
-        p.setPen( Qt::DotLine );
+        p.setPen( TQt::DotLine );
         while ( (notesPosition += int(1.5*lineHeight)) < notesBox.bottom() ) {
           p.drawLine( notesBox.left()+padding(), notesPosition, notesBox.right()-padding(), notesPosition );
         }
@@ -481,24 +481,24 @@ void CalPrintIncidence::print( TQPainter &p, int width, int height )
           datesString = "";
           if ( (*rit)->dtStart().isValid() ) {
                 datesString += i18n(
-                "Start Date: %1\n").arg(
+                "Start Date: %1\n").tqarg(
                 KGlobal::locale()->formatDate( (*rit)->dtStart().date(),
                                 true ) );
             if ( !(*rit)->doesFloat() ) {
                 datesString += i18n(
-                "Start Time: %1\n").arg(
+                "Start Time: %1\n").tqarg(
                 KGlobal::locale()->formatTime((*rit)->dtStart().time(),
                      false, false) );
             }
           }
           if ( (*rit)->dtEnd().isValid() ) {
             subitemString += i18n(
-                "Due Date: %1\n").arg(
+                "Due Date: %1\n").tqarg(
                 KGlobal::locale()->formatDate( (*rit)->dtEnd().date(),
                                 true ) );
             if ( !(*rit)->doesFloat() ) {
               subitemString += i18n(
-                  "subitem due time", "Due Time: %1\n").arg(
+                  "subitem due time", "Due Time: %1\n").tqarg(
                   KGlobal::locale()->formatTime((*rit)->dtEnd().time(),
                       false, false) );
             }
@@ -511,12 +511,12 @@ void CalPrintIncidence::print( TQPainter &p, int width, int height )
             subitemString += "\n";
           }
           subitemString += i18n( "subitem Status: statusString",
-                                  "Status: %1\n").arg( statusString );
+                                  "Status: %1\n").tqarg( statusString );
           subitemString += IncidenceFormatter::recurrenceString((*rit)) + "\n";
           subitemString += i18n( "subitem Priority: N",
-                                  "Priority: %1\n").arg( (*rit)->priority() );
+                                  "Priority: %1\n").tqarg( (*rit)->priority() );
           subitemString += i18n( "subitem Secrecy: secrecyString",
-                                  "Secrecy: %1\n").arg( (*rit)->secrecyStr() );
+                                  "Secrecy: %1\n").tqarg( (*rit)->secrecyStr() );
           subitemString += "\n";
         }
         drawBoxWithCaption( p, notesBox, i18n("Subitems:"),
@@ -562,8 +562,8 @@ void CalPrintIncidence::print( TQPainter &p, int width, int height )
                "'Name (Role): Status', e.g. 'Reinhold Kainhofer "
                "<reinhold@kainhofer.com> (Participant): Awaiting Response'",
                "%1 (%2): %3")
-                       .arg( (*ait)->fullName() )
-                       .arg( (*ait)->roleStr() ).arg( (*ait)->statusStr() );
+                       .tqarg( (*ait)->fullName() )
+                       .tqarg( (*ait)->roleStr() ).tqarg( (*ait)->statusStr() );
       }
       drawBoxWithCaption( p, attendeesBox, i18n("Attendees:"), attendeeString,
                /*sameLine=*/false, /*expand=*/false, captionFont, textFont );
@@ -572,11 +572,11 @@ void CalPrintIncidence::print( TQPainter &p, int width, int height )
     if ( mShowOptions ) {
       TQString optionsString;
       if ( !(*it)->statusStr().isEmpty() ) {
-        optionsString += i18n("Status: %1").arg( (*it)->statusStr() );
+        optionsString += i18n("Status: %1").tqarg( (*it)->statusStr() );
         optionsString += "\n";
       }
       if ( !(*it)->secrecyStr().isEmpty() ) {
-        optionsString += i18n("Secrecy: %1").arg( (*it)->secrecyStr() );
+        optionsString += i18n("Secrecy: %1").tqarg( (*it)->secrecyStr() );
         optionsString += "\n";
       }
       if ( (*it)->type() == "Event" ) {
@@ -740,8 +740,8 @@ void CalPrintDay::print( TQPainter &p, int width, int height )
     uint lineSpacing = p.fontMetrics().lineSpacing();
 
     uint maxAllDayEvents = 8; // the max we allow to be printed, sorry.
-    uint allDayHeight = QMIN( alldayEvents.count(), maxAllDayEvents ) * lineSpacing;
-    allDayHeight = QMAX( allDayHeight, ( 5 * lineSpacing ) ) + ( 2 * padding() );
+    uint allDayHeight = TQMIN( alldayEvents.count(), maxAllDayEvents ) * lineSpacing;
+    allDayHeight = TQMAX( allDayHeight, ( 5 * lineSpacing ) ) + ( 2 * padding() );
     TQRect allDayBox( TIMELINE_WIDTH + padding(), headerBox.bottom() + padding(),
                      width - TIMELINE_WIDTH - padding(), allDayHeight );
     if ( alldayEvents.count() > 0 ) {
@@ -936,7 +936,7 @@ void CalPrintWeek::print( TQPainter &p, int width, int height )
         } else {
           title = i18n("date from-\nto", "%1 -\n%2");;
         }
-        title = title.arg( line1 ).arg( line2 );
+        title = title.tqarg( line1 ).tqarg( line2 );
         drawHeader( p, title, curWeek.addDays( -6 ), TQDate(), headerBox );
 
         drawWeek( p, curWeek, weekBox );
@@ -959,7 +959,7 @@ void CalPrintWeek::print( TQPainter &p, int width, int height )
         } else {
           title = i18n("date from -\nto (week number)", "%1 -\n%2 (Week %3)");
         }
-        title = title.arg( line1 ).arg( line2 ).arg( curWeek.weekNumber() );
+        title = title.tqarg( line1 ).tqarg( line2 ).tqarg( curWeek.weekNumber() );
         drawHeader( p, title, curWeek, TQDate(), headerBox );
 
         TQRect weekBox( headerBox );
@@ -1121,8 +1121,8 @@ void CalPrintMonth::print( TQPainter &p, int width, int height )
 
   do {
     TQString title( i18n("monthname year", "%1 %2") );
-    title = title.arg( calSys->monthName( curMonth ) )
-                 .arg( curMonth.year() );
+    title = title.tqarg( calSys->monthName( curMonth ) )
+                 .tqarg( curMonth.year() );
     TQDate tmp( fromMonth );
     int weekdayCol = weekdayColumn( tmp.dayOfWeek() );
     tmp = tmp.addDays( -weekdayCol );
