@@ -19,8 +19,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    with any edition of TQt, and distribute the resulting executable,
+    without including the source code for TQt in the source distribution.
 */
 
 #include <tqpainter.h>
@@ -128,7 +128,7 @@ CalPrintPluginBase::~CalPrintPluginBase()
 TQWidget *CalPrintPluginBase::createConfigWidget( TQWidget *w )
 {
   TQFrame *wdg = new TQFrame( w );
-  TQVBoxLayout *layout = new TQVBoxLayout( wdg );
+  TQVBoxLayout *tqlayout = new TQVBoxLayout( wdg );
 
   TQLabel *title = new TQLabel( description(), wdg );
   TQFont titleFont( title->font() );
@@ -136,13 +136,13 @@ TQWidget *CalPrintPluginBase::createConfigWidget( TQWidget *w )
   titleFont.setBold( true );
   title->setFont( titleFont );
 
-  layout->addWidget( title );
-  layout->addWidget( new TQLabel( info(), wdg ) );
-  layout->addSpacing( 20 );
-  layout->addWidget( new TQLabel( i18n("This printing style does not "
+  tqlayout->addWidget( title );
+  tqlayout->addWidget( new TQLabel( info(), wdg ) );
+  tqlayout->addSpacing( 20 );
+  tqlayout->addWidget( new TQLabel( i18n("This printing style does not "
                                       "have any configuration options."),
                                  wdg ) );
-  layout->addStretch();
+  tqlayout->addStretch();
   return wdg;
 }
 
@@ -156,7 +156,7 @@ void CalPrintPluginBase::doPrint( KPrinter *printer )
 
   p.begin( mPrinter );
   // TODO: Fix the margins!!!
-  // the painter initially begins at 72 dpi per the Qt docs.
+  // the painter initially begins at 72 dpi per the TQt docs.
   // we want half-inch margins.
   int margins = margin();
   p.setViewport( margins, margins,
@@ -182,7 +182,7 @@ void CalPrintPluginBase::doLoadConfig()
   if ( mConfig ) {
     KConfigGroupSaver saver( mConfig, description() );
     mConfig->sync();
-    TQDateTime currDate( TQDate::currentDate() );
+    TQDateTime currDate( TQDate::tqcurrentDate() );
     mFromDate = mConfig->readDateTimeEntry( "FromDate", &currDate ).date();
     mToDate = mConfig->readDateTimeEntry( "ToDate" ).date();
     mUseColors = mConfig->readBoolEntry( "UseColors", true );
@@ -270,7 +270,7 @@ bool CalPrintPluginBase::isWorkingDay( const TQDate &dt )
 
 TQString CalPrintPluginBase::holidayString( const TQDate &dt )
 {
-  return (mCoreHelper)?(mCoreHelper->holidayString(dt)):(TQString::null);
+  return (mCoreHelper)?(mCoreHelper->holidayString(dt)):(TQString());
 }
 
 
@@ -387,7 +387,7 @@ void CalPrintPluginBase::printEventString( TQPainter &p, const TQRect &box, cons
 {
   TQRect newbox( box );
   newbox.addCoords( 3, 1, -1, -1 );
-  p.drawText( newbox, (flags==-1)?(Qt::AlignTop | Qt::AlignJustify | Qt::BreakAnywhere):flags, str );
+  p.drawText( newbox, (flags==-1)?(TQt::AlignTop | TQt::AlignJustify | TQt::BreakAnywhere):flags, str );
 }
 
 
@@ -418,7 +418,7 @@ void CalPrintPluginBase::drawSubHeaderBox(TQPainter &p, const TQString &str, con
   drawShadedBox( p, BOX_BORDER_WIDTH, TQColor( 232, 232, 232 ), box );
   TQFont oldfont( p.font() );
   p.setFont( TQFont( "sans-serif", 10, TQFont::Bold ) );
-  p.drawText( box, Qt::AlignCenter | Qt::AlignVCenter, str );
+  p.drawText( box, TQt::AlignCenter | TQt::AlignVCenter, str );
   p.setFont( oldfont );
 }
 
@@ -429,7 +429,7 @@ void CalPrintPluginBase::drawVerticalBox( TQPainter &p, int linewidth, const TQR
   p.rotate( -90 );
   TQRect rotatedBox( -box.top()-box.height(), box.left(), box.height(), box.width() );
   showEventBox( p, linewidth, rotatedBox, 0, str,
-                ( flags == -1 ) ? Qt::AlignLeft | Qt::AlignVCenter | Qt::SingleLine : flags );
+                ( flags == -1 ) ? TQt::AlignLeft | TQt::AlignVCenter | TQt::SingleLine : flags );
 
   p.restore();
 }
@@ -455,7 +455,7 @@ int CalPrintPluginBase::drawBoxWithCaption( TQPainter &p, const TQRect &allbox,
   // Bounding rectangle for caption, single-line, clip on the right
   TQRect captionBox( box.left() + padding(), box.top() + padding(), 0, 0 );
   p.setFont( captionFont );
-  captionBox = p.boundingRect( captionBox, Qt::AlignLeft | Qt::AlignTop | Qt::SingleLine, caption );
+  captionBox = p.boundingRect( captionBox, TQt::AlignLeft | TQt::AlignTop | TQt::SingleLine, caption );
   p.setFont( oldFont );
   if ( captionBox.right() > box.right() )
     captionBox.setRight( box.right() );
@@ -473,7 +473,7 @@ int CalPrintPluginBase::drawBoxWithCaption( TQPainter &p, const TQRect &allbox,
     textBox.setRight( box.right() );
     textBox.setHeight( 0 );
     p.setFont( textFont );
-    textBox = p.boundingRect( textBox, Qt::WordBreak | Qt::AlignTop | Qt::AlignLeft, contents );
+    textBox = p.boundingRect( textBox, TQt::WordBreak | TQt::AlignTop | TQt::AlignLeft, contents );
     p.setFont( oldFont );
     if ( textBox.bottom() + padding() > box.bottom() ) {
       if ( expand ) {
@@ -486,10 +486,10 @@ int CalPrintPluginBase::drawBoxWithCaption( TQPainter &p, const TQRect &allbox,
 
   drawBox( p, BOX_BORDER_WIDTH, box );
   p.setFont( captionFont );
-  p.drawText( captionBox, Qt::AlignLeft | Qt::AlignTop | Qt::SingleLine, caption );
+  p.drawText( captionBox, TQt::AlignLeft | TQt::AlignTop | TQt::SingleLine, caption );
   if ( !contents.isEmpty() ) {
     p.setFont( textFont );
-    p.drawText( textBox, Qt::WordBreak | Qt::AlignTop | Qt::AlignLeft, contents );
+    p.drawText( textBox, TQt::WordBreak | TQt::AlignTop | TQt::AlignLeft, contents );
   }
   p.setFont( oldFont );
 
@@ -523,7 +523,7 @@ int CalPrintPluginBase::drawHeader( TQPainter &p, TQString title,
   TQFont newFont("sans-serif", (textRect.height()<60)?16:18, TQFont::Bold);
   if ( expand ) {
     p.setFont( newFont );
-    TQRect boundingR = p.boundingRect( textRect, Qt::AlignLeft | Qt::AlignVCenter | Qt::WordBreak, title );
+    TQRect boundingR = p.boundingRect( textRect, TQt::AlignLeft | TQt::AlignVCenter | TQt::WordBreak, title );
     p.setFont( oldFont );
     int h = boundingR.height();
     if ( h > allbox.height() ) {
@@ -546,7 +546,7 @@ int CalPrintPluginBase::drawHeader( TQPainter &p, TQString title,
 
   // Set the margins
   p.setFont( newFont );
-  p.drawText( textRect, Qt::AlignLeft | Qt::AlignVCenter | Qt::WordBreak, title );
+  p.drawText( textRect, TQt::AlignLeft | TQt::AlignVCenter | TQt::WordBreak, title );
   p.setFont( oldFont );
 
   return textRect.bottom();
@@ -558,9 +558,9 @@ int CalPrintPluginBase::drawFooter( TQPainter &p, TQRect &footbox )
   TQFont oldfont( p.font() );
   p.setFont( TQFont( "sans-serif", 6 ) );
   TQFontMetrics fm( p.font() );
-  TQString dateStr = KGlobal::locale()->formatDateTime( TQDateTime::currentDateTime(), false );
+  TQString dateStr = KGlobal::locale()->formatDateTime( TQDateTime::tqcurrentDateTime(), false );
   p.drawText( footbox, TQt::AlignCenter | TQt::AlignVCenter | TQt::SingleLine,
-              i18n( "print date: formatted-datetime", "printed: %1" ).arg( dateStr ) );
+              i18n( "print date: formatted-datetime", "printed: %1" ).tqarg( dateStr ) );
   p.setFont( oldfont );
 
   return footbox.bottom();
@@ -587,7 +587,7 @@ void CalPrintPluginBase::drawSmallMonth(TQPainter &p, const TQDate &qd,
   if ( mCalSys ) {
     TQRect titleBox( box );
     titleBox.setHeight( int(cellHeight+1) );
-    p.drawText( titleBox, Qt::AlignTop | Qt::AlignHCenter, mCalSys->monthName( qd ) );
+    p.drawText( titleBox, TQt::AlignTop | TQt::AlignHCenter, mCalSys->monthName( qd ) );
   }
 
   // draw days of week
@@ -600,7 +600,7 @@ void CalPrintPluginBase::drawSmallMonth(TQPainter &p, const TQDate &qd,
       TQString tmpStr = mCalSys->weekDayName( monthDate2 )[0].upper();
       wdayBox.setLeft( int(box.left() + col*cellWidth) );
       wdayBox.setRight( int(box.left() + (col+1)*cellWidth) );
-      p.drawText( wdayBox, Qt::AlignCenter, tmpStr );
+      p.drawText( wdayBox, TQt::AlignCenter, tmpStr );
       monthDate2 = monthDate2.addDays( 1 );
     }
   }
@@ -616,7 +616,7 @@ void CalPrintPluginBase::drawSmallMonth(TQPainter &p, const TQDate &qd,
         TQRect dayRect( int( box.left() + col*cellWidth ), int( calStartY + row*cellHeight ), 0, 0 );
         dayRect.setRight( int( box.left() + (col+1)*cellWidth ) );
         dayRect.setBottom( int( calStartY + (row+1)*cellHeight ) );
-        p.drawText( dayRect, Qt::AlignCenter, TQString::number( monthDate.day() ) );
+        p.drawText( dayRect, TQt::AlignCenter, TQString::number( monthDate.day() ) );
       }
       monthDate = monthDate.addDays(1);
     }
@@ -655,7 +655,7 @@ void CalPrintPluginBase::drawDaysOfWeek(TQPainter &p,
 void CalPrintPluginBase::drawDaysOfWeekBox(TQPainter &p, const TQDate &qd,
     const TQRect &box )
 {
-  drawSubHeaderBox( p, (mCalSys)?(mCalSys->weekDayName( qd )):(TQString::null), box );
+  drawSubHeaderBox( p, (mCalSys)?(mCalSys->weekDayName( qd )):(TQString()), box );
 }
 
 
@@ -699,10 +699,10 @@ void CalPrintPluginBase::drawTimeLine( TQPainter &p, const TQTime &fromTime,
           p.setFont( TQFont( "sans-serif", 12, TQFont::Bold ) );
         }
         p.drawText( box.left() + 4, (int)currY + 2, box.width() / 2 - 2, (int)cellHeight,
-                    Qt::AlignTop | Qt::AlignRight, numStr );
+                    TQt::AlignTop | TQt::AlignRight, numStr );
         p.setFont( TQFont ( "helvetica", 10, TQFont::Normal ) );
         p.drawText( xcenter + 4, (int)currY + 2, box.width() / 2 + 2, (int)(cellHeight / 2 ) - 3,
-                    Qt::AlignTop | Qt::AlignLeft, "00" );
+                    TQt::AlignTop | TQt::AlignLeft, "00" );
       } else {
         p.drawLine( box.left(), (int)newY, box.right(), (int)newY );
         TQTime time( curTime.hour(), 0 );
@@ -713,7 +713,7 @@ void CalPrintPluginBase::drawTimeLine( TQPainter &p, const TQTime &fromTime,
           p.setFont( TQFont( "sans-serif", 12, TQFont::Bold ) ); // for dayprint
         }
         p.drawText( box.left() + 2, (int)currY + 2, box.width() - 4, (int)cellHeight / 2 - 3,
-                    Qt::AlignTop|Qt::AlignLeft, numStr );
+                    TQt::AlignTop|TQt::AlignLeft, numStr );
       }
       currY += cellHeight;
       p.setFont( oldFont );
@@ -933,9 +933,9 @@ void CalPrintPluginBase::drawDayBox( TQPainter &p, const TQDate &qd,
   if ( fullDate && mCalSys ) {
 
     dayNumStr = i18n("weekday month date", "%1 %2 %3")
-        .arg( mCalSys->weekDayName( qd ) )
-        .arg( mCalSys->monthName( qd ) )
-        .arg( qd.day() );
+        .tqarg( mCalSys->weekDayName( qd ) )
+        .tqarg( mCalSys->monthName( qd ) )
+        .tqarg( qd.day() );
 //    dayNumStr = local->formatDate(qd);
   } else {
     dayNumStr = TQString::number( qd.day() );
@@ -955,10 +955,10 @@ void CalPrintPluginBase::drawDayBox( TQPainter &p, const TQDate &qd,
   if (!hstring.isEmpty()) {
     p.setFont( TQFont( "sans-serif", 8, TQFont::Bold, true ) );
 
-    p.drawText( headerTextBox, Qt::AlignLeft | Qt::AlignVCenter, hstring );
+    p.drawText( headerTextBox, TQt::AlignLeft | TQt::AlignVCenter, hstring );
   }
   p.setFont(TQFont("sans-serif", 10, TQFont::Bold));
-  p.drawText( headerTextBox, Qt::AlignRight | Qt::AlignVCenter, dayNumStr);
+  p.drawText( headerTextBox, TQt::AlignRight | TQt::AlignVCenter, dayNumStr);
 
   Event::List eventList = mCalendar->events( qd,
                                              EventSortStartDate,
@@ -984,7 +984,7 @@ void CalPrintPluginBase::drawDayBox( TQPainter &p, const TQDate &qd,
     TQString str;
     if ( !currEvent->location().isEmpty() ) {
       str = i18n( "summary, location", "%1, %2" ).
-            arg( currEvent->summary() ).arg( currEvent->location() );
+            tqarg( currEvent->summary() ).tqarg( currEvent->location() );
     } else {
       str = currEvent->summary();
     }
@@ -1008,7 +1008,7 @@ void CalPrintPluginBase::drawDayBox( TQPainter &p, const TQDate &qd,
       TQString summaryStr;
       if ( !todo->location().isEmpty() ) {
         summaryStr = i18n( "summary, location", "%1, %2" ).
-                     arg( todo->summary() ).arg( todo->location() );
+                     tqarg( todo->summary() ).tqarg( todo->location() );
       } else {
         summaryStr = todo->summary();
       }
@@ -1026,7 +1026,7 @@ void CalPrintPluginBase::drawDayBox( TQPainter &p, const TQDate &qd,
       } else {
         str = summaryStr;
       }
-      drawIncidence( p, box, timeText, i18n("To-do: %1").arg( str ), textY );
+      drawIncidence( p, box, timeText, i18n("To-do: %1").tqarg( str ), textY );
     }
   }
 
@@ -1038,7 +1038,7 @@ void CalPrintPluginBase::drawIncidence( TQPainter &p, const TQRect &dayBox, cons
 {
   kdDebug(5850) << "summary = " << summary << endl;
 
-  int flags = Qt::AlignLeft;
+  int flags = TQt::AlignLeft;
   TQFontMetrics fm = p.fontMetrics();
   TQRect timeBound = p.boundingRect( dayBox.x() + 5, dayBox.y() + textY,
                                     dayBox.width() - 10, fm.lineSpacing(),
@@ -1180,7 +1180,7 @@ void CalPrintPluginBase::drawMonth( TQPainter &p, const TQDate &dt, const TQRect
   if ( daysinmonth<maxdays ) {
     TQRect dayBox( box.left(), daysBox.top() + round(dayheight*daysinmonth), box.width(), 0 );
     dayBox.setBottom( daysBox.bottom() );
-    p.fillRect( dayBox, Qt::DiagCrossPattern );
+    p.fillRect( dayBox, TQt::DiagCrossPattern );
   }
   // Backgrounded boxes for each day, plus day numbers
   TQBrush oldbrush( p.brush() );
@@ -1195,7 +1195,7 @@ void CalPrintPluginBase::drawMonth( TQPainter &p, const TQDate &dt, const TQRect
     p.drawRect( dayBox );
     TQRect dateBox( dayBox );
     dateBox.setWidth( dayNrWidth+3 );
-    p.drawText( dateBox, Qt::AlignRight | Qt::AlignVCenter | Qt::SingleLine,
+    p.drawText( dateBox, TQt::AlignRight | TQt::AlignVCenter | TQt::SingleLine,
                 TQString::number(d+1) );
   }
   p.setBrush( oldbrush );
@@ -1318,7 +1318,7 @@ void CalPrintPluginBase::drawMonth( TQPainter &p, const TQDate &dt, const TQRect
            14, 0 );
     eventBox.setBottom( daysBox.top() + round( double( minsToEnd*daysBox.height()) / double(maxdays*24*60) ) );
     drawVerticalBox( p, 0, eventBox, placeItem->event()->summary() );
-    newxstartcont = QMAX( newxstartcont, eventBox.right() );
+    newxstartcont = TQMAX( newxstartcont, eventBox.right() );
   }
   xstartcont = newxstartcont;
 
@@ -1330,10 +1330,10 @@ void CalPrintPluginBase::drawMonth( TQPainter &p, const TQDate &dt, const TQRect
     TQRect dayBox( xstartcont, daysBox.top()+round(dayheight*d), 0, 0 );
     dayBox.setRight( box.right() );
     dayBox.setBottom( daysBox.top()+round(dayheight*(d+1)) );
-    printEventString(p, dayBox, txt, Qt::AlignTop | Qt::AlignLeft | Qt::BreakAnywhere );
+    printEventString(p, dayBox, txt, TQt::AlignTop | TQt::AlignLeft | TQt::BreakAnywhere );
   }
   p.setFont( oldfont );
-//   p.setBrush( Qt::NoBrush );
+//   p.setBrush( TQt::NoBrush );
   drawBox( p, BOX_BORDER_WIDTH, borderBox );
   p.restore();
 }
@@ -1379,7 +1379,7 @@ void CalPrintPluginBase::drawMonthTable(TQPainter &p, const TQDate &qd, bool wee
     for (int row = 0; row<rows; ++row ) {
       int calWeek = weekDate.weekNumber();
       TQRect rc( box.left(), rowedges[row], coledges[0] - 3 - box.left(), rowedges[row+1]-rowedges[row] );
-      p.drawText( rc, Qt::AlignRight | Qt::AlignVCenter, TQString::number( calWeek ) );
+      p.drawText( rc, TQt::AlignRight | TQt::AlignVCenter, TQString::number( calWeek ) );
       weekDate = weekDate.addDays( 7 );
     }
     p.setFont( oldFont );
@@ -1442,11 +1442,11 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
   // size of to-do
   outStr=todo->summary();
   int left = posSummary + ( level*10 );
-  rect = p.boundingRect( left, y, ( rhs-left-5 ), -1, Qt::WordBreak, outStr );
+  rect = p.boundingRect( left, y, ( rhs-left-5 ), -1, TQt::WordBreak, outStr );
   if ( !todo->description().isEmpty() && desc ) {
     outStr = todo->description();
     rect = p.boundingRect( left+20, rect.bottom()+5, width-(left+10-x), -1,
-                           Qt::WordBreak, outStr );
+                           TQt::WordBreak, outStr );
   }
   // if too big make new page
   if ( rect.bottom() > pageHeight ) {
@@ -1481,13 +1481,13 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
   }
 
   outStr.setNum( todo->priority() );
-  rect = p.boundingRect( lhs, y + 10, 5, -1, Qt::AlignCenter, outStr );
+  rect = p.boundingRect( lhs, y + 10, 5, -1, TQt::AlignCenter, outStr );
   // Make it a more reasonable size
   rect.setWidth(18);
   rect.setHeight(18);
 
   // Draw a checkbox
-  p.setBrush( TQBrush( Qt::NoBrush ) );
+  p.setBrush( TQBrush( TQt::NoBrush ) );
   p.drawRect( rect );
   if ( todo->isCompleted() ) {
     // cross out the rectangle for completed to-dos
@@ -1498,7 +1498,7 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
 
   // Priority
   if ( todo->priority() > 0 && showPriority ) {
-    p.drawText( rect, Qt::AlignCenter, outStr );
+    p.drawText( rect, TQt::AlignCenter, outStr );
   }
   startpt.mRect = rect; //save for later
 
@@ -1520,7 +1520,7 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
   // summary
   outStr=todo->summary();
   rect = p.boundingRect( lhs, rect.top(), (rhs-(left + rect.width() + 5)),
-                         -1, Qt::WordBreak, outStr );
+                         -1, TQt::WordBreak, outStr );
 
   TQRect newrect;
   //FIXME: the following code prints underline rather than strikeout text
@@ -1530,12 +1530,12 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
     f.setStrikeOut( true );
     p.setFont( f );
   }
-  p.drawText( rect, Qt::WordBreak, outStr, -1, &newrect );
+  p.drawText( rect, TQt::WordBreak, outStr, -1, &newrect );
   f.setStrikeOut( false );
   p.setFont( f );
 #endif
   //TODO: Remove this section when the code above is fixed
-  p.drawText( rect, Qt::WordBreak, outStr, -1, &newrect );
+  p.drawText( rect, TQt::WordBreak, outStr, -1, &newrect );
   if ( todo->isCompleted() && strikeoutCompleted ) {
     // strike out the summary text if to-do is complete
     // Note: we tried to use a strike-out font and for unknown reasons the
@@ -1552,8 +1552,8 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
   if ( todo->hasDueDate() && posDueDt>=0 ) {
     outStr = local->formatDate( todo->dtDue().date(), true );
     rect = p.boundingRect( posDueDt, y, x + width, -1,
-                           Qt::AlignTop | Qt::AlignLeft, outStr );
-    p.drawText( rect, Qt::AlignTop | Qt::AlignLeft, outStr );
+                           TQt::AlignTop | TQt::AlignLeft, outStr );
+    p.drawText( rect, TQt::AlignTop | TQt::AlignLeft, outStr );
   }
 
   // percentage completed
@@ -1564,7 +1564,7 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
     //first, draw the progress bar
     int progress = (int)(( lwidth*todo->percentComplete())/100.0 + 0.5);
 
-    p.setBrush( TQBrush( Qt::NoBrush ) );
+    p.setBrush( TQBrush( TQt::NoBrush ) );
     p.drawRect( posPercentComplete, y+3, lwidth, lheight );
     if ( progress > 0 ) {
       p.setBrush( TQColor( 128, 128, 128 ) );
@@ -1572,10 +1572,10 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
     }
 
     //now, write the percentage
-    outStr = i18n( "%1%" ).arg( todo->percentComplete() );
+    outStr = i18n( "%1%" ).tqarg( todo->percentComplete() );
     rect = p.boundingRect( posPercentComplete+lwidth+3, y, x + width, -1,
-                           Qt::AlignTop | Qt::AlignLeft, outStr );
-    p.drawText( rect, Qt::AlignTop | Qt::AlignLeft, outStr );
+                           TQt::AlignTop | TQt::AlignLeft, outStr );
+    p.drawText( rect, TQt::AlignTop | TQt::AlignLeft, outStr );
   }
 
   // description
@@ -1583,8 +1583,8 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
     y = newrect.bottom() + 5;
     outStr = todo->description();
     rect = p.boundingRect( left+20, y, x+width-(left+10), -1,
-                           Qt::WordBreak, outStr );
-    p.drawText( rect, Qt::WordBreak, outStr, -1, &newrect );
+                           TQt::WordBreak, outStr );
+    p.drawText( rect, TQt::WordBreak, outStr, -1, &newrect );
   }
 
   // Set the new line position
@@ -1648,19 +1648,19 @@ void CalPrintPluginBase::drawJournalField( TQPainter &p, TQString field, TQStrin
 {
   if ( text.isEmpty() ) return;
 
-  TQString entry( field.arg( text ) );
+  TQString entry( field.tqarg( text ) );
 
-  TQRect rect( p.boundingRect( x, y, width, -1, Qt::WordBreak, entry) );
+  TQRect rect( p.boundingRect( x, y, width, -1, TQt::WordBreak, entry) );
   if ( rect.bottom() > pageHeight) {
     // Start new page...
     // FIXME: If it's a multi-line text, draw a few lines on this page, and the
     // remaining lines on the next page.
     y=0;
     mPrinter->newPage();
-    rect = p.boundingRect( x, y, width, -1, Qt::WordBreak, entry);
+    rect = p.boundingRect( x, y, width, -1, TQt::WordBreak, entry);
   }
   TQRect newrect;
-  p.drawText( rect, Qt::WordBreak, entry, -1, &newrect );
+  p.drawText( rect, TQt::WordBreak, entry, -1, &newrect );
   y = newrect.bottom() + 7;
 }
 
@@ -1677,19 +1677,19 @@ void CalPrintPluginBase::drawJournal( Journal * journal, TQPainter &p, int x, in
     headerText = dateText;
   } else {
     headerText = i18n("Description - date", "%1 - %2")
-                     .arg( journal->summary() )
-                     .arg( dateText );
+                     .tqarg( journal->summary() )
+                     .tqarg( dateText );
   }
 
-  TQRect rect( p.boundingRect( x, y, width, -1, Qt::WordBreak, headerText) );
+  TQRect rect( p.boundingRect( x, y, width, -1, TQt::WordBreak, headerText) );
   if ( rect.bottom() > pageHeight) {
     // Start new page...
     y=0;
     mPrinter->newPage();
-    rect = p.boundingRect( x, y, width, -1, Qt::WordBreak, headerText );
+    rect = p.boundingRect( x, y, width, -1, TQt::WordBreak, headerText );
   }
   TQRect newrect;
-  p.drawText( rect, Qt::WordBreak, headerText, -1, &newrect );
+  p.drawText( rect, TQt::WordBreak, headerText, -1, &newrect );
   p.setFont( oldFont );
 
   y = newrect.bottom() + 4;
@@ -1711,21 +1711,21 @@ void CalPrintPluginBase::drawSplitHeaderRight( TQPainter &p, const TQDate &fd,
   TQFont oldFont( p.font() );
 
   TQPen oldPen( p.pen() );
-  TQPen pen( Qt::black, 4 );
+  TQPen pen( TQt::black, 4 );
 
   TQString title;
   if ( mCalSys ) {
     if ( fd.month() == td.month() ) {
       title = i18n("Date range: Month dayStart - dayEnd", "%1 %2 - %3")
-        .arg( mCalSys->monthName( fd.month(), false ) )
-        .arg( mCalSys->dayString( fd, false ) )
-        .arg( mCalSys->dayString( td, false ) );
+        .tqarg( mCalSys->monthName( fd.month(), false ) )
+        .tqarg( mCalSys->dayString( fd, false ) )
+        .tqarg( mCalSys->dayString( td, false ) );
     } else {
       title = i18n("Date range: monthStart dayStart - monthEnd dayEnd", "%1 %2 - %3 %4")
-        .arg( mCalSys->monthName( fd.month(), false ) )
-        .arg( mCalSys->dayString( fd, false ) )
-        .arg( mCalSys->monthName( td.month(), false ) )
-        .arg( mCalSys->dayString( td, false ) );
+        .tqarg( mCalSys->monthName( fd.month(), false ) )
+        .tqarg( mCalSys->dayString( fd, false ) )
+        .tqarg( mCalSys->monthName( td.month(), false ) )
+        .tqarg( mCalSys->dayString( td, false ) );
     }
   }
 
@@ -1734,7 +1734,7 @@ void CalPrintPluginBase::drawSplitHeaderRight( TQPainter &p, const TQDate &fd,
 
   int lineSpacing = p.fontMetrics().lineSpacing();
   p.drawText( 0, lineSpacing * 0, width, lineSpacing,
-              Qt::AlignRight | Qt::AlignTop, title );
+              TQt::AlignRight | TQt::AlignTop, title );
 
   title.truncate(0);
 
@@ -1746,7 +1746,7 @@ void CalPrintPluginBase::drawSplitHeaderRight( TQPainter &p, const TQDate &fd,
   int newlineSpacing = p.fontMetrics().lineSpacing();
   title += TQString::number(fd.year());
   p.drawText( 0, lineSpacing * 1 + 4, width, newlineSpacing,
-              Qt::AlignRight | Qt::AlignTop, title );
+              TQt::AlignRight | TQt::AlignTop, title );
 
   p.setFont( oldFont );
 }
