@@ -63,10 +63,10 @@ namespace KParts
                                              const TQStringList &args = TQStringList() )
         {
             TQObject *object = factory->create( parent, name,
-                                               T::staticMetaObject()->className(),
+                                               T::tqstaticMetaObject()->className(),
                                                args );
 
-            T *result = dynamic_cast<T *>( object );
+            T *result = tqt_dynamic_cast<T *>( object );
             if ( !result )
                     delete object;
             return result;
@@ -101,10 +101,10 @@ namespace KParts
         {
             KParts::Part *object = factory->createPart( parentWidget, widgetName,
                                                         parent, name,
-                                                        T::staticMetaObject()->className(),
+                                                        T::tqstaticMetaObject()->className(),
                                                         args );
 
-            T *result = dynamic_cast<T *>( object );
+            T *result = tqt_dynamic_cast<T *>( object );
             if ( !result )
                 delete object;
             return result;
@@ -178,7 +178,7 @@ namespace KParts
                     *error = ErrNoFactory;
                 return 0;
             }
-            KParts::Factory *partFactory = dynamic_cast<KParts::Factory *>( factory );
+            KParts::Factory *partFactory = tqt_dynamic_cast<KParts::Factory *>( factory );
             if ( !partFactory )
             {
                 library->unload();
@@ -376,7 +376,7 @@ namespace KParts
                                                const TQStringList &args = TQStringList(),
                                                int *error = 0 )
         {
-            KTrader::OfferList offers = KTrader::self()->query( serviceType, TQString::fromLatin1("KParts/ReadOnlyPart"), constraint, TQString::null );
+            KTrader::OfferList offers = KTrader::self()->query( serviceType, TQString::tqfromLatin1("KParts/ReadOnlyPart"), constraint, TQString::null );
             if ( offers.isEmpty() )
             {
                 if ( error )
