@@ -113,7 +113,7 @@ TQString suitToString(Card::Suit s) {
         case Card::Spades:
             return "S";
     }
-    return TQString::null;
+    return TQString();
 }
 
 TQString rankToString(Card::Rank r)
@@ -280,8 +280,8 @@ void FreecellBase::resumeSolution()
         return;
 
     emit gameInfo(i18n("%1 tries - depth %2")
-                  .arg(freecell_solver_user_get_num_times(solver_instance))
-                  .arg(freecell_solver_user_get_current_depth(solver_instance)));
+                  .tqarg(freecell_solver_user_get_num_times(solver_instance))
+                  .tqarg(freecell_solver_user_get_current_depth(solver_instance)));
 
     if (solver_ret == FCS_STATE_WAS_SOLVED)
     {
@@ -296,7 +296,7 @@ void FreecellBase::resumeSolution()
 	int moves = freecell_solver_user_get_num_times(solver_instance);
         freeSolution();
         emit gameInfo(i18n("unsolved after %1 moves")
-                      .arg(moves));
+                      .tqarg(moves));
         stopDemo();
         return;
     }
@@ -379,7 +379,7 @@ TQString FreecellBase::solverFormat() const
         tmp += suitToString(target[i]->top()->suit()) + "-" + rankToString(target[i]->top()->rank()) + " ";
     }
     if (!tmp.isEmpty())
-        output += TQString::fromLatin1("Foundations: %1\n").arg(tmp);
+        output += TQString::tqfromLatin1("Foundations: %1\n").tqarg(tmp);
 
     tmp.truncate(0);
     for (uint i = 0; i < freecell.count(); i++) {
@@ -389,7 +389,7 @@ TQString FreecellBase::solverFormat() const
             tmp += rankToString(freecell[i]->top()->rank()) + suitToString(freecell[i]->top()->suit()) + " ";
     }
     if (!tmp.isEmpty())
-        output += TQString::fromLatin1("Freecells: %1\n").arg(tmp);
+        output += TQString::tqfromLatin1("Freecells: %1\n").tqarg(tmp);
 
     for (uint i = 0; i < store.count(); i++)
     {
@@ -544,7 +544,7 @@ MoveHint *FreecellBase::chooseHint()
 {
     if (solver_instance && freecell_solver_user_get_moves_left(solver_instance)) {
 
-        emit gameInfo(i18n("%1 moves before finish").arg(freecell_solver_user_get_moves_left(solver_instance)));
+        emit gameInfo(i18n("%1 moves before finish").tqarg(freecell_solver_user_get_moves_left(solver_instance)));
 
         fcs_move_t move;
         if (!freecell_solver_user_get_next_move(solver_instance, &move)) {
@@ -665,7 +665,7 @@ void FreecellBase::movePileToPile(CardList &c, Pile *to, PileList fss, PileList
         if ((count > (fcs.count() + 1)) && (count <= 2 * (fcs.count() + 1)))
             moveaway = count - (fcs.count() + 1);
     }
-    uint moving = QMIN(count, QMIN(c.count() - start, fcs.count() + 1));
+    uint moving = TQMIN(count, TQMIN(c.count() - start, fcs.count() + 1));
     assert(moving);
 
     for (uint i = 0; i < moving - 1; i++) {
