@@ -80,12 +80,12 @@ class PDFOptionsPage : public KPrintDialogPage
        PDFOptionsPage()
        {
            setTitle( i18n( "PDF Options" ) );
-           TQVBoxLayout *layout = new TQVBoxLayout(this);
+           TQVBoxLayout *tqlayout = new TQVBoxLayout(this);
            m_forceRaster = new TQCheckBox(i18n("Force rasterization"), this);
            TQToolTip::add(m_forceRaster, i18n("Rasterize into an image before printing"));
            TQWhatsThis::add(m_forceRaster, i18n("Forces the rasterization of each page into an image before printing it. This usually gives somewhat worse results, but is useful when printing documents that appear to print incorrectly."));
-           layout->addWidget(m_forceRaster);
-           layout->addStretch(1);
+           tqlayout->addWidget(m_forceRaster);
+           tqlayout->addStretch(1);
        }
 
        void getOptions( TQMap<TQString,TQString>& opts, bool incldef = false )
@@ -151,7 +151,7 @@ Part::Part(TQWidget *parentWidget, const char *widgetName,
 	connect( m_document, TQT_SIGNAL( openURL(const KURL &) ), this, TQT_SLOT( openURLFromDocument(const KURL &) ) );
 	connect( m_document, TQT_SIGNAL( close() ), this, TQT_SLOT( close() ) );
 	
-	if (parent && parent->metaObject()->slotNames(true).contains("slotQuit()"))
+	if (parent && parent->tqmetaObject()->slotNames(true).contains("slotQuit()"))
 		connect( m_document, TQT_SIGNAL( quit() ), parent, TQT_SLOT( slotQuit() ) );
 	else
 		connect( m_document, TQT_SIGNAL( quit() ), this, TQT_SLOT( cannotQuit() ) );
@@ -186,7 +186,7 @@ Part::Part(TQWidget *parentWidget, const char *widgetName,
 
 	int index;
 	// [left toolbox: Table of Contents] | []
-	// dummy wrapper with layout to enable horizontal scroll bars (bug: 147233)
+	// dummy wrapper with tqlayout to enable horizontal scroll bars (bug: 147233)
 	TQWidget *tocWrapper = new TQWidget(m_toolBox);
 	TQVBoxLayout *tocWrapperLayout = new TQVBoxLayout(tocWrapper);
 	m_tocFrame = new TOC( tocWrapper, m_document );
@@ -297,7 +297,7 @@ Part::Part(TQWidget *parentWidget, const char *widgetName,
 	m_showPresentation = new KAction( i18n("P&resentation"), "kpresenter_kpr", "Ctrl+Shift+P", this, TQT_SLOT(slotShowPresentation()), ac, "presentation");
 	m_showPresentation->setEnabled( false );
 
-	// attach the actions of the children widgets too
+	// attach the actions of the tqchildren widgets too
 	m_pageView->setupActions( ac );
 
 	// apply configuration (both internal settings and GUI configured items)
@@ -310,7 +310,7 @@ Part::Part(TQWidget *parentWidget, const char *widgetName,
 	}
 	m_splitter->setSizes( splitterSizes );
 	// get notified about splitter size changes (HACK that will be removed
-	// by connecting to Qt4::QSplitter's sliderMoved())
+	// by connecting to TQt4::TQSplitter's sliderMoved())
 	m_pageView->installEventFilter( this );
 	m_watcher = new KDirWatch( this );
 	connect( m_watcher, TQT_SIGNAL( dirty( const TQString& ) ), this, TQT_SLOT( slotFileDirty( const TQString& ) ) );
@@ -422,7 +422,7 @@ bool Part::openFile()
         {
             if ( TQFile::exists(m_file) )
 	    {
-                KTempFile tf( TQString::null, ".pdf" );
+                KTempFile tf( TQString(), ".pdf" );
                 if ( tf.status() == 0 )
                 {
                     tf.close();
@@ -447,7 +447,7 @@ bool Part::openFile()
         }
     }
 
-    m_temporaryLocalFile = TQString::null;
+    m_temporaryLocalFile = TQString();
 
     bool ok = m_document->openDocument( m_file, url(), mime );
 
@@ -482,7 +482,7 @@ bool Part::openFile()
     // if the 'StartFullScreen' flag is set, start presentation
     if ( m_document->getMetaData( "StartFullScreen" ) == "yes" )
     {
-	KMessageBox::information(m_presentationWidget, i18n("The document is going to be launched on presentation mode because the file requested it."), TQString::null, "autoPresentationWarning");
+	KMessageBox::information(m_presentationWidget, i18n("The document is going to be launched on presentation mode because the file requested it."), TQString(), "autoPresentationWarning");
         slotShowPresentation();
     }
 
@@ -502,7 +502,7 @@ bool Part::openURL(const KURL &url)
     // if it matches then: download it (if not local) extract to a temp file using
     // KTar and proceed with the URL of the temporary file
 
-    m_jobMime = TQString::null;
+    m_jobMime = TQString();
 
     // this calls the above 'openURL' method
     bool b = KParts::ReadOnlyPart::openURL(url);
@@ -510,7 +510,7 @@ bool Part::openURL(const KURL &url)
     // these setWindowCaption calls only work for local files
     if ( !b )
     {
-        KMessageBox::error( widget(), i18n("Could not open %1").arg( url.prettyURL() ) );
+        KMessageBox::error( widget(), i18n("Could not open %1").tqarg( url.prettyURL() ) );
         emit setWindowCaption("");
     }
     else
@@ -548,7 +548,7 @@ bool Part::closeURL()
     if (!m_temporaryLocalFile.isNull())
     {
         TQFile::remove( m_temporaryLocalFile );
-        m_temporaryLocalFile = TQString::null;
+        m_temporaryLocalFile = TQString();
     }
 
     slotHidePresentation();
@@ -571,7 +571,7 @@ bool Part::closeURL()
 bool Part::eventFilter( TQObject * watched, TQEvent * e )
 {
     // if pageView has been resized, save splitter sizes
-    if ( watched == m_pageView && e->type() == TQEvent::Resize )
+    if ( TQT_BASE_OBJECT(watched) == TQT_BASE_OBJECT(m_pageView) && e->type() == TQEvent::Resize )
         m_saveSplitterSizeTimer->start(500, true);
 
     // only intercept events, don't block them
@@ -638,7 +638,7 @@ void Part::close()
   {
     closeURL();
   }
-  else KMessageBox::information(widget(), i18n("This link points to a close document action that does not work when using the embedded viewer."), TQString::null, "warnNoCloseIfNotInKPDF");
+  else KMessageBox::information(widget(), i18n("This link points to a close document action that does not work when using the embedded viewer."), TQString(), "warnNoCloseIfNotInKPDF");
 }
 
 void Part::updateViewActions()
@@ -686,7 +686,7 @@ void Part::psTransformEnded()
 
 void Part::cannotQuit()
 {
-	KMessageBox::information(widget(), i18n("This link points to a quit application action that does not work when using the embedded viewer."), TQString::null, "warnNoQuitIfNotInKPDF");
+	KMessageBox::information(widget(), i18n("This link points to a quit application action that does not work when using the embedded viewer."), TQString(), "warnNoQuitIfNotInKPDF");
 }
 
 void Part::saveSplitterSize()
@@ -789,7 +789,7 @@ void Part::slotFind()
         m_searchStarted = true;
         m_document->resetSearch( PART_SEARCH_ID );
         m_document->searchText( PART_SEARCH_ID, dlg.pattern(), false, savedCaseSensitive,
-                                KPDFDocument::NextMatch, true, qRgb( 255, 255, 64 ) );
+                                KPDFDocument::NextMatch, true, tqRgb( 255, 255, 64 ) );
     }
 }
 
@@ -801,22 +801,22 @@ void Part::slotFindNext()
 
 void Part::slotSaveFileAs()
 {
-    KURL saveURL = KFileDialog::getSaveURL( url().isLocalFile() ? url().url() : url().fileName(), TQString::null, widget() );
+    KURL saveURL = KFileDialog::getSaveURL( url().isLocalFile() ? url().url() : url().fileName(), TQString(), widget() );
     if ( saveURL.isValid() && !saveURL.isEmpty() )
     {
         if (saveURL == url())
         {
-            KMessageBox::information( widget(), i18n("You are trying to overwrite \"%1\" with itself. This is not allowed. Please save it in another location.").arg(saveURL.filename()) );
+            KMessageBox::information( widget(), i18n("You are trying to overwrite \"%1\" with itself. This is not allowed. Please save it in another location.").tqarg(saveURL.filename()) );
             return;
         }
         if ( KIO::NetAccess::exists( saveURL, false, widget() ) )
         {
-            if (KMessageBox::warningContinueCancel( widget(), i18n("A file named \"%1\" already exists. Are you sure you want to overwrite it?").arg(saveURL.filename()), TQString::null, i18n("Overwrite")) != KMessageBox::Continue)
+            if (KMessageBox::warningContinueCancel( widget(), i18n("A file named \"%1\" already exists. Are you sure you want to overwrite it?").tqarg(saveURL.filename()), TQString(), i18n("Overwrite")) != KMessageBox::Continue)
                 return;
         }
 
         if ( !KIO::NetAccess::file_copy( m_file, saveURL, -1, true ) )
-            KMessageBox::information( 0, i18n("File could not be saved in '%1'. Try to save it to another location.").arg( saveURL.prettyURL() ) );
+            KMessageBox::information( 0, i18n("File could not be saved in '%1'. Try to save it to another location.").tqarg( saveURL.prettyURL() ) );
     }
 }
 
@@ -894,7 +894,7 @@ void Part::slotPrintPreview()
         page = m_document->page(i);
         width = page->width();
         height = page->height();
-        if (page->rotation() == 90 || page->rotation() == 270) qSwap(width, height);
+        if (page->rotation() == 90 || page->rotation() == 270) tqSwap(width, height);
         if (width > height) landscape++;
         else portrait++;
     }
@@ -939,7 +939,7 @@ void Part::slotShowMenu(const KPDFPage *page, const TQPoint &point)
 	KPopupMenu *popup = new KPopupMenu( widget(), "rmb popup" );
 	if (page)
 	{
-		popup->insertTitle( i18n( "Page %1" ).arg( page->number() + 1 ) );
+		popup->insertTitle( i18n( "Page %1" ).tqarg( page->number() + 1 ) );
         if ( page->hasBookmark() )
 			popup->insertItem( SmallIcon("bookmark"), i18n("Remove Bookmark"), 1 );
 		else
@@ -1041,7 +1041,7 @@ void Part::slotPrint()
         page = m_document->page(i);
         width = page->width();
         height = page->height();
-        if (page->rotation() == 90 || page->rotation() == 270) qSwap(width, height);
+        if (page->rotation() == 90 || page->rotation() == 270) tqSwap(width, height);
         if (width > height) landscape++;
         else portrait++;
     }
