@@ -136,7 +136,7 @@ namespace KPF
       TQLabel                * l_bandwidthLimit;
 //      TQLabel                * l_connectionLimit;
       TQLabel                * l_serverName;
-      TQLabel                * l_kpfStatus;
+      TQLabel                * l_kpftqStatus;
 
       TQSpinBox              * sb_listenPort;
       TQSpinBox              * sb_bandwidthLimit;
@@ -278,7 +278,7 @@ namespace KPF
     TQWidget * w = new TQWidget(parent);
 
     TQLabel * about =
-      new QLabel
+      new TQLabel
       (
        i18n
        (
@@ -298,10 +298,10 @@ namespace KPF
 
     l->addWidget(about);
 
-    d->l_kpfStatus =
+    d->l_kpftqStatus =
       new TQLabel(i18n("Applet status: <strong>not running</strong>"), w);
 
-    l->addWidget(d->l_kpfStatus);
+    l->addWidget(d->l_kpftqStatus);
 
     TQHBoxLayout * l2 = new TQHBoxLayout(l);
 
@@ -395,7 +395,7 @@ namespace KPF
        " (%1)"
        "</p>"
       )
-      .arg(TQDir::homeDirPath());
+      .tqarg(TQDir::homeDirPath());
 
     TQString listenPortHelp =
       i18n
@@ -507,11 +507,11 @@ namespace KPF
     void
   PropertiesDialogPlugin::slotStartKPF()
   {
-    d->l_kpfStatus
+    d->l_kpftqStatus
       ->setText(i18n("Applet status: <strong>starting...</strong>"));
 
     kapp->dcopClient()
-      ->send("kicker", "default", "addApplet(TQString)", "kpfapplet.desktop");
+      ->send("kicker", "default", "addApplet(TQString)", TQString("kpfapplet.desktop"));
 
     TQTimer::singleShot(4 * 1000, this, TQT_SLOT(slotStartKPFFailed()));
   }
@@ -519,7 +519,7 @@ namespace KPF
     void
   PropertiesDialogPlugin::slotStartKPFFailed()
   {
-    d->l_kpfStatus
+    d->l_kpftqStatus
       ->setText(i18n("Applet status: <strong>failed to start</strong>"));
 
     d->pb_startKPF->setEnabled(true);
@@ -532,7 +532,7 @@ namespace KPF
     {
       d->kpfRunning = true;
 
-      d->l_kpfStatus
+      d->l_kpftqStatus
         ->setText(i18n("Applet status: <strong>running</strong>"));
 
       d->pb_startKPF->setEnabled(false);
@@ -554,7 +554,7 @@ namespace KPF
 
       d->pb_startKPF->setEnabled(true);
 
-      d->l_kpfStatus
+      d->l_kpftqStatus
         ->setText(i18n("Applet status: <strong>not running</strong>"));
 
       d->stack->raiseWidget(d->initWidget);
