@@ -53,7 +53,7 @@ namespace KPF
 
     d->followSymlinks = followSymlinks;
 
-    d->birth = TQDateTime::currentDateTime();
+    d->birth = TQDateTime::tqcurrentDateTime();
 
     d->socket.setSocket(socket);
 
@@ -226,7 +226,7 @@ namespace KPF
 
     d->request.setMethod    (l[0]);
     d->request.setPath      (l[1]);
-    d->request.setProtocol  (l.count() == 3 ? l[2] : TQString::null);
+    d->request.setProtocol  (l.count() == 3 ? l[2] : TQString());
 
     // Before we check the request, say we received it.
 
@@ -252,7 +252,7 @@ namespace KPF
     // If there's .. or ~ in the path, we disallow. Either there's a mistake
     // or someone's trying to h@x0r us. I wouldn't have worried about ~
     // normally, because I don't do anything with it, so the resource would
-    // simply not be found, but I'm worried that the QDir/QFile/QFileInfo
+    // simply not be found, but I'm worried that the TQDir/TQFile/TQFileInfo
     // stuff might try to expand it, so I'm not taking any chances.
 
     if (d->request.path().contains("..") || d->request.path().contains('~'))
@@ -333,7 +333,7 @@ namespace KPF
 
     while (!d->incomingLineBuffer.isEmpty())
     {
-      // This would be cleaner if there was a QValueQueue.
+      // This would be cleaner if there was a TQValueQueue.
       // Basically we 'dequeue' the first line from incomingHeaderBuffer.
 
       TQString line(d->incomingLineBuffer.first());
@@ -754,12 +754,12 @@ namespace KPF
 
     d->socket.close();
 
-    d->death = TQDateTime::currentDateTime();
+    d->death = TQDateTime::tqcurrentDateTime();
 
     emit(finished(this));
   }
 
-    QHostAddress
+    TQHostAddress
   Server::peerAddress() const
   {
     return d->socket.peerAddress();
@@ -1106,13 +1106,13 @@ namespace KPF
     return d->state;
   }
 
-    QDateTime
+    TQDateTime
   Server::birth() const
   {
     return d->birth;
   }
 
-    QDateTime
+    TQDateTime
   Server::death() const
   {
     return d->death;
