@@ -107,7 +107,7 @@ bool PMGLView::s_bDirect = true;
 
 PMGLView::PMGLView( PMPart* part, PMViewType t,
                     TQWidget* parent, const char* name, WFlags f )
-      : PMViewBase( parent, name, f | Qt::WWinOwnDC | Qt::WRepaintNoErase )
+      : PMViewBase( parent, name, f | TQt::WWinOwnDC | TQt::WRepaintNoErase )
 {
    m_pPart = part;
    m_type = t;
@@ -143,7 +143,7 @@ PMGLView::PMGLView( PMPart* part, PMViewType t,
    initializeGL( );
 
    setMouseTracking( true );
-   setFocusPolicy( WheelFocus );
+   setFocusPolicy( TQ_WheelFocus );
 
    PMRenderManager* rm = PMRenderManager::theManager( );
    rm->viewCreated( );
@@ -326,7 +326,7 @@ void PMGLView::initializeGL( )
       Window* colorMapWindows = 0;
       Window* newWindows = 0;
       int num;
-      if( XGetWMColormapWindows( display, topLevelWidget( )->winId( ),
+      if( XGetWMColormapWindows( display, tqtopLevelWidget( )->winId( ),
                                  &colorMapWindows, &num ) )
       {
          // create a new list and append the new window
@@ -354,10 +354,10 @@ void PMGLView::initializeGL( )
          newWindows = new Window[1];
          newWindows[0] = w;
       }
-      // tell Qt to use this window
+      // tell TQt to use this window
       create( w );
 
-      XSetWMColormapWindows( display, topLevelWidget( )->winId( ),
+      XSetWMColormapWindows( display, tqtopLevelWidget( )->winId( ),
                              newWindows, num );
       delete[] newWindows;
 
@@ -367,7 +367,7 @@ void PMGLView::initializeGL( )
    {
       TQVBoxLayout* topLayout = new TQVBoxLayout( this );
       TQLabel* label = new TQLabel( i18n( "No OpenGL support" ), this );
-      label->setAlignment( Qt::AlignCenter );
+      label->tqsetAlignment( TQt::AlignCenter );
       topLayout->addWidget( label );
    }
 
@@ -431,7 +431,7 @@ void PMGLView::resizeEvent( TQResizeEvent* )
 
 void PMGLView::paintEvent( TQPaintEvent* )
 {
-   repaint( );
+   tqrepaint( );
 }
 
 void PMGLView::invalidateProjection( bool graphicalChange /*= true*/ )
@@ -480,7 +480,7 @@ void PMGLView::invalidateProjection( bool graphicalChange /*= true*/ )
       recalculateControlPointPosition( );
    }
    m_projectionUpToDate = false;
-   repaint( graphicalChange );
+   tqrepaint( graphicalChange );
 }
 
 void PMGLView::enableTranslateMode( bool yes )
@@ -507,7 +507,7 @@ void PMGLView::mousePressEvent( TQMouseEvent* e )
 {
    if( m_bScaleMode || m_bTranslateMode )
    {
-      if( ( e->button( ) & LeftButton ) && ( e->state( ) == 0 ) )
+      if( ( e->button( ) & Qt::LeftButton ) && ( e->state( ) == 0 ) )
       {
          m_bMousePressed = true;
          m_mousePos = e->pos( );
@@ -517,7 +517,7 @@ void PMGLView::mousePressEvent( TQMouseEvent* e )
    }
    else if( m_type != PMViewCamera )
    {
-      if( ( e->button( ) & LeftButton ) && m_bInverseValid
+      if( ( e->button( ) & Qt::LeftButton ) && m_bInverseValid
           && m_pActiveObject )
       {
          if( m_pUnderMouse )
@@ -578,7 +578,7 @@ void PMGLView::mousePressEvent( TQMouseEvent* e )
 
    if( !( m_bGraphicalChangeMode || m_bMousePressed ) )
    {
-      if( ( e->button( ) == RightButton ) && ( e->state( ) == 0 ) )
+      if( ( e->button( ) == Qt::RightButton ) && ( e->state( ) == 0 ) )
       {
          m_contextClickPosition = PMVector( screenToInternalX( e->x( ) ),
                                             screenToInternalY( e->y( ) ) );
@@ -599,7 +599,7 @@ void PMGLView::mousePressEvent( TQMouseEvent* e )
       }
    }
 
-   if( e->button( ) == MidButton )
+   if( e->button( ) == Qt::MidButton )
    {
       m_bMidMousePressed = true;
       m_mousePos = e->pos( );
@@ -677,7 +677,7 @@ void PMGLView::mouseReleaseEvent( TQMouseEvent* e )
       m_autoScrollTimer.stop( );
    }
 
-   if( e->button( ) & TQEvent::MidButton )
+   if( e->button( ) & Qt::MidButton )
       m_bMidMousePressed = false;
 
    m_bSelectUnderMouse = false;
@@ -900,7 +900,7 @@ void PMGLView::slotAutoScroll( )
       if( m_bGraphicalChangeMode )
          graphicalChange( mapFromGlobal( TQCursor::pos( ) ) );
       else
-         repaint( );
+         tqrepaint( );
 
       m_lastAutoScrollUpdate = now;
    }
@@ -955,12 +955,12 @@ void PMGLView::graphicalChange( const TQPoint& mousePos )
    m_pActiveObject->controlPointsChangedList( m_controlPoints, changedObjects );
 
    if( changedObjects.isEmpty( ) )
-      emit objectChanged( m_pActiveObject, PMCGraphicalChange, this );
+      emit objectChanged( m_pActiveObject, PMCGraphicalChange, TQT_TQOBJECT(this) );
    else
    {
       PMObjectListIterator it( changedObjects );
       for( ; it.current( ); ++it )
-         emit objectChanged( it.current( ), PMCGraphicalChange, this );
+         emit objectChanged( it.current( ), PMCGraphicalChange, TQT_TQOBJECT(this) );
    }
 }
 
@@ -1118,7 +1118,7 @@ void PMGLView::slotRefresh( )
       if( !m_pCamera )
          setCamera( m_pPart->firstCamera( ) );
 
-   repaint( );
+   tqrepaint( );
 }
 
 void PMGLView::slotClear( )
@@ -1238,10 +1238,10 @@ void PMGLView::slotObjectChanged( PMObject* obj, const int mode,
       redraw = true;
 
    if( redraw )
-      repaint( sender == this );
+      tqrepaint( TQT_BASE_OBJECT(sender) == TQT_BASE_OBJECT(this) );
 }
 
-void PMGLView::repaint( bool graphicalChange )
+void PMGLView::tqrepaint( bool graphicalChange )
 {
    if( isValid( ) )
    {
@@ -1353,7 +1353,7 @@ void PMGLView::selectControlPoint( PMControlPoint* cp, bool select, bool deselec
    }
 
    if( selectionChanged )
-      emit objectChanged( m_pActiveObject, PMCControlPointSelection, this );
+      emit objectChanged( m_pActiveObject, PMCControlPointSelection, TQT_TQOBJECT(this) );
 }
 
 void PMGLView::startSelection( )
@@ -1652,7 +1652,7 @@ void PMGLView::slotControlPoint( int id )
       PMControlPointListIterator cit( m_controlPoints );
       for( ; cit.current( ); ++cit )
          cit.current( )->setSelected( p == cit.current( ) );
-      emit objectChanged( m_pActiveObject, PMCControlPointSelection, this );
+      emit objectChanged( m_pActiveObject, PMCControlPointSelection, TQT_TQOBJECT(this) );
    }
 }
 
@@ -1754,7 +1754,7 @@ TQString PMGLViewFactory::description( PMViewOptions* vo ) const
    if( vo && vo->viewType( ) == "glview" )
    {
       PMGLViewOptions* o = ( PMGLViewOptions* ) vo;
-      return i18n( "3D View (%1)" ).arg(
+      return i18n( "3D View (%1)" ).tqarg(
          PMGLView::viewTypeAsString( o->glViewType( ) ) );
    }
    return description( );
