@@ -145,7 +145,7 @@ PMPart::PMPart( TQWidget* parentWidget, const char* widgetName,
 
    restoreConfig( instance( )->config( ) );
 
-   connect( qApp->clipboard( ), TQT_SIGNAL( dataChanged( ) ),
+   connect( tqApp->tqclipboard( ), TQT_SIGNAL( dataChanged( ) ),
             TQT_SLOT( slotClipboardDataChanged( ) ) );
    slotClipboardDataChanged( );
    connect( &m_commandManager, TQT_SIGNAL( updateUndoRedo( const TQString&, const TQString& ) ),
@@ -227,7 +227,7 @@ void PMPart::initCopyPasteActions( )
    m_pPasteAction = KStdAction::paste( this, TQT_SLOT( slotEditPaste( ) ), actionCollection( ) );
 
    m_pDeleteAction =
-      new KAction( i18n( "Delete" ), "edittrash", Qt::Key_Delete,
+      new KAction( i18n( "Delete" ), "edittrash", TQt::Key_Delete,
                    this, TQT_SLOT( slotEditDelete( ) ),
                    actionCollection( ), "edit_delete" );
 
@@ -730,7 +730,7 @@ void PMPart::initView( TQWidget* parent, const char* name )
    if( !m_pShell )
    {
       // a part inside konqueror
-      // simple layout
+      // simple tqlayout
       m_pView = new PMView( this, parent, name );
       m_pView->show( );
       setWidget( m_pView );
@@ -951,7 +951,7 @@ bool PMPart::exportPovray( const KURL& url )
    if( ok )
    {
       PMPovray35Format format;
-      PMSerializer* dev = format.newSerializer( file );
+      PMSerializer* dev = format.newSerializer( TQT_TQIODEVICE(file) );
       dev->serialize( m_pScene );
       delete dev;
 
@@ -1032,7 +1032,7 @@ bool PMPart::setActiveObject( const TQString& name )
    else
    {
       pathElem = objPath;
-      objPath = TQString::null;
+      objPath = TQString();
    }
 
    while( !pathElem.isNull( ) )
@@ -1050,7 +1050,7 @@ bool PMPart::setActiveObject( const TQString& name )
          else
             objIndex = 0;
 
-         // Iterate the children for this element. We stop when there are no more siblings
+         // Iterate the tqchildren for this element. We stop when there are no more siblings
          // or the object is of the correct type and it's index count is also correct
          siblingIndex = 0;
          tmpSibling = tmpObj->firstChild( );
@@ -1079,7 +1079,7 @@ bool PMPart::setActiveObject( const TQString& name )
       else
       {
          pathElem = objPath;
-         objPath = TQString::null;
+         objPath = TQString();
       }
    }
    if( tmpObj )
@@ -1369,14 +1369,14 @@ void PMPart::slotFileImport( )
       TQFile file( fileName );
       if( file.open( IO_ReadOnly ) )
       {
-         PMParser* newParser = selectedFormat->newParser( this, &file );
+         PMParser* newParser = selectedFormat->newParser( this, TQT_TQIODEVICE(&file) );
          if( newParser )
          {
             if( m_pActiveObject )
-               insertFromParser( i18n( "Import %1" ).arg( selectedFormat->description( ) ),
+               insertFromParser( i18n( "Import %1" ).tqarg( selectedFormat->description( ) ),
                                  newParser, m_pActiveObject );
             else
-               insertFromParser( i18n( "Import %1" ).arg( selectedFormat->description( ) ),
+               insertFromParser( i18n( "Import %1" ).tqarg( selectedFormat->description( ) ),
                                  newParser, m_pScene );
             delete newParser;
          }
@@ -1404,7 +1404,7 @@ void PMPart::slotFileExport( )
       TQBuffer buffer( baData );
       buffer.open( IO_WriteOnly );
 
-      PMSerializer* newSer = selectedFormat->newSerializer( &buffer );
+      PMSerializer* newSer = selectedFormat->newSerializer( TQT_TQIODEVICE(&buffer) );
       if( newSer )
       {
          newSer->serialize( m_pScene );
@@ -1450,7 +1450,7 @@ void PMPart::slotEditCut( )
 
    if( sortedList.count( ) > 0 )
    {
-      TQApplication::clipboard( )->setData( new PMObjectDrag( this, sortedList ) );
+      TQApplication::tqclipboard( )->setData( new PMObjectDrag( this, sortedList ) );
       removeSelection( i18n( "Cut" ) );
    }
 
@@ -1472,7 +1472,7 @@ void PMPart::slotEditCopy( )
    const PMObjectList& sortedList = selectedObjects( );
 
    if( sortedList.count( ) > 0 )
-      TQApplication::clipboard( )->setData( new PMObjectDrag( this, sortedList ) );
+      TQApplication::tqclipboard( )->setData( new PMObjectDrag( this, sortedList ) );
 
    emit setStatusBarText( "" );
 }
@@ -1549,7 +1549,7 @@ void PMPart::slotEditPaste( )
 {
    emit setStatusBarText( i18n( "Inserting clipboard contents..." ) );
 
-   pasteOrDrop( i18n( "Paste" ), qApp->clipboard( )->data( ),
+   pasteOrDrop( i18n( "Paste" ), tqApp->tqclipboard( )->data( ),
                 m_pActiveObject );
 
    emit setStatusBarText( "" );
@@ -2508,7 +2508,7 @@ void PMPart::slotClipboardDataChanged( )
 {
    if( isReadWrite( ) )
    {
-      m_canDecode = PMObjectDrag::canDecode( qApp->clipboard( )->data( ), this );
+      m_canDecode = PMObjectDrag::canDecode( tqApp->tqclipboard( )->data( ), this );
       m_pPasteAction->setEnabled( m_canDecode && m_pActiveObject );
    }
    else
@@ -2713,7 +2713,7 @@ void PMPart::slotRender( )
       TQBuffer buffer( a );
       buffer.open( IO_WriteOnly );
       PMPovray35Format format;
-      PMSerializer* dev = format.newSerializer( &buffer );
+      PMSerializer* dev = format.newSerializer( TQT_TQIODEVICE(&buffer) );
       dev->serialize( m_pScene );
       delete dev;
 
