@@ -109,11 +109,11 @@ ConnectWidget::ConnectWidget(TQWidget *parent, const char *name, PPPStats *st)
   l0->addSpacing(10);
   messg = new TQLabel(this, "messg");
   messg->setFrameStyle(TQFrame::Panel|TQFrame::Sunken);
-  messg->setAlignment(AlignCenter);
+  messg->tqsetAlignment(AlignCenter);
   messg->setText(i18n("Unable to create modem lock file."));
-  messg->setMinimumHeight(messg->sizeHint().height() + 5);
-  int messw = (messg->sizeHint().width() * 12) / 10;
-  messw = QMAX(messw,280);
+  messg->setMinimumHeight(messg->tqsizeHint().height() + 5);
+  int messw = (messg->tqsizeHint().width() * 12) / 10;
+  messw = TQMAX(messw,280);
   messg->setMinimumWidth(messw);
   messg->setText(i18n("Looking for modem..."));
   l0->addWidget(messg);
@@ -131,16 +131,16 @@ ConnectWidget::ConnectWidget(TQWidget *parent, const char *name, PPPStats *st)
   cancel->setFocus();
   connect(cancel, TQT_SIGNAL(clicked()), TQT_SLOT(cancelbutton()));
 
-  int maxw = QMAX(cancel->sizeHint().width(),
-		 debug->sizeHint().width());
-  maxw = QMAX(maxw,65);
+  int maxw = TQMAX(cancel->tqsizeHint().width(),
+		 debug->tqsizeHint().width());
+  maxw = TQMAX(maxw,65);
   debug->setFixedWidth(maxw);
   cancel->setFixedWidth(maxw);
   l1->addWidget(debug);
   l1->addWidget(cancel);
   l1->addSpacing(10);
 
-  setFixedSize(sizeHint());
+  setFixedSize(tqsizeHint());
 
   pausetimer = new TQTimer(this);
   connect(pausetimer, TQT_SIGNAL(timeout()), TQT_SLOT(pause()));
@@ -210,7 +210,7 @@ void ConnectWidget::init() {
   comlist = &gpppdata.scriptType();
   arglist = &gpppdata.script();
 
-  TQString tit = i18n("Connecting to: %1").arg(gpppdata.accname());
+  TQString tit = i18n("Connecting to: %1").tqarg(gpppdata.accname());
   setCaption(tit);
 
   kapp->processEvents();
@@ -259,7 +259,7 @@ void ConnectWidget::init() {
       semaphore = false;
 
       Modem::modem->stop();
-      Modem::modem->notify(this, TQT_SLOT(readChar(unsigned char)));
+      Modem::modem->notify(TQT_TQOBJECT(this), TQT_SLOT(readChar(unsigned char)));
 
       // if we are stuck anywhere we will time out
       timeout_timer->start(gpppdata.modemTimeout()*1000);
@@ -398,7 +398,7 @@ void ConnectWidget::timerEvent(TQTimerEvent *) {
       TQStringList &plist = gpppdata.phonenumbers();
       TQString bmarg= gpppdata.dialPrefix();
       bmarg += *plist.at(dialnumber);
-      TQString bm = i18n("Dialing %1").arg(bmarg);
+      TQString bm = i18n("Dialing %1").tqarg(bmarg);
       messg->setText(bm);
       emit debugMessage(bm);
 
@@ -434,7 +434,7 @@ void ConnectWidget::timerEvent(TQTimerEvent *) {
       Modem::modem->hangup();
 
       if(gpppdata.busyWait() > 0) {
-	TQString bm = i18n("Line busy. Waiting: %1 seconds").arg(gpppdata.busyWait());
+	TQString bm = i18n("Line busy. Waiting: %1 seconds").tqarg(gpppdata.busyWait());
 	messg->setText(bm);
 	emit debugMessage(bm);
 
@@ -467,7 +467,7 @@ void ConnectWidget::timerEvent(TQTimerEvent *) {
         timeout_timer->start(gpppdata.modemTimeout()*1000);
 
         if(gpppdata.busyWait() > 0) {
-	  TQString bm = i18n("No carrier. Waiting: %1 seconds").arg(gpppdata.busyWait());
+	  TQString bm = i18n("No carrier. Waiting: %1 seconds").tqarg(gpppdata.busyWait());
 	  messg->setText(bm);
 	  emit debugMessage(bm);
 
@@ -553,7 +553,7 @@ void ConnectWidget::timerEvent(TQTimerEvent *) {
       }
 
       if (scriptCommand == "Scan") {
-	TQString bm = i18n("Scanning %1").arg(scriptArgument);
+	TQString bm = i18n("Scanning %1").tqarg(scriptArgument);
 	messg->setText(bm);
 	emit debugMessage(bm);
 
@@ -563,7 +563,7 @@ void ConnectWidget::timerEvent(TQTimerEvent *) {
       }
 
       if (scriptCommand == "Save") {
-	TQString bm = i18n("Saving %1").arg(scriptArgument);
+	TQString bm = i18n("Saving %1").tqarg(scriptArgument);
 	messg->setText(bm);
 	emit debugMessage(bm);
 
@@ -591,10 +591,10 @@ void ConnectWidget::timerEvent(TQTimerEvent *) {
 	arg = arg.replace(re2, gpppdata.storedPassword());
 
 	if (scriptCommand == "Send")
-	  bm = bm.arg(scriptArgument);
+	  bm = bm.tqarg(scriptArgument);
 	else {
 	  for(uint i = 0; i < scriptArgument.length(); i++)
-	    bm = bm.arg("*");
+	    bm = bm.tqarg("*");
 	}
 
 	messg->setText(bm);
@@ -606,7 +606,7 @@ void ConnectWidget::timerEvent(TQTimerEvent *) {
       }
 
       if (scriptCommand == "Expect") {
-        TQString bm = i18n("Expecting %1").arg(scriptArgument);
+        TQString bm = i18n("Expecting %1").tqarg(scriptArgument);
 	messg->setText(bm);
 	emit debugMessage(bm);
 
@@ -620,7 +620,7 @@ void ConnectWidget::timerEvent(TQTimerEvent *) {
 
 
       if (scriptCommand == "Pause") {
-	TQString bm = i18n("Pause %1 seconds").arg(scriptArgument);
+	TQString bm = i18n("Pause %1 seconds").tqarg(scriptArgument);
 	messg->setText(bm);
 	emit debugMessage(bm);
 
@@ -637,7 +637,7 @@ void ConnectWidget::timerEvent(TQTimerEvent *) {
 
 	timeout_timer->stop();
 
-	TQString bm = i18n("Timeout %1 seconds").arg(scriptArgument);
+	TQString bm = i18n("Timeout %1 seconds").tqarg(scriptArgument);
 	messg->setText(bm);
 	emit debugMessage(bm);
 
@@ -672,7 +672,7 @@ void ConnectWidget::timerEvent(TQTimerEvent *) {
       }
 
       if (scriptCommand == "ID") {
-	TQString bm = i18n("ID %1").arg(scriptArgument);
+	TQString bm = i18n("ID %1").tqarg(scriptArgument);
 	messg->setText(bm);
 	emit debugMessage(bm);
 
@@ -708,7 +708,7 @@ void ConnectWidget::timerEvent(TQTimerEvent *) {
       }
 
       if (scriptCommand == "Password") {
-	TQString bm = i18n("Password %1").arg(scriptArgument);
+	TQString bm = i18n("Password %1").tqarg(scriptArgument);
 	messg->setText(bm);
 	emit debugMessage(bm);
 
@@ -758,7 +758,7 @@ void ConnectWidget::timerEvent(TQTimerEvent *) {
 		ts.insert( vstart, scanvar );
 	}
 
-	bm = bm.arg(ts);
+	bm = bm.tqarg(ts);
 	messg->setText(bm);
 	emit debugMessage(bm);
 
@@ -782,7 +782,7 @@ void ConnectWidget::timerEvent(TQTimerEvent *) {
       }
 
       if (scriptCommand == "PWPrompt") {
-	TQString bm = i18n("PW Prompt %1").arg(scriptArgument);
+	TQString bm = i18n("PW Prompt %1").tqarg(scriptArgument);
 	messg->setText(bm);
 	emit debugMessage(bm);
 
@@ -807,7 +807,7 @@ void ConnectWidget::timerEvent(TQTimerEvent *) {
 
       if (scriptCommand == "LoopStart") {
 
-        TQString bm = i18n("Loop Start %1").arg(scriptArgument);
+        TQString bm = i18n("Loop Start %1").tqarg(scriptArgument);
 
 	// The incrementing of the scriptindex MUST be before the
 	// call to setExpect otherwise the expect will miss a string that is
@@ -832,9 +832,9 @@ void ConnectWidget::timerEvent(TQTimerEvent *) {
       }
 
       if (scriptCommand == "LoopEnd") {
-        TQString bm = i18n("Loop End %1").arg(scriptArgument);
+        TQString bm = i18n("Loop End %1").tqarg(scriptArgument);
 	if ( loopnest <= 0 ) {
-		bm = i18n("LoopEnd without matching Start. Line: %1").arg(bm);
+		bm = i18n("LoopEnd without matching Start. Line: %1").tqarg(bm);
 		vmain=20;
 		cancelbutton();
 	        KMessageBox::error(0, bm);
@@ -1003,7 +1003,7 @@ void ConnectWidget::checkBuffers() {
       scanvar = scanvar.stripWhiteSpace();
 
       // Show the Variabel content in the debug window
-      TQString sv = i18n("Scan Var: %1").arg(scanvar);
+      TQString sv = i18n("Scan Var: %1").tqarg(scanvar);
       emit debugMessage(sv);
   }
 
@@ -1013,7 +1013,7 @@ void ConnectWidget::checkBuffers() {
       // keep everything after the expected string
       readbuffer.remove(0, readbuffer.find(expectstr) + expectstr.length());
 
-      TQString ts = i18n("Found: %1").arg(expectstr);
+      TQString ts = i18n("Found: %1").tqarg(expectstr);
       emit debugMessage(ts);
 
       if (loopend) {
@@ -1024,7 +1024,7 @@ void ConnectWidget::checkBuffers() {
     if (loopend && readbuffer.contains(loopstr[loopnest])) {
       expecting = false;
       readbuffer = "";
-      TQString ts = i18n("Looping: %1").arg(loopstr[loopnest]);
+      TQString ts = i18n("Looping: %1").tqarg(loopstr[loopnest]);
       emit debugMessage(ts);
       scriptindex = loopstartindex[loopnest];
       loopend = false;
@@ -1117,7 +1117,7 @@ void ConnectWidget::setScan(const TQString &n) {
   scanstr = n;
   scanbuffer = "";
 
-  TQString ts = i18n("Scanning: %1").arg(n);
+  TQString ts = i18n("Scanning: %1").tqarg(n);
   emit debugMessage(ts);
 }
 
@@ -1126,7 +1126,7 @@ void ConnectWidget::setExpect(const TQString &n) {
   expecting = true;
   expectstr = n;
 
-  TQString ts = i18n("Expecting: %1").arg(n);
+  TQString ts = i18n("Expecting: %1").tqarg(n);
   ts.replace(TQRegExp("\n"), "<LF>");
   emit debugMessage(ts);
 
@@ -1374,7 +1374,7 @@ void auto_hostname() {
 
   gethostname(tmp_str, sizeof(tmp_str));
   tmp_str[sizeof(tmp_str)-1]=0; // panic
-  old_hostname=tmp_str; // copy to QString
+  old_hostname=tmp_str; // copy to TQString
 
   if (!p_kppp->stats->local_ip_address.isEmpty() && gpppdata.autoname()) {
     local_ip.s_addr=inet_addr(p_kppp->stats->local_ip_address.ascii());
