@@ -1,7 +1,7 @@
 /*
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: edit.cpp 1158449 2010-08-02 19:26:34Z tpearson $
+ * $Id: edit.cpp 1246260 2011-08-10 22:19:39Z tpearson $
  *              Copyright (C) 1997 Bernd Johannes Wuebben
  *                      wuebben@math.cornell.edu
  *
@@ -66,7 +66,7 @@ DialWidget::DialWidget( TQWidget *parent, bool isnewaccount, const char *name )
 
 
   number_label = new TQLabel(i18n("P&hone number:"), parent);
-  number_label->setAlignment(AlignTop|AlignLeft);
+  number_label->tqsetAlignment(AlignTop|AlignLeft);
   tl->addWidget(number_label, 1, 0);
 
   TQHBoxLayout *lpn = new TQHBoxLayout(5);
@@ -324,7 +324,7 @@ i18n("Here you can select commands to run at certain stages of the\n"
      "(unless, of course, you are root).\n\n"
      "Be sure to supply the whole path to the program otherwise\n"
      "kppp might be unable to find it."), parent);
-  l->setMinimumHeight(l->sizeHint().height());
+  l->setMinimumHeight(l->tqsizeHint().height());
   tl->addWidget(l);
   tl->addStretch(1);
 
@@ -334,7 +334,7 @@ i18n("Here you can select commands to run at certain stages of the\n"
   l1->setColStretch(1, 1);
 
   before_connect_l = new TQLabel(i18n("&Before connect:"), parent);
-  before_connect_l->setAlignment(AlignVCenter);
+  before_connect_l->tqsetAlignment(AlignVCenter);
   l1->addWidget(before_connect_l, 0, 0);
   before_connect = new TQLineEdit(parent);
   before_connect_l->setBuddy(before_connect);
@@ -350,7 +350,7 @@ i18n("Here you can select commands to run at certain stages of the\n"
   TQWhatsThis::add(before_connect,tmp);
 
   command_label = new TQLabel(i18n("&Upon connect:"), parent);
-  command_label->setAlignment(AlignVCenter);
+  command_label->tqsetAlignment(AlignVCenter);
   l1->addWidget(command_label, 1, 0);
   command = new TQLineEdit(parent);
   command_label->setBuddy(command);
@@ -367,7 +367,7 @@ i18n("Here you can select commands to run at certain stages of the\n"
 
   predisconnect_label = new TQLabel(i18n("Before &disconnect:"),
 				 parent);
-  predisconnect_label->setAlignment(AlignVCenter);
+  predisconnect_label->tqsetAlignment(AlignVCenter);
   l1->addWidget(predisconnect_label, 2, 0);
   predisconnect = new TQLineEdit(parent);
   predisconnect_label->setBuddy(predisconnect);
@@ -382,7 +382,7 @@ i18n("Here you can select commands to run at certain stages of the\n"
 
   discommand_label = new TQLabel(i18n("U&pon disconnect:"),
 			      parent);
-  discommand_label->setAlignment(AlignVCenter);
+  discommand_label->tqsetAlignment(AlignVCenter);
   l1->addWidget(discommand_label, 3, 0);
 
   discommand = new TQLineEdit(parent);
@@ -655,8 +655,8 @@ DNSWidget::DNSWidget( TQWidget *parent, bool isnewaccount, const char *name )
   tl->addLayout(l1, 4, 1);
   add = new TQPushButton(i18n("&Add"), parent);
   connect(add, TQT_SIGNAL(clicked()), TQT_SLOT(adddns()));
-  int width = add->sizeHint().width();
-  width = QMAX(width,60);
+  int width = add->tqsizeHint().width();
+  width = TQMAX(width,60);
   add->setMinimumWidth(width);
   l1->addWidget(add);
   l1->addStretch(1);
@@ -667,8 +667,8 @@ DNSWidget::DNSWidget( TQWidget *parent, bool isnewaccount, const char *name )
 
   remove = new TQPushButton(i18n("&Remove"), parent);
   connect(remove, TQT_SIGNAL(clicked()), TQT_SLOT(removedns()));
-  width = remove->sizeHint().width();
-  width = QMAX(width,60);
+  width = remove->tqsizeHint().width();
+  width = TQMAX(width,60);
   remove->setMinimumWidth(width);
   l1->addWidget(remove);
   TQWhatsThis::add(remove,
@@ -676,7 +676,7 @@ DNSWidget::DNSWidget( TQWidget *parent, bool isnewaccount, const char *name )
 		       "server entry from the list below"));
 
   servers_label = new TQLabel(i18n("DNS address &list:"), parent);
-  servers_label->setAlignment(AlignTop|AlignLeft);
+  servers_label->tqsetAlignment(AlignTop|AlignLeft);
   tl->addWidget(servers_label, 5, 0);
 
   dnsservers = new TQListBox(parent);
@@ -892,7 +892,7 @@ ScriptWidget::ScriptWidget( TQWidget *parent, bool isnewaccount, const char *nam
   bbox->addStretch(1);
   remove = bbox->addButton(i18n("&Remove"));
   connect(remove, TQT_SIGNAL(clicked()), TQT_SLOT(removeButton()));
-  bbox->layout();
+  bbox->tqlayout();
   tl->addWidget(bbox);
 
   TQHBoxLayout *l12 = new TQHBoxLayout(0);
@@ -908,7 +908,7 @@ ScriptWidget::ScriptWidget( TQWidget *parent, bool isnewaccount, const char *nam
   sl->setMinimumSize(TQSize(150, 140));
 
   slb = new TQScrollBar(parent);
-  slb->setFixedWidth(slb->sizeHint().width());
+  slb->setFixedWidth(slb->tqsizeHint().width());
   connect(slb, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(scrolling(int)));
 
   l12->addWidget(stl, 1);
