@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: general.cpp 1158449 2010-08-02 19:26:34Z tpearson $
+ * $Id: general.cpp 1246260 2011-08-10 22:19:39Z tpearson $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -487,7 +487,7 @@ ModemWidget2::ModemWidget2(TQWidget *parent, const char *name)
 
   TQLabel *volumeLabel = new TQLabel(i18n("Modem &volume:"), parent);
   hbl->addWidget(volumeLabel);
-  volume = new TQSlider(0, 2, 1, gpppdata.volume(), TQSlider::Horizontal, parent);
+  volume = new TQSlider(0, 2, 1, gpppdata.volume(), Qt::Horizontal, parent);
   volumeLabel->setBuddy(volume);
   volume->setTickmarks(TQSlider::Below);
   hbl->addWidget(volume);
