@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: iplined.cpp 1157648 2010-07-31 19:48:06Z tpearson $
+ * $Id: iplined.cpp 1246260 2011-08-10 22:19:39Z tpearson $
  * 
  *            Copyright (C) 1997 Bernd Johannes Wuebben 
  *                   wuebben@math.cornell.edu
@@ -32,11 +32,11 @@ IPLineEdit::IPLineEdit( TQWidget *parent, const char *name )
   setMaxLength(3 * 4 + 1 * 3);
 }
 
-TQSize IPLineEdit::sizeHint() const {
+TQSize IPLineEdit::tqsizeHint() const {
   TQFontMetrics fm = fontMetrics();
   
   TQSize s;
-  s.setHeight(TQLineEdit::sizeHint().height());
+  s.setHeight(TQLineEdit::tqsizeHint().height());
   s.setWidth(fm.boundingRect("888.888.888.888XX").width());
   return s;
 }
