@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: iplined.h 1157648 2010-07-31 19:48:06Z tpearson $
+ * $Id: iplined.h 1246260 2011-08-10 22:19:39Z tpearson $
  * 
  *            Copyright (C) 1997 Bernd Johannes Wuebben 
  *                   wuebben@math.cornell.edu
@@ -34,7 +34,7 @@ public:
   IPLineEdit( TQWidget *parent=0, const char *name=0 );
   ~IPLineEdit() {}
 
-  virtual TQSize sizeHint() const;
+  virtual TQSize tqsizeHint() const;
 };
 
 #endif
