@@ -2,7 +2,7 @@
 /*
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: opener.cpp 1070598 2010-01-06 06:05:05Z tpearson $
+ * $Id: opener.cpp 1259480 2011-10-18 17:20:56Z tpearson $
  *
  *              Copyright (C) 1997,98 Bernd Johannes Wuebben,
  *		                      Mario Weilguni
@@ -28,7 +28,7 @@
  *
  * Apart from the first dozen lines in main() the following code represents
  * the setuid root part of kppp. So please be careful !
- * o restrain from using X, Qt or KDE library calls
+ * o restrain from using X, TQt or KDE library calls
  * o check for possible buffer overflows
  * o handle requests from the parent process with care. They might be forged.
  * o be paranoid and think twice about everything you change.
@@ -72,6 +72,11 @@ extern "C" int _Precvmsg(int, void*, int);
 #    include <net/ppp_layer/ppp_defs.h>
 #    include <net/if.h>
 #    include <net/ppp/if_ppp.h>
+#  elif defined HAVE_LINUX_IF_PPP_H
+#    ifndef aligned_u64
+#      define aligned_u64 unsigned long long __attribute__((aligned(8)))
+#    endif
+#    include <linux/if_ppp.h>
 #  endif
 #else
 #  include <net/ppp_defs.h>
@@ -123,7 +128,7 @@ extern "C" {
 
 static void sighandler_child(int);
 static pid_t pppdPid = -1;
-static int pppdExitStatus = -1;
+static int pppdExittqStatus = -1;
 static int checkForInterface();
 
 // processing will stop at first file that could be opened successfully
@@ -311,10 +316,10 @@ void Opener::mainLoop() {
 	sendResponse(&response);
 	break;
 
-      case PPPDExitStatus:
+      case PPPDExittqStatus:
 	Debug("Opener: received PPPDExitStatus");
 	MY_ASSERT(len == sizeof(struct PPPDExitStatusRequest));
-	response.status = pppdExitStatus;
+	response.status = pppdExittqStatus;
 	sendResponse(&response);
 	break;
 
@@ -514,7 +519,7 @@ bool Opener::execpppd(const char *arguments) {
   if(ttyfd<0)
     return false;
 
-  pppdExitStatus = -1;
+  pppdExittqStatus = -1;
 
   switch(pppdPid = fork())
     {
@@ -706,10 +711,10 @@ void sighandler_child(int) {
       Debug("It was pppd that died");
       pppdPid = -1;
       if((WIFEXITED(status))) {
-	pppdExitStatus = (WEXITSTATUS(status));
-        Debug2("pppd exited with return value %d\n", pppdExitStatus);
+	pppdExittqStatus = (WEXITSTATUS(status));
+        Debug2("pppd exited with return value %d\n", pppdExittqStatus);
       } else {
-	pppdExitStatus = 99;
+	pppdExittqStatus = 99;
         Debug("pppd exited abnormally.");
       }
       Debug2("Sending %i a SIGUSR1\n", getppid());
