@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: pppdata.cpp 1157648 2010-07-31 19:48:06Z tpearson $
+ * $Id: pppdata.cpp 1246260 2011-08-10 22:19:39Z tpearson $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -300,12 +300,12 @@ void PPPData::set_redial_on_nocarrier(bool set) {
 
 
 bool PPPData::quit_on_disconnect() {
-  return (bool) readNumConfig(GENERAL_GRP, QUITONDISCONNECT_KEY, false);
+  return (bool) readNumConfig(GENERAL_GRP, TQUITONDISCONNECT_KEY, false);
 }
 
 
 void PPPData::set_quit_on_disconnect(bool set) {
-  writeConfig(GENERAL_GRP, QUITONDISCONNECT_KEY, (int) set);
+  writeConfig(GENERAL_GRP, TQUITONDISCONNECT_KEY, (int) set);
 }
 
 
@@ -350,7 +350,7 @@ void PPPData::set_dock_into_panel(bool set) {
 
 
 TQString PPPData::pppdVersion() {
-  return TQString("%1.%2.%3").arg(pppdVer).arg(pppdMod).arg(pppdPatch);
+  return TQString("%1.%2.%3").tqarg(pppdVer).tqarg(pppdMod).tqarg(pppdPatch);
 }
 
 bool PPPData::pppdVersionMin(int ver, int mod, int patch) {
@@ -498,7 +498,7 @@ int PPPData::copymodem(int i) {
   TQMap <TQString, TQString> map = config->entryMap(cmodemgroup);
   TQMap <TQString, TQString>::ConstIterator it = map.begin();
 
-  TQString newname = i18n("%1_copy").arg(modname());
+  TQString newname = i18n("%1_copy").tqarg(modname());
 
   newmodem();
 
@@ -1026,7 +1026,7 @@ int PPPData::copyaccount(int i) {
   TQMap <TQString, TQString> map = config->entryMap(caccountgroup);
   TQMap <TQString, TQString>::ConstIterator it = map.begin();
 
-  TQString newname = i18n("%1_copy").arg(accname());
+  TQString newname = i18n("%1_copy").tqarg(accname());
 
   newaccount();
 
@@ -1418,13 +1418,13 @@ void PPPData::graphingOptions(bool &enable,
   if(config) {
     config->setGroup(GRAPH_GRP);
     enable = config->readBoolEntry(GENABLED, true);
-    c = Qt::white;
+    c = TQt::white;
     bg = config->readColorEntry(GCOLOR_BG, &c);
-    c = Qt::black;
+    c = TQt::black;
     text = config->readColorEntry(GCOLOR_TEXT, &c);
-    c = Qt::blue;
+    c = TQt::blue;
     in = config->readColorEntry(GCOLOR_IN, &c);
-    c = Qt::red;
+    c = TQt::red;
     out = config->readColorEntry(GCOLOR_OUT, &c);
   }
 }
