@@ -72,7 +72,7 @@ KVncView::KVncView(TQWidget *parent,
 		   Quality quality,
 		   DotCursorState dotCursorState,
 		   const TQString &encodings) :
-  KRemoteView(parent, name, Qt::WResizeNoErase | Qt::WRepaintNoErase | Qt::WStaticContents),
+  KRemoteView(parent, name, TQt::WResizeNoErase | TQt::WRepaintNoErase | TQt::WStaticContents),
   m_cthread(this, m_wthread, m_quitFlag),
   m_wthread(this, m_quitFlag),
   m_quitFlag(false),
@@ -90,9 +90,9 @@ KVncView::KVncView(TQWidget *parent,
 	password = _password.latin1();
 	dpy = qt_xdisplay();
 	setFixedSize(16,16);
-	setFocusPolicy(TQWidget::StrongFocus);
+	setFocusPolicy(TQ_StrongFocus);
 
-	m_cb = TQApplication::clipboard();
+	m_cb = TQApplication::tqclipboard();
 	connect(m_cb, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(selectionChanged()));
 	connect(m_cb, TQT_SIGNAL(dataChanged()), this, TQT_SLOT(clipboardChanged()));
 
@@ -103,7 +103,7 @@ KVncView::KVncView(TQWidget *parent,
 					      "pics/pointcursormask.png"));
 	m_cursor = TQCursor(cursorBitmap, cursorMask);
 
-	if ((quality != QUALITY_UNKNOWN) ||
+	if ((quality != TQUALITY_UNKNOWN) ||
 	    !encodings.isNull())
 		configureApp(quality, encodings);
 }
@@ -126,11 +126,11 @@ void KVncView::showDotCursorInternal() {
 		setCursor(m_cursor);
 		break;
 	case DOT_CURSOR_OFF:
-		setCursor(TQCursor(Qt::BlankCursor));
+		setCursor(TQCursor(TQt::BlankCursor));
 		break;
 	case DOT_CURSOR_AUTO:
 		if (m_enableClientCursor)
-			setCursor(TQCursor(Qt::BlankCursor));
+			setCursor(TQCursor(TQt::BlankCursor));
 		else
 			setCursor(m_cursor);
 		break;
@@ -160,21 +160,21 @@ void KVncView::configureApp(Quality q, const TQString specialEncodings) {
 	appData.shareDesktop = 1;
 	appData.viewOnly = 0;
 
-	if (q == QUALITY_LOW) {
+	if (q == TQUALITY_LOW) {
 		appData.useBGR233 = 1;
 		appData.encodingsString = "background copyrect softcursor tight zlib hextile raw";
 		appData.compressLevel = -1;
 		appData.qualityLevel = 1;
 		appData.dotCursor = 1;
 	}
-	else if (q == QUALITY_MEDIUM) {
+	else if (q == TQUALITY_MEDIUM) {
 		appData.useBGR233 = 0;
 		appData.encodingsString = "background copyrect softcursor tight zlib hextile raw";
 		appData.compressLevel = -1;
 		appData.qualityLevel = 7;
 		appData.dotCursor = 1;
 	}
-	else if ((q == QUALITY_HIGH) || (q == QUALITY_UNKNOWN)) {
+	else if ((q == TQUALITY_HIGH) || (q == TQUALITY_UNKNOWN)) {
 		appData.useBGR233 = 0;
 		appData.encodingsString = "copyrect softcursor hextile raw";
 		appData.compressLevel = -1;
@@ -219,7 +219,7 @@ bool KVncView::checkLocalKRfb() {
 	if (m_port != portNum)
 		return true;
 
-	setStatus(REMOTE_VIEW_DISCONNECTED);
+	settqStatus(REMOTE_VIEW_DISCONNECTED);
 	KMessageBox::error(0,
 			   i18n("It is not possible to connect to a local desktop sharing service."),
 			   i18n("Connection Failure"));
@@ -236,7 +236,7 @@ bool KVncView::editPreferences( HostPrefPtr host )
 
 	// show preferences dialog
 	KDialogBase *dlg = new KDialogBase( 0L, "dlg", true,
-		i18n( "VNC Host Preferences for %1" ).arg( host->host() ),
+		i18n( "VNC Host Preferences for %1" ).tqarg( host->host() ),
 		KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true );
 
 	TQVBox *vbox = dlg->makeVBoxMainWidget();
@@ -281,11 +281,11 @@ bool KVncView::start() {
 
 		Quality quality;
 		if (ci == 0)
-			quality = QUALITY_HIGH;
+			quality = TQUALITY_HIGH;
 		else if (ci == 1)
-			quality = QUALITY_MEDIUM;
+			quality = TQUALITY_MEDIUM;
 		else if (ci == 2)
-			quality = QUALITY_LOW;
+			quality = TQUALITY_LOW;
 		else {
 			kdDebug() << "Unknown quality";
 				return false;
@@ -295,10 +295,10 @@ bool KVncView::start() {
 		useKWallet = hp->useKWallet();
 	}
 
-	setStatus(REMOTE_VIEW_CONNECTING);
+	settqStatus(REMOTE_VIEW_CONNECTING);
 
 	m_cthread.start();
-	setBackgroundMode(Qt::NoBackground);
+	setBackgroundMode(TQt::NoBackground);
 	return true;
 }
 
@@ -339,7 +339,7 @@ void KVncView::setViewOnly(bool s) {
 	m_viewOnly = s;
 
 	if (s)
-		setCursor(Qt::ArrowCursor);
+		setCursor(TQt::ArrowCursor);
 	else
 		showDotCursorInternal();
 }
@@ -390,7 +390,7 @@ void KVncView::customEvent(TQCustomEvent *e)
 	}
 	else if (e->type() == StatusChangeEventType) {
 		StatusChangeEvent *sce = (StatusChangeEvent*) e;
-		setStatus(sce->status());
+		settqStatus(sce->status());
 		if (m_status == REMOTE_VIEW_CONNECTED) {
 			emit connected();
 			setFocus();
@@ -458,7 +458,7 @@ void KVncView::customEvent(TQCustomEvent *e)
 	}
 	else if (e->type() == FatalErrorEventType) {
 		FatalErrorEvent *fee = (FatalErrorEvent*) e;
-		setStatus(REMOTE_VIEW_DISCONNECTED);
+		settqStatus(REMOTE_VIEW_DISCONNECTED);
 		switch (fee->errorCode()) {
 		case ERROR_CONNECTION:
 			KMessageBox::error(0,
@@ -514,8 +514,8 @@ void KVncView::customEvent(TQCustomEvent *e)
 		ServerCutEvent *sce = (ServerCutEvent*) e;
 		TQString ctext = TQString::fromUtf8(sce->bytes(), sce->length());
 		m_dontSendCb = true;
-		m_cb->setText(ctext, QClipboard::Clipboard);
-		m_cb->setText(ctext, QClipboard::Selection);
+		m_cb->setText(ctext, TQClipboard::Clipboard);
+		m_cb->setText(ctext, TQClipboard::Selection);
 		m_dontSendCb = false;
 	}
 	else if (e->type() == MouseStateEventType) {
@@ -536,19 +536,19 @@ void KVncView::mouseEvent(TQMouseEvent *e) {
 	if ( e->type() != TQEvent::MouseMove ) {
 		if ( (e->type() == TQEvent::MouseButtonPress) ||
                      (e->type() == TQEvent::MouseButtonDblClick)) {
-			if ( e->button() & LeftButton )
+			if ( e->button() & Qt::LeftButton )
 				m_buttonMask |= 0x01;
-			if ( e->button() & MidButton )
+			if ( e->button() & Qt::MidButton )
 				m_buttonMask |= 0x02;
-			if ( e->button() & RightButton )
+			if ( e->button() & Qt::RightButton )
 				m_buttonMask |= 0x04;
 		}
 		else if ( e->type() == TQEvent::MouseButtonRelease ) {
-			if ( e->button() & LeftButton )
+			if ( e->button() & Qt::LeftButton )
 				m_buttonMask &= 0xfe;
-			if ( e->button() & MidButton )
+			if ( e->button() & Qt::MidButton )
 				m_buttonMask &= 0xfd;
-			if ( e->button() & RightButton )
+			if ( e->button() & Qt::RightButton )
 				m_buttonMask &= 0xfb;
 		}
 	}
@@ -683,8 +683,8 @@ void KVncView::focusOutEvent(TQFocusEvent *) {
 	unpressModifiers();
 }
 
-TQSize KVncView::sizeHint() {
-	return maximumSize();
+TQSize KVncView::tqsizeHint() {
+	return tqmaximumSize();
 }
 
 void KVncView::setRemoteMouseTracking(bool s) {
@@ -702,7 +702,7 @@ void KVncView::clipboardChanged() {
 	if (m_cb->ownsClipboard() || m_dontSendCb)
 		return;
 
-	TQString text = m_cb->text(QClipboard::Clipboard);
+	TQString text = m_cb->text(TQClipboard::Clipboard);
 	if (text.length() > MAX_SELECTION_LENGTH)
 		return;
 
@@ -716,7 +716,7 @@ void KVncView::selectionChanged() {
 	if (m_cb->ownsSelection() || m_dontSendCb)
 		return;
 
-	TQString text = m_cb->text(QClipboard::Selection);
+	TQString text = m_cb->text(TQClipboard::Selection);
 	if (text.length() > MAX_SELECTION_LENGTH)
 		return;
 
