@@ -159,7 +159,7 @@ ConnectToRFBServer(const char *hostname, int port)
  * InitialiseRFBConnection.
  */
 
-enum InitStatus
+enum InittqStatus
 InitialiseRFBConnection()
 {
   rfbProtocolVersionMsg pv;
@@ -734,12 +734,12 @@ static void *MakeSoftCursor(int bpp, int cursorWidth, int cursorHeight,
 
 
 /*********************************************************************
- * HandleCursorShape(). Support for XCursor and RichCursor shape
+ * HandletqCursorShape(). Support for XCursor and RichCursor tqshape
  * updates. We emulate cursor operating on the frame buffer (that is
  * why we call it "software cursor").
  ********************************************************************/
 
-static Bool HandleCursorShape(int xhot, int yhot, int width, int height, CARD32 enc)
+static Bool HandletqCursorShape(int xhot, int yhot, int width, int height, CARD32 enc)
 {
   int bytesPerPixel;
   size_t bytesPerRow, bytesMaskData;
@@ -910,9 +910,9 @@ HandleRFBServerMessage()
       xc.blue = Swap16IfLE(rgb[2]);
       xc.flags = DoRed|DoGreen|DoBlue;
       /* Disable colormaps
-      lockQt();
+      lockTQt();
       XStoreColor(dpy, cmap, &xc);
-      unlockQt();
+      unlockTQt();
       */
     }
 
@@ -956,7 +956,7 @@ HandleRFBServerMessage()
 
       if (rect.encoding == rfbEncodingXCursor ||
 	  rect.encoding == rfbEncodingRichCursor) {
-	if (!HandleCursorShape(rect.r.x, rect.r.y, rect.r.w, rect.r.h,
+	if (!HandletqCursorShape(rect.r.x, rect.r.y, rect.r.w, rect.r.h,
 			      rect.encoding)) {
 	  return False;
 	}
