@@ -24,9 +24,10 @@ class TQComboBox;
 class TQWidgetStack;
 class LimitedCharLineEdit;
 
-class CharSelector :public QWidget
+class CharSelector :public TQWidget
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     CharSelector( TQWidget* parent, const char* name = 0 );
