@@ -105,7 +105,7 @@ ResourceCalDav::~ResourceCalDav() {
     while ((mWriter->running() == true) || (mWritingQueue.isEmpty() == false) || !mWritingQueueReady) {
         readLockout = true;
         sleep(1);
-        qApp->processEvents(TQEventLoop::ExcludeUserInput);
+        tqApp->tqprocessEvents(TQEventLoop::ExcludeUserInput);
     }
 
     if (mWriter) {
@@ -147,7 +147,7 @@ bool ResourceCalDav::doLoad() {
         return true;	// Silently fail; the user has obviously not responded to a dialog and we don't need to pop up more of them!
     }
 
-    log(TQString("doLoad(%1)").arg(syncCache));
+    log(TQString("doLoad(%1)").tqarg(syncCache));
 
     clearCache();
 
@@ -168,7 +168,7 @@ bool ResourceCalDav::doLoad() {
 bool ResourceCalDav::doSave() {
     bool syncCache = true;
 
-    log(TQString("doSave(%1)").arg(syncCache));
+    log(TQString("doSave(%1)").tqarg(syncCache));
 
     if (!hasChanges()) {
         log("no changes");
@@ -246,8 +246,8 @@ void ResourceCalDav::init() {
     mWriter = new CalDavWriter;
 
     // creating jobs
-    // Qt4 handles this quite differently, as shown below,
-    // whereas Qt3 needs events (see ::event())
+    // TQt4 handles this quite differently, as shown below,
+    // whereas TQt3 needs events (see ::event())
 //     connect(mLoader, TQT_SIGNAL(finished()), this, TQT_SLOT(loadFinished()));
 //     connect(mWriter, TQT_SIGNAL(finished()), this, TQT_SLOT(writingFinished()));
 
@@ -338,7 +338,7 @@ void ResourceCalDav::loadingQueuePop() {
     mLoader->setParent(this);
     mLoader->setType(0);
 
-    TQDateTime dt(TQDate::currentDate());
+    TQDateTime dt(TQDate::tqcurrentDate());
     mLoader->setRange(dt.addDays(-CACHE_DAYS), dt.addDays(CACHE_DAYS));
     //mLoader->setGetAll();
 
@@ -378,7 +378,7 @@ void ResourceCalDav::loadFinished() {
                 TQCString newpass;
                 if (KPasswordDialog::getPassword (newpass, TQString("<b>") + i18n("Remote authorization required") + TQString("</b><p>") + i18n("Please input the password for") + TQString(" ") + mPrefs->getusername(), NULL) != 1) {
                     log("load error: " + loader->errorString() );
-                    loadError(TQString("[%1] ").arg(abs(loader->errorNumber())) + loader->errorString());
+                    loadError(TQString("[%1] ").tqarg(abs(loader->errorNumber())) + loader->errorString());
                 }
                 else {
                     // Set new password and try again
@@ -388,12 +388,12 @@ void ResourceCalDav::loadFinished() {
             }
             else {
                 log("load error: " + loader->errorString() );
-                loadError(TQString("[%1] ").arg(abs(loader->errorNumber())) + loader->errorString());
+                loadError(TQString("[%1] ").tqarg(abs(loader->errorNumber())) + loader->errorString());
             }
         }
         else {
             log("load error: " + loader->errorString() );
-            loadError(TQString("[%1] ").arg(abs(loader->errorNumber())) + loader->errorString());
+            loadError(TQString("[%1] ").tqarg(abs(loader->errorNumber())) + loader->errorString());
         }
     } else {
         log("successful event load");
@@ -426,7 +426,7 @@ void ResourceCalDav::loadFinished() {
 //                 TQCString newpass;
 //                 if (KPasswordDialog::getPassword (newpass, TQString("<b>") + i18n("Remote authorization required") + TQString("</b><p>") + i18n("Please input the password for") + TQString(" ") + mPrefs->getusername(), NULL) != 1) {
 //                     log("load error: " + loader->tasksErrorString() );
-//                     loadError(TQString("[%1] ").arg(abs(loader->tasksErrorNumber())) + loader->tasksErrorString());
+//                     loadError(TQString("[%1] ").tqarg(abs(loader->tasksErrorNumber())) + loader->tasksErrorString());
 //                 }
 //                 else {
 //                     // Set new password and try again
@@ -436,12 +436,12 @@ void ResourceCalDav::loadFinished() {
             }
             else {
                 log("load error: " + loader->tasksErrorString() );
-                loadError(TQString("[%1] ").arg(abs(loader->tasksErrorNumber())) + loader->tasksErrorString());
+                loadError(TQString("[%1] ").tqarg(abs(loader->tasksErrorNumber())) + loader->tasksErrorString());
             }
         }
         else {
             log("load error: " + loader->tasksErrorString() );
-            loadError(TQString("[%1] ").arg(abs(loader->tasksErrorNumber())) + loader->tasksErrorString());
+            loadError(TQString("[%1] ").tqarg(abs(loader->tasksErrorNumber())) + loader->tasksErrorString());
         }
     } else {
         log("successful tasks load");
@@ -474,7 +474,7 @@ void ResourceCalDav::loadFinished() {
 //                 TQCString newpass;
 //                 if (KPasswordDialog::getPassword (newpass, TQString("<b>") + i18n("Remote authorization required") + TQString("</b><p>") + i18n("Please input the password for") + TQString(" ") + mPrefs->getusername(), NULL) != 1) {
 //                     log("load error: " + loader->journalsErrorString() );
-//                     loadError(TQString("[%1] ").arg(abs(loader->journalsErrorNumber())) + loader->journalsErrorString());
+//                     loadError(TQString("[%1] ").tqarg(abs(loader->journalsErrorNumber())) + loader->journalsErrorString());
 //                 }
 //                 else {
 //                     // Set new password and try again
@@ -484,12 +484,12 @@ void ResourceCalDav::loadFinished() {
             }
             else {
                 log("load error: " + loader->journalsErrorString() );
-                loadError(TQString("[%1] ").arg(abs(loader->journalsErrorNumber())) + loader->journalsErrorString());
+                loadError(TQString("[%1] ").tqarg(abs(loader->journalsErrorNumber())) + loader->journalsErrorString());
             }
         }
         else {
             log("load error: " + loader->journalsErrorString() );
-            loadError(TQString("[%1] ").arg(abs(loader->journalsErrorNumber())) + loader->journalsErrorString());
+            loadError(TQString("[%1] ").tqarg(abs(loader->journalsErrorNumber())) + loader->journalsErrorString());
         }
     } else {
         log("successful journals load");
@@ -971,7 +971,7 @@ void ResourceCalDav::writingFinished() {
                 TQCString newpass;
                 if (KPasswordDialog::getPassword (newpass, TQString("<b>") + i18n("Remote authorization required") + TQString("</b><p>") + i18n("Please input the password for") + TQString(" ") + mPrefs->getusername(), NULL) != 1) {
                     log("write error: " + mWriter->errorString());
-                    saveError(TQString("[%1] ").arg(abs(mWriter->errorNumber())) + mWriter->errorString());
+                    saveError(TQString("[%1] ").tqarg(abs(mWriter->errorNumber())) + mWriter->errorString());
                 }
                 else {
                     // Set new password and try again
@@ -981,12 +981,12 @@ void ResourceCalDav::writingFinished() {
             }
             else {
                 log("write error: " + mWriter->errorString());
-                saveError(TQString("[%1] ").arg(abs(mWriter->errorNumber())) + mWriter->errorString());
+                saveError(TQString("[%1] ").tqarg(abs(mWriter->errorNumber())) + mWriter->errorString());
             }
         }
         else {
             log("write error: " + mWriter->errorString());
-            saveError(TQString("[%1] ").arg(abs(mWriter->errorNumber())) + mWriter->errorString());
+            saveError(TQString("[%1] ").tqarg(abs(mWriter->errorNumber())) + mWriter->errorString());
         }
     } else {
         log("success");
@@ -1005,4 +1005,6 @@ void ResourceCalDav::writingFinished() {
     writingQueuePop();
 }
 
+#include "resource.moc"
+
 // EOF ========================================================================
