@@ -78,7 +78,7 @@ ResourceExchange::ResourceExchange( const KConfig *config )
 {
   mLock = new KABC::LockNull( true );
 
-  mTimeZoneId = TQString::fromLatin1( "UTC" );
+  mTimeZoneId = TQString::tqfromLatin1( "UTC" );
 
   kdDebug() << "Creating ResourceExchange" << endl;
   if (config ) {
@@ -139,7 +139,7 @@ bool ResourceExchange::doOpen()
   mMonitor->addWatch( mAccount->calendarURL(), ExchangeMonitor::UpdateNewMember, 1 );
 #endif
 
-  TQWidgetList* widgets = TQApplication::topLevelWidgets();
+  TQWidgetList* widgets = TQApplication::tqtopLevelWidgets();
   if ( !widgets->isEmpty() )
     mClient->setWindow( widgets->first() );
   delete widgets;
@@ -477,7 +477,7 @@ Event::List ResourceExchange::rawEventsForDate( const TQDate &qd,
   if (!mCache) return Event::List();
   // If the events for this date are not in the cache, or if they are old,
   // get them again
-  TQDateTime now = TQDateTime::currentDateTime();
+  TQDateTime now = TQDateTime::tqcurrentDateTime();
   // kdDebug() << "Now is " << now.toString() << endl;
   // kdDebug() << "mDates: " << mDates << endl;
   TQDate start = TQDate( qd.year(), qd.month(), 1 ); // First day of month
@@ -495,7 +495,7 @@ Event::List ResourceExchange::rawEventsForDate( const TQDate &qd,
     // FIXME: This is needed for the hack below:
     Event::List eventsBefore = mCache->rawEvents();
 
-    kdDebug() << "Reading events for month of " << start.toString() << endl;
+    kdDebug() << "Reading events for month of " << TQString(start.toString()) << endl;
     mClient->downloadSynchronous( mCache, start, end, true ); // Show progress dialog
 
     // FIXME: This is a terrible hack! We need to install the observer for
