@@ -70,7 +70,7 @@ ngwt__Contact* ContactConverter::convertToContact( const KABC::Addressee &addr )
     std::vector<ngwt__ContainerRef*>* container = soap_new_std__vectorTemplateOfPointerTongwt__ContainerRef( soap(), -1 );
     ngwt__ContainerRef* containerRef = soap_new_ngwt__ContainerRef( soap(), -1 );
     containerRef->deleted = 0;
-    containerRef->__item = addr.custom( "GWRESOURCE", "CONTAINER" ).utf8();
+    containerRef->__item = addr.custom( "GWRESOURCE", "CONTAINER" ).utf8().data();
     container->push_back( containerRef );
 
     contact->container = *container;
@@ -223,11 +223,11 @@ KABC::Addressee ContactConverter::convertFromAddressBookItem( ngwt__AddressBookI
     return addr;
   }
   // gwt:Item
-  addr.insertCustom( "GWRESOURCE", "UID", stringToQString( addrBkItem->id ) );
-  addr.setFormattedName( stringToQString( addrBkItem->name ) );
+  addr.insertCustom( "GWRESOURCE", "UID", stringToTQString( addrBkItem->id ) );
+  addr.setFormattedName( stringToTQString( addrBkItem->name ) );
   // gwt::AddressBookItem
-  addr.insertCustom( "GWRESOURCE", "UUID", stringToQString( addrBkItem->uuid ) );
-  addr.setNote( stringToQString( addrBkItem->comment ) );
+  addr.insertCustom( "GWRESOURCE", "UUID", stringToTQString( addrBkItem->uuid ) );
+  addr.setNote( stringToTQString( addrBkItem->comment ) );
   
   return addr;
 }
@@ -242,11 +242,11 @@ KABC::Addressee ContactConverter::convertFromResource( ngwt__Resource* resource
     return addr;
   }
   if ( resource->phone )
-    addr.insertPhoneNumber( KABC::PhoneNumber( stringToQString( resource->phone ), KABC::PhoneNumber::Work ) );
+    addr.insertPhoneNumber( KABC::PhoneNumber( stringToTQString( resource->phone ), KABC::PhoneNumber::Work ) );
   if ( resource->email )
-    addr.insertEmail( stringToQString( resource->email ), true );
+    addr.insertEmail( stringToTQString( resource->email ), true );
   if ( resource->owner )
-    addr.insertCustom( "KADDRESSBOOK", "X-ManagersName", stringToQString( resource->owner->__item ) );
+    addr.insertCustom( "KADDRESSBOOK", "X-ManagersName", stringToTQString( resource->owner->__item ) );
 
   addr.insertCategory( i18n( "Resource" ) );
   return addr;
@@ -282,24 +282,24 @@ KABC::Addressee ContactConverter::convertFromContact( ngwt__Contact* contact )
 
   if ( fullName ) {
     if ( fullName->displayName )
-      addr.setFormattedName( stringToQString( fullName->displayName ) );
+      addr.setFormattedName( stringToTQString( fullName->displayName ) );
     else
-      addr.setFormattedName( TQString::null );
+      addr.setFormattedName( TQString() );
     
     if ( fullName->namePrefix )
-      addr.setPrefix( stringToQString( fullName->namePrefix ) );
+      addr.setPrefix( stringToTQString( fullName->namePrefix ) );
 
     if ( fullName->firstName )
-      addr.setGivenName( stringToQString( fullName->firstName ) );
+      addr.setGivenName( stringToTQString( fullName->firstName ) );
 
     if ( fullName->middleName )
-      addr.setAdditionalName( stringToQString( fullName->middleName ) );
+      addr.setAdditionalName( stringToTQString( fullName->middleName ) );
 
     if ( fullName->lastName )
-      addr.setFamilyName( stringToQString( fullName->lastName ) );
+      addr.setFamilyName( stringToTQString( fullName->lastName ) );
 
     if ( fullName->nameSuffix )
-      addr.setSuffix( stringToQString( fullName->nameSuffix ) );
+      addr.setSuffix( stringToTQString( fullName->nameSuffix ) );
   }
 
   // Emails
@@ -307,14 +307,14 @@ KABC::Addressee ContactConverter::convertFromContact( ngwt__Contact* contact )
      TQStringList emails;
 
      if ( contact->emailList->primary )
-         emails.append( stringToQString( contact->emailList->primary ) );
+         emails.append( stringToTQString( contact->emailList->primary ) );
 
      if ( !contact->emailList->email.empty() ) {
        std::vector<std::string> list = contact->emailList->email;
        std::vector<std::string>::const_iterator it;
        for ( it = list.begin(); it != list.end(); ++it ) {
-         if ( emails.find( stringToQString( *it ) ) == emails.end() )
-           emails.append( stringToQString( *it ) );
+         if ( emails.find( stringToTQString( *it ) ) == emails.end() )
+           emails.append( stringToTQString( *it ) );
        }
      }
 
@@ -324,7 +324,7 @@ KABC::Addressee ContactConverter::convertFromContact( ngwt__Contact* contact )
 
   // Phone numbers
   if ( contact->phoneList && !contact->phoneList->phone.empty() ) {
-    TQString defaultNumber = stringToQString( contact->phoneList->default_ );
+    TQString defaultNumber = stringToTQString( contact->phoneList->default_ );
 
     std::vector<class ngwt__PhoneNumber*> list = contact->phoneList->phone;
     std::vector<class ngwt__PhoneNumber*>::const_iterator it;
@@ -354,16 +354,16 @@ KABC::Addressee ContactConverter::convertFromContact( ngwt__Contact* contact )
     ngwt__OfficeInfo* info = contact->officeInfo;
 
     if ( info->organization )
-      addr.setOrganization( stringToQString( info->organization->__item ) );
+      addr.setOrganization( stringToTQString( info->organization->__item ) );
 
     if ( info->department )
-      addr.insertCustom( "KADDRESSBOOK", "X-Department", stringToQString( info->department ) );
+      addr.insertCustom( "KADDRESSBOOK", "X-Department", stringToTQString( info->department ) );
 
     if ( info->title )
-      addr.setTitle( stringToQString( info->title ) );
+      addr.setTitle( stringToTQString( info->title ) );
 
     if ( info->website )
-      addr.setUrl( KURL( stringToQString( info->website ) ) );
+      addr.setUrl( KURL( stringToTQString( info->website ) ) );
   }
 
   // Personal information
@@ -371,13 +371,13 @@ KABC::Addressee ContactConverter::convertFromContact( ngwt__Contact* contact )
     ngwt__PersonalInfo* info = contact->personalInfo;
 
     if ( info->birthday ) {
-      TQDate date = stringToQDate( info->birthday );
+      TQDate date = stringToTQDate( info->birthday );
       if ( date.isValid() )
         addr.setBirthday( date );
     }
 
     if ( info->website ) // we might overwrite the office info website here... :(
-      addr.setUrl( KURL( stringToQString( info->website ) ) );
+      addr.setUrl( KURL( stringToTQString( info->website ) ) );
   }
 
   // IM addresses
@@ -387,9 +387,9 @@ KABC::Addressee ContactConverter::convertFromContact( ngwt__Contact* contact )
     std::vector<ngwt__ImAddress*> list = contact->imList->im;
     std::vector<ngwt__ImAddress*>::const_iterator it;
     for ( it = list.begin(); it != list.end(); ++it ) {
-      TQStringList addressesForService = addressMap[ stringToQString( (*it)->service ) ];
-      addressesForService.append( stringToQString( (*it)->address ) );
-      addressMap.insert( stringToQString( (*it)->service ), addressesForService );
+      TQStringList addressesForService = addressMap[ stringToTQString( (*it)->service ) ];
+      addressesForService.append( stringToTQString( (*it)->address ) );
+      addressMap.insert( stringToTQString( (*it)->service ), addressesForService );
     }
 
     // then construct a custom field from each qstringlist
@@ -402,8 +402,8 @@ KABC::Addressee ContactConverter::convertFromContact( ngwt__Contact* contact )
       // TODO: map protocol to KDE's set of known protocol names (need to know the set of services in use elsewhere)
       if ( protocol == "nov" )
         protocol = "groupwise";
-      addr.insertCustom( TQString::fromLatin1("messaging/%1").arg( protocol ),
-                          TQString::fromLatin1( "All" ),
+      addr.insertCustom( TQString::tqfromLatin1("messaging/%1").tqarg( protocol ),
+                          TQString::tqfromLatin1( "All" ),
                           addresses.join( TQChar( 0xE000 ) ) );
     }
   }
@@ -432,7 +432,7 @@ KABC::PhoneNumber ContactConverter::convertPhoneNumber( ngwt__PhoneNumber *phone
   if ( !phone )
     return phoneNumber;
 
-  phoneNumber.setNumber( stringToQString( phone->__item ) );
+  phoneNumber.setNumber( stringToTQString( phone->__item ) );
   if ( phone->type == Fax ) {
     phoneNumber.setType( KABC::PhoneNumber::Fax );
   } else if ( phone->type == Home ) {
@@ -456,7 +456,7 @@ ngwt__PhoneNumber* ContactConverter::convertPhoneNumber( const KABC::PhoneNumber
     return 0;
 
   ngwt__PhoneNumber* phoneNumber = soap_new_ngwt__PhoneNumber( soap(), -1 );
-  phoneNumber->__item = number.number().utf8();
+  phoneNumber->__item = number.number().utf8().data();
 
   if ( number.type() & KABC::PhoneNumber::Fax ) {
     phoneNumber->type = Fax;
@@ -483,22 +483,22 @@ KABC::Address ContactConverter::convertPostalAddress( ngwt__PostalAddress *addr
     return address;
 
   if ( addr->streetAddress )
-    address.setStreet( stringToQString( addr->streetAddress ) );
+    address.setStreet( stringToTQString( addr->streetAddress ) );
 
   if ( addr->location )
-    address.setExtended( stringToQString( addr->location ) );
+    address.setExtended( stringToTQString( addr->location ) );
 
   if ( addr->city ) // isn't city the same like location?
-    address.setLocality( stringToQString( addr->city ) );
+    address.setLocality( stringToTQString( addr->city ) );
 
   if ( addr->state )
-    address.setRegion( stringToQString( addr->state ) );
+    address.setRegion( stringToTQString( addr->state ) );
 
   if ( addr->postalCode )
-    address.setPostalCode( stringToQString( addr->postalCode ) );
+    address.setPostalCode( stringToTQString( addr->postalCode ) );
 
   if ( addr->country )
-    address.setCountry( stringToQString( addr->country ) );
+    address.setCountry( stringToTQString( addr->country ) );
 
   if ( addr->type == Home_ ) {
     address.setType( KABC::Address::Home );
@@ -583,7 +583,7 @@ ngwt__ImAddressList* ContactConverter::convertImAddresses( const KABC::Addressee
     TQString app, name, value;
     splitField( *it, app, name, value );
 
-    if ( app.startsWith( TQString::fromLatin1( "messaging/" ) ) && name == TQString::fromLatin1( "All" ) ) {
+    if ( app.startsWith( TQString::tqfromLatin1( "messaging/" ) ) && name == TQString::tqfromLatin1( "All" ) ) {
       // get the protocol for this field
       TQString protocol = app.section( '/', 1, 1 );
       if ( !protocol.isEmpty() ) {
