@@ -65,10 +65,10 @@ KCal::Event* IncidenceConverter::convertFromAppointment( ngwt__Appointment* appo
     event->setFloats( true );
 
     if ( appointment->startDay != 0 )
-      event->setDtStart( stringToQDate( appointment->startDay ).addDays( 1 ) );
+      event->setDtStart( stringToTQDate( appointment->startDay ).addDays( 1 ) );
 
     if ( appointment->endDay != 0 )
-      event->setDtEnd( stringToQDate( appointment->endDay) );
+      event->setDtEnd( stringToTQDate( appointment->endDay) );
     
     kdDebug() << " all day event." << endl;
   }
@@ -77,11 +77,11 @@ KCal::Event* IncidenceConverter::convertFromAppointment( ngwt__Appointment* appo
     event->setFloats( false );
 
     if ( appointment->startDate != 0 ) {
-      event->setDtStart( charToQDateTime( appointment->startDate, mTimezone ) );
+      event->setDtStart( charToTQDateTime( appointment->startDate, mTimezone ) );
     }
     
     if ( appointment->endDate != 0 )
-      event->setDtEnd( charToQDateTime( appointment->endDate, mTimezone ) );
+      event->setDtEnd( charToTQDateTime( appointment->endDate, mTimezone ) );
   }
 
   kdDebug() << "start date: " << event->dtStart() << endl;
@@ -94,7 +94,7 @@ KCal::Event* IncidenceConverter::convertFromAppointment( ngwt__Appointment* appo
   }
 
   if ( appointment->place )
-    event->setLocation( stringToQString( appointment->place ) );
+    event->setLocation( stringToTQString( appointment->place ) );
 
   if ( appointment->acceptLevel ) {
     if ( *appointment->acceptLevel == Tentative )
@@ -206,16 +206,16 @@ KCal::Todo* IncidenceConverter::convertFromTask( ngwt__Task* task )
 
   if ( task->startDate ) {
     todo->setHasStartDate( true );
-    todo->setDtStart( stringToQDateTime( task->startDate ) );
+    todo->setDtStart( stringToTQDateTime( task->startDate ) );
   }
 
   if ( task->dueDate ) {
     todo->setHasDueDate( true );
-    todo->setDtDue( stringToQDateTime( task->dueDate ) );
+    todo->setDtDue( stringToTQDateTime( task->dueDate ) );
   }
 
   if ( task->taskPriority ) {
-    TQString priority = stringToQString( task->taskPriority );
+    TQString priority = stringToTQString( task->taskPriority );
 
     // FIXME: Store priority string somewhere
 
@@ -284,7 +284,7 @@ KCal::Journal* IncidenceConverter::convertFromNote( ngwt__Note* note)
 
   if ( note->startDate ) {
     kdDebug() << "Journal start date is: " << note->startDate->c_str() << endl;
-    journal->setDtStart( stringToQDate( note->startDate ) );
+    journal->setDtStart( stringToTQDate( note->startDate ) );
   }
 
   return journal;
@@ -370,7 +370,7 @@ bool IncidenceConverter::convertToCalendarItem( KCal::Incidence* incidence, ngwt
     std::vector<ngwt__ContainerRef*>* container = soap_new_std__vectorTemplateOfPointerTongwt__ContainerRef( soap(), -1 );
     ngwt__ContainerRef* containerRef = soap_new_ngwt__ContainerRef( soap(), -1 );
     containerRef->deleted = 0;
-    containerRef->__item = incidence->customProperty( "GWRESOURCE", "CONTAINER" ).utf8();
+    containerRef->__item = incidence->customProperty( "GWRESOURCE", "CONTAINER" ).utf8().data();
     container->push_back( containerRef );
 
     item->container = *container;
@@ -470,7 +470,7 @@ void IncidenceConverter::setAttendees( KCal::Incidence *incidence,
   KCal::Attendee::List::ConstIterator it;
   for( it = attendees.begin(); it != attendees.end(); ++it ) {
     if ( !to.isEmpty() )
-      to += TQString::fromLatin1( ";  %1" ).arg( (*it)->name() );
+      to += TQString::tqfromLatin1( ";  %1" ).tqarg( (*it)->name() );
     kdDebug() << "IncidenceConverter::setAttendees(), adding " << (*it)->fullName()
       << endl;
     TQString uuid;
@@ -489,7 +489,7 @@ ngwt__Recipient *IncidenceConverter::createRecipient( const TQString &name,
 {
   ngwt__Recipient *recipient = soap_new_ngwt__Recipient( soap(), -1 );
 
-  recipient->recipientStatus = 0;
+  recipient->recipientqStatus = 0;
   if ( !uuid.isEmpty() ) recipient->uuid = qStringToString( uuid );
   else recipient->uuid = 0;
   if ( !name.isEmpty() ) {
@@ -514,20 +514,20 @@ bool IncidenceConverter::convertFromCalendarItem( ngwt__CalendarItem* item,
   KCal::Incidence* incidence )
 {
   incidence->setCustomProperty( "GWRESOURCE", "UID",
-                                stringToQString( item->id ) );
+                                stringToTQString( item->id ) );
 
   if ( item->subject && !item->subject->empty() )
-    incidence->setSummary( stringToQString( item->subject ) );
+    incidence->setSummary( stringToTQString( item->subject ) );
 
   kdDebug() << "SUMMARY: " << incidence->summary() << endl;
 
   if ( item->created ) {
     kdDebug() << "item created at " << item->created << endl;
-    incidence->setCreated( charToQDateTime( item->created, mTimezone ) );
+    incidence->setCreated( charToTQDateTime( item->created, mTimezone ) );
   }
   if ( item->modified != 0 ) {
     kdDebug() << "item modified at " << item->created << endl;
-    incidence->setLastModified( charToQDateTime( item->modified, mTimezone ) );
+    incidence->setLastModified( charToTQDateTime( item->modified, mTimezone ) );
   }
 
   getItemDescription( item, incidence );
@@ -567,7 +567,7 @@ void IncidenceConverter::getItemDescription( ngwt__CalendarItem *item, KCal::Inc
       xsd__base64Binary data = (*it)->__item;
 
       // text/plain should be the description
-      if ( stringToQString( (*it)->contentType ) == "text/plain" ) {
+      if ( stringToTQString( (*it)->contentType ) == "text/plain" ) {
         TQString description = TQString::fromUtf8( (char*)data.__ptr, data.__size );
         incidence->setDescription( description );
         kdDebug() << "Incidence description decodes to: " << description << endl;
@@ -615,8 +615,8 @@ void IncidenceConverter::getAttendees( ngwt__CalendarItem *item, KCal::Incidence
 
   if ( item->distribution && item->distribution->from ) {
     kdDebug() << "-- from" << endl;
-    KCal::Person organizer( stringToQString( item->distribution->from->displayName ),
-                            stringToQString( item->distribution->from->email ) );
+    KCal::Person organizer( stringToTQString( item->distribution->from->displayName ),
+                            stringToTQString( item->distribution->from->email ) );
     incidence->setOrganizer( organizer );
   }
 
@@ -629,13 +629,13 @@ void IncidenceConverter::getAttendees( ngwt__CalendarItem *item, KCal::Incidence
       ngwt__Recipient *recipient = *it;
       kdDebug() << "---- recipient " << recipient->email->c_str() << endl;
       KCal::Attendee *attendee = new KCal::Attendee(
-        stringToQString( recipient->displayName ),
-        stringToQString( recipient->email ) );
+        stringToTQString( recipient->displayName ),
+        stringToTQString( recipient->email ) );
 
       // set our status
-      if ( emailsMatch( stringToQString(recipient->email), mFromEmail ) )
+      if ( emailsMatch( stringToTQString(recipient->email), mFromEmail ) )
         if ( item->status->accepted )
-          attendee->setStatus( ( *item->status->accepted ) ? KCal::Attendee::Accepted : KCal::Attendee::NeedsAction );
+          attendee->setqStatus( ( *item->status->accepted ) ? KCal::Attendee::Accepted : KCal::Attendee::NeedsAction );
         else 
           kdDebug() << "---- found ourselves, but not accepted" << endl;
       else
@@ -704,7 +704,7 @@ void IncidenceConverter::setRecurrence( KCal::Incidence * incidence, ngwt__Calen
       for ( KCal::DateList::ConstIterator it = exceptions.begin(); it != exceptions.end(); ++it )
       {
         std::string startDate;
-        startDate.append( (*it).toString( Qt::ISODate ).utf8() );
+        startDate.append( TQString((*it).toString( Qt::ISODate )).utf8() );
         item->exdate->date.push_back( startDate );
       }
     }
