@@ -380,8 +380,8 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 # endif
 #endif
 
-/* QNX does not have a working version of strtof */
-#if defined(__QNX__) || defined(QNX)
+/* TQNX does not have a working version of strtof */
+#if defined(__TQNX__) || defined(TQNX)
 # undef HAVE_STRTOF
 #endif
 
@@ -547,7 +547,7 @@ extern "C" {
 /* Portability: define SOAP_SOCKLEN_T */
 #if defined(SOCKLEN_T)
 # define SOAP_SOCKLEN_T SOCKLEN_T
-#elif defined(__socklen_t_defined) || defined(_SOCKLEN_T) || defined(CYGWIN) || defined(FREEBSD) || defined(__FreeBSD__) || defined(__QNX__) || defined(QNX) || defined(_AIX) || defined(__NetBSD__) || defined(__DragonFly__)
+#elif defined(__socklen_t_defined) || defined(_SOCKLEN_T) || defined(CYGWIN) || defined(FREEBSD) || defined(__FreeBSD__) || defined(__TQNX__) || defined(TQNX) || defined(_AIX) || defined(__NetBSD__) || defined(__DragonFly__)
 # define SOAP_SOCKLEN_T socklen_t
 #elif defined(IRIX) || defined(WIN32) || defined(__APPLE__) || defined(HP_UX) || defined(SUN_OS) || defined(OPENSERVER) || defined(__osf__) || defined(VXWORKS)
 # define SOAP_SOCKLEN_T int
@@ -849,12 +849,12 @@ extern const struct soap_double_nan { unsigned int n1, n2; } soap_double_nan;
 #define SOAP_VERSIONMISMATCH		32
 #define SOAP_PLUGIN_ERROR		33
 #define SOAP_DATAENCODINGUNKNOWN	34
-#define SOAP_REQUIRED			35
+#define SOAP_RETQUIRED			35
 #define SOAP_PROHIBITED			36
 #define SOAP_OCCURS			37
 #define SOAP_LENGTH			38
 
-#define soap_xml_error_check(e) ((e) == SOAP_TAG_MISMATCH || (e) == SOAP_TAG_END || (e) == SOAP_SYNTAX_ERROR || (e) == SOAP_NAMESPACE || (e) == SOAP_MULTI_ID || (e) == SOAP_MISSING_ID || (e) == SOAP_REQUIRED || (e) == SOAP_PROHIBITED || (e) == SOAP_OCCURS || (e) == SOAP_LENGTH || (e) == SOAP_NULL || (e) == SOAP_HREF)
+#define soap_xml_error_check(e) ((e) == SOAP_TAG_MISMATCH || (e) == SOAP_TAG_END || (e) == SOAP_SYNTAX_ERROR || (e) == SOAP_NAMESPACE || (e) == SOAP_MULTI_ID || (e) == SOAP_MISSING_ID || (e) == SOAP_RETQUIRED || (e) == SOAP_PROHIBITED || (e) == SOAP_OCCURS || (e) == SOAP_LENGTH || (e) == SOAP_NULL || (e) == SOAP_HREF)
 #define soap_soap_error_check(e) ((e) == SOAP_CLI_FAULT || (e) == SOAP_SVR_FAULT || (e) == SOAP_VERSIONMISMATCH || (e) == SOAP_MUSTUNDERSTAND || (e) == SOAP_FAULT || (e) == SOAP_NO_METHOD)
 #define soap_tcp_error_check(e) ((e) == SOAP_EOF || (e) == SOAP_TCP_ERROR)
 #define soap_ssl_error_check(e) ((e) == SOAP_SSL_ERROR)
@@ -936,10 +936,10 @@ typedef soap_int32 soap_mode;
 /* SSL client/server authentication settings */
 
 #define SOAP_SSL_NO_AUTHENTICATION		0x00	/* for testing purposes */
-#define SOAP_SSL_REQUIRE_SERVER_AUTHENTICATION	0x01	/* client requires server to authenticate */
-#define SOAP_SSL_REQUIRE_CLIENT_AUTHENTICATION	0x02	/* server requires client to authenticate */
+#define SOAP_SSL_RETQUIRE_SERVER_AUTHENTICATION	0x01	/* client requires server to authenticate */
+#define SOAP_SSL_RETQUIRE_CLIENT_AUTHENTICATION	0x02	/* server requires client to authenticate */
 
-#define SOAP_SSL_DEFAULT			SOAP_SSL_REQUIRE_SERVER_AUTHENTICATION
+#define SOAP_SSL_DEFAULT			SOAP_SSL_RETQUIRE_SERVER_AUTHENTICATION
 
 /* */
 
@@ -1157,7 +1157,7 @@ enum soap_mime_encoding
   SOAP_MIME_7BIT,
   SOAP_MIME_8BIT,
   SOAP_MIME_BINARY,
-  SOAP_MIME_QUOTED_PRINTABLE,
+  SOAP_MIME_TQUOTED_PRINTABLE,
   SOAP_MIME_BASE64,
   SOAP_MIME_IETF_TOKEN,
   SOAP_MIME_X_TOKEN
@@ -1294,7 +1294,7 @@ struct soap
   int send_timeout;		/* when > 0, gives socket send timeout in seconds, < 0 in usec */
   int connect_timeout;		/* when > 0, gives socket connect() timeout in seconds, < 0 in usec */
   int accept_timeout;		/* when > 0, gives socket accept() timeout in seconds, < 0 in usec */
-  int socket_flags;		/* socket recv() and send() flags, e.g. set to MSG_NOQT_SIGNAL to disable sigpipe */
+  int socket_flags;		/* socket recv() and send() flags, e.g. set to MSG_NOTQT_SIGNAL to disable sigpipe */
   int connect_flags;		/* connect() SOL_SOCKET sockopt flags, e.g. set to SO_DEBUG to debug socket */
   int bind_flags;		/* bind() SOL_SOCKET sockopt flags, e.g. set to SO_REUSEADDR to enable reuse */
   int accept_flags;		/* accept() SOL_SOCKET sockopt flags */
@@ -1350,8 +1350,8 @@ struct soap
   std::ostream *os;
   std::istream *is;
 #else
-  void *os;	/* preserve alignment */
-  void *is;	/* preserve alignment */
+  void *os;	/* preserve tqalignment */
+  void *is;	/* preserve tqalignment */
 #endif
 #ifndef UNDER_CE
   int sendfd;
@@ -1822,7 +1822,7 @@ SOAP_FMAC1 int SOAP_FMAC2 soap_s2unsignedInt(struct soap*, const char*, unsigned
 SOAP_FMAC1 int SOAP_FMAC2 soap_s2unsignedLong(struct soap*, const char*, unsigned long*);
 SOAP_FMAC1 int SOAP_FMAC2 soap_s2ULONG64(struct soap*, const char*, ULONG64*);
 SOAP_FMAC1 int SOAP_FMAC2 soap_s2string(struct soap*, const char*, char**);
-SOAP_FMAC1 int SOAP_FMAC2 soap_s2QName(struct soap*, const char*, char**);
+SOAP_FMAC1 int SOAP_FMAC2 soap_s2TQName(struct soap*, const char*, char**);
 
 #ifndef WITH_LEAN
 SOAP_FMAC1 int SOAP_FMAC2 soap_s2dateTime(struct soap*, const char*, time_t*);
@@ -1842,7 +1842,7 @@ SOAP_FMAC1 const char* SOAP_FMAC2 soap_unsignedShort2s(struct soap*, unsigned sh
 SOAP_FMAC1 const char* SOAP_FMAC2 soap_unsignedInt2s(struct soap*, unsigned int);
 SOAP_FMAC1 const char* SOAP_FMAC2 soap_unsignedLong2s(struct soap*, unsigned long);
 SOAP_FMAC1 const char* SOAP_FMAC2 soap_ULONG642s(struct soap*, ULONG64);
-SOAP_FMAC1 const char* SOAP_FMAC2 soap_QName2s(struct soap*, const char*);
+SOAP_FMAC1 const char* SOAP_FMAC2 soap_TQName2s(struct soap*, const char*);
 
 #ifndef WITH_LEAN
 SOAP_FMAC1 const char* SOAP_FMAC2 soap_dateTime2s(struct soap*, time_t);
