@@ -20,11 +20,11 @@
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
+    the TQt library by Trolltech AS, Norway (or with modified versions
+    of TQt that use the same license as TQt), and distribute linked
     combinations including the two.  You must obey the GNU General
     Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
+    TQt.  If you modify this file, you may extend this exception to
     your version of the file, but you are not obligated to do so.  If
     you do not wish to do so, delete this exception statement from
     your version.
@@ -57,7 +57,7 @@ Contact::Contact( const KABC::Addressee* addr )
 }
 
 // loading (xml->addressee)
-Contact::Contact( const TQString& xml, KABC::ResourceKolab* resource, const TQString& subResource, Q_UINT32 sernum )
+Contact::Contact( const TQString& xml, KABC::ResourceKolab* resource, const TQString& subResource, TQ_UINT32 sernum )
   : mHasGeo( false )
 {
   load( xml );
@@ -293,12 +293,12 @@ TQDate Contact::anniversary() const
   return mAnniversary;
 }
 
-void Contact::setChildren( const TQString& children )
+void Contact::setChildren( const TQString& tqchildren )
 {
-  mChildren = children;
+  mChildren = tqchildren;
 }
 
-TQString Contact::children() const
+TQString Contact::tqchildren() const
 {
   return mChildren;
 }
@@ -487,7 +487,7 @@ void Contact::saveCustomAttributes( TQDomElement& element ) const
       writeString( element, (*it).name, (*it).value );
     } else {
       // skip writing the freebusyurl as it is a hack we need to remove eventually
-      if ( (*it).name == TQString::fromLatin1( "FreeBusyURL" ) ) {
+      if ( (*it).name == TQString::tqfromLatin1( "FreeBusyURL" ) ) {
         continue;
       }
 
@@ -619,7 +619,7 @@ bool Contact::loadAttribute( TQDomElement& element )
     }
     break;
   case 'c':
-    if ( tagName == "children" ) {
+    if ( tagName == "tqchildren" ) {
       setChildren( element.text() );
       return true;
     }
@@ -798,7 +798,7 @@ bool Contact::saveAttributes( TQDomElement& element ) const
       writeString( element, "x-logo", mLogoAttachmentName );
     if ( !sound().isNull() )
       writeString( element, "x-sound", mSoundAttachmentName );
-    writeString( element, "children", children() );
+    writeString( element, "tqchildren", tqchildren() );
     writeString( element, "gender", gender() );
     writeString( element, "language", language() );
     savePhoneAttributes( element );
@@ -1110,7 +1110,7 @@ void Contact::setFields( const KABC::Addressee* addressee )
   //    (includes e.g. crypto settings, and extra im addresses)
   TQStringList knownCustoms;
   for ( const char** p = s_knownCustomFields; *p; ++p )
-    knownCustoms << TQString::fromLatin1( *p );
+    knownCustoms << TQString::tqfromLatin1( *p );
   TQStringList customs = addressee->customs();
   for( TQStringList::Iterator it = customs.begin(); it != customs.end(); ++it ) {
     // KABC::Addressee doesn't offer a real way to iterate over customs, other than splitting strings ourselves
@@ -1146,7 +1146,7 @@ void Contact::setFields( const KABC::Addressee* addressee )
   // mailer, timezone, productId, sortString, agent, rfc2426 name()
 
   // Things KAddressBook can't handle, so they are saved as unhandled tags:
-  // initials, children, gender, language
+  // initials, tqchildren, gender, language
 }
 
 // The loading is: xml -> Contact -> addressee, this is the second part
@@ -1253,13 +1253,13 @@ void Contact::saveTo( KABC::Addressee* addressee )
   }
 
   for( TQValueList<Custom>::ConstIterator it = mCustomList.begin(); it != mCustomList.end(); ++it ) {
-    TQString app = (*it).app.isEmpty() ? TQString::fromLatin1( "KADDRESSBOOK" ) : (*it).app;
+    TQString app = (*it).app.isEmpty() ? TQString::tqfromLatin1( "KADDRESSBOOK" ) : (*it).app;
     addressee->insertCustom( app, (*it).name, (*it).value );
   }
   //kdDebug(5006) << addressee->customs() << endl;
 }
 
-TQImage Contact::loadPictureFromKMail( const TQString& attachmentName, KABC::ResourceKolab* resource, const TQString& subResource, Q_UINT32 sernum )
+TQImage Contact::loadPictureFromKMail( const TQString& attachmentName, KABC::ResourceKolab* resource, const TQString& subResource, TQ_UINT32 sernum )
 {
   TQImage img;
   KURL url;
@@ -1285,7 +1285,7 @@ TQImage Contact::loadPictureFromAddressee( const KABC::Picture& picture )
   return img;
 }
 
-TQByteArray Kolab::Contact::loadDataFromKMail( const TQString& attachmentName, KABC::ResourceKolab* resource, const TQString& subResource, Q_UINT32 sernum )
+TQByteArray Kolab::Contact::loadDataFromKMail( const TQString& attachmentName, KABC::ResourceKolab* resource, const TQString& subResource, TQ_UINT32 sernum )
 {
   TQByteArray data;
   KURL url;
