@@ -21,11 +21,11 @@
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
+    the TQt library by Trolltech AS, Norway (or with modified versions
+    of TQt that use the same license as TQt), and distribute linked
     combinations including the two.  You must obey the GNU General
     Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
+    TQt.  If you modify this file, you may extend this exception to
     your version of the file, but you are not obligated to do so.  If
     you do not wish to do so, delete this exception statement from
     your version.
@@ -49,9 +49,9 @@
 using namespace Kolab;
 
 
-Incidence::Incidence( KCal::ResourceKolab *res, const TQString &subResource, Q_UINT32 sernum,
+Incidence::Incidence( KCal::ResourceKolab *res, const TQString &subResource, TQ_UINT32 sernum,
                       const TQString& tz )
-  : KolabBase( tz ), mFloatingStatus( Unset ), mHasAlarm( false ),
+  : KolabBase( tz ), mFloatingtqStatus( Unset ), mHasAlarm( false ),
     mResource( res ),
     mSubResource( subResource ),
     mSernum( sernum )
@@ -95,17 +95,17 @@ KolabBase::Email Incidence::organizer() const
 void Incidence::setStartDate( const TQDateTime& startDate )
 {
   mStartDate = startDate;
-  if ( mFloatingStatus == AllDay )
+  if ( mFloatingtqStatus == AllDay )
     kdDebug() << "ERROR: Time on start date but no time on the event\n";
-  mFloatingStatus = HasTime;
+  mFloatingtqStatus = HasTime;
 }
 
 void Incidence::setStartDate( const TQDate& startDate )
 {
   mStartDate = startDate;
-  if ( mFloatingStatus == HasTime )
+  if ( mFloatingtqStatus == HasTime )
     kdDebug() << "ERROR: No time on start date but time on the event\n";
-  mFloatingStatus = AllDay;
+  mFloatingtqStatus = AllDay;
 }
 
 void Incidence::setStartDate( const TQString& startDate )
@@ -546,7 +546,7 @@ bool Incidence::saveAttributes( TQDomElement& element ) const
   // Save the base class elements
   KolabBase::saveAttributes( element );
 
-  if ( mFloatingStatus == HasTime )
+  if ( mFloatingtqStatus == HasTime )
     writeString( element, "start-date", dateTimeToString( startDate() ) );
   else
     writeString( element, "start-date", dateToString( startDate().date() ) );
@@ -559,7 +559,7 @@ bool Incidence::saveAttributes( TQDomElement& element ) const
   saveAttachments( element );
   if ( mHasAlarm ) {
     // Alarms should be minutes before. Libkcal uses event time + alarm time
-    int alarmTime = qRound( -alarm() );
+    int alarmTime = tqRound( -alarm() );
     writeString( element, "alarm", TQString::number( alarmTime ) );
   }
   saveAlarms( element );
@@ -595,7 +595,7 @@ void Incidence::loadCustomAttributes( TQDomElement& element )
   mCustomList.append( custom );
 }
 
-static KCal::Attendee::PartStat attendeeStringToStatus( const TQString& s )
+static KCal::Attendee::PartStat attendeeStringTotqStatus( const TQString& s )
 {
   if ( s == "none" )
     return KCal::Attendee::NeedsAction;
@@ -771,10 +771,10 @@ void Incidence::setFields( const KCal::Incidence* incidence )
 
   if ( incidence->doesFloat() ) {
     // This is a floating event. Don't timezone move this one
-    mFloatingStatus = AllDay;
+    mFloatingtqStatus = AllDay;
     setStartDate( incidence->dtStart().date() );
   } else {
-    mFloatingStatus = HasTime;
+    mFloatingtqStatus = HasTime;
     setStartDate( localToUTC( incidence->dtStart() ) );
   }
 
@@ -844,7 +844,7 @@ void Incidence::setFields( const KCal::Incidence* incidence )
   // Handle the scheduling ID
   if ( incidence->schedulingID() == incidence->uid() ) {
     // There is no scheduling ID
-    setInternalUID( TQString::null );
+    setInternalUID( TQString() );
   } else {
     // We've internally been using a different uid, so save that as the
     // temporary (internal) uid and restore the original uid, the one that
@@ -856,7 +856,7 @@ void Incidence::setFields( const KCal::Incidence* incidence )
   if ( incidence->pilotId() != 0 )
     setPilotSyncId( incidence->pilotId() );
 
-  setPilotSyncStatus( incidence->syncStatus() );
+  setPilotSynctqStatus( incidence->synctqStatus() );
 
   // Unhandled tags and other custom properties (see libkcal/customproperties.h)
   const TQMap<TQCString, TQString> map = incidence->customProperties();
@@ -886,7 +886,7 @@ void Incidence::saveTo( KCal::Incidence* incidence )
 {
   KolabBase::saveTo( incidence );
 
-  if ( mFloatingStatus == AllDay ) {
+  if ( mFloatingtqStatus == AllDay ) {
     // This is a floating event. Don't timezone move this one
     incidence->setDtStart( startDate() );
     incidence->setFloats( true );
@@ -900,7 +900,7 @@ void Incidence::saveTo( KCal::Incidence* incidence )
 
   if ( mHasAlarm && mAlarms.isEmpty() ) {
     KCal::Alarm* alarm = incidence->newAlarm();
-    alarm->setStartOffset( qRound( mAlarm * 60.0 ) );
+    alarm->setStartOffset( tqRound( mAlarm * 60.0 ) );
     alarm->setEnabled( true );
     alarm->setType( KCal::Alarm::Display );
   } else if ( !mAlarms.isEmpty() ) {
@@ -920,7 +920,7 @@ void Incidence::saveTo( KCal::Incidence* incidence )
   incidence->clearAttendees();
   TQValueList<Attendee>::ConstIterator it;
   for ( it = mAttendees.begin(); it != mAttendees.end(); ++it ) {
-    KCal::Attendee::PartStat status = attendeeStringToStatus( (*it).status );
+    KCal::Attendee::PartStat status = attendeeStringTotqStatus( (*it).status );
     KCal::Attendee::Role role = attendeeStringToRole( (*it).role );
     KCal::Attendee* attendee = new KCal::Attendee( (*it).displayName,
                                                    (*it).smtpAddress,
@@ -994,8 +994,8 @@ void Incidence::saveTo( KCal::Incidence* incidence )
   }
   if ( hasPilotSyncId() )
     incidence->setPilotId( pilotSyncId() );
-  if ( hasPilotSyncStatus() )
-    incidence->setSyncStatus( pilotSyncStatus() );
+  if ( hasPilotSynctqStatus() )
+    incidence->setSynctqStatus( pilotSynctqStatus() );
 
   for( TQValueList<Custom>::ConstIterator it = mCustomList.constBegin(); it != mCustomList.constEnd(); ++it ) {
     incidence->setNonKDECustomProperty( (*it).key, (*it).value );
@@ -1030,7 +1030,7 @@ void Incidence::loadAttachments()
 
 TQString Incidence::productID() const
 {
-  return TQString( "KOrganizer %1, Kolab resource" ).arg( korgVersion );
+  return TQString( "KOrganizer %1, Kolab resource" ).tqarg( korgVersion );
 }
 
 // Unhandled KCal::Incidence fields:
