@@ -34,7 +34,7 @@
 using namespace KCal;
 
 #define TaskNamespace1 "http://schemas.microsoft.com/mapi/id/{00062003-0000-0000-C000-000000000046}/"
-#define TaskProp_Status            "0x00008101"
+#define TaskProp_tqStatus            "0x00008101"
 #define TaskProp_PercentCompleted  "0x00008102"
 #define TaskProp_DtStart           "0x00008104"
 #define TaskProp_DtDue             "0x00008105"
@@ -164,7 +164,7 @@ void ExchangeConverterCalendar::createRequestTask( TQDomDocument &doc, TQDomElem
   propertyTask2( TaskProp_ReminderTime );
   propertyTask2( TaskProp_ReminderPlaySound );
   propertyTask2( TaskProp_ReminderSoundFile );
-  propertyTask1( TaskProp_Status );
+  propertyTask1( TaskProp_tqStatus );
 }
 #undef propertyTask1
 #undef propertyTask2
@@ -497,7 +497,7 @@ kdDebug()<<"ExchangeConverterCalendar::readIncidence: ERROR: No UID given"<<endl
   // What to do about recurrence rules?
 
   // FIXME: Reminders, use TaskProp_ReminderSet, TaskProp_ReminderTime,
-  //        TaskProp_ReminderPlaySound, TaskProp_ReminderSoundFile, TaskProp_Status
+  //        TaskProp_ReminderPlaySound, TaskProp_ReminderSoundFile, TaskProp_tqStatus
   //        But how do I get the offset?
 
   return true;
@@ -605,9 +605,9 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
       domHTTPMailProperty( "textdescription", incidence->description() );
       // FIXME: timestampt, comments and categories
 //       domHTTPMailProperty( "date", ??? ); // timestamp not available in libkcal
-//       domDavProperty( "comment", incidence->comments() ); // libkcal has a QStringlist, not one string
+//       domDavProperty( "comment", incidence->comments() ); // libkcal has a TQStringlist, not one string
 //       domProperty( "urn:schemas-microsoft-com:office:office", "Keywords", ??? ); // It's a <v>entyr1</v><v>entry2</v> String list!
-      tmpstr = TQString::null;
+      tmpstr = TQString();
       switch ( incidence->secrecy() ) {
         case KCal::Incidence::SecrecyPublic: tmpstr = "0"; break;
         case KCal::Incidence::SecrecyPrivate: tmpstr = "2"; break;
@@ -622,7 +622,7 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
       domMailHeaderProperty( "from", incidence->organizer().fullName() );
 
       //  Attendees:
-      tmpstr = TQString::null;
+      tmpstr = TQString();
       TQStringList reqattnames;
       TQStringList optattnames;
       Attendee::List atts = incidence->attendees();
@@ -668,7 +668,7 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
 //       FIXME: domCalendarProperty( "sequence", event->sequence() );
       domCalendarProperty( "location", event->location() );
 
-      TQString tmpstr( TQString::null );
+      TQString tmpstr;
       switch ( event->transparency() ) {
         case KCal::Event::Transparent: tmpstr = "FREE"; break;
         case KCal::Event::Opaque: tmpstr = "BUSY"; break;
@@ -747,7 +747,7 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
   propertyTask2( TaskProp_ReminderTime );
   propertyTask2( TaskProp_ReminderPlaySound );
   propertyTask2( TaskProp_ReminderSoundFile );
-  propertyTask1( TaskProp_Status );*/
+  propertyTask1( TaskProp_tqStatus );*/
       return true;
     }
     bool visit( Journal *journal )
