@@ -24,9 +24,10 @@
 #include <tqobject.h>
 #include <tqstringlist.h>
 
-class OtherUserManager : public QObject
+class OtherUserManager : public TQObject
 {
   Q_OBJECT
+  TQ_OBJECT
 
   public:
     OtherUserManager();
