@@ -28,9 +28,10 @@ class TQPushButton;
 class TQRadioButton;
 class TQTextEdit;
 
-class OutOfOfficePage : public QWidget
+class OutOfOfficePage : public TQWidget
 {
   Q_OBJECT
+  TQ_OBJECT
 
   public:
     OutOfOfficePage( TQWidget *parent = 0 );
