@@ -30,9 +30,10 @@ namespace KIO {
 class Job;
 }
 
-class PasswordPage : public QWidget
+class PasswordPage : public TQWidget
 {
   Q_OBJECT
+  TQ_OBJECT
 
   public:
     PasswordPage( TQWidget *parent = 0 );
