@@ -218,7 +218,7 @@ bool ResourceSlox::asyncLoad()
            TQT_SIGNAL( progressItemCanceled( KPIM::ProgressItem * ) ),
            TQT_SLOT( cancelDownload() ) );
 
-  mPrefs->setLastSync( TQDateTime::currentDateTime() );
+  mPrefs->setLastSync( TQDateTime::tqcurrentDateTime() );
 
   return true;
 }
@@ -255,7 +255,7 @@ void ResourceSlox::slotResult( KIO::Job *job )
         Addressee a;
         a.setUid( uid );
 
-        mWebdavHandler.clearSloxAttributeStatus();
+        mWebdavHandler.clearSloxAttributetqStatus();
 
         TQDomNode n;
         for( n = item.domNode.firstChild(); !n.isNull(); n = n.nextSibling() ) {
@@ -344,7 +344,7 @@ void ResourceSlox::parseContactAttribute( const TQDomElement &e, Addressee &a )
   int pnType = 0;
 
   if ( tag == fieldName( Birthday ) ) {
-    TQDateTime dt = WebdavHandler::sloxToQDateTime( text );
+    TQDateTime dt = WebdavHandler::sloxToTQDateTime( text );
     a.setBirthday( dt.date() );
   } else if ( tag == fieldName( Role ) ) {
     a.setRole( text );
@@ -400,7 +400,7 @@ void ResourceSlox::parseContactAttribute( const TQDomElement &e, Addressee &a )
   } else if ( tag == fieldName( SpousesName ) ) {
     a.insertCustom( "KADDRESSBOOK", "X-SpousesName", text );
   } else if ( tag == fieldName( Anniversary ) ) {
-    TQDateTime dt = WebdavHandler::sloxToQDateTime( text );
+    TQDateTime dt = WebdavHandler::sloxToTQDateTime( text );
     a.insertCustom( "KADDRESSBOOK", "X-Anniversary", dt.toString( Qt::ISODate ) );
   } else if ( tag == fieldName( Categories ) ) {
     a.setCategories( TQStringList::split( TQRegExp(",\\s*"), text ) );
