@@ -290,7 +290,7 @@ Engine::Engine() : SuperEngine(1)
 // keep GUI alive
 void Engine::yield() 
 {
-  qApp->processEvents();
+  tqApp->processEvents();
 }
 
 
