@@ -320,8 +320,8 @@ void ClipboardEvent::exec() {
 	controller->lastClipboardDirection = RFBController::LAST_SYNC_TO_SERVER;
 	controller->lastClipboardText = text;
 
-	controller->clipboard->setText(text, QClipboard::Clipboard);
-	controller->clipboard->setText(text, QClipboard::Selection);
+	controller->clipboard->setText(text, TQClipboard::Clipboard);
+	controller->clipboard->setText(text, TQClipboard::Selection);
 }
 
 
@@ -361,7 +361,7 @@ RFBController::RFBController(Configuration *c) :
 	connect(&initIdleTimer, TQT_SIGNAL(timeout()), TQT_SLOT(checkAsyncEvents()));
 	connect(&idleTimer, TQT_SIGNAL(timeout()), TQT_SLOT(idleSlot()));
 
-	clipboard = TQApplication::clipboard();
+	clipboard = TQApplication::tqclipboard();
 	connect(clipboard, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(selectionChanged()));
 	connect(clipboard, TQT_SIGNAL(dataChanged()), this, TQT_SLOT(clipboardChanged()));
 
@@ -373,7 +373,7 @@ RFBController::RFBController(Configuration *c) :
 	if (gethostname(hostname, 255))
 		hostname[0] = 0;
 	hostname[255] = 0;
-	desktopName = i18n("%1@%2 (shared desktop)").arg(KUser().loginName()).arg(hostname);
+	desktopName = i18n("%1@%2 (shared desktop)").tqarg(KUser().loginName()).tqarg(hostname);
 }
 
 RFBController::~RFBController()
@@ -508,7 +508,7 @@ void RFBController::acceptConnection(bool aRemoteControl)
 {
 	KNotifyClient::event("UserAcceptsConnection",
 			     i18n("User accepts connection from %1")
-			     .arg(remoteIp));
+			     .tqarg(remoteIp));
 
 	if (state != RFB_CONNECTING)
 		return;
@@ -521,7 +521,7 @@ void RFBController::refuseConnection()
 {
 	KNotifyClient::event("UserRefusesConnection",
 			     i18n("User refuses connection from %1")
-			     .arg(remoteIp));
+			     .tqarg(remoteIp));
 
 	if (state != RFB_CONNECTING)
 		return;
@@ -569,7 +569,7 @@ void RFBController::connectionClosed()
 {
 	KNotifyClient::event("ConnectionClosed",
 			     i18n("Closed connection: %1.")
-			     .arg(remoteIp));
+			     .tqarg(remoteIp));
 
 	idleTimer.stop();
 	initIdleTimer.stop();
@@ -698,12 +698,12 @@ bool RFBController::handleCheckPassword(rfbClientPtr cl,
 		if (configuration->invitations().size() > 0) {
 			sendKNotifyEvent("InvalidPasswordInvitations",
 					i18n("Failed login attempt from %1: wrong password")
-					.arg(remoteIp));
+					.tqarg(remoteIp));
 }
 		else
 			sendKNotifyEvent("InvalidPassword",
 					i18n("Failed login attempt from %1: wrong password")
-					.arg(remoteIp));
+					.tqarg(remoteIp));
 		return FALSE;
 	}
 
@@ -739,7 +739,7 @@ enum rfbNewClientAction RFBController::handleNewClient(rfbClientPtr cl)
 	if (state != RFB_WAITING) {
 		sendKNotifyEvent("TooManyConnections",
 					i18n("Connection refused from %1, already connected.")
-					.arg(host));
+					.tqarg(host));
 		return RFB_CLIENT_REFUSE;
 	}
 	remoteIp = host;
@@ -749,7 +749,7 @@ enum rfbNewClientAction RFBController::handleNewClient(rfbClientPtr cl)
 	    (configuration->invitations().size() == 0)) {
 		sendKNotifyEvent("NewConnectionAutoAccepted",
 					i18n("Accepted uninvited connection from %1")
-					.arg(remoteIp));
+					.tqarg(remoteIp));
 
 		connectionAccepted(configuration->allowDesktopControl());
 		return RFB_CLIENT_ACCEPT;
@@ -757,11 +757,11 @@ enum rfbNewClientAction RFBController::handleNewClient(rfbClientPtr cl)
 
 	sendKNotifyEvent("NewConnectionOnHold",
 				i18n("Received connection from %1, on hold (waiting for confirmation)")
-				.arg(remoteIp));
+				.tqarg(remoteIp));
 
 	dialog.setRemoteHost(remoteIp);
 	dialog.setAllowRemoteControl( true );
-	dialog.setFixedSize(dialog.sizeHint());
+	dialog.setFixedSize(dialog.tqsizeHint());
 	dialog.show();
 	return RFB_CLIENT_ON_HOLD;
 }
@@ -814,7 +814,7 @@ void RFBController::clipboardChanged() {
 	if (clipboard->ownsClipboard())
 		return;
 
-	TQString text = clipboard->text(QClipboard::Clipboard);
+	TQString text = clipboard->text(TQClipboard::Clipboard);
 
 	// avoid ping-pong between client&server
 	if ((lastClipboardDirection == LAST_SYNC_TO_SERVER) &&
@@ -835,7 +835,7 @@ void RFBController::selectionChanged() {
 	if (clipboard->ownsSelection())
 		return;
 
-	TQString text = clipboard->text(QClipboard::Selection);
+	TQString text = clipboard->text(TQClipboard::Selection);
 	// avoid ping-pong between client&server
 	if ((lastClipboardDirection == LAST_SYNC_TO_SERVER) &&
 	    (lastClipboardText == text))
