@@ -40,14 +40,7 @@ extern "C"
 /* TODO: this stuff has to go into autoconf */
 typedef unsigned char CARD8;
 typedef unsigned short CARD16;
-
-#ifdef LONG64
-typedef unsigned long CARD64;
 typedef unsigned int CARD32;
-#else
-typedef unsigned long CARD32;
-#endif
-
 typedef CARD32 Pixel;
 /* typedef CARD32 KeySym; */
 #ifndef __osf__
@@ -542,10 +535,10 @@ typedef struct _rfbClientRec {
     Bool enableLastRectEncoding;   /* client supports LastRect encoding */
     Bool enableSoftCursorUpdates;  /* client supports softcursor updates */
     Bool disableBackground;        /* client wants to disable background */
-    Bool enableCursorShapeUpdates; /* client supports cursor shape updates */
+    Bool enabletqCursorShapeUpdates; /* client supports cursor tqshape updates */
     Bool useRichCursorEncoding;    /* rfbEncodingRichCursor is preferred */
-    Bool cursorWasChanged;         /* cursor shape update should be sent */
-    Bool cursorWasMoved;           /* cursor move shape update should be sent */
+    Bool cursorWasChanged;         /* cursor tqshape update should be sent */
+    Bool cursorWasMoved;           /* cursor move tqshape update should be sent */
 #ifdef BACKCHANNEL
     Bool enableBackChannel;
 #endif
@@ -576,8 +569,8 @@ typedef struct _rfbClientRec {
  */
 
 #define FB_UPDATE_PENDING(cl)                           \
-     ((!(cl)->enableCursorShapeUpdates && !(cl)->screen->cursorIsDrawn) ||   \
-     ((cl)->enableCursorShapeUpdates && (cl)->cursorWasChanged) ||      \
+     ((!(cl)->enabletqCursorShapeUpdates && !(cl)->screen->cursorIsDrawn) ||   \
+     ((cl)->enabletqCursorShapeUpdates && (cl)->cursorWasChanged) ||      \
      !sraRgnEmpty((cl)->copyRegion) || !sraRgnEmpty((cl)->modifiedRegion))
 
 /*
@@ -740,7 +733,7 @@ typedef struct rfbCursor {
     unsigned char *richSource; /* source bytes for a rich cursor */
 } rfbCursor, *rfbCursorPtr;
 
-extern Bool rfbSendCursorShape(rfbClientPtr cl/*, rfbScreenInfoPtr pScreen*/);
+extern Bool rfbSendtqCursorShape(rfbClientPtr cl/*, rfbScreenInfoPtr pScreen*/);
 extern Bool rfbSendSoftCursor(rfbClientPtr cl, Bool cursorWasChanged);
 extern unsigned char rfbReverseByte[0x100];
 extern void rfbConvertLSBCursorBitmapOrMask(int width,int height,unsigned char* bitmap);
