@@ -12,7 +12,7 @@
 #ifndef KTTSDSETUPIMPL_H
 #define KTTSDSETUPIMPL_H
 
-// Qt includes
+// TQt includes
 
 // KDE includes
 #include <kprocess.h>
@@ -26,6 +26,7 @@
 class KTTSDlibSetupImpl : public KTTSDlibSetup
 {
 Q_OBJECT
+  TQ_OBJECT
 public:
     KTTSDlibSetupImpl(TQWidget *parent = 0, const char *name = 0);
 
