@@ -65,7 +65,7 @@
 App::App(TQWidget *parent, const char *name) : KMainWindow(parent, name),
    cheat(false)
 {
-	highscoreTable = new KHighscore(this);
+	highscoreTable = new KHighscore(TQT_TQOBJECT(this));
 
 	// TODO?
 	// Would it make sense long term to have a kconfig update rather then
@@ -89,13 +89,13 @@ App::App(TQWidget *parent, const char *name) : KMainWindow(parent, name),
 
 	setupGUI();
 
-	connect(board, TQT_SIGNAL(changed()), this, TQT_SLOT(enableItems()));
+	connect(board, TQT_SIGNAL(changed()), TQT_TQOBJECT(this), TQT_SLOT(enableItems()));
 
 	TQTimer *t = new TQTimer(this);
 	t->start(1000);
-	connect(t, TQT_SIGNAL(timeout()), this, TQT_SLOT(updateScore()));
-	connect(board, TQT_SIGNAL(endOfGame()), this, TQT_SLOT(slotEndOfGame()));
-	connect(board, TQT_SIGNAL(resized()), this, TQT_SLOT(boardResized()));
+	connect(t, TQT_SIGNAL(timeout()), TQT_TQOBJECT(this), TQT_SLOT(updateScore()));
+	connect(board, TQT_SIGNAL(endOfGame()), TQT_TQOBJECT(this), TQT_SLOT(slotEndOfGame()));
+	connect(board, TQT_SIGNAL(resized()), TQT_TQOBJECT(this), TQT_SLOT(boardResized()));
 
 	kapp->processEvents();
 
@@ -106,16 +106,16 @@ App::App(TQWidget *parent, const char *name) : KMainWindow(parent, name),
 void App::initKAction()
 {
 	// Game
-	KStdGameAction::gameNew(this, TQT_SLOT(newGame()), actionCollection());
-	KStdGameAction::restart(this, TQT_SLOT(restartGame()), actionCollection());
-	KStdGameAction::pause(this, TQT_SLOT(pause()), actionCollection());
-	KStdGameAction::highscores(this, TQT_SLOT(hallOfFame()), actionCollection());
-	KStdGameAction::quit(this, TQT_SLOT(quitGame()), actionCollection());
+	KStdGameAction::gameNew(TQT_TQOBJECT(this), TQT_SLOT(newGame()), actionCollection());
+	KStdGameAction::restart(TQT_TQOBJECT(this), TQT_SLOT(restartGame()), actionCollection());
+	KStdGameAction::pause(TQT_TQOBJECT(this), TQT_SLOT(pause()), actionCollection());
+	KStdGameAction::highscores(TQT_TQOBJECT(this), TQT_SLOT(hallOfFame()), actionCollection());
+	KStdGameAction::quit(TQT_TQOBJECT(this), TQT_SLOT(quitGame()), actionCollection());
 
 	// Move
-	KStdGameAction::undo(this, TQT_SLOT(undo()), actionCollection());
-	KStdGameAction::redo(this, TQT_SLOT(redo()), actionCollection());
-	KStdGameAction::hint(this, TQT_SLOT(hint()), actionCollection());
+	KStdGameAction::undo(TQT_TQOBJECT(this), TQT_SLOT(undo()), actionCollection());
+	KStdGameAction::redo(TQT_TQOBJECT(this), TQT_SLOT(redo()), actionCollection());
+	KStdGameAction::hint(TQT_TQOBJECT(this), TQT_SLOT(hint()), actionCollection());
 	//new KAction(i18n("Is Game Solvable?"), 0, this,
 	//	TQT_SLOT(isSolvable()), actionCollection(), "move_solvable");
 
@@ -124,7 +124,7 @@ void App::initKAction()
 #endif
 
 	// Settings
-	KStdAction::preferences(this, TQT_SLOT(showSettings()), actionCollection());
+	KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(showSettings()), actionCollection());
 }
 
 void App::hallOfFame()
@@ -299,9 +299,9 @@ void App::slotEndOfGame()
 		else
 		{
 			TQString s = i18n("Congratulations! You made it in %1:%2:%3")
-				.arg(TQString().sprintf("%02d", board->getTimeForGame()/3600))
-				.arg(TQString().sprintf("%02d", (board->getTimeForGame() / 60) % 60))
-				.arg(TQString().sprintf("%02d", board->getTimeForGame() % 60));
+				.tqarg(TQString().sprintf("%02d", board->getTimeForGame()/3600))
+				.tqarg(TQString().sprintf("%02d", (board->getTimeForGame() / 60) % 60))
+				.tqarg(TQString().sprintf("%02d", board->getTimeForGame() % 60));
 
 			KMessageBox::information(this, s, i18n("End of Game"));
 		}
@@ -315,18 +315,18 @@ void App::updateScore()
 {
 	int t = board->getTimeForGame();
 	TQString s = i18n(" Your time: %1:%2:%3 %4")
-		.arg(TQString().sprintf("%02d", t / 3600 ))
-		.arg(TQString().sprintf("%02d", (t / 60) % 60 ))
-		.arg(TQString().sprintf("%02d", t % 60 ))
-		.arg(board->isPaused()?i18n("(Paused) "):TQString::null);
+		.tqarg(TQString().sprintf("%02d", t / 3600 ))
+		.tqarg(TQString().sprintf("%02d", (t / 60) % 60 ))
+		.tqarg(TQString().sprintf("%02d", t % 60 ))
+		.tqarg(board->isPaused()?i18n("(Paused) "):TQString());
 
 	statusBar()->changeItem(s, SBI_TIME);
 
 	// Number of tiles
 	int tl = (board->x_tiles() * board->y_tiles());
 	s = i18n(" Removed: %1/%2 ")
-		.arg(TQString().sprintf("%d", tl - board->tilesLeft()))
-		.arg(TQString().sprintf("%d", tl ));
+		.tqarg(TQString().sprintf("%d", tl - board->tilesLeft()))
+		.tqarg(TQString().sprintf("%d", tl ));
 
 	statusBar()->changeItem(s, SBI_TILES);
 }
@@ -356,26 +356,26 @@ TQString App::getPlayerName()
 	TQDialog *dlg = new TQDialog(this, "Hall of Fame", true);
 
 	TQLabel  *l1  = new TQLabel(i18n("You've made it into the \"Hall Of Fame\". Type in\nyour name so mankind will always remember\nyour cool rating."), dlg);
-	l1->setFixedSize(l1->sizeHint());
+	l1->setFixedSize(l1->tqsizeHint());
 
 	TQLabel *l2 = new TQLabel(i18n("Your name:"), dlg);
-	l2->setFixedSize(l2->sizeHint());
+	l2->setFixedSize(l2->tqsizeHint());
 
 	TQLineEdit *e = new TQLineEdit(dlg);
 	e->setText("XXXXXXXXXXXXXXXX");
-	e->setMinimumWidth(e->sizeHint().width());
-	e->setFixedHeight(e->sizeHint().height());
+	e->setMinimumWidth(e->tqsizeHint().width());
+	e->setFixedHeight(e->tqsizeHint().height());
 	e->setText( lastPlayerName );
 	e->setFocus();
 
 	TQPushButton *b = new KPushButton(KStdGuiItem::ok(), dlg);
 	b->setDefault(true);
-	b->setFixedSize(b->sizeHint());
+	b->setFixedSize(b->tqsizeHint());
 
 	connect(b, TQT_SIGNAL(released()), dlg, TQT_SLOT(accept()));
 	connect(e, TQT_SIGNAL(returnPressed()), dlg, TQT_SLOT(accept()));
 
-	// create layout
+	// create tqlayout
 	TQVBoxLayout *tl = new TQVBoxLayout(dlg, 10);
 	TQHBoxLayout *tl1 = new TQHBoxLayout();
 	tl->addWidget(l1);
@@ -603,12 +603,12 @@ void App::showHighscore(int focusitem)
 	f.setPointSize(24);
 	f.setBold(true);
 	l->setFont(f);
-	l->setFixedSize(l->sizeHint());
+	l->setFixedSize(l->tqsizeHint());
 	l->setFixedWidth(l->width() + 32);
-	l->setAlignment(AlignCenter);
+	l->tqsetAlignment(AlignCenter);
 	tl->addWidget(l);
 
-	// insert highscores in a gridlayout
+	// insert highscores in a gridtqlayout
 	TQGridLayout *table = new TQGridLayout(12, 5, 5);
 	tl->addLayout(table, 1);
 
@@ -621,23 +621,23 @@ void App::showHighscore(int focusitem)
 	f.setBold(true);
 	l = new TQLabel(i18n("Rank"), dlg);
 	l->setFont(f);
-	l->setMinimumSize(l->sizeHint());
+	l->setMinimumSize(l->tqsizeHint());
 	table->addWidget(l, 0, 0);
 	l = new TQLabel(i18n("Name"), dlg);
 	l->setFont(f);
-	l->setMinimumSize(l->sizeHint());
+	l->setMinimumSize(l->tqsizeHint());
 	table->addWidget(l, 0, 1);
 	l = new TQLabel(i18n("Time"), dlg);
 	l->setFont(f);
-	l->setMinimumSize(l->sizeHint());
+	l->setMinimumSize(l->tqsizeHint());
 	table->addWidget(l, 0, 2);
 	l = new TQLabel(i18n("Size"), dlg);
 	l->setFont(f);
-	l->setMinimumSize(l->sizeHint());
+	l->setMinimumSize(l->tqsizeHint());
 	table->addWidget(l, 0, 3);
 	l = new TQLabel(i18n("Score"), dlg);
 	l->setFont(f);
-	l->setMinimumSize(l->sizeHint().width()*3, l->sizeHint().height());
+	l->setMinimumSize(l->tqsizeHint().width()*3, l->tqsizeHint().height());
 	table->addWidget(l, 0, 4);
 
 	TQString s;
@@ -685,8 +685,8 @@ void App::showHighscore(int focusitem)
 		if(i < highscore.size())
 		{
 			s = TQString("%1 %2")
-			    .arg(getScore(hs))
-			    .arg(hs.gravity ? i18n("(gravity)") : TQString(""));
+			    .tqarg(getScore(hs))
+			    .tqarg(hs.gravity ? i18n("(gravity)") : TQString(""));
 		}
 		else
 		{
@@ -694,7 +694,7 @@ void App::showHighscore(int focusitem)
 		}
 
 		e[i][4] = new TQLabel(s, dlg);
-		e[i][4]->setAlignment(AlignRight);
+		e[i][4]->tqsetAlignment(AlignRight);
 	}
 
 	f = font();
@@ -704,12 +704,12 @@ void App::showHighscore(int focusitem)
 	{
 		for(j = 0; j < 5; j++)
 		{
-			e[i][j]->setMinimumHeight(e[i][j]->sizeHint().height());
+			e[i][j]->setMinimumHeight(e[i][j]->tqsizeHint().height());
 
 			if(j == 1)
-				e[i][j]->setMinimumWidth(std::max(e[i][j]->sizeHint().width(), 100));
+				e[i][j]->setMinimumWidth(std::max(e[i][j]->tqsizeHint().width(), 100));
 			else
-				e[i][j]->setMinimumWidth(std::max(e[i][j]->sizeHint().width(), 60));
+				e[i][j]->setMinimumWidth(std::max(e[i][j]->tqsizeHint().width(), 60));
 
 			if((int)i == focusitem)
 				e[i][j]->setFont(f);
@@ -720,14 +720,14 @@ void App::showHighscore(int focusitem)
 
 	TQPushButton *b = new KPushButton(KStdGuiItem::close(), dlg);
 
-	b->setFixedSize(b->sizeHint());
+	b->setFixedSize(b->tqsizeHint());
 
 	// connect the "Close"-button to done
 	connect(b, TQT_SIGNAL(clicked()), dlg, TQT_SLOT(accept()));
 	b->setDefault(true);
 	b->setFocus();
 
-	// make layout
+	// make tqlayout
 	tl->addSpacing(10);
 	tl->addWidget(b);
 	tl->activate();
@@ -752,7 +752,7 @@ void App::showSettings(){
 	KConfigDialog *dialog = new KConfigDialog(this, "settings", Prefs::self(), KDialogBase::Swallow);
 	Settings *general = new Settings(0, "General");
 	dialog->addPage(general, i18n("General"), "package_settings");
-	connect(dialog, TQT_SIGNAL(settingsChanged()), this, TQT_SLOT(loadSettings()));
+	connect(dialog, TQT_SIGNAL(settingsChanged()), TQT_TQOBJECT(this), TQT_SLOT(loadSettings()));
 	connect(dialog, TQT_SIGNAL(settingsChanged()), board, TQT_SLOT(loadSettings()));
 	dialog->show();
 }
