@@ -179,7 +179,7 @@ void Board::mousePressEvent(TQMouseEvent *e)
 	}
 
 	// Mark tile
-	if(e->button() == LeftButton)
+	if(e->button() == Qt::LeftButton)
 	{
 		clearHighlight();
 
@@ -188,7 +188,7 @@ void Board::mousePressEvent(TQMouseEvent *e)
 	}
 
 	// Assist by highlighting all tiles of same type
-	if(e->button() == RightButton)
+	if(e->button() == Qt::RightButton)
 	{
 		int clicked_tile = getField(pos_x, pos_y);
 
@@ -261,8 +261,8 @@ void Board::setSize(int x, int y)
 
 	// set the minimum size of the scalable window
 	const double MINIMUM_SCALE = 0.2;
-	int w = qRound(tiles.unscaledTileWidth() * MINIMUM_SCALE) * x_tiles();
-	int h = qRound(tiles.unscaledTileHeight() * MINIMUM_SCALE) * y_tiles();
+	int w = tqRound(tiles.unscaledTileWidth() * MINIMUM_SCALE) * x_tiles();
+	int h = tqRound(tiles.unscaledTileHeight() * MINIMUM_SCALE) * y_tiles();
 	w += tiles.unscaledTileWidth();
 	h += tiles.unscaledTileWidth();
 
@@ -444,7 +444,7 @@ void Board::updateField(int x, int y, bool erase)
 	        tiles.tileWidth(),
 	        tiles.tileHeight());
 
-	repaint(r, erase);
+	tqrepaint(r, erase);
 }
 
 void Board::paintEvent(TQPaintEvent *e)
@@ -459,7 +459,7 @@ void Board::paintEvent(TQPaintEvent *e)
 	if(paused)
 	{
 		p.setFont(KGlobalSettings::largeFont());
-		p.drawText(rect(), Qt::AlignCenter, i18n("Game Paused"));
+		p.drawText(rect(), TQt::AlignCenter, i18n("Game Paused"));
 	}
 	else
 	{
@@ -900,7 +900,7 @@ void Board::dumpBoard() const
 			if(tile == EMPTY)
 				row += " --";
 			else
-				row += TQString("%1").arg(getField(x, y), 3);
+				row += TQString("%1").tqarg(getField(x, y), 3);
 		}
 		kdDebug() << row << endl;
 	}
@@ -1071,7 +1071,7 @@ bool Board::pause()
 	return paused;
 }
 
-TQSize Board::sizeHint() const
+TQSize Board::tqsizeHint() const
 {
 	int dpi = TQPaintDeviceMetrics(this).logicalDpiX();
 	if (dpi < 75)
