@@ -1,6 +1,6 @@
 /**********************************************************************
 
-	--- Qt Architect generated file ---
+	--- TQt Architect generated file ---
 
 	File: open_ksirc.h
 	Last generated: Wed Jul 29 16:41:26 1998
@@ -19,6 +19,7 @@ class KSircServer;
 class open_ksirc : public open_ksircData
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
 
