@@ -1,7 +1,7 @@
 #ifndef _PAGE_FONT
 #define _PAGE_FONT
 #include <kfontdialog.h> // For the font selection widget
-#include <tqlayout.h> // For the layout
+#include <tqlayout.h> // For the tqlayout
 #include "ksopts.h"  // For storing the info.
 
 /**
@@ -9,9 +9,10 @@
  *
  * @author Markus Weimer <markus.weimer@web.de>
  */
-class PageFont : public QWidget
+class PageFont : public TQWidget
 {
  Q_OBJECT
+  TQ_OBJECT
 
  public:
   /**
@@ -56,7 +57,7 @@ class PageFont : public QWidget
 
  private:
   KFontChooser* fontchooser; /** The font choosing widget from kdelib */
-  TQHBoxLayout* layout;
+  TQHBoxLayout* tqlayout;
 };
 
 #endif
