@@ -1,6 +1,6 @@
 /**********************************************************************
 
-	--- Qt Architect generated file ---
+	--- TQt Architect generated file ---
 
 	File: ksprogress.h
 	Last generated: Thu Dec 18 08:01:39 1997
@@ -15,6 +15,7 @@
 class KSProgress : public ksprogressData
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
 
