@@ -1,6 +1,6 @@
 /**********************************************************************
 
-	--- Qt Architect generated file ---
+	--- TQt Architect generated file ---
 
 	File: speeddialog.cpp
 	Last generated: Sun Dec 21 08:52:31 1997
