@@ -1,6 +1,6 @@
 /**********************************************************************
 
-	--- Qt Architect generated file ---
+	--- TQt Architect generated file ---
 
 	File: speeddialog.h
 	Last generated: Sun Dec 21 08:52:31 1997
@@ -15,6 +15,7 @@
 class SpeedDialog : public speeddialogData
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
 
