@@ -5,9 +5,10 @@
 #include <tqstringlist.h>
 #include <tqsize.h>
 
-class aHistLineEdit : public QTextEdit
+class aHistLineEdit : public TQTextEdit
 {
 Q_OBJECT
+  TQ_OBJECT
 public:
     aHistLineEdit(TQWidget *parent = 0, const char *name = 0);
 
