@@ -2,7 +2,7 @@
 
 #include "dccManager.h"
 
-class Timer : public QObject
+class Timer : public TQObject
 {
 public:
     Timer( dccManager *view )
@@ -19,7 +19,7 @@ public:
     }
     void timerEvent( TQTimerEvent * )
         {
-            m_it->changeStatus(dccItem::dccSending);
+            m_it->changetqStatus(dccItem::dccSending);
             bytes += 1000;
             m_it->setReceivedBytes(bytes);
 
