@@ -2,7 +2,7 @@
 
  The IO DCC Window
 
- $$Id: ioDCC.cpp 1157648 2010-07-31 19:48:06Z tpearson $$
+ $$Id: ioDCC.cpp 1246075 2011-08-10 06:08:18Z tpearson $$
 
  Display DCC progress, etc.  This in the future should be expanded.
 
@@ -61,7 +61,7 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
   if(str.find("DCC GET read:", 0) != -1){ /*fold01*/
       TQRegExp rx("read: (.+) who: (.+) bytes: (.*)");
       if(rx.search(str)){
-	  TQString key = TQString("%1/%2").arg(rx.cap(1)).arg(rx.cap(2));
+	  TQString key = TQString("%1/%2").tqarg(rx.cap(1)).tqarg(rx.cap(2));
 	  uint bytesXfer = rx.cap(3).toUInt();
 
 	  //
@@ -76,7 +76,7 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
   else if(str.find("DCC SEND write:", 0) != -1){ /*fold01*/
       TQRegExp rx("write: (.+) who: (.+) bytes: (.*)");
       if(rx.search(str)){
-	  TQString key = TQString("%1/%2").arg(rx.cap(1)).arg(rx.cap(2));
+	  TQString key = TQString("%1/%2").tqarg(rx.cap(1)).tqarg(rx.cap(2));
 	  uint bytesXfer = rx.cap(3).toUInt();
 
 	  if(DCCSendItems[key]){
@@ -91,7 +91,7 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
           TQString filename = rx.cap(2);
           TQString size = rx.cap(3);
           TQString ip = rx.cap(4);
-          //QSTring port = rx.cap(5);
+          //TQSTring port = rx.cap(5);
 
           int fileSize = size.toInt(); // Bytes per step
           fileSize /= 1024;
@@ -103,7 +103,7 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
                   this, TQT_SLOT(dccRenameDone(dccItem *, TQString, TQString)));
 	  it->setWhoPostfix("(" + ip + ")");
 
-          TQString key = TQString("%1/%2").arg(filename).arg(who);
+          TQString key = TQString("%1/%2").tqarg(filename).tqarg(who);
 	  if(DCCGetItems[key]){
 	      /*
 	       * don't add duplicates, this cuases real headaches
@@ -113,11 +113,11 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
 	      dccItem *old = DCCGetItems.take(key);
 	      int i;
 	      for(i = 0; i <= (int) DCCGetItems.count()+1; i++){
-		  renamed = TQString("%1 (finished %2)/%3").arg(filename).arg(i+1).arg(old->who());
+		  renamed = TQString("%1 (finished %2)/%3").tqarg(filename).tqarg(i+1).tqarg(old->who());
 		  if( DCCGetItems[renamed] == 0x0)
                       break;
 	      }
-	      old->changeFilename(TQString("%1 (finished %2)").arg(filename).arg(i+1));
+	      old->changeFilename(TQString("%1 (finished %2)").tqarg(filename).tqarg(i+1));
               DCCGetItems.insert(renamed, it);
 	  }
 
@@ -139,7 +139,7 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
           // setup dcc dialog
           displayMgr->show(mgr);
 	  dccItem *it = mgr->mgr()->newSendItem(filename, who, dccItem::dccSentOffer, fileSize);
-	  TQString key = TQString("%1/%2").arg(filename).arg(who);
+	  TQString key = TQString("%1/%2").tqarg(filename).tqarg(who);
 	  if(DCCSendItems[key]){
 	      /*
 	       * don't add duplicates, this cuases real headaches
@@ -151,11 +151,11 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
 	      dccItem *old = DCCSendItems.take(key);
 	      int i;
 	      for(i = 0; i <= (int) DCCSendItems.count()+1; i++){
-		  renamed = TQString("%1 (sent %2)/%3").arg(filename).arg(i+1).arg(old->who());
+		  renamed = TQString("%1 (sent %2)/%3").tqarg(filename).tqarg(i+1).tqarg(old->who());
 		  if( DCCSendItems[renamed] == 0x0)
                       break;
 	      }
-	      old->changeFilename(TQString("%1 (sent %2)").arg(filename).arg(i+1));
+	      old->changeFilename(TQString("%1 (sent %2)").tqarg(filename).tqarg(i+1));
               DCCSendItems.insert(renamed, it);
 	  }
           DCCSendItems.insert(key, it);
@@ -204,21 +204,21 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
           TQString who = rx.cap(1);
           TQString filename = rx.cap(2);
           TQString error = rx.cap(3);
-          enum dccItem::dccStatus status = dccItem::dccDone;
+          enum dccItem::dcctqStatus status = dccItem::dccDone;
 
 	  if(error == "CLOSE"){
               status = dccItem::dccCancel;
 	  }
           if(error != "OK"){
               status = dccItem::dccError;
-              KPassivePopup::message(i18n("DCC SEND with %1 for %2 failed because of %3").arg(who).arg(filename).arg(error), mgr->mgr());
+              KPassivePopup::message(i18n("DCC SEND with %1 for %2 failed because of %3").tqarg(who).tqarg(filename).tqarg(error), mgr->mgr());
 	  }
-	  TQString key = TQString("%1/%2").arg(filename).arg(who);
+	  TQString key = TQString("%1/%2").tqarg(filename).tqarg(who);
           if(DCCSendItems[key]){
               kdDebug(5008) << "SendPercent: " << DCCSendItems[key]->getPercent() << endl;
               if((status == dccItem::dccDone) && (DCCSendItems[key]->getPercent() < 100))
                   status = dccItem::dccError;
-              DCCSendItems[key]->changeStatus(status);
+              DCCSendItems[key]->changetqStatus(status);
           }
       }
   }
@@ -229,18 +229,18 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
           TQString who = rx.cap(1);
           TQString filename = rx.cap(2);
           TQString error = rx.cap(3);
-          enum dccItem::dccStatus status = dccItem::dccDone;
+          enum dccItem::dcctqStatus status = dccItem::dccDone;
 
           if(error != "OK"){
               status = dccItem::dccError;
-              KPassivePopup::message(i18n("DCC GET with %1 for %2 failed because of %3").arg(who).arg(filename).arg(error), mgr->mgr());
+              KPassivePopup::message(i18n("DCC GET with %1 for %2 failed because of %3").tqarg(who).tqarg(filename).tqarg(error), mgr->mgr());
 	  }
-                    TQString key = TQString("%1/%2").arg(filename).arg(who);
+                    TQString key = TQString("%1/%2").tqarg(filename).tqarg(who);
           if(DCCGetItems[key]){
               kdDebug(5008) << "GetPercent: " << DCCGetItems[key]->getPercent() << endl;
               if((status == dccItem::dccDone) && (DCCGetItems[key]->getPercent() < 100))
                   status = dccItem::dccError;
-              DCCGetItems[key]->changeStatus(status);
+              DCCGetItems[key]->changetqStatus(status);
           }
       }
       else {
@@ -252,13 +252,13 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
       if(rx.search(str)){
           TQString who = rx.cap(1);
 	  TQString filename = rx.cap(2);
-	  TQString key = TQString("%1/%2").arg(filename).arg(who);
+	  TQString key = TQString("%1/%2").tqarg(filename).tqarg(who);
 	  if(DCCGetItems[key]){
 	      dccItem *it = DCCGetItems[key];
 	      kdDebug(5008) << "Got DCC GET resumed message..." << it->file() << endl;
 	      if(it->status() == dccItem::dccWaitOnResume)
                   dccConnectClicked(it);
-              it->changeStatus(dccItem::dccResumed);
+              it->changetqStatus(dccItem::dccResumed);
           }
       }
   }
@@ -267,9 +267,9 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
       if(rx.search(str)){
           TQString who = rx.cap(1);
 	  TQString filename = rx.cap(2);
-	  TQString key = TQString("%1/%2").arg(filename).arg(who);
+	  TQString key = TQString("%1/%2").tqarg(filename).tqarg(who);
           if(DCCSendItems[key]){
-              DCCSendItems[key]->changeStatus(dccItem::dccResumed);
+              DCCSendItems[key]->changetqStatus(dccItem::dccResumed);
           }
       }
   }
@@ -278,9 +278,9 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
       if(rx.search(str)){
           TQString who = rx.cap(1);
 	  TQString filename = rx.cap(2);
-	  TQString key = TQString("%1/%2").arg(filename).arg(who);
+	  TQString key = TQString("%1/%2").tqarg(filename).tqarg(who);
           if(DCCGetItems[key]){
-              DCCGetItems[key]->changeStatus(dccItem::dccRecving);
+              DCCGetItems[key]->changetqStatus(dccItem::dccRecving);
           }
       }
   }
@@ -290,10 +290,10 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
           TQString who = rx.cap(1);
           TQString filename = rx.cap(2);
 	  TQString ip = rx.cap(3);
-	  TQString key = TQString("%1/%2").arg(filename).arg(who);
+	  TQString key = TQString("%1/%2").tqarg(filename).tqarg(who);
           if(DCCSendItems[key]){
               DCCSendItems[key]->setWhoPostfix("(" + ip + ")");
-              DCCSendItems[key]->changeStatus(dccItem::dccSending);
+              DCCSendItems[key]->changetqStatus(dccItem::dccSending);
           }
       }
   }
@@ -302,7 +302,7 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
       if(rx.search(str)){
           TQString who = rx.cap(1);
           if(DCCChatItems[who]){
-	      DCCChatItems[who]->changeStatus(dccItem::dccOpen);
+	      DCCChatItems[who]->changetqStatus(dccItem::dccOpen);
               proc->new_toplevel(KSircChannel(proc->serverName(), TQString("=") + who.lower()));
           }
       }
@@ -314,7 +314,7 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
           TQString ip = rx.cap(2);
           if(DCCChatItems[who]){
               DCCChatItems[who]->setWhoPostfix("(" + ip + ")");
-	      DCCChatItems[who]->changeStatus(dccItem::dccOpen);
+	      DCCChatItems[who]->changetqStatus(dccItem::dccOpen);
 	      proc->new_toplevel(KSircChannel(proc->serverName(), TQString("=") + who.lower()));
           }
       }
@@ -325,11 +325,11 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
           TQString who = rx.cap(1);
           TQString filename = rx.cap(2);
 	  TQString error = rx.cap(3);
-	  TQString key = TQString("%1/%2").arg(filename).arg(who);
+	  TQString key = TQString("%1/%2").tqarg(filename).tqarg(who);
           if(DCCGetItems[key]){
-              DCCGetItems[key]->changeStatus(dccItem::dccError);
+              DCCGetItems[key]->changetqStatus(dccItem::dccError);
           }
-          KPassivePopup::message(i18n("DCC Get with %1 for %2 failed because of %3").arg(who).arg(filename).arg(error), mgr->mgr());
+          KPassivePopup::message(i18n("DCC Get with %1 for %2 failed because of %3").tqarg(who).tqarg(filename).tqarg(error), mgr->mgr());
       }
   }
   else if(str.find("DCC CHAT failed") != -1){ /*FOLD01*/
@@ -338,9 +338,9 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
           TQString who = rx.cap(1);
           TQString error = rx.cap(2);
           if(DCCChatItems[who]){
-              DCCChatItems[who]->changeStatus(dccItem::dccError);
+              DCCChatItems[who]->changetqStatus(dccItem::dccError);
           }
-          KPassivePopup::message(i18n("DCC Chat with %1 failed because of %2").arg(who).arg(error), mgr->mgr());
+          KPassivePopup::message(i18n("DCC Chat with %1 failed because of %2").tqarg(who).tqarg(error), mgr->mgr());
       }
   }
   else if(str.find("DCC CHAT renamed") != -1){ /*FOLD01*/
@@ -360,9 +360,9 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
       if(rx.search(str)){
           TQString who = rx.cap(1);
 	  TQString filename = rx.cap(2);
-	  TQString key = TQString("%1/%2").arg(filename).arg(who);
+	  TQString key = TQString("%1/%2").tqarg(filename).tqarg(who);
           if(DCCGetItems[key]){
-              DCCGetItems[key]->changeStatus(dccItem::dccCancel);
+              DCCGetItems[key]->changetqStatus(dccItem::dccCancel);
           }
       }
   }
@@ -371,9 +371,9 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
 //      if(rx.search(str)){
 //          TQString who = rx.cap(1);
 //	  TQString filename = rx.cap(2);
-//	  TQString key = TQString("%1/%2").arg(filename).arg(who);
+//	  TQString key = TQString("%1/%2").tqarg(filename).tqarg(who);
 //          if(DCCSendItems[key]){
-//              DCCSendItems[key]->changeStatus(dccItem::dccCancel);
+//              DCCSendItems[key]->changetqStatus(dccItem::dccCancel);
 //          }
 //      }
 //  }
@@ -382,7 +382,7 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
       if(rx.search(str)){
           TQString who = rx.cap(1);
           if(DCCChatItems[who]){
-              DCCChatItems[who]->changeStatus(dccItem::dccDone);
+              DCCChatItems[who]->changetqStatus(dccItem::dccDone);
           }
       }
   }
@@ -392,7 +392,7 @@ void KSircIODCC::sirc_receive(TQCString str, bool )
           TQString who = rx.cap(1);
 	  TQString filename = rx.cap(2);
 
-	  //TQString key = TQString("%1/%2").arg(filename).arg(who);
+	  //TQString key = TQString("%1/%2").tqarg(filename).tqarg(who);
 
           TQPtrList<dccItem> toDel;
           TQDict<dccItem> new_list;
@@ -470,11 +470,11 @@ void KSircIODCC::control_message(int, TQString)
 void KSircIODCC::cancelTransfer(TQString filename)
 {
     //if(DlgList[filename]){
-    //emit outputLine(DCCStatus[filename]->cancelMessage.ascii());
+    //emit outputLine(DCCtqStatus[filename]->cancelMessage.ascii());
     //delete DlgList[filename];
     //DlgList.remove(filename);
-    //delete DCCStatus[filename];
-    //DCCStatus.remove(filename);
+    //delete DCCtqStatus[filename];
+    //DCCtqStatus.remove(filename);
   //}
 }
 
@@ -561,7 +561,7 @@ void KSircIODCC::dccResumeClicked(dccItem *it)
     kdDebug(5008) << "Got resume click on " << it->who() << " " << it->type() << endl;
     switch(it->type()){
     case dccItem::dccGet:
-	it->changeStatus(dccItem::dccWaitOnResume);
+	it->changetqStatus(dccItem::dccWaitOnResume);
         str = "/resume " + it->who() + " " + it->file() + "\n";
         emit outputLine(str.ascii());
         break;
@@ -583,10 +583,10 @@ void KSircIODCC::dccAbortClicked(dccItem *it)
     case dccItem::dccError:
         switch(it->type()) {
 	case dccItem::dccGet:
-            DCCGetItems.remove(TQString("%1/%2").arg(it->file()).arg(it->who()));
+            DCCGetItems.remove(TQString("%1/%2").tqarg(it->file()).tqarg(it->who()));
             break;
         case dccItem::dccSend:
-            DCCSendItems.remove(TQString("%1/%2").arg(it->file()).arg(it->who()));
+            DCCSendItems.remove(TQString("%1/%2").tqarg(it->file()).tqarg(it->who()));
             break;
         case dccItem::dccChat:
             DCCChatItems.remove(it->who());
@@ -615,11 +615,11 @@ void KSircIODCC::dccAbortClicked(dccItem *it)
 void KSircIODCC::dccRenameDone(dccItem *it, TQString oldWho, TQString oldFile)
 {
     if(it->type() == dccItem::dccGet){
-	TQString str = TQString("/dcc rename %1 %2 %3\n").arg(oldWho).arg(oldFile).arg(it->file());
-	TQString key = TQString("%1/%2").arg(oldFile).arg(oldWho);
+	TQString str = TQString("/dcc rename %1 %2 %3\n").tqarg(oldWho).tqarg(oldFile).tqarg(it->file());
+	TQString key = TQString("%1/%2").tqarg(oldFile).tqarg(oldWho);
 	if(DCCGetItems[key]){
             DCCGetItems.take(key);
-	    TQString newkey = TQString("%1/%2").arg(it->file()).arg(it->who());
+	    TQString newkey = TQString("%1/%2").tqarg(it->file()).tqarg(it->who());
             DCCGetItems.insert(newkey, it);
 	}
 	emit outputLine(str.ascii());
@@ -629,7 +629,7 @@ void KSircIODCC::dccRenameDone(dccItem *it, TQString oldWho, TQString oldFile)
 	    DCCChatItems.take(oldWho);
 	    DCCChatItems.insert(it->who(), it);
 	}
-	TQString str = TQString("/dcc rchat %1 %2\n").arg(oldWho).arg(it->who());
+	TQString str = TQString("/dcc rchat %1 %2\n").tqarg(oldWho).tqarg(it->who());
 	emit outputLine(str.ascii());
 
     }
