@@ -23,6 +23,7 @@ class KSircIODCC : public TQObject,
 		   public KSircMessageReceiver
 {
   Q_OBJECT
+  TQ_OBJECT
 public:
   KSircIODCC(KSircProcess *_proc);
   virtual ~KSircIODCC();
@@ -51,7 +52,7 @@ signals:
 private:
 //  TQDict<TQProgressDialog> DlgList;
     //TQDict<KSProgress> DlgList;
-    //TQDict<DCCInfo> DCCStatus;
+    //TQDict<DCCInfo> DCCtqStatus;
   TQDict<dccItem> DCCGetItems;
   TQDict<dccItem> DCCSendItems;
   TQDict<dccItem> DCCChatItems;
