@@ -130,38 +130,38 @@
 // cArg: not define
 #define PUKE_WIDGET_HIDE_ACK -1003
 
-// Desc: repaint widget
-// iWinId: widget to repaint
+// Desc: tqrepaint widget
+// iWinId: widget to tqrepaint
 // iArg: erase, 0 for false, 1 for true
 // cArg: no defines
 #define PUKE_WIDGET_REPAINT 1005
 
-// Desc: repaint widget ack
-// iWinId: widget to repaint
+// Desc: tqrepaint widget ack
+// iWinId: widget to tqrepaint
 // iArg: not defined
 // cArg: not defined
 #define PUKE_WIDGET_REPAINT_ACK -1005
 
 // Desc: update widget on next event loop
-// iWinId: widget to repaint
+// iWinId: widget to tqrepaint
 // iArg: erase, 0 for false, 1 for true
 // cArg: no defines
 #define PUKE_WIDGET_UPDATE 1010
 
-// Desc: repaint widget ack
-// iWinId: widget to repaint
+// Desc: tqrepaint widget ack
+// iWinId: widget to tqrepaint
 // iArg: not defined
 // cArg: not defined
 #define PUKE_WIDGET_UPDATE_ACK -1010
 
 // Desc: resize the widget
-// iWinId: widget to repaint
+// iWinId: widget to tqrepaint
 // iArg: width in the low 16 bit, height in next 16 bits
 // cArg: not defined
 #define PUKE_WIDGET_RESIZE 1015
 
-// Desc: repaint widget ack
-// iWinId: widget to repaint
+// Desc: tqrepaint widget ack
+// iWinId: widget to tqrepaint
 // iArg: new widget in lower 16 bit, new height in lower 16 bits
 // cArg: not defined
 #define PUKE_WIDGET_RESIZE_ACK -1015
@@ -349,33 +349,33 @@
 
 // TQFrame gets 1100
 
-// 1100 defines QFrame
+// 1100 defines TQFrame
 // Desc: set Frame style
 // iWinId: widget to chanse
 // iArg: frame style to set.
 // cArg: no define
-#define PUKE_QFRAME_SET_FRAME 1100
+#define PUKE_TQFRAME_SET_FRAME 1100
 
 // Desc: get/ack Frame style
 // iWinId: widget to changed
 // iArg: frame style.
 // cArg: no define
-#define PUKE_QFRAME_SET_FRAME_ACK -1100
+#define PUKE_TQFRAME_SET_FRAME_ACK -1100
 
 // Desc: set Frame line width
 // iWinId: widget to chanse
 // iArg: newline width.
 // cArg: no define
-#define PUKE_QFRAME_SET_LINEWIDTH 1105
+#define PUKE_TQFRAME_SET_LINEWIDTH 1105
 
 // Desc: get/ack Frame line width
 // iWinId: widget to changed
 // iArg: line width.
 // cArg: no define
-#define PUKE_QFRAME_SET_LINEWIDTH_ACK -1105
+#define PUKE_TQFRAME_SET_LINEWIDTH_ACK -1105
 
 //----------------------------------------------------
-// 1200 is a QLineEdit
+// 1200 is a TQLineEdit
 
 // Desc: set max line length
 // iWinId: widget to change
@@ -766,13 +766,13 @@
 
 // Desc: Set label's allignment
 // iWinId: window id
-// iArg: alignment
+// iArg: tqalignment
 // cArg: not defined
 #define PUKE_LABEL_SETALIGNMENT 1715
 
 // Desc: Set label's allignment, ACK
 // iWinId: window id
-// iArg: alignment
+// iArg: tqalignment
 // cArg: not defined
 #define PUKE_LABEL_SETALIGNMENT_ACK -1715
 
@@ -944,7 +944,7 @@
 // LINED defines the simple SLE
 #define PWIDGET_LINED 4
 
-// BUTTON defines the abstract class QButton
+// BUTTON defines the abstract class TQButton
 #define PWIDGET_BUTTON 5
 
 // PUSH defined the push button
@@ -993,14 +993,14 @@
 #define PWIDGET_OBJFINDER 18
 
 
-// Group layout commands exist between 10000 and 11000
+// Group tqlayout commands exist between 10000 and 11000
 
-// Desc: create new box layout
+// Desc: create new box tqlayout
 // iWinId: PWidget parent
 // iArg: 2 shorts, short[0] direction, short[1] border
 // cArg: random character string
 #define PUKE_LAYOUT_NEW 11000
-// Desc: ack for box layout
+// Desc: ack for box tqlayout
 // iWinId: Layout ID.
 // iArg: not define
 // cArg: same random m character string as PUKE_LAYOUT_NEW
@@ -1009,10 +1009,10 @@
 #define PUKE_LAYOUT_ADDLAYOUT 11005
 #define PUKE_LAYOUT_ADDLAYOUT_ACK -11005
 
-// Desc: add widget into layout manager
+// Desc: add widget into tqlayout manager
 // iWinId: Layout Manager to add widget too
 // iArg: Widget Id to be added
-// cArg: 2 characters, char[0] strech, char[1] alignment
+// cArg: 2 characters, char[0] strech, char[1] tqalignment
 #define PUKE_LAYOUT_ADDWIDGET 11010
 // Desc: ack for add widget
 // iWinId: Layout manager 
@@ -1032,7 +1032,7 @@
 // cArg: not define
 #define PUKE_LAYOUT_ADDSTRUT_ACK -11015
 
-// Desc: activates layout management, like show() for widget
+// Desc: activates tqlayout management, like show() for widget
 // iWinId: Layout Manager to activate
 // iArg: undef
 // cArg: undef
