@@ -15,7 +15,7 @@
 #include <sys/stat.h>
 
 using namespace std; // iostream.h include cstring which puts strlen into 
-                     // std:: namespace, which breaks Qt's strlen() call 
+                     // std:: namespace, which breaks TQt's strlen() call 
                      // in tqcstring.h (in gcc3's libstdc++)
 
 #include <klibloader.h>
@@ -32,7 +32,7 @@ using namespace std; // iostream.h include cstring which puts strlen into
 #include "pframe.h"
 #include "pkfiledialog.h"
 #include "plabel.h"
-#include "playout.h"
+#include "ptqlayout.h"
 #include "plined.h"
 #include "plistbox.h"
 #include "pmenudta.h"
@@ -173,7 +173,7 @@ void PukeController::NewConnect(int)
   fcntl(cfd, F_SETFL, O_NONBLOCK);  // Set it non-block so that
                                     // cfd() never blocks.
 
-  fdStatus *fds = new fdStatus();
+  fdtqStatus *fds = new fdtqStatus();
   fds->sr = new TQSocketNotifier(cfd, TQSocketNotifier::Read, this);
   fds->sw = new TQSocketNotifier(cfd, TQSocketNotifier::Write, this);
   connect(fds->sr, TQT_SIGNAL(activated(int)),
@@ -868,7 +868,7 @@ void PukeController::messageHandler(int fd, PukeMessage *pm) {
       return;
     }
 
-    TQString libName = "ksirc/lib"+TQString::fromLatin1(pm->cArg);
+    TQString libName = "ksirc/lib"+TQString::tqfromLatin1(pm->cArg);
     if (libName.right(3) == ".so")
        libName = libName.left(libName.length()-2)+"la";
 
