@@ -11,6 +11,7 @@ class PLayout;
 class PLayout : public PObject
 {
   Q_OBJECT
+  TQ_OBJECT
 public:
   static PObject *createWidget(CreateArgs &ca);
 
@@ -35,7 +36,7 @@ public:
 
 private:
 
-  TQBoxLayout *layout;
+  TQBoxLayout *tqlayout;
 
 };
 
