@@ -2,7 +2,7 @@
 
  Server Controller
 
- $$Id: servercontroller.cpp 1157648 2010-07-31 19:48:06Z tpearson $$
+ $$Id: servercontroller.cpp 1246260 2011-08-10 22:19:39Z tpearson $$
 
  Main Server Controller.  Displays server connection window, and makes
  new server connection on demand.
@@ -151,7 +151,7 @@ servercontroller::servercontroller( TQWidget*, const char* name )
   setFrameBorderWidth(5);
 
   TQPopupMenu *file = new TQPopupMenu(this, TQCString(name) + "_menu_file");
-  KStdAction::quit(this, TQT_SLOT(endksirc()), actionCollection())->plug(file);
+  KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(endksirc()), actionCollection())->plug(file);
 #ifndef NDEBUG
   file->insertItem(i18n("Dump Object Tree"), this, TQT_SLOT(dump_obj()));
   file->insertItem(i18n("Server Debug Window"), this, TQT_SLOT(server_debug()));
@@ -173,21 +173,21 @@ servercontroller::servercontroller( TQWidget*, const char* name )
   options->insertItem(SmallIcon( "filter" ), i18n("&Filter Rule Editor..."),
 		      this, TQT_SLOT(filter_rule_editor()));
   options->insertSeparator();
-  KStdAction::configureNotifications(this, TQT_SLOT(notification_prefs()), actionCollection())->plug(options);
+  KStdAction::configureNotifications(TQT_TQOBJECT(this), TQT_SLOT(notification_prefs()), actionCollection())->plug(options);
 
-  KStdAction::preferences(this, TQT_SLOT(general_prefs()), actionCollection())->plug(options);
+  KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(general_prefs()), actionCollection())->plug(options);
 
   MenuBar->insertItem(i18n("&Settings"), options);
 
   KHelpMenu *help = new KHelpMenu( this, kapp->aboutData() );
   MenuBar->insertItem( KStdGuiItem::help().text(), help->menu() );
 
-  m_kga = new KGlobalAccel(this, "globalAccess");
+  m_kga = new KGlobalAccel(TQT_TQOBJECT(this), "globalAccess");
   m_kga->insert("New Server", i18n("New Server"),
 		i18n("This action allows you to open a new server more easily "
 		     "when in docked mode, since you don't need to click on the "
 		     "dock icon."),
-		ALT+CTRL+Key_C, KKey::QtWIN+CTRL+Key_C, this,
+		ALT+CTRL+Key_C, KKey::QtWIN+CTRL+Key_C, TQT_TQOBJECT(this),
 		TQT_SLOT(new_connection()));
 
   open_toplevels = 0;
@@ -253,7 +253,7 @@ void servercontroller::new_ksircprocess(KSircServer &kss)
     return;
   server_id = kss.server();
   while(proc_list[server_id]){   // if it already exists, quit
-    server_id = TQString("%1 %2").arg(kss.server()).arg(id++);
+    server_id = TQString("%1 %2").tqarg(kss.server()).tqarg(id++);
   }
 
   // Insert new base
@@ -303,7 +303,7 @@ void servercontroller::new_channel()
   if(server.isEmpty())
     return;
 
-  KSircChannel ci(server, TQString::null);
+  KSircChannel ci(server, TQString());
   NewWindowDialog w(ci);
   connect(&w, TQT_SIGNAL(openTopLevel(const KSircChannel &)),
 	  this, TQT_SLOT(new_toplevel(const KSircChannel &)));
@@ -386,7 +386,7 @@ void servercontroller::font_update(const TQFont &font)
   KConfig *kConfig = kapp->config();
   kConfig->setGroup("GlobalOptions");
   kConfig->sync();
-  TQApplication::setFont( font, true, "KSirc::TextView" );
+  TQApplication::tqsetFont( font, true, "KSirc::TextView" );
 }
 
 void servercontroller::configChange()
@@ -435,7 +435,7 @@ void servercontroller::ProcMessage(TQString server, int command, TQString args)
               if(online_item->childCount() == 0)
                   delete online_item;
               if(ksopts->runDocked && ksopts->dockPopups)
-                  KPassivePopup::message(i18n("%1 just went offline on %2").arg(args).arg(server), dockWidget);
+                  KPassivePopup::message(i18n("%1 just went offline on %2").tqarg(args).tqarg(server), dockWidget);
           }
           dockWidget->nickOffline(server, args);
           break;
@@ -457,7 +457,7 @@ void servercontroller::ProcMessage(TQString server, int command, TQString args)
           item = new TQListViewItem(online_item, args);
 	  item->setPixmap( 0, pic_run );
 	  if(ksopts->runDocked && ksopts->dockPopups)
-	      KPassivePopup::message(i18n("%1 just came online on %2").arg(args).arg(server), dockWidget);
+	      KPassivePopup::message(i18n("%1 just came online on %2").tqarg(args).tqarg(server), dockWidget);
           dockWidget->nickOnline(server, args);
           break;
       }
@@ -615,7 +615,7 @@ void servercontroller::saveGlobalProperties(KConfig *ksc)
 
   ksc->setGroup("ServerController");
 //  ksc->writeEntry("Docked", !isVisible());
-  ksc->writeEntry("Size", geometry());
+  ksc->writeEntry("Size", tqgeometry());
   ksc->setGroup(group);
 }
 
@@ -661,7 +661,7 @@ void servercontroller::readGlobalProperties(KConfig *ksc)
 	    int desktop = ( *desktopNumberIt ).toInt();
 	    if ( desktop == -1 )
 		continue;
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 	    NETWinInfo winInfo( qt_xdisplay(), topLevel->winId(), qt_xrootwin(), NET::WMDesktop );
 	    winInfo.setDesktop( desktop );
 #endif
@@ -700,7 +700,7 @@ void servercontroller::saveSessionConfig()
 		sessionInfo.port = ksp.current()->serverPort();
 		KSircTopLevel *topLev = dynamic_cast<KSircTopLevel *>( ksm.current() );
 		if ( topLev && topLev->isTopLevel() ) {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 		    NETWinInfo winInfo( qt_xdisplay(), topLev->winId(), qt_xrootwin(), NET::WMDesktop );
 		    sessionInfo.desktop = winInfo.desktop();
 #endif
@@ -718,7 +718,7 @@ void servercontroller::showEvent( TQShowEvent *e )
 {
   TQWidget::showEvent( e );
   if ( !e->spontaneous() )
-    saveDockingStatus();
+    saveDockingtqStatus();
 }
 
 void servercontroller::hideEvent( TQHideEvent * )
@@ -726,7 +726,7 @@ void servercontroller::hideEvent( TQHideEvent * )
     /*
   TQWidget::hideEvent( e );
   if ( !e->spontaneous() )
-    saveDockingStatus();
+    saveDockingtqStatus();
   if(TQWidget::isMinimized()){
     hide();
     KWin::setState(winId(), NET::SkipTaskbar);
@@ -734,7 +734,7 @@ void servercontroller::hideEvent( TQHideEvent * )
     */
 }
 
-void servercontroller::saveDockingStatus()
+void servercontroller::saveDockingtqStatus()
 {
     if ( we_are_exiting ) // we are hidden by closeEvent
 	return;
@@ -821,7 +821,7 @@ void servercontroller::decreaseNotificationCount(TQString reason)
 void servercontroller::resetNotification()
 {
     m_notificationCount = 0;
-    dockWidget->stopBlink(TQString::null, true);
+    dockWidget->stopBlink(TQString(), true);
     TQDictIterator<KSircProcess> it( proc_list );
     while(it.current()){
 	it.current()->filters_update();
@@ -852,7 +852,7 @@ void servercontroller::do_autoconnect()
 		TQString server = *ser;
 		TQString port = "6667";
 		bool usessl = false;
-		TQString pass = TQString::null;
+		TQString pass = TQString();
 
 		TQRegExp rx("(.+) \\(SSL\\)(.*)");
 		if(rx.search(server) >= 0){
@@ -888,7 +888,7 @@ void servercontroller::do_autoconnect()
                 if(loop++ == ctime){
 		    ctime++;
 		    TQString channel = *chan;
-		    TQString key = TQString::null;
+		    TQString key = TQString();
 		    TQRegExp crx("(.+) \\(key: (\\S+)\\)");
 		    if(crx.search(channel) >= 0){
 			channel = crx.cap(1);
@@ -954,7 +954,7 @@ scInside::scInside ( TQWidget * parent, const char * name, WFlags
   ASConn->setFont(asfont);
 
   ConnectionTree = new KListView(this, "connectiontree");
-  ConnectionTree->addColumn(TQString::null);
+  ConnectionTree->addColumn(TQString());
   ConnectionTree->setRootIsDecorated( true );
   ConnectionTree->setSorting( 0 );
   ConnectionTree->header()->hide();
