@@ -1,6 +1,6 @@
 /**********************************************************************
 
-	--- Qt Architect generated file ---
+	--- TQt Architect generated file ---
 
 	File: ssfeprompt.h
 	Last generated: Thu Jan 15 20:49:55 1998
@@ -15,6 +15,7 @@
 class ssfePrompt : public ssfepromptdata
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     
