@@ -18,6 +18,7 @@ class KSircTopicEditor;
 class KSircTopic : public KActiveLabel
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     KSircTopic( TQWidget *parent, const char *name = 0 );
 
@@ -46,9 +47,10 @@ private:
     TQString m_text;
 };
 
-class KSircTopicEditor : public QTextEdit
+class KSircTopicEditor : public TQTextEdit
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     KSircTopicEditor( TQWidget *parent, const char *name = 0 );
 
