@@ -297,7 +297,7 @@ void KSMGetPropertiesProc (
 }
 
 
-class KSMListener : public QSocketNotifier
+class KSMListener : public TQSocketNotifier
 {
 public:
     KSMListener( IceListenObj obj )
@@ -310,7 +310,7 @@ public:
     IceListenObj listenObj;
 };
 
-class KSMConnection : public QSocketNotifier
+class KSMConnection : public TQSocketNotifier
 {
  public:
   KSMConnection( IceConn conn )
@@ -366,12 +366,12 @@ Status SetAuthentication_local (int count, IceListenObj *listenObjs)
     for (i = 0; i < count; i ++) {
         char *prot = IceGetListenConnectionString(listenObjs[i]);
         if (!prot) continue;
-        char *host = (char*)strchr(prot, '/');
+        char *host = strchr(prot, '/');
         char *sock = 0;
         if (host) {
             *host=0;
             host++;
-            sock = (char*)strchr(host, ':');
+            sock = strchr(host, ':');
             if (sock) {
                 *sock = 0;
                 sock++;
@@ -579,7 +579,7 @@ extern "C" int _IceTransNoListen(const char * protocol);
 #endif
 
 KSMServer::KSMServer( const TQString& windowManager, bool _only_local )
-  : DCOPObject("ksmserver"), sessionGroup( "" )
+  : DCOPObject("ksmserver"), sessionGroup( "" ), startupNotifierIPDlg(0), shutdownNotifierIPDlg(0)
 {
     the_server = this;
     clean = false;
@@ -913,7 +913,18 @@ bool KSMServer::isWM( const TQString& program ) const
     // therefore make sure it's recognized even if ksmserver
     // was initially started with different WM, and kwin replaced
     // it later
-    return program == wm || program == "kwin";
+    return ((program == wm) || (program == "kwin"));
+}
+
+bool KSMServer::isCM( const KSMClient* client ) const
+{
+    return isCM( client->program());
+}
+
+bool KSMServer::isCM( const TQString& program ) const
+{
+    // Returns true if the program in question is a composition manager
+    return (program == "kompmgr");
 }
 
 bool KSMServer::defaultSession() const
