@@ -27,7 +27,7 @@ MyMainView::MyMainView(TQWidget *parent)
    setMinimumSize(600,400);
    random.setSeed(0);
    TQPixmap backgr(locate("appdata", MV_BACKGROUND));
-   field.setBackgroundPixmap(backgr);
+   field.tqsetBackgroundPixmap(backgr);
 
    view.setResizePolicy(TQScrollView::AutoOne);
    view.setHScrollBarMode(TQScrollView::AlwaysOff);
@@ -99,7 +99,7 @@ MyMainView::MyMainView(TQWidget *parent)
 
 MyMainView::~MyMainView()
 {
-   killTimers();
+   TQT_TQOBJECT(this)->killTimers();
    writeConfig();
 }
 
@@ -340,7 +340,7 @@ void MyMainView::pause()
       pauseAction->setChecked( true );
 
       waitForStart=true;
-      killTimers();
+      TQT_TQOBJECT(this)->killTimers();
       emit setStatusText(i18n(" paused "), IDS_PAUSE);
    }
 }
@@ -375,7 +375,7 @@ void MyMainView::stop()
    pauseAction->setEnabled( false );
    pauseAction->setChecked( false );
 
-   killTimers();
+   TQT_TQOBJECT(this)->killTimers();
    waitForStart = true;
 }
 
@@ -444,7 +444,7 @@ void MyMainView::newRound()
    timeToNextPowerup=random.getDouble() * config.powerupRefreshTime;
    powerups.clear();
 
-   killTimers();
+   TQT_TQOBJECT(this)->killTimers();
    mx=width()/2.0;
    my=height()/2.0;
    ship[0]->move(mx+config.startPosX,my+config.startPosY);
@@ -492,7 +492,7 @@ void MyMainView::newRound()
    field.update();
 
    TQString str = i18n("Press %1 to start")
-                 .arg(KShortcut(GAME_START_SHORTCUT).toString());
+                 .tqarg(KShortcut(GAME_START_SHORTCUT).toString());
    emit(setStatusText(str,IDS_MAIN));
    emit( setStatusText( "", IDS_PAUSE ) );
    stop( );
@@ -517,7 +517,7 @@ void MyMainView::timerEvent(TQTimerEvent *event)
 
    if(event->timerId()==timerID)
    {
-      killTimers();
+      TQT_TQOBJECT(this)->killTimers();
       if(gameEnd>0.0)
       {
          gameEnd-=1.0;
@@ -534,7 +534,7 @@ void MyMainView::timerEvent(TQTimerEvent *event)
             textSprite=new TQCanvasText(&field);
             textSprite->move(width()/2,height()/2-90);
             textSprite->setTextFlags(AlignCenter);
-            textSprite->setColor(qRgb(255,160,0));
+            textSprite->setColor(tqRgb(255,160,0));
             textSprite->setFont(TQFont(KGlobalSettings::generalFont().family(),14));
             textSprite->show( );
             if(ship[0]->getHitPoints()==0)
@@ -557,7 +557,7 @@ void MyMainView::timerEvent(TQTimerEvent *event)
                emit(wins(0,w));
             }
             TQString str = i18n("Press %1 for new round")
-                          .arg(KShortcut(GAME_START_SHORTCUT).toString());
+                          .tqarg(KShortcut(GAME_START_SHORTCUT).toString());
             emit(setStatusText(str,IDS_MAIN));
             stop( );
          }
@@ -1015,7 +1015,7 @@ TQCanvasPixmapArray* MyMainView::loadOldPixmapSequence(const TQString& datapatte
 
    for( image=0; image < framecount; image++ )
    {
-      // #### Why is this a QString??
+      // #### Why is this a TQString??
       dataname.sprintf( datapattern.ascii(), image );
       maskname.sprintf( maskpattern.ascii(), image );
 
