@@ -1,5 +1,5 @@
 /***************************************************************************
-                          receiversview.h  -  description
+                          tqreceiversview.h  -  description
                              -------------------
     begin                : Tue Jan 11 2005
     copyright            : (C) 2005 by Richard Dale
@@ -27,6 +27,7 @@
 
 class ReceiversView : public KListView  {
    Q_OBJECT
+   TQ_OBJECT
 public: 
    ReceiversView(TQWidget *parent=0, const char *name=0);
    ~ReceiversView();
