@@ -118,7 +118,7 @@ FITSViewer::FITSViewer (const KURL *url, TQWidget *parent, const char *name)
     statusBar()->insertItem("", 2);
     statusBar()->setItemFixed(2, 100);
     statusBar()->insertItem(i18n("Welcome to KStars FITS Viewer"), 3, 1, true);
-    statusBar()->setItemAlignment(3 , Qt::AlignLeft);
+    statusBar()->setItemAlignment(3 , TQt::AlignLeft);
     
     /* FITS initializations */
     if (!initFITS())
@@ -131,41 +131,41 @@ FITSViewer::FITSViewer (const KURL *url, TQWidget *parent, const char *name)
     
     if (KSUtils::openDataFile( tempFile, "imgreduction.png" ) )
     {
-    	new KAction( i18n("Image Reduction"), tempFile.name(), KShortcut( "Ctrl+R" ), this, TQT_SLOT( imageReduction()), actionCollection(), "image_reduce");
+    	new KAction( i18n("Image Reduction"), tempFile.name(), KShortcut( "Ctrl+R" ), TQT_TQOBJECT(this), TQT_SLOT( imageReduction()), actionCollection(), "image_reduce");
 	tempFile.close();
     }
     else
-    	new KAction( i18n("Image Reduction"), "blend", KShortcut( "Ctrl+R" ), this, TQT_SLOT( imageReduction()), actionCollection(), "image_reduce");
+    	new KAction( i18n("Image Reduction"), "blend", KShortcut( "Ctrl+R" ), TQT_TQOBJECT(this), TQT_SLOT( imageReduction()), actionCollection(), "image_reduce");
 	
     /*if (KSUtils::openDataFile( tempFile, "bricon.png" ) )
     {
-    	new KAction( i18n("Brightness/Contrast"), tempFile.name(), KShortcut( "Ctrl+T" ), this, TQT_SLOT( BrightContrastDlg()), actionCollection(), "image_brightness_contrast");
+    	new KAction( i18n("Brightness/Contrast"), tempFile.name(), KShortcut( "Ctrl+T" ), TQT_TQOBJECT(this), TQT_SLOT( BrightContrastDlg()), actionCollection(), "image_brightness_contrast");
 	tempFile.close();
     }
     else*/
-       	new KAction( i18n("Brightness/Contrast"), "contrast+", KShortcut( "Ctrl+T" ), this, TQT_SLOT( BrightContrastDlg()), actionCollection(), "image_brightness_contrast");
+       	new KAction( i18n("Brightness/Contrast"), "contrast+", KShortcut( "Ctrl+T" ), TQT_TQOBJECT(this), TQT_SLOT( BrightContrastDlg()), actionCollection(), "image_brightness_contrast");
 	
     if (KSUtils::openDataFile( tempFile, "histogram.png" ) )
     {
-    	new KAction ( i18n("Histogram"), tempFile.name(), KShortcut("Ctrl+H"), this, TQT_SLOT (imageHistogram()), actionCollection(), "image_histogram");
+    	new KAction ( i18n("Histogram"), tempFile.name(), KShortcut("Ctrl+H"), TQT_TQOBJECT(this), TQT_SLOT (imageHistogram()), actionCollection(), "image_histogram");
 	tempFile.close();
     }
     else
-        new KAction ( i18n("Histogram"), "wizard", KShortcut("Ctrl+H"), this, TQT_SLOT (imageHistogram()), actionCollection(), "image_histogram");
+        new KAction ( i18n("Histogram"), "wizard", KShortcut("Ctrl+H"), TQT_TQOBJECT(this), TQT_SLOT (imageHistogram()), actionCollection(), "image_histogram");
     
-    KStdAction::open(this, TQT_SLOT(fileOpen()), actionCollection());   
-    KStdAction::save(this, TQT_SLOT(fileSave()), actionCollection());
-    KStdAction::saveAs(this, TQT_SLOT(fileSaveAs()), actionCollection());
-    KStdAction::close(this, TQT_SLOT(slotClose()), actionCollection());
-    KStdAction::copy(this, TQT_SLOT(fitsCOPY()), actionCollection());
-    KStdAction::zoomIn(image, TQT_SLOT(fitsZoomIn()), actionCollection());
-    KStdAction::zoomOut(image, TQT_SLOT(fitsZoomOut()), actionCollection());
+    KStdAction::open(TQT_TQOBJECT(this), TQT_SLOT(fileOpen()), actionCollection());   
+    KStdAction::save(TQT_TQOBJECT(this), TQT_SLOT(fileSave()), actionCollection());
+    KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(fileSaveAs()), actionCollection());
+    KStdAction::close(TQT_TQOBJECT(this), TQT_SLOT(slotClose()), actionCollection());
+    KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(fitsCOPY()), actionCollection());
+    KStdAction::zoomIn(TQT_TQOBJECT(image), TQT_SLOT(fitsZoomIn()), actionCollection());
+    KStdAction::zoomOut(TQT_TQOBJECT(image), TQT_SLOT(fitsZoomOut()), actionCollection());
     new KAction( i18n( "&Default Zoom" ), "viewmagfit.png", KShortcut( "Ctrl+D" ),
-		image, TQT_SLOT(fitsZoomDefault()), actionCollection(), "zoom_default" );
-    new KAction( i18n( "Statistics"), "sum", 0, this, TQT_SLOT(fitsStatistics()), actionCollection(), "image_stats");
-    new KAction( i18n( "FITS Header"), "frame_spreadsheet.png", 0, this, TQT_SLOT(fitsHeader()), actionCollection(), "fits_editor");
+		TQT_TQOBJECT(image), TQT_SLOT(fitsZoomDefault()), actionCollection(), "zoom_default" );
+    new KAction( i18n( "Statistics"), "sum", 0, TQT_TQOBJECT(this), TQT_SLOT(fitsStatistics()), actionCollection(), "image_stats");
+    new KAction( i18n( "FITS Header"), "frame_spreadsheet.png", 0, TQT_TQOBJECT(this), TQT_SLOT(fitsHeader()), actionCollection(), "fits_editor");
     
-   /* Create GUI */  
+   /* Create GUI */
    createGUI("fitsviewer.rc");
      
    /* initially resize in accord with KDE rules */
@@ -311,7 +311,7 @@ float * FITSViewer::loadData(const char *filename, float *buffer)
   
   if (fread(tempData, 1, width * height * bpp, ifp->fp) != (unsigned int) (width * height * bpp))
   {
-    KMessageBox::error(0, i18n("Unable to read FITS data from file. %1.\n").arg(strerror(errno)));
+    KMessageBox::error(0, i18n("Unable to read FITS data from file. %1.\n").tqarg(strerror(errno)));
     return (NULL);
   }
   
@@ -388,7 +388,7 @@ void FITSViewer::calculateStats()
   kdDebug() << "Average: " << stats.average << " - stddev: " << stats.stddev << endl;
   kdDebug() << "Width: " << stats.width << " - Height " << stats.height << " - bitpix " << stats.bitpix << endl;*/
   
-  statusBar()->changeItem( TQString("%1 x %2").arg( (int) stats.width).arg( (int) stats.height), 2);
+  statusBar()->changeItem( TQString("%1 x %2").tqarg( (int) stats.width).tqarg( (int) stats.height), 2);
 
 }
 
@@ -553,9 +553,9 @@ void FITSViewer::fileSave()
 	
 	if (TQFile::exists(currentURL.path()))
         {
-            int r=KMessageBox::warningContinueCancel(static_cast<TQWidget *>(parent()),
+            int r=KMessageBox::warningContinueCancel(TQT_TQWIDGET(parent()),
             i18n( "A file named \"%1\" already exists. "
-                  "Overwrite it?" ).arg(currentURL.fileName()),
+                  "Overwrite it?" ).tqarg(currentURL.fileName()),
             i18n( "Overwrite File?" ),
             i18n( "&Overwrite" ) );
   
@@ -692,7 +692,7 @@ void FITSViewer::fileSave()
   }
   else
   {
-		TQString message = i18n( "Invalid URL: %1" ).arg( currentURL.url() );
+		TQString message = i18n( "Invalid URL: %1" ).tqarg( currentURL.url() );
 		KMessageBox::sorry( 0, message, i18n( "Invalid URL" ) );
   }
 	
@@ -880,15 +880,15 @@ void FITSViewer::fitsStatistics()
   
   calculateStats();
   
-  stat.widthOUT->setText(TQString("%1").arg(stats.width));
-  stat.heightOUT->setText(TQString("%1").arg(stats.height));
-  stat.bitpixOUT->setText(TQString("%1").arg(stats.bitpix));
-  stat.maxOUT->setText(TQString("%1").arg(stats.max));
-  stat.minOUT->setText(TQString("%1").arg(stats.min));
-  stat.atMaxOUT->setText(TQString("%1").arg(stats.maxAt));
-  stat.atMinOUT->setText(TQString("%1").arg(stats.minAt));
-  stat.meanOUT->setText(TQString("%1").arg(stats.average));
-  stat.stddevOUT->setText(TQString("%1").arg(stats.stddev));
+  stat.widthOUT->setText(TQString("%1").tqarg(stats.width));
+  stat.heightOUT->setText(TQString("%1").tqarg(stats.height));
+  stat.bitpixOUT->setText(TQString("%1").tqarg(stats.bitpix));
+  stat.maxOUT->setText(TQString("%1").tqarg(stats.max));
+  stat.minOUT->setText(TQString("%1").tqarg(stats.min));
+  stat.atMaxOUT->setText(TQString("%1").tqarg(stats.maxAt));
+  stat.atMinOUT->setText(TQString("%1").tqarg(stats.minAt));
+  stat.meanOUT->setText(TQString("%1").tqarg(stats.average));
+  stat.stddevOUT->setText(TQString("%1").tqarg(stats.stddev));
   
   stat.exec();
 
@@ -903,7 +903,7 @@ void FITSViewer::fitsHeader()
 
    fitsHeaderDialog header(this);
    header.headerView->setSorting(-1);
-   header.headerView->setColumnAlignment(1, Qt::AlignHCenter);
+   header.headerView->setColumnAlignment(1, TQt::AlignHCenter);
    
    for (unsigned int i=0; i < record.count(); i++)
    {
