@@ -453,7 +453,7 @@ void SkyMap::mouseMoveEvent( TQMouseEvent *e ) {
 	if ( ZoomRect.center().x() > 0 && ZoomRect.center().y() > 0 ) {
 		//cancel operation if the user let go of CTRL
 		if ( !( e->state() & ControlButton ) ) {
-			ZoomRect = TQRect(); //invalidate ZoomRect
+			ZoomRect = TQRect(); //tqinvalidate ZoomRect
 			update();
 		} else {
 			//Resize the rectangle so that it passes through the cursor position
@@ -600,7 +600,7 @@ void SkyMap::mouseReleaseEvent( TQMouseEvent * ) {
 		ksw->zoom( Options::zoomFactor() * factor );
 		
 		setDefaultMouseCursor();
-		ZoomRect = TQRect(); //invalidate ZoomRect
+		ZoomRect = TQRect(); //tqinvalidate ZoomRect
 		forceUpdate();
 	} else {
 		setDefaultMouseCursor();
@@ -629,12 +629,12 @@ void SkyMap::mouseReleaseEvent( TQMouseEvent * ) {
 
 void SkyMap::mousePressEvent( TQMouseEvent *e ) {
 	//did we Grab an infoBox?
-	if ( e->button() == LeftButton && infoBoxes()->grabBox( e ) ) {
+	if ( e->button() == Qt::LeftButton && infoBoxes()->grabBox( e ) ) {
 		update(); //refresh without redrawing skymap
 		return;
 	}
 
-	if ( (e->state() & ControlButton) && (e->button() == LeftButton) ) {
+	if ( (e->state() & ControlButton) && (e->button() == Qt::LeftButton) ) {
 		ZoomRect.moveCenter( e->pos() );
 		setZoomMouseCursor();
 		update(); //refresh without redrawing skymap
@@ -649,13 +649,13 @@ void SkyMap::mousePressEvent( TQMouseEvent *e ) {
 	double dy = ( 0.5*height() - e->y() )/Options::zoomFactor();
 	if (unusablePoint (dx, dy)) return;	// break if point is unusable
 
-	if ( !midMouseButtonDown && e->button() == MidButton ) {
+	if ( !midMouseButtonDown && e->button() == Qt::MidButton ) {
 		y0 = 0.5*height() - e->y();  //record y pixel coordinate for middle-button zooming
 		midMouseButtonDown = true;
 	}
 
 	if ( !mouseButtonDown ) {
-		if ( e->button()==LeftButton ) {
+		if ( e->button()==Qt::LeftButton ) {
 			mouseButtonDown = true;
 			scrollCount = 0;
 		}
@@ -671,11 +671,11 @@ void SkyMap::mousePressEvent( TQMouseEvent *e ) {
 		if ( clickedObject() ) {
 			setClickedPoint( clickedObject() );
 			
-			if ( e->button() == RightButton ) {
+			if ( e->button() == Qt::RightButton ) {
 				clickedObject()->showPopupMenu( pmenu, TQCursor::pos() );
 			}
 			
-			if ( ksw && e->button() == LeftButton ) {
+			if ( ksw && e->button() == Qt::LeftButton ) {
 				ksw->statusBar()->changeItem( clickedObject()->translatedLongName(), 0 );
 			}
 		} else {
@@ -684,10 +684,10 @@ void SkyMap::mousePressEvent( TQMouseEvent *e ) {
 			setClickedObject( NULL );
 
 			switch (e->button()) {
-				case LeftButton:
+				case Qt::LeftButton:
 					if ( ksw ) ksw->statusBar()->changeItem( i18n( "Empty sky" ), 0 );
 					break;
-				case RightButton:
+				case Qt::RightButton:
 				{
 					SkyObject *nullObj = new SkyObject( SkyObject::TYPE_UNKNOWN, clickedPoint()->ra()->Hours(), clickedPoint()->dec()->Degrees() );
 					pmenu->createEmptyMenu( nullObj );
@@ -706,7 +706,7 @@ void SkyMap::mousePressEvent( TQMouseEvent *e ) {
 
 void SkyMap::mouseDoubleClickEvent( TQMouseEvent *e ) {
 	//Was the event inside an infoBox?  If so, shade the box.
-	if ( e->button() == LeftButton ) {
+	if ( e->button() == Qt::LeftButton ) {
 		if ( infoBoxes()->shadeBox( e ) ) {
 			update();
 			return;
@@ -754,7 +754,7 @@ void SkyMap::paintEvent( TQPaintEvent * )
 	bool drawGrid( Options::showGrid() && !(checkSlewing && Options::hideGrid() ) );
 
 	psky.begin( sky );
-	psky.fillRect( 0, 0, width(), height(), TQBrush( data->colorScheme()->colorNamed( "SkyColor" ) ) );
+	psky.fillRect( 0, 0, width(), height(), TQBrush( TQColor(data->colorScheme()->colorNamed( "SkyColor" ) )) );
 
 	if ( drawMW ) drawMilkyWay( psky );
 	if ( drawGrid ) drawCoordinateGrid( psky );
