@@ -330,11 +330,11 @@ Value WindowFunc::call(ExecState *exec, Object &thisObj, const List &args)
 		case KSVG::Window::_GetURL:
 		{
 			KURL url((const_cast<Window *>(window))->doc()->baseUrl(), args[0].toString(exec).qstring());
-			Value asyncStatus = (const_cast<Window *>(window))->doc()->ecmaEngine()->getUrl(exec, url);
+			Value asynctqStatus = (const_cast<Window *>(window))->doc()->ecmaEngine()->getUrl(exec, url);
 			Object callBackFunction = Object::dynamicCast(args[1]);
 			List callBackArgs;
 
-			callBackArgs.append(asyncStatus);
+			callBackArgs.append(asynctqStatus);
 			callBackFunction.call(exec, callBackFunction, callBackArgs);
 
 			return Undefined();
@@ -392,7 +392,7 @@ Value WindowFunc::call(ExecState *exec, Object &thisObj, const List &args)
 		    else
 			str2 = KInputDialog::getText(i18n("Prompt"),
 				TQStyleSheet::convertFromPlainText(str),
-				TQString::null, &ok);
+				TQString(), &ok);
 		    if ( ok )
 			return String(str2);
 		    else
