@@ -484,7 +484,7 @@ void SVGStylableImpl::processStyle()
 		if(parentStyle)
 			m_startMarker = parentStyle->getStartMarker();
 		else
-			m_startMarker = TQString::null;
+			m_startMarker = TQString();
 	}
 
 	// Spec: default "none"
@@ -493,7 +493,7 @@ void SVGStylableImpl::processStyle()
 		if(parentStyle)
 			m_midMarker = parentStyle->getMidMarker();
 		else
-			m_midMarker = TQString::null;
+			m_midMarker = TQString();
 	}
 
 	// Spec: default "none"
@@ -502,7 +502,7 @@ void SVGStylableImpl::processStyle()
 		if(parentStyle)
 			m_endMarker = parentStyle->getEndMarker();
 		else
-			m_endMarker = TQString::null;
+			m_endMarker = TQString();
 	}
 }
 
@@ -556,7 +556,7 @@ void SVGStylableImpl::setStartMarker(const TQString &startMarker)
 		m_startMarker = startMarker.mid(idstart, startMarker.length() - idstart - 1);
 	}
 	else if(startMarker == "none")
-		m_startMarker = TQString::null;
+		m_startMarker = TQString();
 }
 
 void SVGStylableImpl::setMidMarker(const TQString &midMarker)
@@ -567,7 +567,7 @@ void SVGStylableImpl::setMidMarker(const TQString &midMarker)
 		m_midMarker = midMarker.mid(idstart, midMarker.length() - idstart - 1);
 	}
 	else if(midMarker == "none")
-		m_midMarker = TQString::null;
+		m_midMarker = TQString();
 }
 
 void SVGStylableImpl::setEndMarker(const TQString &endMarker)
@@ -578,7 +578,7 @@ void SVGStylableImpl::setEndMarker(const TQString &endMarker)
 		m_endMarker = endMarker.mid(idstart, endMarker.length() - idstart - 1);
 	}
 	else if(endMarker == "none")
-		m_endMarker = TQString::null;
+		m_endMarker = TQString();
 }
 
 bool SVGStylableImpl::hasMarkers() const
@@ -711,7 +711,7 @@ float SVGStylableImpl::fontSizeForText(const TQString &value)
  text-anchor		SVGStylableImpl::TextAnchor			DontDelete|ReadOnly
  direction			SVGStylableImpl::Direction			DontDelete|ReadOnly
  writing-mode		SVGStylableImpl::WritingMode		DontDelete|ReadOnly
- unicode-bidi		SVGStylableImpl::UnicodeBidi		DontDelete|ReadOnly
+ tqunicode-bidi		SVGStylableImpl::UnicodeBidi		DontDelete|ReadOnly
  opacity			SVGStylableImpl::Opacity			DontDelete|ReadOnly
  fill-opacity		SVGStylableImpl::FillOpacity		DontDelete|ReadOnly
  stroke-opacity		SVGStylableImpl::StrokeOpacity		DontDelete|ReadOnly
@@ -946,7 +946,7 @@ void SVGStylableImpl::putValueProperty(ExecState *exec, int token, const Value &
 
 			// Hacks
 			// #1 Replace "'" characters by ""
-			param = param.replace('\'', TQString::null);
+			param = param.replace('\'', TQString());
 			// #2 Replace "MS-Gothic" by "MS Gothic"
 			param = param.replace("MS-Gothic", "MS Gothic");
 			// #3 Replace "Helvetica" by "Arial"
@@ -974,7 +974,7 @@ void SVGStylableImpl::putValueProperty(ExecState *exec, int token, const Value &
 			else if(param == "italic")
 				m_fontStyle = ITALIC;
 			else if(param == "oblique")
-				m_fontStyle = OBLIQUE;
+				m_fontStyle = OBLITQUE;
 			break;
 		case TextDecoration:
 			m_flags |= SVG_STYLE_FLAG_TEXT_DECORATION;
@@ -1006,7 +1006,7 @@ void SVGStylableImpl::putValueProperty(ExecState *exec, int token, const Value &
 			break;
 		case Direction:
 			m_flags |= SVG_STYLE_FLAG_TEXT_DIRECTION;
-			// Spec: direction is only processed when unicode-bidi
+			// Spec: direction is only processed when tqunicode-bidi
 			//       is set to bidi-override or embedded
 			if(m_textUnicodeBidi == OVERRIDE ||
 				m_textUnicodeBidi == EMBED ||
@@ -1276,16 +1276,16 @@ void SVGStylableImpl::putValueProperty(ExecState *exec, int token, const Value &
 
 	if(redraw)
 	{
-		SVGShapeImpl *shape = dynamic_cast<SVGShapeImpl *>(m_object);
+		SVGShapeImpl *tqshape = dynamic_cast<SVGShapeImpl *>(m_object);
 		if(inherit)
 			processStyle();
 			
-		if(shape && shape->item())
+		if(tqshape && tqshape->item())
 		{
 			if(update > -1)
-				shape->item()->update(static_cast<CanvasItemUpdate>(update));
+				tqshape->item()->update(static_cast<CanvasItemUpdate>(update));
 			else if(m_object)
-				m_object->ownerDoc()->canvas()->invalidate(shape->item(), false);
+				m_object->ownerDoc()->canvas()->tqinvalidate(tqshape->item(), false);
 		}
 	}
 }
