@@ -129,9 +129,9 @@ TQRect LibartShape::bbox() const
 	return rect;
 }
 
-bool LibartShape::isVisible(SVGShapeImpl *shape)
+bool LibartShape::isVisible(SVGShapeImpl *tqshape)
 {
-	return m_referenced || (m_style->getVisible() && m_style->getDisplay() && shape->directRender());
+	return m_referenced || (m_style->getVisible() && m_style->getDisplay() && tqshape->directRender());
 }
 
 bool LibartShape::fillContains(const TQPoint &p)
@@ -160,12 +160,12 @@ void LibartShape::update(CanvasItemUpdate reason, int param1, int param2)
 			m_fillPainter->update(m_style);
 		if(m_strokePainter)
 			m_strokePainter->update(m_style);
-		m_canvas->invalidate(this, false);
+		m_canvas->tqinvalidate(this, false);
 	}
 	else if(reason == UPDATE_TRANSFORM)
 	{
 		reset();
-		m_canvas->invalidate(this, true);
+		m_canvas->tqinvalidate(this, true);
 	}
 	else if(reason == UPDATE_ZOOM)
 		reset();
@@ -184,13 +184,13 @@ void LibartShape::update(CanvasItemUpdate reason, int param1, int param2)
 			m_strokeSVP = 0;
 		}
 		init();
-		m_canvas->invalidate(this, true);
+		m_canvas->tqinvalidate(this, true);
 	}
 }
 
-void LibartShape::draw(SVGShapeImpl *shape)
+void LibartShape::draw(SVGShapeImpl *tqshape)
 {
-	if(!m_referenced && (!m_style->getVisible() || !m_style->getDisplay() || !shape->directRender()))
+	if(!m_referenced && (!m_style->getVisible() || !m_style->getDisplay() || !tqshape->directRender()))
 		return;
 
 	bool fillOk = m_fillSVP && m_style->isFilled();
@@ -199,10 +199,10 @@ void LibartShape::draw(SVGShapeImpl *shape)
 	if(fillOk || strokeOk)
 	{
 		if(m_fillPainter && m_fillSVP)
-			m_fillPainter->draw(m_canvas, m_fillSVP, m_style, shape);
+			m_fillPainter->draw(m_canvas, m_fillSVP, m_style, tqshape);
 
 		if(m_strokePainter && m_strokeSVP)
-			m_strokePainter->draw(m_canvas, m_strokeSVP, m_style, shape);
+			m_strokePainter->draw(m_canvas, m_strokeSVP, m_style, tqshape);
 	}
 }
 
@@ -230,9 +230,9 @@ void LibartPainter::update(SVGStylableImpl *style)
 	}
 }
 
-void LibartPainter::draw(LibartCanvas *canvas, _ArtSVP *svp, SVGStylableImpl *style, SVGShapeImpl *shape)
+void LibartPainter::draw(LibartCanvas *canvas, _ArtSVP *svp, SVGStylableImpl *style, SVGShapeImpl *tqshape)
 {
-	ArtSVP *clippedSvp = canvas->clipSingleSVP(svp, shape);
+	ArtSVP *clippedSvp = canvas->clipSingleSVP(svp, tqshape);
 
 	// Clipping
 	ArtDRect bbox;
@@ -252,15 +252,15 @@ void LibartPainter::draw(LibartCanvas *canvas, _ArtSVP *svp, SVGStylableImpl *st
 
 		TQRect screenBBox(x0, y0, x1 - x0 + 1, y1 - y0 + 1);
 
-		TQByteArray mask = SVGMaskElementImpl::maskRectangle(shape, screenBBox);
+		TQByteArray mask = SVGMaskElementImpl::maskRectangle(tqshape, screenBBox);
 
 		if(paintType(style) == SVG_PAINTTYPE_URI)
 		{
-			LibartPaintServer *pserver = static_cast<LibartPaintServer *>(SVGPaintServerImpl::paintServer(shape->ownerDoc(), paintUri(style)));
+			LibartPaintServer *pserver = static_cast<LibartPaintServer *>(SVGPaintServerImpl::paintServer(tqshape->ownerDoc(), paintUri(style)));
 
 			if(pserver)
 			{
-				pserver->setBBoxTarget(shape);
+				pserver->setBBoxTarget(tqshape);
 				if(!pserver->finalized())
 					pserver->finalizePaintServer();
 				pserver->render(canvas, clippedSvp, opacity(style), mask, screenBBox);
@@ -1285,28 +1285,28 @@ void LibartClipPath::init()
 	for(; !node.isNull(); node = node.nextSibling())
 	{
 		SVGElementImpl *element = m_clipPath->ownerDoc()->getElementFromHandle(node.handle());
-		SVGShapeImpl *shape = dynamic_cast<SVGShapeImpl *>(element);
+		SVGShapeImpl *tqshape = dynamic_cast<SVGShapeImpl *>(element);
 		SVGTestsImpl *tests = dynamic_cast<SVGTestsImpl *>(element);
 
 		bool ok = tests ? tests->ok() : true;
 
-		if(element && shape && ok && !shape->isContainer())
+		if(element && tqshape && ok && !tqshape->isContainer())
 		{
-			LibartClipItem *clipElement = dynamic_cast<LibartClipItem *>(shape->item());
+			LibartClipItem *clipElement = dynamic_cast<LibartClipItem *>(tqshape->item());
 			
-			if(dynamic_cast<LibartText *>(shape->item()))
+			if(dynamic_cast<LibartText *>(tqshape->item()))
 			{
 				// The cast to a clipElement above is failing when it is valid. But only
 				// in the plugin - svgdisplay works fine. What's going on? (Adrian)
-				clipElement = dynamic_cast<LibartText *>(shape->item());
+				clipElement = dynamic_cast<LibartText *>(tqshape->item());
 			}
 
 			if(clipElement)
 			{
 				clipElement->setRenderContext(CLIPPING);
 
-				// Push coordinate system down to children.
-				SVGLocatableImpl *locatable = dynamic_cast<SVGLocatableImpl *>(shape);
+				// Push coordinate system down to tqchildren.
+				SVGLocatableImpl *locatable = dynamic_cast<SVGLocatableImpl *>(tqshape);
 				if(locatable)
 					locatable->updateCachedScreenCTM(clipMatrix);
 
@@ -1514,13 +1514,13 @@ void LibartText::update(CanvasItemUpdate reason, int param1, int param2)
 			fill = ++it1;
 			stroke = ++it2;
 		}
-		m_canvas->invalidate(this, false);
+		m_canvas->tqinvalidate(this, false);
 	}
 	else if(reason == UPDATE_TRANSFORM)
 	{
 		clearSVPs();
 		init();
-		m_canvas->invalidate(this, true);
+		m_canvas->tqinvalidate(this, true);
 	}
 	else if(reason == UPDATE_ZOOM)
 	{
@@ -1799,10 +1799,10 @@ ArtRender *LibartPaintServer::createRenderer(TQRect bbox, KSVGCanvas *c)
 	// Note: We always pass 3 for the number of channels since the ART_ALPHA parameter
 	// adds the alpha channel when present.
 	ArtRender *render = 0;
-	render = art_render_new(QMIN(x0, x1),
-							QMIN(y0, y1),
-							QMAX(x0, x1) + 1,
-							QMAX(y0, y1) + 1,
+	render = art_render_new(TQMIN(x0, x1),
+							TQMIN(y0, y1),
+							TQMAX(x0, x1) + 1,
+							TQMAX(y0, y1) + 1,
 							c->renderingBuffer() + x0 * c->nrChannels() + y0 * c->rowStride(),
 							c->rowStride(), 3, 8,
 							c->nrChannels() == 3 ? ART_ALPHA_NONE : ART_ALPHA_PREMUL, 0);
@@ -1868,8 +1868,8 @@ void LibartGradient::parseGradientStops(SVGGradientElementImpl *gradient)
 			float opacity = elem->stopOpacity();
 
 			// Get rgba color including stop-opacity
-			Q_UINT32 rgba = (stopColor << 8) | int(opacity * 255.0 + 0.5);
-			Q_UINT32 r, g, b, a;
+			TQ_UINT32 rgba = (stopColor << 8) | int(opacity * 255.0 + 0.5);
+			TQ_UINT32 r, g, b, a;
 
 			a = rgba & 0xff;
 			r = (rgba >> 24) & 0xff;
@@ -2085,7 +2085,7 @@ void LibartRadialGradient::render(KSVGCanvas *c, ArtSVP *svp, float opacity, TQB
 			// Here we're undoing the unit-converter's work because putting the
 			// bounding box transform into the matrix here lets the gradient transform
 			// sit at the right point in the chain to work with bounding box coordinates.
-			// It also produces the elliptical shape due to the non-uniform scaling.
+			// It also produces the elliptical tqshape due to the non-uniform scaling.
 			SVGRectImpl *userBBox = getBBoxTarget()->getBBox();
 
 			double width = userBBox->width();
