@@ -9,9 +9,10 @@ class KSVData;
 class KSVItem;
 class TQWidget;
 
-class KSVDrag : public QDragObject
+class KSVDrag : public TQDragObject
 {
   Q_OBJECT
+  TQ_OBJECT
 
 public:
   KSVDrag (const KSVData& item, TQWidget* dragSource = 0L, const char* name = 0L);
@@ -19,7 +20,7 @@ public:
   virtual ~KSVDrag();
 
   virtual const char* format (int i) const;
-  TQByteArray encodedData (const char*) const;
+  TQByteArray tqencodedData (const char*) const;
   
   static bool decodeNative (const TQMimeSource*, KSVData&);
   
