@@ -40,11 +40,11 @@
 
 
 typedef struct {
-	Q_UINT16 type;
-	Q_UINT16 tag;
+	TQ_UINT16 type;
+	TQ_UINT16 tag;
 	TQVariant value;
 	struct {
-		Q_UINT32 type;
+		TQ_UINT32 type;
 		TQVariant value;
 	} name;
 } MAPI_value;
@@ -52,12 +52,12 @@ typedef struct {
 void clearMAPIName( MAPI_value& mapi );
 void clearMAPIValue(MAPI_value& mapi, bool clearName = true);
 TQString readMAPIString( TQDataStream& stream, bool isUnicode = false, bool align = true, int len = -1 );
-Q_UINT16 readMAPIValue(TQDataStream& stream, MAPI_value& mapi);
+TQ_UINT16 readMAPIValue(TQDataStream& stream, MAPI_value& mapi);
 TQDateTime readTNEFDate( TQDataStream& stream );
 TQString readTNEFAddress( TQDataStream& stream );
-TQByteArray readTNEFData( TQDataStream& stream, Q_UINT32 len );
-TQVariant readTNEFAttribute( TQDataStream& stream, Q_UINT16 type, Q_UINT32 len );
-TQDateTime formatTime( Q_UINT32 lowB, Q_UINT32 highB );
+TQByteArray readTNEFData( TQDataStream& stream, TQ_UINT32 len );
+TQVariant readTNEFAttribute( TQDataStream& stream, TQ_UINT16 type, TQ_UINT32 len );
+TQDateTime formatTime( TQ_UINT32 lowB, TQ_UINT32 highB );
 TQString formatRecipient( const TQMap<int,KTNEFProperty*>& props );
 
 //------------------------------------------------------------------------------------
@@ -70,7 +70,7 @@ public:
 		defaultdir_ = "/tmp/";
 		current_ = 0;
 		deleteDevice_ = false;
-		device_ = 0;
+		tqdevice_ = 0;
 		message_ = new KTNEFMessage;
 	}
 	~ParserPrivate()
@@ -79,7 +79,7 @@ public:
 	}
 
 	TQDataStream              stream_;
-	TQIODevice                *device_;
+	TQIODevice                *tqdevice_;
 	bool                     deleteDevice_;
 	TQString                  defaultdir_;
 	KTNEFAttach              *current_;
@@ -105,15 +105,15 @@ KTNEFMessage* KTNEFParser::message() const
 void KTNEFParser::deleteDevice()
 {
 	if ( d->deleteDevice_ )
-		delete d->device_;
-	d->device_ = 0;
+		delete d->tqdevice_;
+	d->tqdevice_ = 0;
 	d->deleteDevice_ = false;
 }
 
 bool KTNEFParser::decodeMessage()
 {
-	Q_UINT32	i1, i2, off;
-	Q_UINT16	u, tag, type;
+	TQ_UINT32	i1, i2, off;
+	TQ_UINT16	u, tag, type;
 	TQVariant value;
 
 	// read (type+name)
@@ -124,7 +124,7 @@ bool KTNEFParser::decodeMessage()
 	// read data length
 	d->stream_ >> i2;
 	// offset after reading the value
-	off = d->device_->at() + i2;
+	off = d->tqdevice_->at() + i2;
 	switch ( tag )
 	{
 		case attAIDOWNER:
@@ -158,11 +158,11 @@ bool KTNEFParser::decodeMessage()
 			kdDebug() << "Message MAPI Properties" << " (length=" << i2 << ")" << endl;
 			{
 				int nProps = d->message_->properties().count();
-				i2 += d->device_->at();
+				i2 += d->tqdevice_->at();
 				readMAPIProperties( d->message_->properties(), 0 );
-				d->device_->at( i2 );
+				d->tqdevice_->at( i2 );
 				kdDebug() << "Properties: " << d->message_->properties().count() << endl;
-				value = TQString( "< %1 properties >" ).arg( d->message_->properties().count() - nProps );
+				value = TQString( "< %1 properties >" ).tqarg( d->message_->properties().count() - nProps );
 			}
 			break;
 		case attTNEFVERSION:
@@ -171,7 +171,7 @@ bool KTNEFParser::decodeMessage()
 			break;
 		case attFROM:
 			d->message_->addProperty( 0x0024, MAPI_TYPE_STRING8, readTNEFAddress( d->stream_ ) );
-			d->device_->at( d->device_->at() - i2 );
+			d->tqdevice_->at( d->tqdevice_->at() - i2 );
 			value = readTNEFData( d->stream_, i2 );
 			kdDebug() << "Message From" << " (length=" << i2 << ")" << endl;
 			break;
@@ -187,8 +187,8 @@ bool KTNEFParser::decodeMessage()
 			break;
 		case attMSGSTATUS:
 			{
-				Q_UINT8 c;
-				Q_UINT32 flag = 0;
+				TQ_UINT8 c;
+				TQ_UINT32 flag = 0;
 				d->stream_ >> c;
 				if ( c & fmsRead ) flag |= MSGFLAG_READ;
 				if ( !( c & fmsModified ) ) flag |= MSGFLAG_UNMODIFIED;
@@ -202,7 +202,7 @@ bool KTNEFParser::decodeMessage()
 			break;
 		case attRECIPTABLE:
 			{
-				Q_UINT32 rows;
+				TQ_UINT32 rows;
 				TQValueList<TQVariant> recipTable;
 				d->stream_ >> rows;
 				for ( uint i=0; i<rows; i++ )
@@ -212,7 +212,7 @@ bool KTNEFParser::decodeMessage()
 					recipTable << formatRecipient( props );
 				}
 				d->message_->addProperty( 0x0E12, MAPI_TYPE_STRING8, recipTable );
-				d->device_->at( d->device_->at() - i2 );
+				d->tqdevice_->at( d->tqdevice_->at() - i2 );
 				value = readTNEFData( d->stream_, i2 );
 			}
 			kdDebug() << "Message Recipient Table" << " (length=" << i2 << ")" << endl;
@@ -242,20 +242,20 @@ bool KTNEFParser::decodeMessage()
 			break;
 	}
 	// skip data
-	if ( d->device_->at() != off && !d->device_->at( off ) )
+	if ( d->tqdevice_->at() != off && !d->tqdevice_->at( off ) )
 		return false;
 	// get checksum
 	d->stream_ >> u;
 	// add TNEF attribute
 	d->message_->addAttribute( tag, type, value, true );
-	//kdDebug() << "stream: " << d->device_->at() << endl;
+	//kdDebug() << "stream: " << d->tqdevice_->at() << endl;
 	return true;
 }
 
 bool KTNEFParser::decodeAttachment()
 {
-	Q_UINT32	i;
-	Q_UINT16	tag, type, u;
+	TQ_UINT32	i;
+	TQ_UINT16	tag, type, u;
 	TQVariant value;
 	TQString str;
 
@@ -273,15 +273,15 @@ bool KTNEFParser::decodeAttachment()
 		   break;
 	   case attATTACHDATA:
 		   d->current_->setSize( i );
-		   d->current_->setOffset( d->device_->at() );
-		   d->device_->at( d->device_->at() + i );
-		   value = TQString( "< size=%1 >" ).arg( i );
+		   d->current_->setOffset( d->tqdevice_->at() );
+		   d->tqdevice_->at( d->tqdevice_->at() + i );
+		   value = TQString( "< size=%1 >" ).tqarg( i );
 		   kdDebug() << "Attachment Data: size=" << i << endl;
 		   break;
 	   case attATTACHMENT:	// try to get attachment info
-		   i += d->device_->at();
+		   i += d->tqdevice_->at();
 		   readMAPIProperties( d->current_->properties(), d->current_ );
-		   d->device_->at( i );
+		   d->tqdevice_->at( i );
 		   d->current_->setIndex( d->current_->property( MAPI_TAG_INDEX ).toUInt() );
 		   d->current_->setDisplaySize( d->current_->property( MAPI_TAG_SIZE ).toUInt() );
 		   str = d->current_->property( MAPI_TAG_DISPLAYNAME ).toString();
@@ -292,7 +292,7 @@ bool KTNEFParser::decodeAttachment()
 		   if ( !str.isEmpty() )
 			   d->current_->setMimeTag( str );
 		   d->current_->setExtension( d->current_->property( MAPI_TAG_EXTENSION ).toString() );
-		   value = TQString( "< %1 properties >" ).arg( d->current_->properties().count() );
+		   value = TQString( "< %1 properties >" ).tqarg( d->current_->properties().count() );
 		   break;
 	   case attATTACHMODDATE:
 		   value = readTNEFDate( d->stream_ );
@@ -304,8 +304,8 @@ bool KTNEFParser::decodeAttachment()
 		   break;
 	   case attATTACHMETAFILE:
 		   kdDebug() << "Attachment Metafile: size=" << i << endl;
-		   //value = TQString( "< size=%1 >" ).arg( i );
-		   //d->device_->at( d->device_->at()+i );
+		   //value = TQString( "< size=%1 >" ).tqarg( i );
+		   //d->tqdevice_->at( d->tqdevice_->at()+i );
 		   value = readTNEFData( d->stream_, i );
 		   break;
 	   default:
@@ -316,7 +316,7 @@ bool KTNEFParser::decodeAttachment()
 	d->stream_ >> u;	// u <- checksum
 	// add TNEF attribute
 	d->current_->addAttribute( tag, type, value, true );
-	//kdDebug() << "stream: " << d->device_->at() << endl;
+	//kdDebug() << "stream: " << d->tqdevice_->at() << endl;
 
 	return true;
 }
@@ -328,9 +328,9 @@ void KTNEFParser::setDefaultExtractDir(const TQString& dirname)
 
 bool KTNEFParser::parseDevice()
 {
-	Q_UINT16	u;
-	Q_UINT32	i;
-	Q_UINT8		c;
+	TQ_UINT16	u;
+	TQ_UINT32	i;
+	TQ_UINT8		c;
 
 	d->message_->clearAttachments();
 	if (d->current_)
@@ -339,19 +339,19 @@ bool KTNEFParser::parseDevice()
 		d->current_ = 0;
 	}
 
-	if ( !d->device_->open( IO_ReadOnly ) ) {
-	  kdDebug() << "Couldn't open device" << endl;
+	if ( !d->tqdevice_->open( IO_ReadOnly ) ) {
+	  kdDebug() << "Couldn't open tqdevice" << endl;
 		return false;
 	}
 
-	d->stream_.setDevice( d->device_ );
+	d->stream_.setDevice( d->tqdevice_ );
 	d->stream_.setByteOrder( TQDataStream::LittleEndian );
 	d->stream_ >> i;
 	if (i == TNEF_SIGNATURE)
 	{
 		d->stream_ >> u;
 		kdDebug().form( "Attachment cross reference key: 0x%04x\n",u );
-		//kdDebug() << "stream: " << d->device_->at() << endl;
+		//kdDebug() << "stream: " << d->tqdevice_->at() << endl;
 		while (!d->stream_.eof())
 		{
 			d->stream_ >> c;
@@ -364,7 +364,7 @@ bool KTNEFParser::parseDevice()
 				if (!decodeAttachment()) goto end;
 				break;
 			   default:
-				kdDebug() << "Unknown Level: " << c << ", at offset " << d->device_->at() << endl;
+				kdDebug() << "Unknown Level: " << c << ", at offset " << d->tqdevice_->at() << endl;
 				goto end;
 			}
 		}
@@ -381,7 +381,7 @@ bool KTNEFParser::parseDevice()
 	else
 	{
 	  kdDebug() << "This is not a TNEF file" << endl;
-end:	d->device_->close();
+end:	d->tqdevice_->close();
 		return false;
 	}
 }
@@ -395,23 +395,23 @@ bool KTNEFParser::extractFile(const TQString& filename)
 
 bool KTNEFParser::extractAttachmentTo(KTNEFAttach *att, const TQString& dirname)
 {
-	QString	filename = dirname + "/" + att->name();
-	if (!d->device_->isOpen())
+	TQString	filename = dirname + "/" + att->name();
+	if (!d->tqdevice_->isOpen())
 		return false;
-	if (!d->device_->at(att->offset()))
+	if (!d->tqdevice_->at(att->offset()))
 		return false;
 	KSaveFile saveFile( filename );
 	TQFile *outfile = saveFile.file();
 	if ( !outfile )
 		return false;
 
-	Q_UINT32	len = att->size(), sz(16384);
+	TQ_UINT32	len = att->size(), sz(16384);
 	int		n(0);
 	char		*buf = new char[sz];
 	bool		ok(true);
 	while (ok && len > 0)
 	{
-		n = d->device_->readBlock(buf,QMIN(sz,len));
+		n = d->tqdevice_->readBlock(buf,TQMIN(sz,len));
 		if (n < 0)
 			ok = false;
 		else
@@ -447,15 +447,15 @@ bool KTNEFParser::openFile(const TQString& filename)
 	deleteDevice();
 	delete d->message_;
 	d->message_ = new KTNEFMessage();
-	d->device_ = new TQFile( filename );
+	d->tqdevice_ = TQT_TQIODEVICE(new TQFile( filename ));
 	d->deleteDevice_ = true;
 	return parseDevice();
 }
 
-bool KTNEFParser::openDevice( TQIODevice *device )
+bool KTNEFParser::openDevice( TQIODevice *tqdevice )
 {
 	deleteDevice();
-	d->device_ = device;
+	d->tqdevice_ = tqdevice;
 	return parseDevice();
 }
 
@@ -482,12 +482,12 @@ void KTNEFParser::checkCurrent( int key )
                                         if (!mimetype) return; // FIXME
 					if ( mimetype->name() == "application/octet-stream" && d->current_->size() > 0 )
 					{
-						int oldOffset = d->device_->at();
-						TQByteArray buffer( QMIN( 32, d->current_->size() ) );
-						d->device_->at( d->current_->offset() );
-						d->device_->readBlock( buffer.data(), buffer.size() );
+						int oldOffset = d->tqdevice_->at();
+						TQByteArray buffer( TQMIN( 32, d->current_->size() ) );
+						d->tqdevice_->at( d->current_->offset() );
+						d->tqdevice_->readBlock( buffer.data(), buffer.size() );
 						mimetype = KMimeType::findByContent( buffer );
-						d->device_->at( oldOffset );
+						d->tqdevice_->at( oldOffset );
 					}
 					d->current_->setMimeTag( mimetype->name() );
 				}
@@ -521,7 +521,7 @@ void clearMAPIValue(MAPI_value& mapi, bool clearName)
 		clearMAPIName( mapi );
 }
 
-TQDateTime formatTime( Q_UINT32 lowB, Q_UINT32 highB )
+TQDateTime formatTime( TQ_UINT32 lowB, TQ_UINT32 highB )
 {
 	TQDateTime dt;
 #if ( SIZEOF_UINT64_T == 8 )
@@ -580,27 +580,27 @@ TQString formatRecipient( const TQMap<int,KTNEFProperty*>& props )
 TQDateTime readTNEFDate( TQDataStream& stream )
 {
 	// 14-bytes long
-	Q_UINT16 y, m, d, hh, mm, ss, dm;
+	TQ_UINT16 y, m, d, hh, mm, ss, dm;
 	stream >> y >> m >> d >> hh >> mm >> ss >> dm;
 	return TQDateTime( TQDate( y, m, d ), TQTime( hh, mm, ss ) );
 }
 
 TQString readTNEFAddress( TQDataStream& stream )
 {
-	Q_UINT16 totalLen, strLen, addrLen;
+	TQ_UINT16 totalLen, strLen, addrLen;
 	TQString s;
 	stream >> totalLen >> totalLen >> strLen >> addrLen;
 	s.append( readMAPIString( stream, false, false, strLen ) );
 	s.append( " <" );
 	s.append( readMAPIString( stream, false, false, addrLen ) );
 	s.append( ">" );
-	Q_UINT8 c;
+	TQ_UINT8 c;
 	for ( int i=8+strLen+addrLen; i<totalLen; i++ )
 		stream >> c;
 	return s;
 }
 
-TQByteArray readTNEFData( TQDataStream& stream, Q_UINT32 len )
+TQByteArray readTNEFData( TQDataStream& stream, TQ_UINT32 len )
 {
 	TQByteArray array( len );
 	if ( len > 0 )
@@ -608,7 +608,7 @@ TQByteArray readTNEFData( TQDataStream& stream, Q_UINT32 len )
 	return array;
 }
 
-TQVariant readTNEFAttribute( TQDataStream& stream, Q_UINT16 type, Q_UINT32 len )
+TQVariant readTNEFAttribute( TQDataStream& stream, TQ_UINT16 type, TQ_UINT32 len )
 {
 	switch ( type )
 	{
@@ -624,18 +624,18 @@ TQVariant readTNEFAttribute( TQDataStream& stream, Q_UINT16 type, Q_UINT32 len )
 
 TQString readMAPIString( TQDataStream& stream, bool isUnicode, bool align, int len_ )
 {
-	Q_UINT32 len;
+	TQ_UINT32 len;
 	char *buf = 0;
 	if ( len_ == -1 )
 		stream >> len;
 	else
 		len = len_;
-	Q_UINT32 fullLen = len;
+	TQ_UINT32 fullLen = len;
 	if ( align )
 		ALIGN( fullLen, 4 );
 	buf = new char[ len ];
 	stream.readRawBytes( buf, len );
-	Q_UINT8 c;
+	TQ_UINT8 c;
 	for ( uint i=len; i<fullLen; i++ )
 		stream >> c;
 	TQString res;
@@ -647,9 +647,9 @@ TQString readMAPIString( TQDataStream& stream, bool isUnicode, bool align, int l
 	return res;
 }
 
-Q_UINT16 readMAPIValue(TQDataStream& stream, MAPI_value& mapi)
+TQ_UINT16 readMAPIValue(TQDataStream& stream, MAPI_value& mapi)
 {
-	Q_UINT32	d;
+	TQ_UINT32	d;
 
 	clearMAPIValue(mapi);
 	stream >> d;
@@ -696,7 +696,7 @@ Q_UINT16 readMAPIValue(TQDataStream& stream, MAPI_value& mapi)
 			break;
 		   case MAPI_TYPE_TIME:
 			{
-				Q_UINT32 lowB, highB;
+				TQ_UINT32 lowB, highB;
 				stream >> lowB >> highB;
 				value = formatTime( lowB, highB );
 			}
@@ -726,7 +726,7 @@ Q_UINT16 readMAPIValue(TQDataStream& stream, MAPI_value& mapi)
 			for (uint i=0;i<d;i++)
 			{
 				value.clear();
-				Q_UINT32 len;
+				TQ_UINT32 len;
 				stream >> len;
 				value = TQByteArray( len );
 				if (len > 0)
@@ -734,7 +734,7 @@ Q_UINT16 readMAPIValue(TQDataStream& stream, MAPI_value& mapi)
 					int fullLen = len;
 					ALIGN(fullLen, 4);
 					stream.readRawBytes(value.asByteArray().data(), len);
-					Q_UINT8 c;
+					TQ_UINT8 c;
 					for ( int i=len; i<fullLen; i++ )
 						stream >> c;
 				}
@@ -754,7 +754,7 @@ Q_UINT16 readMAPIValue(TQDataStream& stream, MAPI_value& mapi)
 
 bool KTNEFParser::readMAPIProperties( TQMap<int,KTNEFProperty*>& props, KTNEFAttach *attach )
 {
-	Q_UINT32	n;
+	TQ_UINT32	n;
 	MAPI_value	mapi;
 	KTNEFProperty *p;
 	TQMap<int,KTNEFProperty*>::ConstIterator it;
@@ -791,20 +791,20 @@ bool KTNEFParser::readMAPIProperties( TQMap<int,KTNEFProperty*>& props, KTNEFAtt
 					TQByteArray data = mapi.value.toByteArray();
 					int len = data.size();
 					ALIGN( len, 4 );
-					d->device_->at( d->device_->at()-len );
-					Q_UINT32 interface_ID;
+					d->tqdevice_->at( d->tqdevice_->at()-len );
+					TQ_UINT32 interface_ID;
 					d->stream_ >> interface_ID;
 					if ( interface_ID == MAPI_IID_IMessage )
 					{
 						// embedded TNEF file
 						attach->unsetDataParser();
-						attach->setOffset( d->device_->at()+12 );
+						attach->setOffset( d->tqdevice_->at()+12 );
 						attach->setSize( data.size()-16 );
 						attach->setMimeTag( "application/ms-tnef" );
 						attach->setDisplayName( "Embedded Message" );
 						kdDebug() << "MAPI Embedded Message: size=" << data.size() << endl;
 					}
-					d->device_->at( d->device_->at() + ( len-4 ) );
+					d->tqdevice_->at( d->tqdevice_->at() + ( len-4 ) );
 					break;
 				}
 				else if ( mapi.type == MAPI_TYPE_BINARY && attach && attach->offset() < 0 )
@@ -813,8 +813,8 @@ bool KTNEFParser::readMAPIProperties( TQMap<int,KTNEFProperty*>& props, KTNEFAtt
 					int len = mapi.value.toByteArray().size();
 					ALIGN( len, 4 )
 					attach->setSize( len );
-					attach->setOffset( d->device_->at() - len );
-					attach->addAttribute( attATTACHDATA, atpBYTE, TQString( "< size=%1 >" ).arg( len ), false );
+					attach->setOffset( d->tqdevice_->at() - len );
+					attach->addAttribute( attATTACHDATA, atpBYTE, TQString( "< size=%1 >" ).tqarg( len ), false );
 				}
 			}
 			kdDebug().form( "MAPI data: size=%d\n", mapi.value.toByteArray().size() );
@@ -827,7 +827,7 @@ bool KTNEFParser::readMAPIProperties( TQMap<int,KTNEFProperty*>& props, KTNEFAtt
 					if ( mapi.name.type == 0 )
 						mapiname = TQString().sprintf( " [name = 0x%04x]", mapi.name.value.toUInt() );
 					else
-						mapiname = TQString( " [name = %1]" ).arg( mapi.name.value.toString() );
+						mapiname = TQString( " [name = %1]" ).tqarg( mapi.name.value.toString() );
 				}
 				switch ( mapi.type & 0x0FFF )
 				{
@@ -860,7 +860,7 @@ bool KTNEFParser::readMAPIProperties( TQMap<int,KTNEFProperty*>& props, KTNEFAtt
 			p = new KTNEFProperty( key, ( mapi.type & 0x0FFF ), mapi.value, mapi.name.value );
 			props[ p->key() ] = p;
 		}
-		//kdDebug() << "stream: " << d->device_->at() << endl;
+		//kdDebug() << "stream: " << d->tqdevice_->at() << endl;
 	}
 
 	if ( foundAttachment && attach )
