@@ -111,7 +111,7 @@ void KTouchLectureEditor::saveBtnClicked() {
 // -----------------------------------------------------------------------------
 
 void KTouchLectureEditor::saveAsBtnClicked() {
-    TQString tmp = KFileDialog::getSaveFileName(TQString::null, 
+    TQString tmp = KFileDialog::getSaveFileName(TQString(), 
         "*.ktouch.xml|KTouch Lecture Files(*.ktouch.xml)\n*.*|All Files", this, i18n("Save Training Lecture") );
     if (!tmp.isEmpty()) {
         transfer_from_dialog();
@@ -307,7 +307,7 @@ void KTouchLectureEditor::transfer_from_dialog() {
 
 void KTouchLectureEditor::showCurrentLevel() {
     if (m_level >= m_lecture.m_lectureData.size())  return;  // should not happen, but why running a risk here...
-    levelLabel->setText(i18n("Data of Level %1").arg(m_level+1) );
+    levelLabel->setText(i18n("Data of Level %1").tqarg(m_level+1) );
     levelCommentEdit->setText(m_lecture.m_lectureData[m_level].m_comment);
     newCharsEdit->setText(m_lecture.m_lectureData[m_level].m_newChars);
     TQString text;
@@ -379,7 +379,7 @@ int KTouchLectureEditor::openLectureFile(const KURL& url) {
 			// try to read old format first then XML format
 			if (!m_lecture.load(this, m_currentURL) && !m_lecture.loadXML(this, m_currentURL)) {
             	KMessageBox::sorry(this, i18n("Could not open the lecture file, creating a new one instead."));
-            	m_currentURL = TQString::null; // new lectures haven't got a URL
+            	m_currentURL = TQString(); // new lectures haven't got a URL
 			}
         }
         // If we have no URL, we create a new lecture - can happen if either the user
@@ -411,7 +411,7 @@ bool KTouchLectureEditor::saveModified() {
     if (!m_modified) return true;
     // ok, ask the user to save the changes
     int result = KMessageBox::questionYesNoCancel(this, 
-        i18n("The lecture has been changed. Do you want to save the changes?"),TQString::null,KStdGuiItem::save(),KStdGuiItem::discard());
+        i18n("The lecture has been changed. Do you want to save the changes?"),TQString(),KStdGuiItem::save(),KStdGuiItem::discard());
     if (result == KMessageBox::Cancel) return false; // User aborted
     if (result == KMessageBox::Yes) saveBtnClicked();
     // if successfully saved the modified flag will be resetted in the saveBtnClicked() function
