@@ -237,8 +237,8 @@ void KTouchSlideLine::resizeEvent ( TQResizeEvent * ) {
     KD_DEBUG( "[KTouchSlideLine::resizeEvent]" << endl );
 	// required input member variables:  none
 
-	// when the widget is resized, the whole geometry is invalidated, so we do:
-	//   1. recalculate and store the geometry of the sliding lines
+	// when the widget is resized, the whole tqgeometry is invalidated, so we do:
+	//   1. recalculate and store the tqgeometry of the sliding lines
 	//   2. resize the font
 	//   3. recreate the sliding lines (this is done from the resizeFont() function
 
@@ -411,7 +411,7 @@ void KTouchSlideLine::updateSlidingLines() {
 
 	// draw the teacher pixmap text
     TQPainter painter;
-    painter.begin (m_teacherPixmap, this);
+    painter.tqbegin (TQT_TQPAINTDEVICE(m_teacherPixmap), this);
     painter.setFont( m_font );
 
 	TQColor col_tt = Prefs::commonTypingLineColors() ?
@@ -443,7 +443,7 @@ void KTouchSlideLine::updateSlidingLines() {
 	KD_DEBUG( "  m_studentPixmap  = " << w+100 << " x " << h << endl );
 
 	// update (draw) student line and calculate coordinates needed for sliding
-	repaint(true); // trigger a paint event to erase the background
+	tqrepaint(true); // trigger a paint event to erase the background
 	updateStudentLine();
 }
 // ----------------------------------------------------------------------------
@@ -465,7 +465,7 @@ void KTouchSlideLine::updateStudentLine() {
     int teacherLen = m_teacherText.length();
     int studentLen = m_studentText.length();
 
-	unsigned int min_len = QMIN(teacherLen, studentLen);
+	unsigned int min_len = TQMIN(teacherLen, studentLen);
 
 	TQString correctText;
 	if (!Prefs::right2LeftTyping()) {
@@ -532,7 +532,7 @@ void KTouchSlideLine::updateStudentLine() {
 
     // now let's draw the students pixmap
     TQPainter painter;
-    painter.begin (m_studentPixmap, this);
+    painter.tqbegin (TQT_TQPAINTDEVICE(m_studentPixmap), this);
     if (Prefs::colorOnError()) {
         // draw the student line depending on the colour settings
         if (error) {
