@@ -18,7 +18,7 @@
  *                                                                         *
  ***************************************************************************/
 
-// Qt includes.
+// TQt includes.
 #include <tqcstring.h>
 #include <tqclipboard.h>
 #include <tqtextstream.h>
@@ -479,7 +479,7 @@ uint KTTSD::getTextJobCount()
 */
 TQString KTTSD::getTextJobNumbers()
 {
-    if (!m_speaker) return TQString::null;
+    if (!m_speaker) return TQString();
     return m_speechData->getTextJobNumbers();
 }
 
@@ -540,7 +540,7 @@ TQByteArray KTTSD::getTextJobInfo(const uint jobNum /*=0*/)
 */
 TQString KTTSD::talkerCodeToTalkerId(const TQString& talkerCode)
 {
-    if (!m_talkerMgr) return TQString::null;
+    if (!m_talkerMgr) return TQString();
     return m_talkerMgr->talkerCodeToTalkerId(fixNullString(talkerCode));
 }
 
@@ -728,7 +728,7 @@ void KTTSD::changeTextTalker(const TQString &talker, uint jobNum)
 */
 TQString KTTSD::userDefaultTalker()
 {
-    if (!m_talkerMgr) return TQString::null;
+    if (!m_talkerMgr) return TQString();
     return m_talkerMgr->userDefaultTalker();
 }
 
@@ -790,7 +790,7 @@ uint KTTSD::moveRelTextSentence(const int n, const uint jobNum /*=0*/)
 void KTTSD::speakClipboard()
 {
     // Get the clipboard object.
-    QClipboard *cb = kapp->clipboard();
+    TQClipboard *cb = kapp->tqclipboard();
 
     // Copy text from the clipboard.
     TQString text = cb->text();
@@ -906,7 +906,7 @@ void KTTSD::notificationSignal( const TQString& event, const TQString& fromApp,
                     {
                         found = true;
                         notifyOptions = notifyEventMap[ "default" ];
-                        notifyOptions.eventName = TQString::null;
+                        notifyOptions.eventName = TQString();
                     }
                 }
             }
@@ -1084,12 +1084,12 @@ uint KTTSD::applyDefaultJobNum(const uint jobNum)
 
 /*
 * Fixes a string argument passed in via dcop.
-* If NULL or "0" return TQString::null.
+* If NULL or "0" return TQString().
 */
 TQString KTTSD::fixNullString(const TQString &talker) const
 {
-    if (!talker) return TQString::null;
-    if (talker == "0") return TQString::null;
+    if (!talker) return TQString();
+    if (talker == "0") return TQString();
     return talker;
 }
 
