@@ -25,7 +25,7 @@
 // C++ includes.
 #include <stdlib.h>
 
-// Qt includes.
+// TQt includes.
 #include <tqregexp.h>
 #include <tqpair.h>
 #include <tqvaluelist.h>
@@ -156,8 +156,8 @@ void SpeechData::loadNotifyEventsFromFile( const TQString& filename, bool clear)
     {
         notifyDefaultPresent = NotifyPresent::Passive;
         notifyDefaultOptions.action = NotifyAction::SpeakMsg;
-        notifyDefaultOptions.talker = TQString::null;
-        notifyDefaultOptions.customMsg = TQString::null;
+        notifyDefaultOptions.talker = TQString();
+        notifyDefaultOptions.customMsg = TQString();
         notifyAppMap.clear();
     }
 
@@ -195,7 +195,7 @@ void SpeechData::loadNotifyEventsFromFile( const TQString& filename, bool clear)
             notifyEventMap[ event ] = notifyOptions;
             notifyAppMap[ eventSrc ] = notifyEventMap;
         } else {
-            notifyOptions.eventName = TQString::null;
+            notifyOptions.eventName = TQString();
             notifyDefaultPresent = NotifyPresent::present( event );
             notifyDefaultOptions = notifyOptions;
         }
@@ -695,7 +695,7 @@ int SpeechData::getJobPartNumFromSeq(const mlJob& job, const int seq)
 void SpeechData::deleteExpiredJobs(const uint finishedJobNum)
 {
     // Save current pointer.
-    typedef QPair<TQCString, uint> removedJob;
+    typedef TQPair<TQCString, uint> removedJob;
     typedef TQValueList<removedJob> removedJobsList;
     removedJobsList removedJobs;
     // Walk through jobs and delete any other finished jobs.
