@@ -89,7 +89,7 @@ KAboutData *KttsJobMgrFactory::aboutData()
 KttsJobMgrPart::KttsJobMgrPart(TQWidget *parent, const char *name) :
     DCOPStub("kttsd", "KSpeech"),
     DCOPObject("kttsjobmgr_kspeechsink"),
-    KParts::ReadOnlyPart(parent, name)
+    KParts::ReadOnlyPart(TQT_TQOBJECT(parent), name)
 {
     // Initialize some variables.
     m_selectOnTextSet = false;
@@ -106,7 +106,7 @@ KttsJobMgrPart::KttsJobMgrPart(TQWidget *parent, const char *name) :
 
     // Create a splitter to contain the Job List View and the current sentence.
     TQSplitter* splitter = new TQSplitter(vBox);
-    splitter->setOrientation(TQSplitter::Vertical);
+    splitter->setOrientation(Qt::Vertical);
 
     // Create Job List View widget.
     m_jobListView = new KListView(splitter, "joblistview");
@@ -163,7 +163,7 @@ KttsJobMgrPart::KttsJobMgrPart(TQWidget *parent, const char *name) :
     hbox3->setSpacing(6);
 
     // Do not let button box stretch vertically.
-    m_buttonBox->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed));
+    m_buttonBox->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed));
 
     // All the buttons with "job_" at start of their names will be enabled/disabled when a job is
     // selected in the Job List View.
@@ -274,7 +274,7 @@ KttsJobMgrPart::KttsJobMgrPart(TQWidget *parent, const char *name) :
 
     // Create a label for current sentence.
     TQLabel* currentSentenceLabel = new TQLabel(sentenceVBox);
-    currentSentenceLabel->setSizePolicy(TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed));
+    currentSentenceLabel->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed));
     currentSentenceLabel->setText(i18n("Current Sentence"));
 
     // Create a box to contain the current sentence.
@@ -506,7 +506,7 @@ void KttsJobMgrPart::slot_job_change_talker()
 void KttsJobMgrPart::slot_speak_clipboard()
 {
     // Get the clipboard object.
-    QClipboard *cb = kapp->clipboard();
+    TQClipboard *cb = kapp->tqclipboard();
 
 
     // Copy text from the clipboard.
@@ -518,7 +518,7 @@ void KttsJobMgrPart::slot_speak_clipboard()
         {
             if (supportsMarkup(NULL, KSpeech::mtHtml))
             {
-                TQByteArray d = data->encodedData("text/html");
+                TQByteArray d = data->tqencodedData("text/html");
                 text = TQString(d);
             }
         }
@@ -526,7 +526,7 @@ void KttsJobMgrPart::slot_speak_clipboard()
         {
             if (supportsMarkup(NULL, KSpeech::mtSsml))
             {
-                TQByteArray d = data->encodedData("text/ssml");
+                TQByteArray d = data->tqencodedData("text/ssml");
                 text = TQString(d);
             }
         }
@@ -764,7 +764,7 @@ TQString KttsJobMgrPart::cachedTalkerCodeToTalkerID(const TQString& talkerCode)
 void KttsJobMgrPart::enableJobActions(bool enable)
 {
     if (!m_buttonBox) return;
-    TQObjectList *l = m_buttonBox->queryList( "TQPushButton", "job_*", true, true );
+    TQObjectList *l = m_buttonBox->queryList( TQPUSHBUTTON_OBJECT_NAME_STRING, "job_*", true, true );
     TQObjectListIt it( *l ); // iterate over the buttons
     TQObject *obj;
 
@@ -783,7 +783,7 @@ void KttsJobMgrPart::enableJobActions(bool enable)
         {
             bool enableLater = item->nextSibling();
 
-            l = m_buttonBox->queryList( "TQPushButton", "job_later", false, true );
+            l = m_buttonBox->queryList( TQPUSHBUTTON_OBJECT_NAME_STRING, "job_later", false, true );
             it = TQObjectListIt( *l ); // iterate over the buttons
             if ( (obj = it.current()) != 0 ) {
                 // for each found object...
@@ -801,7 +801,7 @@ void KttsJobMgrPart::enableJobActions(bool enable)
 void KttsJobMgrPart::enableJobPartActions(bool enable)
 {
     if (!m_buttonBox) return;
-    TQObjectList *l = m_buttonBox->queryList( "TQPushButton", "part_*", true, true );
+    TQObjectList *l = m_buttonBox->queryList( TQPUSHBUTTON_OBJECT_NAME_STRING, "part_*", true, true );
     TQObjectListIt it( *l ); // iterate over the buttons
     TQObject *obj;
 
@@ -952,7 +952,7 @@ ASYNC KttsJobMgrPart::textFinished(const TQCString&, const uint jobNum)
         // Update sentence pointer, since signal may not be emitted for final CR.
         refreshJob(jobNum);
     }
-    m_currentSentence->setText(TQString::null);
+    m_currentSentence->setText(TQString());
 }
 
 /**
