@@ -94,7 +94,7 @@ void PlayGround::repaintAll()
          editableArea.width() + 20,
          editableArea.height() + 20);
 
-  repaint(dirtyArea, false);
+  tqrepaint(dirtyArea, false);
 }
 
 // Undo last action
@@ -241,7 +241,7 @@ void PlayGround::paintEvent( TQPaintEvent *event )
 
   drawGameboard(artist, area);
 
-  bitBlt(this, destination, &cache, area, Qt::CopyROP);
+  bitBlt(this, destination, &cache, area, TQt::CopyROP);
 }
 
 // Mouse pressed event
@@ -255,10 +255,10 @@ void PlayGround::mousePressEvent( TQMouseEvent *event )
 
   int draggedNumber = draggedObject.getNumber();
   TQPixmap object(objectsLayout[draggedNumber].size());
-  TQBitmap shape(objectsLayout[draggedNumber].size());
-  bitBlt(&object, TQPoint(0, 0), &gameboard, objectsLayout[draggedNumber], Qt::CopyROP);
-  bitBlt(&shape, TQPoint(0, 0), &masks, objectsLayout[draggedNumber], Qt::CopyROP);
-  object.setMask(shape);
+  TQBitmap tqshape(objectsLayout[draggedNumber].size());
+  bitBlt(&object, TQPoint(0, 0), &gameboard, objectsLayout[draggedNumber], TQt::CopyROP);
+  bitBlt(&tqshape, TQPoint(0, 0), &masks, objectsLayout[draggedNumber], TQt::CopyROP);
+  object.setMask(tqshape);
 
   draggedCursor = new TQCursor(object, position.x(), position.y());
   setCursor(*draggedCursor);
@@ -320,7 +320,7 @@ void PlayGround::mouseReleaseEvent( TQMouseEvent *event )
 
   // Repaint the editable area
   position.moveBy(XMARGIN, YMARGIN);
-  repaint(position, false);
+  tqrepaint(position, false);
 
 }
 
@@ -421,9 +421,9 @@ bool PlayGround::loadPlayGround(TQDomDocument &layoutDocument, uint toLoad)
     return false;
 
   delete[] textsLayout;
-  textsLayout = new QRect[texts];
+  textsLayout = new TQRect[texts];
   delete[] textsList;
-  textsList = new QString[texts];
+  textsList = new TQString[texts];
 
   for (int text = 0; text < texts; text++)
   {
@@ -460,9 +460,9 @@ bool PlayGround::loadPlayGround(TQDomDocument &layoutDocument, uint toLoad)
     return false;
 
   delete[] objectsLayout;
-  objectsLayout = new QRect[decorations];
+  objectsLayout = new TQRect[decorations];
   delete[] soundsList;
-  soundsList = new QString[decorations];
+  soundsList = new TQString[decorations];
 
   for (int decoration = 0; decoration < decorations; decoration++)
   {
@@ -506,7 +506,7 @@ void PlayGround::loadFailure()
   exit(-1);
 }
 
-// Set up play ground's geometry
+// Set up play ground's tqgeometry
 void PlayGround::setupGeometry()
 {
   int width = gameboard.width() + 2 * XMARGIN,
@@ -547,15 +547,15 @@ bool PlayGround::zone(TQPoint &position)
     draggedObject = *currentObject;
     draggedNumber = draggedObject.getNumber();
 
-    TQBitmap shape(objectsLayout[draggedNumber].size());
+    TQBitmap tqshape(objectsLayout[draggedNumber].size());
     TQPoint relative(position.x() - toUpdate.x(),
                     position.y() - toUpdate.y());
-    bitBlt(&shape, TQPoint(0, 0), &masks, objectsLayout[draggedNumber], Qt::CopyROP);
-    if (!shape.convertToImage().pixelIndex(relative.x(), relative.y())) continue;
+    bitBlt(&tqshape, TQPoint(0, 0), &masks, objectsLayout[draggedNumber], TQt::CopyROP);
+    if (!tqshape.convertToImage().pixelIndex(relative.x(), relative.y())) continue;
 
     toDraw.remove(draggedZOrder);
     toUpdate.moveBy(XMARGIN, YMARGIN);
-    repaint(toUpdate, false);
+    tqrepaint(toUpdate, false);
 
     position = relative;
 
