@@ -123,59 +123,59 @@ void MainWindow::setupActions()
 	KActionCollection *ac = actionCollection(); // abbreviation
 	
 	// File actions
-	KStdAction::openNew(this, TQT_SLOT(slotNewFile()), ac);
-	openExAction = new KAction(i18n("Open Exa&mples..."), "bookmark_folder", CTRL+Key_E, this, TQT_SLOT(slotOpenExample()), ac, "open_examples");
-	KStdAction::open(this, TQT_SLOT(slotOpenFile()), ac);
-	m_recentFiles = KStdAction::openRecent(this, TQT_SLOT(slotOpenFile(const KURL&)), ac);
-	KStdAction::save(this, TQT_SLOT(slotSaveFile()), ac);
-	KStdAction::saveAs(this, TQT_SLOT(slotSaveAs()), ac);
-	new KAction(i18n("Save &Canvas..."), 0, 0, this, TQT_SLOT(slotSaveCanvas()), ac, "save_canvas");
-	speed = new KSelectAction(i18n("Execution Speed"), 0, ALT+Key_S, this, TQT_SLOT( slotChangeSpeed() ), ac, "speed");
+	KStdAction::openNew(TQT_TQOBJECT(this), TQT_SLOT(slotNewFile()), ac);
+	openExAction = new KAction(i18n("Open Exa&mples..."), "bookmark_folder", CTRL+Key_E, TQT_TQOBJECT(this), TQT_SLOT(slotOpenExample()), ac, "open_examples");
+	KStdAction::open(TQT_TQOBJECT(this), TQT_SLOT(slotOpenFile()), ac);
+	m_recentFiles = KStdAction::openRecent(TQT_TQOBJECT(this), TQT_SLOT(slotOpenFile(const KURL&)), ac);
+	KStdAction::save(TQT_TQOBJECT(this), TQT_SLOT(slotSaveFile()), ac);
+	KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(slotSaveAs()), ac);
+	new KAction(i18n("Save &Canvas..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotSaveCanvas()), ac, "save_canvas");
+	speed = new KSelectAction(i18n("Execution Speed"), 0, ALT+Key_S, TQT_TQOBJECT(this), TQT_SLOT( slotChangeSpeed() ), ac, "speed");
 	TQStringList speeds; speeds << i18n("Full Speed") << i18n("Slow") << i18n("Slower") << i18n("Slowest");
 	speed->setItems(speeds);
 	speed->setCurrentItem(0);
-	run = new KAction(i18n("&Execute Commands"), "gear", ALT+Key_Return, this, TQT_SLOT( slotExecute() ), ac, "run");
-	pause = new KToggleAction(i18n("Pause E&xecution"), "player_pause", Key_Pause, this, TQT_SLOT( slotPauseExecution() ), ac, "pause");
+	run = new KAction(i18n("&Execute Commands"), "gear", ALT+Key_Return, TQT_TQOBJECT(this), TQT_SLOT( slotExecute() ), ac, "run");
+	pause = new KToggleAction(i18n("Pause E&xecution"), "player_pause", Key_Pause, TQT_TQOBJECT(this), TQT_SLOT( slotPauseExecution() ), ac, "pause");
 	pause->setChecked(false);
 	pause->setEnabled(false);
-	stop = new KAction(i18n("Stop E&xecution"), "stop", Key_Escape, this, TQT_SLOT( slotAbortExecution() ), ac, "stop");
+	stop = new KAction(i18n("Stop E&xecution"), "stop", Key_Escape, TQT_TQOBJECT(this), TQT_SLOT( slotAbortExecution() ), ac, "stop");
 	stop->setEnabled(false);
-	KStdAction::print(this, TQT_SLOT(slotPrint()), ac);
-	KStdAction::quit(this, TQT_SLOT(close()), ac);
+	KStdAction::print(TQT_TQOBJECT(this), TQT_SLOT(slotPrint()), ac);
+	KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), ac);
 	
 	// Edit actions
-	KStdAction::undo(this, TQT_SLOT(slotUndo()), ac);
-	KStdAction::redo(this, TQT_SLOT(slotRedo()), ac);
-	KStdAction::cut(this, TQT_SLOT(slotCut()), ac);
-	KStdAction::copy(this, TQT_SLOT(slotCopy()), ac);
-	KStdAction::paste(this, TQT_SLOT(slotPaste()), ac);
-	KStdAction::selectAll(this, TQT_SLOT(slotSelectAll()), ac);
-	KStdAction::deselect(this, TQT_SLOT(slotClearSelection()), ac);
-	new KToggleAction(i18n("Toggle Insert"), Key_Insert, this, TQT_SLOT(slotToggleInsert()), ac, "set_insert");
-	KStdAction::find(this, TQT_SLOT(slotFind()), ac);
-	KStdAction::findNext(this, TQT_SLOT(slotFindNext()), ac);
-	KStdAction::findPrev(this, TQT_SLOT(slotFindPrevious()), ac);
-	KStdAction::replace(this, TQT_SLOT(slotReplace()), ac);
+	KStdAction::undo(TQT_TQOBJECT(this), TQT_SLOT(slotUndo()), ac);
+	KStdAction::redo(TQT_TQOBJECT(this), TQT_SLOT(slotRedo()), ac);
+	KStdAction::cut(TQT_TQOBJECT(this), TQT_SLOT(slotCut()), ac);
+	KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(slotCopy()), ac);
+	KStdAction::paste(TQT_TQOBJECT(this), TQT_SLOT(slotPaste()), ac);
+	KStdAction::selectAll(TQT_TQOBJECT(this), TQT_SLOT(slotSelectAll()), ac);
+	KStdAction::deselect(TQT_TQOBJECT(this), TQT_SLOT(slotClearSelection()), ac);
+	new KToggleAction(i18n("Toggle Insert"), Key_Insert, TQT_TQOBJECT(this), TQT_SLOT(slotToggleInsert()), ac, "set_insert");
+	KStdAction::find(TQT_TQOBJECT(this), TQT_SLOT(slotFind()), ac);
+	KStdAction::findNext(TQT_TQOBJECT(this), TQT_SLOT(slotFindNext()), ac);
+	KStdAction::findPrev(TQT_TQOBJECT(this), TQT_SLOT(slotFindPrevious()), ac);
+	KStdAction::replace(TQT_TQOBJECT(this), TQT_SLOT(slotReplace()), ac);
 	
 	// View actions
-	new KToggleAction(i18n("Show &Line Numbers"), 0, Key_F11, this, TQT_SLOT(slotToggleLineNumbers()), ac, "line_numbers");
-	m_fullscreen = KStdAction::fullScreen(this, TQT_SLOT(slotToggleFullscreen()), ac, this, "full_screen");
+	new KToggleAction(i18n("Show &Line Numbers"), 0, Key_F11, TQT_TQOBJECT(this), TQT_SLOT(slotToggleLineNumbers()), ac, "line_numbers");
+	m_fullscreen = KStdAction::fullScreen(TQT_TQOBJECT(this), TQT_SLOT(slotToggleFullscreen()), ac, this, "full_screen");
 	m_fullscreen->setChecked(b_fullscreen);
 
 	// Tools actions
-	colorpicker = new KToggleAction(i18n("&Color Picker"), "colorize", ALT+Key_C, this, TQT_SLOT(slotColorPicker()), ac, "color_picker");
-	new KAction(i18n("&Indent"), "indent", CTRL+Key_I, this, TQT_SLOT(slotIndent()), ac, "edit_indent");
-	new KAction(i18n("&Unindent"), "unindent", CTRL+SHIFT+Key_I, this, TQT_SLOT(slotUnIndent()), ac, "edit_unindent");
-	new KAction(i18n("Cl&ean Indentation"), 0, 0, this, TQT_SLOT(slotCleanIndent()), ac, "edit_cleanIndent");
-	new KAction(i18n("Co&mment"), 0, CTRL+Key_D, this, TQT_SLOT(slotComment()), ac, "edit_comment");
-	new KAction(i18n("Unc&omment"), 0, CTRL+SHIFT+Key_D, this, TQT_SLOT(slotUnComment()), ac, "edit_uncomment");
+	colorpicker = new KToggleAction(i18n("&Color Picker"), "colorize", ALT+Key_C, TQT_TQOBJECT(this), TQT_SLOT(slotColorPicker()), ac, "color_picker");
+	new KAction(i18n("&Indent"), "indent", CTRL+Key_I, TQT_TQOBJECT(this), TQT_SLOT(slotIndent()), ac, "edit_indent");
+	new KAction(i18n("&Unindent"), "unindent", CTRL+SHIFT+Key_I, TQT_TQOBJECT(this), TQT_SLOT(slotUnIndent()), ac, "edit_unindent");
+	new KAction(i18n("Cl&ean Indentation"), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotCleanIndent()), ac, "edit_cleanIndent");
+	new KAction(i18n("Co&mment"), 0, CTRL+Key_D, TQT_TQOBJECT(this), TQT_SLOT(slotComment()), ac, "edit_comment");
+	new KAction(i18n("Unc&omment"), 0, CTRL+SHIFT+Key_D, TQT_TQOBJECT(this), TQT_SLOT(slotUnComment()), ac, "edit_uncomment");
 	
 	// Settings actions
-	KStdAction::preferences( this, TQT_SLOT(slotSettings()), ac );
-	new KAction(i18n("&Configure Editor..."), "configure", 0, this, TQT_SLOT(slotEditor()), ac, "set_confdlg");
+	KStdAction::preferences( TQT_TQOBJECT(this), TQT_SLOT(slotSettings()), ac );
+	new KAction(i18n("&Configure Editor..."), "configure", 0, TQT_TQOBJECT(this), TQT_SLOT(slotEditor()), ac, "set_confdlg");
 	
 	// Help actions
-	ContextHelp = new KAction(0, 0, Key_F2, this, TQT_SLOT(slotContextHelp()), ac, "context_help");
+	ContextHelp = new KAction(0, 0, Key_F2, TQT_TQOBJECT(this), TQT_SLOT(slotContextHelp()), ac, "context_help");
 	slotContextHelpUpdate(); // this sets the label of this action
 	
 	// other
@@ -192,7 +192,7 @@ void MainWindow::setupEditor()
 	editorDock->setResizeEnabled(true);
 	editorDock->setFrameShape(TQFrame::ToolBarPanel);
 	TQWhatsThis::add( editorDock, i18n( "This is the code editor, here you type the Logo commands to instruct the turtle. You can also open an existing Logo program with File->Open Examples... or File->Open." ) );
-	moveDockWindow(editorDock, Qt::DockLeft);
+	moveDockWindow(editorDock, TQt::DockLeft);
 	editor = doc->createView (editorDock, 0L);
 	// editorInterface is the editor interface which allows us to access the text in the part
 	editorInterface = dynamic_cast<KTextEditor::EditInterface*>(doc);
@@ -221,7 +221,7 @@ void MainWindow::setupStatusBar()
 	
 	// fill the statusbar
 	slotStatusBar(i18n("Welcome to KTurtle..."),  IDS_STATUS); // the message part
-	slotStatusBar(i18n("Line: %1 Column: %2").arg(1).arg(1), IDS_LINECOLUMN);
+	slotStatusBar(i18n("Line: %1 Column: %2").tqarg(1).tqarg(1), IDS_LINECOLUMN);
 	slotStatusBar(i18n("INS"), IDS_INS);
 }
 
@@ -247,7 +247,7 @@ void MainWindow::setupCanvas()
 
 void MainWindow::slotStatusBar(TQString text, int id)
 {
-	text = " " + text + " "; // help the layout
+	text = " " + text + " "; // help the tqlayout
 	statusBar()->changeItem(text, id);
 }
 
@@ -256,7 +256,7 @@ void MainWindow::slotCursorStatusBar()
 	uint cursorLine;
 	uint cursorCol;
 	dynamic_cast<KTextEditor::ViewCursorInterface*>(editor)->cursorPositionReal(&cursorLine, &cursorCol);
-	TQString linenumber = i18n(" Line: %1 Column: %2 ").arg(cursorLine + 1).arg(cursorCol + 1);
+	TQString linenumber = i18n(" Line: %1 Column: %2 ").tqarg(cursorLine + 1).tqarg(cursorCol + 1);
 	statusBar()->changeItem(linenumber, IDS_LINECOLUMN);
 }
 
@@ -330,7 +330,7 @@ void MainWindow::loadFile(const KURL &url)
 			file.close();
 			m_recentFiles->addURL(url);
 			setCaption( url.fileName() );
-			slotStatusBar(i18n("Opened file: %1").arg( url.fileName() ), IDS_STATUS);
+			slotStatusBar(i18n("Opened file: %1").tqarg( url.fileName() ), IDS_STATUS);
 			editor->document()->setModified(false);
 			CurrentFile = url;
 			return;
@@ -338,7 +338,7 @@ void MainWindow::loadFile(const KURL &url)
 		else
 		{
 			KMessageBox::error( this,
-				i18n("KTurtle was unable to open: \n%1.").arg( url.prettyURL() ),
+				i18n("KTurtle was unable to open: \n%1.").tqarg( url.prettyURL() ),
 				i18n("Open Error") );
 			slotStatusBar(i18n("Opening aborted because of error."),  IDS_STATUS);
 			return;
@@ -367,7 +367,7 @@ void MainWindow::slotSaveAs()
 		{
 			int result = KMessageBox::warningContinueCancel ( this,
 					i18n("A program named \"%1\" already exists in this folder. "
-							"Do you want to overwrite it?").arg( url.fileName() ),
+							"Do you want to overwrite it?").tqarg( url.fileName() ),
 					i18n("Overwrite?"), i18n("&Overwrite") );
 			if (result != KMessageBox::Continue) return;
 		}
@@ -384,7 +384,7 @@ void MainWindow::writeFile(const KURL &url)
 		editor->document()->saveAs(url); // use the KateParts method for saving
 		loadFile(url); // reload the file as utf8 otherwise display weird chars
 		setCaption( url.fileName() );
-		slotStatusBar(i18n("Saved to: %1").arg( url.fileName() ),  IDS_STATUS);
+		slotStatusBar(i18n("Saved to: %1").tqarg( url.fileName() ),  IDS_STATUS);
 		m_recentFiles->addURL(url);
 		editor->document()->setModified(false);
 		CurrentFile = url;
@@ -405,7 +405,7 @@ void MainWindow::slotSaveCanvas()
 		{
 			int result = KMessageBox::warningContinueCancel( this,
 				i18n("A picture named \"%1\" already in this folder. "
-				     "Do you want to overwrite it?").arg( url.fileName() ),
+				     "Do you want to overwrite it?").tqarg( url.fileName() ),
 				i18n("Overwrite?"), i18n("&Overwrite") );
 			if (result != KMessageBox::Continue) return;
 		}
@@ -428,12 +428,12 @@ void MainWindow::slotSaveCanvas()
 	{
 		kdWarning() << "KTurtle was unable to save the canvas drawing" << endl;
 		KMessageBox::error(this,
-			i18n("KTurtle was unable to save the image to: \n%1.").arg( url.prettyURL() ),
+			i18n("KTurtle was unable to save the image to: \n%1.").tqarg( url.prettyURL() ),
 			i18n("Unable to Save Image") );
 		slotStatusBar(i18n("Could not save image."),  IDS_STATUS);
 		return;
 	}
-	slotStatusBar(i18n("Saved canvas to: %1").arg( url.fileName() ),  IDS_STATUS);
+	slotStatusBar(i18n("Saved canvas to: %1").tqarg( url.fileName() ),  IDS_STATUS);
 }
 
 
@@ -877,39 +877,39 @@ void MainWindow::slotSettings()
 	TQGridLayout *generalLayout = new TQGridLayout( general, 1, 1, 11, 6, "generalLayout");
 	WidthHeightBox = new TQGroupBox( i18n("Initial Canvas Size"), general );
 	WidthHeightBox->setColumnLayout(0, Qt::Vertical );
-	WidthHeightBox->layout()->setSpacing( 6 );
-	WidthHeightBox->layout()->setMargin( 11 );
-	TQVBoxLayout *WidthHeightBoxLayout = new TQVBoxLayout( WidthHeightBox->layout() );
-	WidthHeightBoxLayout->setAlignment( Qt::AlignTop );
-	TQHBoxLayout *layout3 = new TQHBoxLayout( 0, 0, 6, "layout3");
-	TQVBoxLayout *layout2 = new TQVBoxLayout( 0, 0, 6, "layout2");
+	WidthHeightBox->tqlayout()->setSpacing( 6 );
+	WidthHeightBox->tqlayout()->setMargin( 11 );
+	TQVBoxLayout *WidthHeightBoxLayout = new TQVBoxLayout( WidthHeightBox->tqlayout() );
+	WidthHeightBoxLayout->tqsetAlignment( TQt::AlignTop );
+	TQHBoxLayout *tqlayout3 = new TQHBoxLayout( 0, 0, 6, "tqlayout3");
+	TQVBoxLayout *tqlayout2 = new TQVBoxLayout( 0, 0, 6, "tqlayout2");
 	
-	TQVBoxLayout *layout1 = new TQVBoxLayout( 0, 0, 6, "layout1");
+	TQVBoxLayout *tqlayout1 = new TQVBoxLayout( 0, 0, 6, "tqlayout1");
 
 	kcfg_CanvasWidth = new KIntNumInput( WidthHeightBox, "kcfg_CanvasWidth" );
 	kcfg_CanvasWidth->setValue( 400 );
 	kcfg_CanvasWidth->setMinValue( 1 );
 	kcfg_CanvasWidth->setReferencePoint( 1 );
-	layout1->addWidget( kcfg_CanvasWidth );
+	tqlayout1->addWidget( kcfg_CanvasWidth );
 
 	kcfg_CanvasHeight = new KIntNumInput( WidthHeightBox, "kcfg_CanvasHeight" );
 	kcfg_CanvasHeight->setValue( 300 );
 	kcfg_CanvasHeight->setMinValue( 1 );
 	kcfg_CanvasHeight->setReferencePoint( 1 );
-	layout1->addWidget( kcfg_CanvasHeight );
+	tqlayout1->addWidget( kcfg_CanvasHeight );
 
 	WidthLabel = new TQLabel( kcfg_CanvasWidth, i18n("Canvas &width:"), WidthHeightBox );
-	layout2->addWidget( WidthLabel );
+	tqlayout2->addWidget( WidthLabel );
 	HeightLabel = new TQLabel( kcfg_CanvasHeight, i18n("Ca&nvas height:"), WidthHeightBox );
-	layout2->addWidget( HeightLabel );
-	layout3->addLayout( layout2 );
+	tqlayout2->addWidget( HeightLabel );
+	tqlayout3->addLayout( tqlayout2 );
 
-	layout3->addLayout( layout1 );
-	WidthHeightBoxLayout->addLayout( layout3 );
+	tqlayout3->addLayout( tqlayout1 );
+	WidthHeightBoxLayout->addLayout( tqlayout3 );
 	TQLabel* WidthHeightLabel = new TQLabel(i18n("You need to restart before these settings have effect"), WidthHeightBox);
 	WidthHeightBoxLayout->addWidget( WidthHeightLabel );
 	generalLayout->addWidget( WidthHeightBox, 0, 0 );
-	general->resize( TQSize(234, 109).expandedTo(minimumSizeHint()) );
+	general->resize( TQSize(234, 109).expandedTo(tqminimumSizeHint()) );
 
 	dialog->addPage( general, i18n("General"), "package_settings", i18n("General Settings") );
 
@@ -918,12 +918,12 @@ void MainWindow::slotSettings()
 	TQGridLayout *languageLayout = new TQGridLayout( language, 1, 1, 11, 6, "Form1Layout");
 	TQGroupBox *groupBox1 = new TQGroupBox( language, "groupBox1" );
 	groupBox1->setColumnLayout(0, Qt::Vertical );
-	groupBox1->layout()->setSpacing( 6 );
-	groupBox1->layout()->setMargin( 11 );
-	TQGridLayout *groupBox1Layout = new TQGridLayout( groupBox1->layout() );
-	groupBox1Layout->setAlignment( Qt::AlignTop );
+	groupBox1->tqlayout()->setSpacing( 6 );
+	groupBox1->tqlayout()->setMargin( 11 );
+	TQGridLayout *groupBox1Layout = new TQGridLayout( groupBox1->tqlayout() );
+	groupBox1Layout->tqsetAlignment( TQt::AlignTop );
 
-	TQVBoxLayout *layout4 = new TQVBoxLayout( 0, 0, 6, "layout4");
+	TQVBoxLayout *tqlayout4 = new TQVBoxLayout( 0, 0, 6, "tqlayout4");
 
 	kcfg_LanguageComboBox = new KComboBox(groupBox1, "kcfg_LanguageComboBox");
 	kcfg_LanguageComboBox->setEditable(false);
@@ -935,13 +935,13 @@ void MainWindow::slotSettings()
 	kcfg_LanguageComboBox->insertStringList(LogoLanguageList);
 	
 	LanguageLabel = new TQLabel(kcfg_LanguageComboBox, i18n("&Select the language for the Logo commands:"), groupBox1);
-	layout4->addWidget( LanguageLabel );
-	layout4->addWidget( kcfg_LanguageComboBox );
+	tqlayout4->addWidget( LanguageLabel );
+	tqlayout4->addWidget( kcfg_LanguageComboBox );
 	LanguageLabel->setBuddy( kcfg_LanguageComboBox );
 
-	groupBox1Layout->addLayout( layout4, 0, 0 );
+	groupBox1Layout->addLayout( tqlayout4, 0, 0 );
 	languageLayout->addWidget( groupBox1, 0, 0 );
-	language->resize( TQSize(373, 80).expandedTo(minimumSizeHint()) );
+	language->resize( TQSize(373, 80).expandedTo(tqminimumSizeHint()) );
 
 	dialog->addPage( language, i18n("Language"), "locale", i18n("Language Settings") );
 
@@ -967,7 +967,7 @@ void MainWindow::slotUpdateSettings()
 	// TODO maybe this language name can be more pretty by not using ".left(2)", ie "American English" would than be possible... [if this is possible this should be fixed at more places.]
 	KConfig entry(locate("locale", "all_languages"));
 	entry.setGroup(Settings::logoLanguage().left(2));
-	slotStatusBar(i18n("Command language: %1").arg( entry.readEntry("Name") ), IDS_LANG);
+	slotStatusBar(i18n("Command language: %1").tqarg( entry.readEntry("Name") ), IDS_LANG);
 	
 	delete translate; // to update the currently used language
 	translate = new Translate();
@@ -979,7 +979,7 @@ void MainWindow::readConfig(KConfig *config)
 	m_recentFiles->loadEntries(config, "Recent Files");
 	KConfig entry(locate("locale", "all_languages"));
 	entry.setGroup(Settings::logoLanguage().left(2));
-	slotStatusBar(i18n("Command language: %1").arg( entry.readEntry("Name") ), IDS_LANG);
+	slotStatusBar(i18n("Command language: %1").tqarg( entry.readEntry("Name") ), IDS_LANG);
 }
 
 void MainWindow::slotSettingsHelp()
@@ -1044,8 +1044,8 @@ void MainWindow::slotContextHelp()
 	
 	TQString help2statusBar;
 	if ( helpKeyword.startsWith("<") ) help2statusBar = helpKeyword;
-	else                               help2statusBar = i18n("\"%1\"").arg(helpKeyword);
-	slotStatusBar(i18n("Displaying help on %1").arg(help2statusBar), IDS_STATUS);
+	else                               help2statusBar = i18n("\"%1\"").tqarg(helpKeyword);
+	slotStatusBar(i18n("Displaying help on %1").tqarg(help2statusBar), IDS_STATUS);
 }
 
 void MainWindow::slotContextHelpUpdate()
@@ -1058,13 +1058,13 @@ void MainWindow::slotContextHelpUpdate()
 	if ( line.stripWhiteSpace().startsWith("#") )
 	{
 		helpKeyword = i18n("<comment>");
-		ContextHelp->setText( i18n("Help on: %1").arg(helpKeyword) );
+		ContextHelp->setText( i18n("Help on: %1").tqarg(helpKeyword) );
 		return;
 	}
 	if ( line.stripWhiteSpace().isEmpty() || line.mid(col-1,2).stripWhiteSpace().isEmpty() )
 	{
 		helpKeyword = i18n("<no keyword>");
-		ContextHelp->setText( i18n("Help on: %1").arg(helpKeyword) );
+		ContextHelp->setText( i18n("Help on: %1").tqarg(helpKeyword) );
 		return;
 	}
 	
@@ -1082,7 +1082,7 @@ void MainWindow::slotContextHelpUpdate()
 			if ( col >= (uint)start && col < (uint)(start+length) )
 			{
 				helpKeyword = i18n("<string>");
-				ContextHelp->setText( i18n("Help on: %1").arg(helpKeyword) );
+				ContextHelp->setText( i18n("Help on: %1").tqarg(helpKeyword) );
 				return;
 			}
 			pos += (length <= 0 ? 1 : length);
@@ -1125,7 +1125,7 @@ void MainWindow::slotContextHelpUpdate()
 			
 			else helpKeyword = i18n("<name>");
 			
-			ContextHelp->setText( i18n("Help on: %1").arg(helpKeyword) );
+			ContextHelp->setText( i18n("Help on: %1").tqarg(helpKeyword) );
 			return;
 		}
 		pos += (length <= 0 ? 1 : length); // the pos had to be increased with at least one
@@ -1133,7 +1133,7 @@ void MainWindow::slotContextHelpUpdate()
 	
 	// we allready cached some in the beginning of this method; yet its still needed as fall-through
 	helpKeyword = i18n("<no keyword>");
-	ContextHelp->setText( i18n("Help on: %1").arg(helpKeyword) );
+	ContextHelp->setText( i18n("Help on: %1").tqarg(helpKeyword) );
 }
 
 // END
