@@ -24,9 +24,10 @@
 class TQCheckBox;
 class KIntNumInput;
 
-class SlideShowWidget : public QWidget
+class SlideShowWidget : public TQWidget
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     SlideShowWidget( TQWidget *parent, const char *name );
     ~SlideShowWidget();
