@@ -108,7 +108,7 @@ class PageNode
 					if( **i < **j )
 					{
 						finished = false;
-						qSwap( *i, *j );
+						tqSwap( *i, *j );
 						lastswapped = j;
 					}
 					--i;
@@ -225,7 +225,7 @@ class PageNode
 				TQVBox * page = dlg->addVBoxPage( m_value.group->name,
 						TQString::null, icon );
 				TQLabel * comment = new TQLabel( m_value.group->comment, page );
-				comment->setTextFormat( Qt::RichText );
+				comment->setTextFormat( TQt::RichText );
 				m_value.group->page = page;
 			}
 			List::Iterator end = m_children.end();
