@@ -16,9 +16,10 @@
 
 class SimplePageSize;
 
-class SizePreview : public QWidget
+class SizePreview : public TQWidget
 {
   Q_OBJECT
+  TQ_OBJECT
 
 public:
   SizePreview( TQWidget *parent, const char* name=0, WFlags f=0 );
