@@ -23,14 +23,15 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef QUERYOPTIONS_H
-#define QUERYOPTIONS_H
+#ifndef TQUERYOPTIONS_H
+#define TQUERYOPTIONS_H
 
 #include "queryoptionsbase.h"
 
 class QueryOptions : public QueryOptionsBase
 {
   Q_OBJECT
+  TQ_OBJECT
 
 public:
   QueryOptions(TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
