@@ -36,7 +36,7 @@
 #include "query-dialogs/SimpleQueryDlg.h"
 #include "prefs.h"
 
-#define MAX_QUERY_TIMEOUT 3
+#define MAX_TQUERY_TIMEOUT 3
 
 
 static const char not_answered[] = I18N_NOOP(
@@ -205,7 +205,7 @@ void kvoctrainApp::slotTimeOutProperty(QueryDlgBase::Result res)
   doc->setModified();
   switch (res) {
     case QueryDlgBase::Timeout:
-      if (++num_queryTimeout >= MAX_QUERY_TIMEOUT) {
+      if (++num_queryTimeout >= MAX_TQUERY_TIMEOUT) {
         slotStopQuery(true);
         KMessageBox::information(this, i18n(not_answered),
                                  kapp->makeStdCaption(i18n("Stopping Query")));
@@ -339,7 +339,7 @@ void kvoctrainApp::slotStartTypeQuery(int col, const TQString & type)
 
   hide();
   querymode = true;
-  if (queryType == QT_Conjugation) {
+  if (queryType == TQT_Conjugation) {
     verbQueryDlg = new VerbQueryDlg (exp->getType(act_query_col),
                             random_expr1[random_query_nr].nr,
                             act_query_col,
@@ -359,7 +359,7 @@ void kvoctrainApp::slotStartTypeQuery(int col, const TQString & type)
                    this, TQT_SLOT(slotTimeOutType(QueryDlgBase::Result)));
     verbQueryDlg->show();
   }
-  else if (queryType == QT_Articles) {
+  else if (queryType == TQT_Articles) {
     artQueryDlg = new ArtQueryDlg(exp->getType(act_query_col),
                           random_expr1[random_query_nr].nr,
                           act_query_col,
@@ -376,7 +376,7 @@ void kvoctrainApp::slotStartTypeQuery(int col, const TQString & type)
                       this, TQT_SLOT(slotTimeOutType(QueryDlgBase::Result)));
     artQueryDlg->show();
   }
-  else if (queryType == QT_Comparison) {
+  else if (queryType == TQT_Comparison) {
     adjQueryDlg = new AdjQueryDlg(exp->getType(act_query_col),
                           random_expr1[random_query_nr].nr,
                           act_query_col,
@@ -411,7 +411,7 @@ void kvoctrainApp::slotTimeOutType(QueryDlgBase::Result res)
   doc->setModified();
   switch (res) {
     case QueryDlgBase::Timeout:
-      if (++num_queryTimeout >= MAX_QUERY_TIMEOUT) {
+      if (++num_queryTimeout >= MAX_TQUERY_TIMEOUT) {
         slotStopQuery(true);
         KMessageBox::information(this, i18n(not_answered),
                                  kapp->makeStdCaption(i18n("Stopping Query")));
@@ -486,7 +486,7 @@ void kvoctrainApp::slotTimeOutType(QueryDlgBase::Result res)
   random_query_nr = random.getLong(random_expr1.size());
   kvoctrainExpr *exp = random_expr1[random_query_nr].exp;
 
-  if (queryType == QT_Conjugation) {
+  if (queryType == TQT_Conjugation) {
     if (verbQueryDlg == 0) {
       kdError() << "verbQueryDlg == 0\n";
       slotStopQuery(true);
@@ -505,7 +505,7 @@ void kvoctrainApp::slotTimeOutType(QueryDlgBase::Result res)
 
     verbQueryDlg->initFocus();
   }
-  else if (queryType == QT_Articles) {
+  else if (queryType == TQT_Articles) {
     if (artQueryDlg == 0) {
       kdError() << "artQueryDlg == 0\n";
       slotStopQuery(true);
@@ -522,7 +522,7 @@ void kvoctrainApp::slotTimeOutType(QueryDlgBase::Result res)
                           doc->getArticle(act_query_col));
     artQueryDlg->initFocus();
   }
-  else if (queryType == QT_Comparison) {
+  else if (queryType == TQT_Comparison) {
     if (adjQueryDlg == 0) {
       kdError() << "adjQueryDlg == 0\n";
       slotStopQuery(true);
@@ -629,7 +629,7 @@ void kvoctrainApp::slotStartQuery(const TQString & translang, const TQString & o
     q_trans = exp->getOriginal();
   }
 
-  if (queryType == QT_Random) {
+  if (queryType == TQT_Random) {
     randomQueryDlg = new RandomQueryDlg (
                              q_org,
                              q_trans,
@@ -648,7 +648,7 @@ void kvoctrainApp::slotStartQuery(const TQString & translang, const TQString & o
                this, TQT_SLOT(slotTimeOutRandomQuery(QueryDlgBase::Result)));
       randomQueryDlg->show();
   }
-  else if (queryType == QT_Multiple) {
+  else if (queryType == TQT_Multiple) {
     mcQueryDlg = new MCQueryDlg(
                              q_org,
                              q_trans,
@@ -678,14 +678,14 @@ void kvoctrainApp::slotStartQuery(const TQString & translang, const TQString & o
 
 void kvoctrainApp::slotTimeOutRandomQuery(QueryDlgBase::Result res)
 {
-  queryType = QT_Random;
+  queryType = TQT_Random;
   slotTimeOutQuery(res);
 }
 
 
 void kvoctrainApp::slotTimeOutMultipleChoice(QueryDlgBase::Result res)
 {
-  queryType = QT_Multiple;
+  queryType = TQT_Multiple;
   slotTimeOutQuery(res);
 }
 
@@ -715,7 +715,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
 
   switch (res) {
     case QueryDlgBase::Timeout:
-      if (++num_queryTimeout >= MAX_QUERY_TIMEOUT) {
+      if (++num_queryTimeout >= MAX_TQUERY_TIMEOUT) {
         slotStopQuery(true);
         KMessageBox::information(this, i18n(not_answered),
                                  kapp->makeStdCaption(i18n("Stopping Query")));
@@ -957,7 +957,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
     q_trans = exp->getOriginal();
   }
 
-  if (queryType == QT_Random) {
+  if (queryType == TQT_Random) {
     if (randomQueryDlg == 0) {
       kdError() << "randomQueryDlg == 0\n";
       slotStopQuery(true);
@@ -975,7 +975,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
                              doc);
       randomQueryDlg->initFocus();
   }
-  else if (queryType == QT_Multiple) {
+  else if (queryType == TQT_Multiple) {
     if (mcQueryDlg == 0) {
       kdError() << "mcQueryDlg == 0\n";
       slotStopQuery(true);
