@@ -126,7 +126,7 @@ bool kvoctrainDoc::saveLessonKvtMl (XmlWriter &xml)
       if (getCurrentLesson() == lfn+1)
         xml.addAttribute (KV_LESS_CURR, (TQString) "1" );
       if (lfn < (int) lessons_in_query.size() && lessons_in_query[lfn])
-        xml.addAttribute (KV_LESS_QUERY, (TQString) "1" );
+        xml.addAttribute (KV_LESS_TQUERY, (TQString) "1" );
       xml.closeTag();
       xml.writeText (lesson_descr[lfn]);
       xml.endTag (KV_LESS_DESC, true);
@@ -261,7 +261,7 @@ bool kvoctrainDoc::saveConjugHeader(vector<Conjugation> &curr_conjug,
   xml.closeTag(false, true);
 
   TQString def, indef, s;
-  for (int ent = 0; ent < QMIN((int) curr_conjug.size(), numLangs()); ent++) {
+  for (int ent = 0; ent < TQMIN((int) curr_conjug.size(), numLangs()); ent++) {
     xml.writeText("  ");            // indent entry a bit
     xml.startTag (KV_CON_ENTRY, false);
 
@@ -485,7 +485,7 @@ bool kvoctrainDoc::saveArticleKvtMl (XmlWriter &xml)
   xml.closeTag(false, true);
 
   TQString def, indef, s;
-  for (int lfn = 0; lfn < QMIN((int) articles.size(), numLangs()); lfn++) {
+  for (int lfn = 0; lfn < TQMIN((int) articles.size(), numLangs()); lfn++) {
     xml.writeText("  ");            // indent entry a bit
     xml.startTag (KV_ART_ENTRY, false);
     if (lfn == 0) {
@@ -759,9 +759,9 @@ bool kvoctrainDoc::saveToKvtMl (TQTextStream& os, TQString &title) {
          s = "original";
       xml.addAttribute (KV_LANG, s);
       if (s == q_org)
-        xml.addAttribute (KV_QUERY, (TQString) KV_O);
+        xml.addAttribute (KV_TQUERY, (TQString) KV_O);
       else if (s == q_trans)
-        xml.addAttribute (KV_QUERY, (TQString) KV_T);
+        xml.addAttribute (KV_TQUERY, (TQString) KV_T);
 
     }
 
@@ -804,19 +804,19 @@ bool kvoctrainDoc::saveToKvtMl (TQTextStream& os, TQString &title) {
 
     TQString s;
     TQString entype = s = (*first).getType(0);
-    int pos = s.find (QM_TYPE_DIV);
+    int pos = s.find (TQM_TYPE_DIV);
     if (pos >= 0)
       entype = s.left (pos);
     else
       entype = s;
 
-    if (   entype == QM_VERB
+    if (   entype == TQM_VERB
         && (*first).getConjugation(0).numEntries() > 0) {
       Conjugation conj = (*first).getConjugation(0);
       if (!saveConjugEntry(conj, xml, 1))
         return false;
     }
-    else if (entype == QM_ADJ
+    else if (entype == TQM_ADJ
         && !(*first).getComparison(0).isEmpty()) {
       Comparison comp = (*first).getComparison(0);
       if (!saveComparison (comp, xml, 1))
@@ -841,9 +841,9 @@ bool kvoctrainDoc::saveToKvtMl (TQTextStream& os, TQString &title) {
         }
         xml.addAttribute (KV_LANG, s);
         if (s == q_org)
-          xml.addAttribute (KV_QUERY, (TQString) KV_O);
+          xml.addAttribute (KV_TQUERY, (TQString) KV_O);
         else if (s == q_trans)
-          xml.addAttribute (KV_QUERY, (TQString) KV_T);
+          xml.addAttribute (KV_TQUERY, (TQString) KV_T);
       }
 
       TQString s1, s2;
@@ -925,20 +925,20 @@ bool kvoctrainDoc::saveToKvtMl (TQTextStream& os, TQString &title) {
 
       TQString s;
       TQString entype = s = (*first).getType(0);
-      int pos = s.find (QM_TYPE_DIV);
+      int pos = s.find (TQM_TYPE_DIV);
       if (pos >= 0)
         entype = s.left (pos);
       else
         entype = s;
 
-      if (   entype == QM_VERB
+      if (   entype == TQM_VERB
           && (*first).getConjugation(trans).numEntries() > 0) {
         Conjugation conj = (*first).getConjugation(trans);
         if (!saveConjugEntry(conj, xml, 1+trans))
           return false;
       }
 
-      if (   entype == QM_ADJ
+      if (   entype == TQM_ADJ
           && !(*first).getComparison(trans).isEmpty()) {
         Comparison comp = (*first).getComparison(trans);
         if (!saveComparison (comp, xml, 1+trans))
@@ -956,5 +956,5 @@ bool kvoctrainDoc::saveToKvtMl (TQTextStream& os, TQString &title) {
   xml.endTag (KV_DOCTYPE, true);
 
   setModified (false);
-  return os.device()->status() == IO_Ok;
+  return os.tqdevice()->status() == IO_Ok;
 }
