@@ -105,7 +105,7 @@ kvoctrainDoc::kvoctrainDoc(TQObject *parent, const KURL& url)
     TQFile f(tmpfile);
     if (!f.open(IO_ReadOnly))
     {
-      KMessageBox::error(0, i18n("<qt>Cannot open file<br><b>%1</b></qt>").arg(url.path()));
+      KMessageBox::error(0, i18n("<qt>Cannot open file<br><b>%1</b></qt>").tqarg(url.path()));
       return;
     }
 
@@ -166,7 +166,7 @@ kvoctrainDoc::kvoctrainDoc(TQObject *parent, const KURL& url)
           return;
         }
         TQString format = i18n("Could not load \"%1\"\nDo you want to try again?");
-        TQString msg = format.arg(url.path());
+        TQString msg = format.tqarg(url.path());
         int result = KMessageBox::warningContinueCancel(0, msg,
                                                         kapp->makeStdCaption(i18n("I/O Failure")),
                                                         i18n("&Retry"));
@@ -193,9 +193,9 @@ bool kvoctrainDoc::saveAs (TQObject *parent, const KURL & url, TQString title, F
 
   KURL tmp (url);
   if (title == i18n("Untitled"))
-    title = TQString::null;
+    title = TQString();
   if (title == doc_url.fileName())
-    title = TQString::null;
+    title = TQString();
 
   if (ft == automatic)
   {
@@ -222,7 +222,7 @@ bool kvoctrainDoc::saveAs (TQObject *parent, const KURL & url, TQString title, F
 
     if (!f.open(IO_WriteOnly))
     {
-      KMessageBox::error(0, i18n("<qt>Cannot write to file<br><b>%1</b></qt>").arg(tmp.path()));
+      KMessageBox::error(0, i18n("<qt>Cannot write to file<br><b>%1</b></qt>").tqarg(tmp.path()));
       return false;
     }
 
@@ -262,7 +262,7 @@ bool kvoctrainDoc::saveAs (TQObject *parent, const KURL & url, TQString title, F
 
     if (!saved) {
       TQString format = i18n("Could not save \"%1\"\nDo you want to try again?");
-      TQString msg = format.arg(tmp.path());
+      TQString msg = format.tqarg(tmp.path());
       int result = KMessageBox::warningContinueCancel(0, msg,
                                                       kapp->makeStdCaption(i18n("I/O Failure")),
                                                       i18n("&Retry"));
@@ -920,7 +920,7 @@ kvoctrainDoc::FileType kvoctrainDoc::detectFT(const TQString &filename)
 
    TQDataStream is( &f );
 
-   Q_INT8 c1, c2, c3, c4, c5;
+   TQ_INT8 c1, c2, c3, c4, c5;
    is >> c1
       >> c2
       >> c3
@@ -937,7 +937,7 @@ kvoctrainDoc::FileType kvoctrainDoc::detectFT(const TQString &filename)
    line.insert (0, c1);
    f.close();
 
-   bool stat = is.device()->status();
+   bool stat = is.tqdevice()->status();
    if (stat != IO_Ok)
      return kvd_none;
    if (c1 == '<' && c2 == '?' && c3 == 'x' && c4 == 'm' && c5 == 'l')
