@@ -336,7 +336,7 @@ int Backend::open(const TQByteArray& password) {
 	_hashes.clear();
 	// Read in the hashes
 	TQDataStream hds(&db);
-	Q_UINT32 n;
+	TQ_UINT32 n;
 	hds >> n;
 	if (n > 0xffff) { // sanity check
 		return -43;
@@ -346,7 +346,7 @@ int Backend::open(const TQByteArray& password) {
 		KMD5::Digest d, d2; // judgment day
 		MD5Digest ba;
 		TQMap<MD5Digest,TQValueList<MD5Digest> >::iterator it;
-		Q_UINT32 fsz;
+		TQ_UINT32 fsz;
 		if (hds.atEnd()) return -43;
 		hds.readRawBytes(reinterpret_cast<char *>(d), 16);
 		hds >> fsz;
@@ -422,7 +422,7 @@ int Backend::open(const TQByteArray& password) {
 	// compare hashes
 	int sz = encrypted.size();
 	for (int i = 0; i < 20; i++) {
-		if (testhash[i] != encrypted[sz - 20 + i]) {
+		if (testhash[i] != static_cast<const char>(encrypted.tqat(sz - 20 + i))) {
 			encrypted.fill(0);
 			sha.reset();
 			return -8;         // hash error.
@@ -443,7 +443,7 @@ int Backend::open(const TQByteArray& password) {
 
 	while (!eStream.atEnd()) {
 		TQString folder;
-		Q_UINT32 n;
+		TQ_UINT32 n;
 
 		eStream >> folder;
 		eStream >> n;
@@ -456,7 +456,7 @@ int Backend::open(const TQByteArray& password) {
 			KWallet::Wallet::EntryType et = KWallet::Wallet::Unknown;
 			Entry *e = new Entry;
 			eStream >> key;
-			Q_INT32 x = 0; // necessary to read properly
+			TQ_INT32 x = 0; // necessary to read properly
 			eStream >> x;
 			et = static_cast<KWallet::Wallet::EntryType>(x);
 
@@ -511,7 +511,7 @@ int Backend::sync(const TQByteArray& password) {
 	TQByteArray hashes;
 	TQDataStream hashStream(hashes, IO_WriteOnly);
 	KMD5 md5;
-	hashStream << static_cast<Q_UINT32>(_entries.count());
+	hashStream << static_cast<TQ_UINT32>(_entries.count());
 
 	// Holds decrypted data prior to encryption
 	TQByteArray decrypted;
@@ -524,16 +524,16 @@ int Backend::sync(const TQByteArray& password) {
 	TQDataStream dStream(decrypted, IO_WriteOnly);
 	for (FolderMap::ConstIterator i = _entries.begin(); i != _entries.end(); ++i) {
 		dStream << i.key();
-		dStream << static_cast<Q_UINT32>(i.data().count());
+		dStream << static_cast<TQ_UINT32>(i.data().count());
 
 		md5.reset();
 		md5.update(i.key().utf8());
 		hashStream.writeRawBytes(reinterpret_cast<const char*>(&(md5.rawDigest()[0])), 16);
-		hashStream << static_cast<Q_UINT32>(i.data().count());
+		hashStream << static_cast<TQ_UINT32>(i.data().count());
 
 		for (EntryMap::ConstIterator j = i.data().begin(); j != i.data().end(); ++j) {
 			dStream << j.key();
-			dStream << static_cast<Q_INT32>(j.data()->type());
+			dStream << static_cast<TQ_INT32>(j.data()->type());
 			dStream << j.data()->value();
 
 			md5.reset();
