@@ -16,23 +16,21 @@ License. See the file "COPYING" for the exact licensing terms.
 
 */
 
-#include "client.h"
-#include "workspace.h"
-
-#include <fixx11h.h>
 #include <tqpopupmenu.h>
 #include <kxerrorhandler.h>
 #include <kstartupinfo.h>
 #include <kstringhandler.h>
 #include <klocale.h>
 
+#include "client.h"
+#include "workspace.h"
+#include <fixx11h.h>
+
 #include "notifications.h"
 #include "atoms.h"
 #include "group.h"
 #include "rules.h"
 
-extern Time qt_x_time;
-
 namespace KWinInternal
 {
 
@@ -672,7 +670,7 @@ void Workspace::unfakeActivity( Client* c )
 void Client::updateUserTime( Time time )
     { // copied in Group::updateUserTime
     if( time == CurrentTime )
-        time = qt_x_time;
+        time = GET_QT_X_TIME();
     if( time != -1U
         && ( user_time == CurrentTime
             || timestampCompare( time, user_time ) > 0 )) // time > user_time
@@ -997,7 +995,7 @@ void Group::startupIdChanged()
 void Group::updateUserTime( Time time )
     { // copy of Client::updateUserTime
     if( time == CurrentTime )
-        time = qt_x_time;
+        time = GET_QT_X_TIME();
     if( time != -1U
         && ( user_time == CurrentTime
             || timestampCompare( time, user_time ) > 0 )) // time > user_time
