@@ -110,7 +110,7 @@ KFocusConfig::KFocusConfig (bool _standAlone, KConfig *_config, TQWidget * paren
     //iTLabel = new TQLabel(i18n("  Allowed overlap:\n"
     //                         "(% of desktop space)"),
     //             plcBox);
-    //iTLabel->setAlignment(AlignTop|AlignHCenter);
+    //iTLabel->tqsetAlignment(AlignTop|AlignHCenter);
     //pLay->addWidget(iTLabel,1,1);
 
     //interactiveTrigger = new TQSpinBox(0, 500, 1, plcBox);
@@ -124,7 +124,7 @@ KFocusConfig::KFocusConfig (bool _standAlone, KConfig *_config, TQWidget * paren
     fcsBox = new TQButtonGroup(i18n("Focus"),this);
     fcsBox->setColumnLayout( 0, Qt::Horizontal );
 
-    TQBoxLayout *fLay = new TQVBoxLayout(fcsBox->layout(),
+    TQBoxLayout *fLay = new TQVBoxLayout(fcsBox->tqlayout(),
         KDialog::spacingHint());
 
     TQBoxLayout *cLay = new TQHBoxLayout(fLay);
@@ -192,8 +192,8 @@ KFocusConfig::KFocusConfig (bool _standAlone, KConfig *_config, TQWidget * paren
     connect(clickRaiseOn,TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(clickRaiseOnTog(bool)));
     fLay->addWidget(clickRaiseOn);
 
-//     fLay->addColSpacing(0,QMAX(autoRaiseOn->sizeHint().width(),
-//                                clickRaiseOn->sizeHint().width()) + 15);
+//     fLay->addColSpacing(0,QMAX(autoRaiseOn->tqsizeHint().width(),
+//                                clickRaiseOn->tqsizeHint().width()) + 15);
 
     TQWhatsThis::add( autoRaiseOn, i18n("When this option is enabled, a window in the background will automatically"
                                        " come to the front when the mouse pointer has been over it for some time.") );
@@ -236,7 +236,7 @@ KFocusConfig::KFocusConfig (bool _standAlone, KConfig *_config, TQWidget * paren
 
     kbdBox = new TQButtonGroup(i18n("Navigation"), this);
     kbdBox->setColumnLayout( 0, Qt::Horizontal );
-    TQVBoxLayout *kLay = new TQVBoxLayout(kbdBox->layout(), KDialog::spacingHint());
+    TQVBoxLayout *kLay = new TQVBoxLayout(kbdBox->tqlayout(), KDialog::spacingHint());
 
     altTabPopup = new TQCheckBox( i18n("Show window list while switching windows"), kbdBox );
     kLay->addWidget( altTabPopup );
@@ -535,7 +535,7 @@ void KFocusConfig::save( void )
         config->sync();
         if ( !kapp->dcopClient()->isAttached() )
             kapp->dcopClient()->attach();
-        kapp->dcopClient()->send("kwin*", "", "reconfigure()", "");
+        kapp->dcopClient()->send("kwin*", "", "reconfigure()", TQString(""));
     }
     emit KCModule::changed(false);
 }
@@ -573,7 +573,7 @@ KAdvancedConfig::KAdvancedConfig (bool _standAlone, KConfig *_config, TQWidget *
     //iTLabel = new TQLabel(i18n("  Allowed overlap:\n"
     //                         "(% of desktop space)"),
     //             plcBox);
-    //iTLabel->setAlignment(AlignTop|AlignHCenter);
+    //iTLabel->tqsetAlignment(AlignTop|AlignHCenter);
     //pLay->addWidget(iTLabel,1,1);
 
     //interactiveTrigger = new TQSpinBox(0, 500, 1, plcBox);
@@ -762,7 +762,7 @@ void KAdvancedConfig::save( void )
         config->sync();
         if ( !kapp->dcopClient()->isAttached() )
             kapp->dcopClient()->attach();
-        kapp->dcopClient()->send("kwin*", "", "reconfigure()", "");
+        kapp->dcopClient()->send("kwin*", "", "reconfigure()", TQString(""));
     }
     emit KCModule::changed(false);
 }
@@ -831,7 +831,7 @@ KMovingConfig::KMovingConfig (bool _standAlone, KConfig *_config, TQWidget *pare
     windowsBox = new TQButtonGroup(i18n("Windows"), this);
     windowsBox->setColumnLayout( 0, Qt::Horizontal );
 
-    TQBoxLayout *wLay = new TQVBoxLayout (windowsBox->layout(), KDialog::spacingHint());
+    TQBoxLayout *wLay = new TQVBoxLayout (windowsBox->tqlayout(), KDialog::spacingHint());
 
     TQBoxLayout *bLay = new TQVBoxLayout;
     wLay->addLayout(bLay);
@@ -856,7 +856,7 @@ KMovingConfig::KMovingConfig (bool _standAlone, KConfig *_config, TQWidget *pare
                                         " its size."));
 
     TQGridLayout *rLay = new TQGridLayout(2,3);
-    bLay->addLayout(rLay);
+    bLay->addLayout(TQT_TQLAYOUT(rLay));
     rLay->setColStretch(0,0);
     rLay->setColStretch(1,1);
 
@@ -866,7 +866,7 @@ KMovingConfig::KMovingConfig (bool _standAlone, KConfig *_config, TQWidget *pare
                                           " windows are minimized or restored." ) );
     rLay->addWidget(minimizeAnimOn,0,0);
 
-    minimizeAnimSlider = new TQSlider(0,10,10,0,TQSlider::Horizontal, windowsBox);
+    minimizeAnimSlider = new TQSlider(0,10,10,0,Qt::Horizontal, windowsBox);
     minimizeAnimSlider->setSteps(1, 1);
     // TQSlider::Below clashes with a X11/X.h #define
     #undef Below
@@ -877,11 +877,11 @@ KMovingConfig::KMovingConfig (bool _standAlone, KConfig *_config, TQWidget *pare
     connect(minimizeAnimSlider, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(setMinimizeAnimSpeed(int)));
 
     minimizeAnimSlowLabel= new TQLabel(i18n("Slow"),windowsBox);
-    minimizeAnimSlowLabel->setAlignment(Qt::AlignTop|Qt::AlignLeft);
+    minimizeAnimSlowLabel->tqsetAlignment(Qt::AlignTop|Qt::AlignLeft);
     rLay->addWidget(minimizeAnimSlowLabel,1,1);
 
     minimizeAnimFastLabel= new TQLabel(i18n("Fast"),windowsBox);
-    minimizeAnimFastLabel->setAlignment(Qt::AlignTop|Qt::AlignRight);
+    minimizeAnimFastLabel->tqsetAlignment(Qt::AlignTop|Qt::AlignRight);
     rLay->addWidget(minimizeAnimFastLabel,1,2);
 
     wtstr = i18n("Here you can set the speed of the animation shown when windows are"
@@ -940,7 +940,7 @@ KMovingConfig::KMovingConfig (bool _standAlone, KConfig *_config, TQWidget *pare
     //iTLabel = new TQLabel(i18n("  Allowed overlap:\n"
     //                         "(% of desktop space)"),
     //             plcBox);
-    //iTLabel->setAlignment(AlignTop|AlignHCenter);
+    //iTLabel->tqsetAlignment(AlignTop|AlignHCenter);
     //pLay->addWidget(iTLabel,1,1);
 
     //interactiveTrigger = new TQSpinBox(0, 500, 1, plcBox);
@@ -1219,7 +1219,7 @@ void KMovingConfig::save( void )
         config->sync();
         if ( !kapp->dcopClient()->isAttached() )
             kapp->dcopClient()->attach();
-        kapp->dcopClient()->send("kwin*", "", "reconfigure()", "");
+        kapp->dcopClient()->send("kwin*", "", "reconfigure()", TQString(""));
     }
     emit KCModule::changed(false);
 }
@@ -1345,53 +1345,64 @@ KTranslucencyConfig::KTranslucencyConfig (bool _standAlone, KConfig *_config, TQ
 //   sGroup->setCheckable(TRUE);
   TQVBoxLayout *vLay2 = new TQVBoxLayout (sGroup,11,6);
   vLay2->addSpacing(11); // to get the proper gb top offset
-  useShadows = new TQCheckBox(i18n("Use shadows"),sGroup);
+  useShadows = new TQCheckBox(i18n("Use shadows (standard effects should be disabled in the Styles module if this is checked)"),sGroup);
   vLay2->addWidget(useShadows);
-  
+
   vLay2->addSpacing(11);
 
   TQGridLayout *gLay2 = new TQGridLayout(vLay2,6,2);
   gLay2->setColStretch(1,1);
 
-  TQLabel *label1 = new TQLabel(i18n("Active window size:"),sGroup);
-  gLay2->addWidget(label1,0,0);
-  activeWindowShadowSize = new KIntNumInput(12,sGroup);
-  activeWindowShadowSize->setRange(0,32);
-//   activeWindowShadowSize->setSuffix("px");
-  gLay2->addWidget(activeWindowShadowSize,0,1);
-
-  TQLabel *label2 = new TQLabel(i18n("Inactive window size:"),sGroup);
-  gLay2->addWidget(label2,1,0);
+  TQLabel *label2 = new TQLabel(i18n("Base shadow size:"),sGroup);
+  gLay2->addWidget(label2,0,0);
   inactiveWindowShadowSize = new KIntNumInput(6,sGroup);
   inactiveWindowShadowSize->setRange(0,32);
 //   inactiveWindowShadowSize->setSuffix("px");
-  gLay2->addWidget(inactiveWindowShadowSize,1,1);
+  gLay2->addWidget(inactiveWindowShadowSize,0,1);
 
-  TQLabel *label3 = new TQLabel(i18n("Dock window size:"),sGroup);
+  TQLabel *label1 = new TQLabel(i18n("Active window shadow size multiplier:"),sGroup);
+  gLay2->addWidget(label1,1,0);
+  activeWindowShadowSize = new KIntNumInput(12,sGroup);
+  activeWindowShadowSize->setRange(0,32);
+//   activeWindowShadowSize->setSuffix("px");
+  gLay2->addWidget(activeWindowShadowSize,1,1);
+
+  TQLabel *label3 = new TQLabel(i18n("Dock shadow size multiplier:"),sGroup);
   gLay2->addWidget(label3,2,0);
   dockWindowShadowSize = new KIntNumInput(6,sGroup);
   dockWindowShadowSize->setRange(0,32);
 //   dockWindowShadowSize->setSuffix("px");
   gLay2->addWidget(dockWindowShadowSize,2,1);
 
+  TQLabel *label3a = new TQLabel(i18n("Menu shadow size multiplier:"),sGroup);
+  gLay2->addWidget(label3a,3,0);
+  menuWindowShadowSize = new KIntNumInput(6,sGroup);
+  menuWindowShadowSize->setRange(0,32);
+//   menuWindowShadowSize->setSuffix("px");
+  gLay2->addWidget(menuWindowShadowSize,3,1);
+
+  // Menu shadow settings don't work
+  label3a->hide();
+  menuWindowShadowSize->hide();
+
   TQLabel *label4 = new TQLabel(i18n("Vertical offset:"),sGroup);
-  gLay2->addWidget(label4,3,0);
+  gLay2->addWidget(label4,4,0);
   shadowTopOffset = new KIntNumInput(80,sGroup);
   shadowTopOffset->setSuffix("%");
   shadowTopOffset->setRange(-200,200);
-  gLay2->addWidget(shadowTopOffset,3,1);
+  gLay2->addWidget(shadowTopOffset,4,1);
 
   TQLabel *label5 = new TQLabel(i18n("Horizontal offset:"),sGroup);
-  gLay2->addWidget(label5,4,0);
+  gLay2->addWidget(label5,5,0);
   shadowLeftOffset = new KIntNumInput(0,sGroup);
   shadowLeftOffset->setSuffix("%");
   shadowLeftOffset->setRange(-200,200);
-  gLay2->addWidget(shadowLeftOffset,4,1);
+  gLay2->addWidget(shadowLeftOffset,5,1);
 
   TQLabel *label6 = new TQLabel(i18n("Shadow color:"),sGroup);
   gLay2->addWidget(label6,5,0);
   shadowColor = new KColorButton(Qt::black,sGroup);
-  gLay2->addWidget(shadowColor,5,1);
+  gLay2->addWidget(shadowColor,6,1);
   gLay2->setColStretch(1,1);
   vLay2->addSpacing(11);
   removeShadowsOnMove = new TQCheckBox(i18n("Remove shadows on move"),sGroup);
@@ -1405,6 +1416,7 @@ KTranslucencyConfig::KTranslucencyConfig (bool _standAlone, KConfig *_config, TQ
   TQVBoxLayout *vLay3 = new TQVBoxLayout (eGroup,11,6);
 
   fadeInWindows = new TQCheckBox(i18n("Fade-in windows (including popups)"),eGroup);
+  fadeInMenuWindows = new TQCheckBox(i18n("Fade-in menus (requires menu fade effect to be disabled in the Styles module)"),eGroup);
   fadeOnOpacityChange = new TQCheckBox(i18n("Fade between opacity changes"),eGroup);
   fadeInSpeed = new KIntNumInput(100, eGroup);
   fadeInSpeed->setRange(1,100);
@@ -1413,6 +1425,7 @@ KTranslucencyConfig::KTranslucencyConfig (bool _standAlone, KConfig *_config, TQ
   fadeOutSpeed->setRange(1,100);
   fadeOutSpeed->setLabel(i18n("Fade-out speed:"));
   vLay3->addWidget(fadeInWindows);
+  vLay3->addWidget(fadeInMenuWindows);
   vLay3->addWidget(fadeOnOpacityChange);
   vLay3->addWidget(fadeInSpeed);
   vLay3->addWidget(fadeOutSpeed);
@@ -1420,7 +1433,7 @@ KTranslucencyConfig::KTranslucencyConfig (bool _standAlone, KConfig *_config, TQ
 
   tabW->addTab(eGroup, i18n("Effects"));
 
-  useTranslucency = new TQCheckBox(i18n("Use translucency/shadows"),this);
+  useTranslucency = new TQCheckBox(i18n("Enable the Trinity window composition manager"),this);
   lay->addWidget(useTranslucency);
   lay->addWidget(tabW);
 
@@ -1448,17 +1461,20 @@ KTranslucencyConfig::KTranslucencyConfig (bool _standAlone, KConfig *_config, TQ
   connect(movingWindowOpacity, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(changed()));
   connect(dockWindowOpacity, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(changed()));
   connect(dockWindowShadowSize, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(changed()));
+  connect(menuWindowShadowSize, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(changed()));
   connect(activeWindowShadowSize, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(changed()));
   connect(inactiveWindowShadowSize, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(changed()));
   connect(shadowTopOffset, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(changed()));
   connect(shadowLeftOffset, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(changed()));
   connect(shadowColor, TQT_SIGNAL(changed(const TQColor&)), TQT_SLOT(changed()));
   connect(fadeInWindows, TQT_SIGNAL(toggled(bool)), TQT_SLOT(changed()));
+  connect(fadeInMenuWindows, TQT_SIGNAL(toggled(bool)), TQT_SLOT(changed()));
   connect(fadeOnOpacityChange, TQT_SIGNAL(toggled(bool)), TQT_SLOT(changed()));
   connect(fadeInSpeed, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(changed()));
   connect(fadeOutSpeed, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(changed()));
 
   connect(useShadows, TQT_SIGNAL(toggled(bool)), dockWindowShadowSize, TQT_SLOT(setEnabled(bool)));
+  connect(useShadows, TQT_SIGNAL(toggled(bool)), menuWindowShadowSize, TQT_SLOT(setEnabled(bool)));
   connect(useShadows, TQT_SIGNAL(toggled(bool)), activeWindowShadowSize, TQT_SLOT(setEnabled(bool)));
   connect(useShadows, TQT_SIGNAL(toggled(bool)), inactiveWindowShadowSize, TQT_SLOT(setEnabled(bool)));
   connect(useShadows, TQT_SIGNAL(toggled(bool)), shadowTopOffset, TQT_SLOT(setEnabled(bool)));
@@ -1480,6 +1496,7 @@ KTranslucencyConfig::KTranslucencyConfig (bool _standAlone, KConfig *_config, TQ
   connect(shadowLeftOffset, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(resetKompmgr()));
   connect(shadowColor, TQT_SIGNAL(changed(const TQColor&)), TQT_SLOT(resetKompmgr()));
   connect(fadeInWindows, TQT_SIGNAL(toggled(bool)), TQT_SLOT(resetKompmgr()));
+  connect(fadeInMenuWindows, TQT_SIGNAL(toggled(bool)), TQT_SLOT(resetKompmgr()));
   connect(fadeOnOpacityChange, TQT_SIGNAL(toggled(bool)), TQT_SLOT(resetKompmgr()));
   connect(fadeInSpeed, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(resetKompmgr()));
   connect(fadeOutSpeed, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(resetKompmgr()));
@@ -1501,11 +1518,11 @@ void KTranslucencyConfig::load( void )
 
   config->setGroup( "Translucency" );
   activeWindowTransparency->setChecked(config->readBoolEntry("TranslucentActiveWindows",false));
-  inactiveWindowTransparency->setChecked(config->readBoolEntry("TranslucentInactiveWindows",true));
+  inactiveWindowTransparency->setChecked(config->readBoolEntry("TranslucentInactiveWindows",false));
   movingWindowTransparency->setChecked(config->readBoolEntry("TranslucentMovingWindows",false));
   removeShadowsOnMove->setChecked(config->readBoolEntry("RemoveShadowsOnMove",false));
   removeShadowsOnResize->setChecked(config->readBoolEntry("RemoveShadowsOnResize",false));
-  dockWindowTransparency->setChecked(config->readBoolEntry("TranslucentDocks",true));
+  dockWindowTransparency->setChecked(config->readBoolEntry("TranslucentDocks",false));
   keepAboveAsActive->setChecked(config->readBoolEntry("TreatKeepAboveAsActive",true));
   onlyDecoTranslucent->setChecked(config->readBoolEntry("OnlyDecoTranslucent",false));
 
@@ -1514,8 +1531,9 @@ void KTranslucencyConfig::load( void )
   movingWindowOpacity->setValue(config->readNumEntry("MovingWindowOpacity",25));
   dockWindowOpacity->setValue(config->readNumEntry("DockOpacity",80));
 
-  int ass, iss, dss;
+  int ass, iss, dss, mss;
   dss = config->readNumEntry("DockShadowSize", 33);
+  mss = config->readNumEntry("MenuShadowSize", 33);
   ass = config->readNumEntry("ActiveWindowShadowSize", 133);
   iss = config->readNumEntry("InactiveWindowShadowSize", 67);
 
@@ -1526,15 +1544,16 @@ void KTranslucencyConfig::load( void )
 
   KConfig conf_(TQDir::homeDirPath() + "/.xcompmgrrc");
   conf_.setGroup("xcompmgr");
-  
+
   disableARGB->setChecked(conf_.readBoolEntry("DisableARGB",FALSE));
 
-  useShadows->setChecked(conf_.readEntry("Compmode","CompClientShadows").compare("CompClientShadows") == 0);
+  useShadows->setChecked(conf_.readEntry("Compmode","").compare("CompClientShadows") == 0);
   shadowTopOffset->setValue(-1*(conf_.readNumEntry("ShadowOffsetY",-80)));
   shadowLeftOffset->setValue(-1*(conf_.readNumEntry("ShadowOffsetX",0)));
 
   int ss =  conf_.readNumEntry("ShadowRadius",6);
   dockWindowShadowSize->setValue((int)(dss*ss/100.0));
+  menuWindowShadowSize->setValue((int)(mss*ss/100.0));
   activeWindowShadowSize->setValue((int)(ass*ss/100.0));
   inactiveWindowShadowSize->setValue((int)(iss*ss/100.0));
 
@@ -1547,9 +1566,10 @@ void KTranslucencyConfig::load( void )
   else
     shadowColor->setColor(TQColor(r,g,b));
 
-  fadeInWindows->setChecked(conf_.readBoolEntry("FadeWindows",TRUE));
+  fadeInWindows->setChecked(conf_.readBoolEntry("FadeWindows",FALSE));
+  fadeInMenuWindows->setChecked(conf_.readBoolEntry("FadeMenuWindows",FALSE));
   fadeOnOpacityChange->setChecked(conf_.readBoolEntry("FadeTrans",FALSE));
-  fadeInSpeed->setValue((int)(conf_.readDoubleNumEntry("FadeInStep",0.020)*1000.0));
+  fadeInSpeed->setValue((int)(conf_.readDoubleNumEntry("FadeInStep",0.070)*1000.0));
   fadeOutSpeed->setValue((int)(conf_.readDoubleNumEntry("FadeOutStep",0.070)*1000.0));
 
   emit KCModule::changed(false);
@@ -1579,9 +1599,10 @@ void KTranslucencyConfig::save( void )
   // this way the user can set the three values without caring about the radius/multiplicator stuff
    // additionally we find a value between big and small values to have a more smooth appereance
    config->writeEntry("DockShadowSize",(int)(200.0 * dockWindowShadowSize->value() / (activeWindowShadowSize->value() + inactiveWindowShadowSize->value())));
+   config->writeEntry("MenuShadowSize",(int)(200.0 * menuWindowShadowSize->value() / (activeWindowShadowSize->value() + inactiveWindowShadowSize->value())));
    config->writeEntry("ActiveWindowShadowSize",(int)(200.0 * activeWindowShadowSize->value() / (activeWindowShadowSize->value() + inactiveWindowShadowSize->value())));
    config->writeEntry("InactiveWindowShadowSize",(int)(200.0 * inactiveWindowShadowSize->value() / (activeWindowShadowSize->value() + inactiveWindowShadowSize->value())));
-   
+
   config->writeEntry("RemoveShadowsOnMove",removeShadowsOnMove->isChecked());
   config->writeEntry("RemoveShadowsOnResize",removeShadowsOnResize->isChecked());
   config->writeEntry("OnlyDecoTranslucent", onlyDecoTranslucent->isChecked());
@@ -1603,6 +1624,7 @@ void KTranslucencyConfig::save( void )
   conf_->writeEntry("ShadowColor",hex);
   conf_->writeEntry("ShadowRadius",(activeWindowShadowSize->value() + inactiveWindowShadowSize->value()) / 2);
   conf_->writeEntry("FadeWindows",fadeInWindows->isChecked());
+  conf_->writeEntry("FadeMenuWindows",fadeInMenuWindows->isChecked());
   conf_->writeEntry("FadeTrans",fadeOnOpacityChange->isChecked());
   conf_->writeEntry("FadeInStep",fadeInSpeed->value()/1000.0);
   conf_->writeEntry("FadeOutStep",fadeOutSpeed->value()/1000.0);
@@ -1614,8 +1636,10 @@ void KTranslucencyConfig::save( void )
     config->sync();
         if ( !kapp->dcopClient()->isAttached() )
             kapp->dcopClient()->attach();
-        kapp->dcopClient()->send("kwin*", "", "reconfigure()", "");
+        kapp->dcopClient()->send("kwin*", "", "reconfigure()", TQString(""));
   }
+  if (useTranslucency->isChecked())
+    startKompmgr();
   emit KCModule::changed(false);
 }
 
@@ -1626,9 +1650,9 @@ void KTranslucencyConfig::defaults()
   useTranslucency->setChecked(false);
   onlyDecoTranslucent->setChecked(false);
   activeWindowTransparency->setChecked(false);
-  inactiveWindowTransparency->setChecked(true);
+  inactiveWindowTransparency->setChecked(false);
   movingWindowTransparency->setChecked(false);
-  dockWindowTransparency->setChecked(true);
+  dockWindowTransparency->setChecked(false);
   keepAboveAsActive->setChecked(true);
   disableARGB->setChecked(false);
 
@@ -1638,23 +1662,25 @@ void KTranslucencyConfig::defaults()
   dockWindowOpacity->setValue(80);
 
   dockWindowShadowSize->setValue(6);
+  menuWindowShadowSize->setValue(6);
   activeWindowShadowSize->setValue(12);
   inactiveWindowShadowSize->setValue(6);
   shadowTopOffset->setValue(80);
   shadowLeftOffset->setValue(0);
 
   activeWindowOpacity->setEnabled(false);
-  inactiveWindowOpacity->setEnabled(true);
+  inactiveWindowOpacity->setEnabled(false);
   movingWindowOpacity->setEnabled(false);
-  dockWindowOpacity->setEnabled(true);
-  useShadows->setChecked(TRUE);
+  dockWindowOpacity->setEnabled(false);
+  useShadows->setChecked(FALSE);
   removeShadowsOnMove->setChecked(FALSE);
   removeShadowsOnResize->setChecked(FALSE);
   shadowColor->setColor(Qt::black);
-  fadeInWindows->setChecked(TRUE);
+  fadeInWindows->setChecked(FALSE);
+  fadeInMenuWindows->setChecked(FALSE);
   fadeOnOpacityChange->setChecked(FALSE);
   fadeInSpeed->setValue(70);
-  fadeOutSpeed->setValue(20);
+  fadeOutSpeed->setValue(70);
   emit KCModule::changed(true);
 }
 
@@ -1669,10 +1695,18 @@ bool KTranslucencyConfig::kompmgrAvailable()
     return ret;
 }
 
+void KTranslucencyConfig::startKompmgr()
+{
+    bool ret;
+    KProcess proc;
+    proc << "kompmgr";
+    ret = proc.start(KProcess::DontCare);
+}
+
 void KTranslucencyConfig::showWarning(bool alphaActivated)
 {
-    if (alphaActivated)
-        KMessageBox::information(this, i18n("<qt>Translucency support is new and may cause problems<br> including crashes (sometimes the translucency engine, seldom even X).</qt>"), i18n("Warning"));
+//    if (alphaActivated)
+//        KMessageBox::information(this, i18n("<qt>Translucency support is new and may cause problems<br> including crashes (sometimes the translucency engine, seldom even X).</qt>"), i18n("Warning"));
 }
 
 #include "windows.moc"
