@@ -35,15 +35,13 @@ License. See the file "COPYING" for the exact licensing terms.
 
 // specify externals before namespace
 
-extern Time qt_x_time;
-
 namespace KWinInternal
 {
 
 extern TQPixmap* kwin_get_menu_pix_hack();
 
 TabBox::TabBox( Workspace *ws, const char *name )
-    : TQFrame( 0, name, Qt::WNoAutoErase ), current_client( NULL ), wspace(ws)
+    : TQFrame( 0, name, TQt::WNoAutoErase ), current_client( NULL ), wspace(ws)
     {
     setFrameStyle(TQFrame::StyledPanel | TQFrame::Plain);
     setLineWidth(2);
@@ -375,7 +373,7 @@ void TabBox::drawContents( TQPainter * )
     pix.fill(this, 0, 0);
 
     TQPainter p;
-    p.begin(&pix, this);
+    p.tqbegin(&pix, this);
 
     TQPixmap* menu_pix = kwin_get_menu_pix_hack();
 
@@ -402,7 +400,7 @@ void TabBox::drawContents( TQPainter * )
                   {
                   // draw highlight background
                   if ( (*it) == current_client )
-                    p.fillRect(x, y, r.width(), lineHeight, colorGroup().highlight());
+                    p.fillRect(x, y, r.width(), lineHeight, tqcolorGroup().highlight());
 
                   // draw icon
                   TQPixmap icon;
@@ -439,11 +437,11 @@ void TabBox::drawContents( TQPainter * )
 
                   // draw text
                   if ( (*it) == current_client )
-                    p.setPen(colorGroup().highlightedText());
+                    p.setPen(tqcolorGroup().highlightedText());
                   else if( (*it)->isMinimized())
                     {
-                    TQColor c1 = colorGroup().text();
-                    TQColor c2 = colorGroup().background();
+                    TQColor c1 = tqcolorGroup().text();
+                    TQColor c2 = tqcolorGroup().background();
                     // from kicker's TaskContainer::blendColors()
                     int r1, g1, b1;
                     int r2, g2, b2;
@@ -458,10 +456,10 @@ void TabBox::drawContents( TQPainter * )
                     p.setPen(TQColor( r1, g1, b1 ));
                     }
                   else
-                    p.setPen(colorGroup().text());
+                    p.setPen(tqcolorGroup().text());
 
                   p.drawText(x+5 + iconWidth + 8, y, r.width() - 5 - iconWidth - 8, lineHeight,
-                              Qt::AlignLeft | Qt::AlignVCenter | Qt::SingleLine, s);
+                              Qt::AlignLeft | Qt::AlignVCenter | TQt::SingleLine, s);
 
                   y += lineHeight;
                   }
@@ -496,13 +494,13 @@ void TabBox::drawContents( TQPainter * )
             {
             // draw highlight background
             if ( iDesktop == desk )  // current desktop
-              p.fillRect(x, y, r.width(), lineHeight, colorGroup().highlight());
+              p.fillRect(x, y, r.width(), lineHeight, tqcolorGroup().highlight());
 
             p.save();
 
             // draw "icon" (here: number of desktop)
-            p.fillRect(x+5, y+2, iconWidth, iconHeight, colorGroup().base());
-            p.setPen(colorGroup().text());
+            p.fillRect(x+5, y+2, iconWidth, iconHeight, tqcolorGroup().base());
+            p.setPen(tqcolorGroup().text());
             p.drawRect(x+5, y+2, iconWidth, iconHeight);
 
             // draw desktop-number
@@ -514,12 +512,12 @@ void TabBox::drawContents( TQPainter * )
 
             // draw desktop name text
             if ( iDesktop == desk )
-              p.setPen(colorGroup().highlightedText());
+              p.setPen(tqcolorGroup().highlightedText());
             else
-              p.setPen(colorGroup().text());
+              p.setPen(tqcolorGroup().text());
 
             p.drawText(x+5 + iconWidth + 8, y, r.width() - 5 - iconWidth - 8, lineHeight,
-                       Qt::AlignLeft | Qt::AlignVCenter | Qt::SingleLine,
+                       Qt::AlignLeft | Qt::AlignVCenter | TQt::SingleLine,
                        workspace()->desktopName(iDesktop));
 
             // show mini icons from that desktop aligned to each other
@@ -694,11 +692,11 @@ void TabBox::delayedShow()
 
 void TabBox::handleMouseEvent( XEvent* e )
     {
-    XAllowEvents( qt_xdisplay(), AsyncPointer, qt_x_time );
+    XAllowEvents( qt_xdisplay(), AsyncPointer, GET_QT_X_TIME() );
     if( e->type != ButtonPress )
         return;
     TQPoint pos( e->xbutton.x_root, e->xbutton.y_root );
-    if( !geometry().contains( pos ))
+    if( !tqgeometry().contains( pos ))
         {
         workspace()->closeTabBox();  // click outside closes tab
         return;
@@ -852,7 +850,7 @@ void Workspace::slotWalkThroughWindows()
         return;
     if ( options->altTabStyle == Options::CDE || !options->focusPolicyIsReasonable())
         {
-        //XUngrabKeyboard(qt_xdisplay(), qt_x_time); // need that because of accelerator raw mode
+        //XUngrabKeyboard(qt_xdisplay(), GET_QT_X_TIME()); // need that because of accelerator raw mode
         // CDE style raise / lower
         CDEWalkThroughWindows( true );
         }
@@ -1319,7 +1317,7 @@ Client* Workspace::previousStaticClient( Client* c ) const
 bool Workspace::establishTabBoxGrab()
     {
     if( XGrabKeyboard( qt_xdisplay(), root, FALSE,
-        GrabModeAsync, GrabModeAsync, qt_x_time) != GrabSuccess )
+        GrabModeAsync, GrabModeAsync, GET_QT_X_TIME()) != GrabSuccess )
         return false;
     // Don't try to establish a global mouse grab using XGrabPointer, as that would prevent
     // using Alt+Tab while DND (#44972). However force passive grabs on all windows
@@ -1335,7 +1333,7 @@ bool Workspace::establishTabBoxGrab()
 
 void Workspace::removeTabBoxGrab()
     {
-    XUngrabKeyboard(qt_xdisplay(), qt_x_time);
+    XUngrabKeyboard(qt_xdisplay(), GET_QT_X_TIME());
     assert( forced_global_mouse_grab );
     forced_global_mouse_grab = false;
     if( active_client != NULL )
