@@ -16,8 +16,8 @@
   Boston, MA 02110-1301, USA.
 */
 
-#ifndef WQPRINTDIALOGPAGE_H
-#define WQPRINTDIALOGPAGE_H
+#ifndef WTQPRINTDIALOGPAGE_H
+#define WTQPRINTDIALOGPAGE_H
 
 
 #include <kdeprint/kprintdialogpage.h>
@@ -30,6 +30,7 @@ Print dialog page to provide specific print options for KWordQuiz
 class WQPrintDialogPage : public KPrintDialogPage
 {
 Q_OBJECT
+  TQ_OBJECT
 public:
     WQPrintDialogPage( TQWidget *parent = 0, const char *name = 0 );
 
