@@ -94,7 +94,7 @@ KXsldbgPart::KXsldbgPart( TQWidget *parentWidget, const char * /*widgetName*/,
     newEvaluate = new TQLineEdit(h);
     evaluateBtn = new TQPushButton(i18n("Evaluate"), h);
 
-    TQSplitter *splitter = new TQSplitter(TQSplitter::Vertical, frame);
+    TQSplitter *splitter = new TQSplitter(Qt::Vertical, frame);
     mainView = new TQWidgetStack(splitter);
     mainView->setMinimumHeight(400); //## TODO don't use a magic number 
     outputview = new XsldbgOutputView(splitter);
@@ -375,13 +375,13 @@ void KXsldbgPart::lookupSystemID( TQString systemID)
      systemID = KInputDialog::getText(
 			      i18n( "Lookup SystemID" ),
 			      i18n( "Please enter SystemID to find:" ),
-			      TQString::null, &ok,
+			      TQString(), &ok,
 			      mainView);
 #else
-     systemID = QInputDialog::getText(
+     systemID = TQInputDialog::getText(
 			      i18n( "Lookup SystemID" ),
 			      i18n( "Please enter SystemID to find:" ),
-			      TQLineEdit::Normal, TQString::null, &ok,
+			      TQLineEdit::Normal, TQString(), &ok,
 			      mainView);
 #endif
    }else{
@@ -389,7 +389,7 @@ void KXsldbgPart::lookupSystemID( TQString systemID)
    }
   if ( ok && !systemID.isEmpty() ){
       // user entered something and pressed ok
-	TQString msg(TQString("system %1").arg(systemID));  // noTr
+	TQString msg(TQString("system %1").tqarg(systemID));  // noTr
 	debugger->fakeInput(msg, true);
   }
 
@@ -407,19 +407,19 @@ void KXsldbgPart::lookupPublicID(TQString publicID)
      publicID = KInputDialog::getText(
 			      i18n( "Lookup PublicID" ),
 			      i18n( "Please enter PublicID to find:" ),
-			      TQString::null, &ok, mainView );
+			      TQString(), &ok, mainView );
 #else
-     publicID = QInputDialog::getText(
+     publicID = TQInputDialog::getText(
 			      i18n( "Lookup PublicID" ),
 			      i18n( "Please enter PublicID to find:" ),
-			      TQLineEdit::Normal, TQString::null, &ok, mainView );
+			      TQLineEdit::Normal, TQString(), &ok, mainView );
 #endif
    }else{
      ok = true;
    }
    if ( ok && !publicID.isEmpty()){
      // user entered something and pressed ok
-	TQString msg(TQString("public %1").arg(publicID));  // noTr
+	TQString msg(TQString("public %1").tqarg(publicID));  // noTr
 	debugger->fakeInput(msg, true);
   }
 }
@@ -774,7 +774,7 @@ void  KXsldbgPart::deleteBreakPoint(int lineNumber)
 void KXsldbgPart::slotSearch()
 {
   if ((newSearch != 0L)  && checkDebugger() ) {
-    TQString msg(TQString("search \"%1\"").arg(newSearch->text()));  // noTr
+    TQString msg(TQString("search \"%1\"").tqarg(newSearch->text()));  // noTr
  		debugger->fakeInput(msg, false);
   }
 }
@@ -800,7 +800,7 @@ void KXsldbgPart::slotProcResolveItem(TQString URI)
 {
   if (!URI.isEmpty()){
     TQMessageBox::information(mainView, i18n("SystemID or PublicID Resolution Result"),
-        i18n("SystemID or PublicID has been resolved to\n.%1").arg(URI),
+        i18n("SystemID or PublicID has been resolved to\n.%1").tqarg(URI),
 	TQMessageBox::Ok);
   }
 }
