@@ -529,10 +529,10 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
                     templateNode =
                         findTemplateNode(styleCtxt->style, &arg[offset]);
                     if (!templateNode) {
-                        xsldbgGenericErrorFunc(i18n("Error: The XSLT template named \"%1\" was not found.\n").arg(xsldbgText(&arg[offset])));
+                        xsldbgGenericErrorFunc(i18n("Error: The XSLT template named \"%1\" was not found.\n").tqarg(xsldbgText(&arg[offset])));
                         return result;
                     } else {
-                        xsldbgGenericErrorFunc(i18n(" template: \"%1\"\n").arg(xsldbgText(&arg[offset])));
+                        xsldbgGenericErrorFunc(i18n(" template: \"%1\"\n").tqarg(xsldbgText(&arg[offset])));
                         ctxt->node = templateNode;
                         result = 1;
                         return result;
@@ -545,7 +545,7 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
                         pctxt = xmlXPathNewContext(source->doc);
                         if (pctxt == NULL) {
                             xmlFree(ctxt);
-                            /* xslDebugStatus = DEBUG_QUIT; */
+                            /* xslDebugStatus = DEBUG_TQUIT; */
                             return result;
                         }
                         if (!xmlXPathNsLookup(pctxt, (xmlChar *) "xsl"))
@@ -560,7 +560,7 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
                         xsldbgGenericErrorFunc(i18n("Error: Unable to cd. No stylesheet loaded.\n"));
                     }
                 } else {
-                    xsldbgGenericErrorFunc(i18n("Error: Unknown arguments to the command %1.\n").arg("cd"));
+                    xsldbgGenericErrorFunc(i18n("Error: Unknown arguments to the command %1.\n").tqarg("cd"));
                 }
             } else
                 xsldbgGenericErrorFunc(i18n("Error: Unable to cd. No stylesheet loaded.\n"));
@@ -582,7 +582,7 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
                                        XSLT_NAMESPACE);
                 list = xmlXPathEval((xmlChar *) arg, ctxt->pctxt);
             } else {
-                xsldbgGenericErrorFunc(i18n("Error: Invalid arguments to the command %1.\n").arg("cd"));
+                xsldbgGenericErrorFunc(i18n("Error: Invalid arguments to the command %1.\n").tqarg("cd"));
             }
         }
 
@@ -594,7 +594,7 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
                             ctxt->node = list->nodesetval->nodeTab[0];
                             /* tell the application about the new line
                              * number we are looking at */
-                            if (getThreadStatus() == XSLDBG_MSG_THREAD_RUN) {
+                            if (getThreadtqStatus() == XSLDBG_MSG_THREAD_RUN) {
                                 int breakpoint = 0;
 
                                 xsldbgUpdateFileDetails(ctxt->node);
@@ -603,9 +603,9 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
                             }
                             result = 1;
                         } else
-                            xsldbgGenericErrorFunc(i18n("Warning: XPath %1 is a Node Set with %n child.", "Warning: XPath %1 is a Node Set with %n children.", list->nodesetval->nodeNr).arg(xsldbgText(arg)) + TQString("\n"));
+                            xsldbgGenericErrorFunc(i18n("Warning: XPath %1 is a Node Set with %n child.", "Warning: XPath %1 is a Node Set with %n tqchildren.", list->nodesetval->nodeNr).tqarg(xsldbgText(arg)) + TQString("\n"));
                     } else {
-                        xsldbgGenericErrorFunc(i18n("Warning: XPath %1 is an empty Node Set.\n").arg(xsldbgText(arg)));
+                        xsldbgGenericErrorFunc(i18n("Warning: XPath %1 is an empty Node Set.\n").tqarg(xsldbgText(arg)));
                     }
                     break;
 
@@ -614,7 +614,7 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
             }
             xmlXPathFreeObject(list);
         } else {
-            xsldbgGenericErrorFunc(i18n("Error: XPath %1 was not found.\n").arg(xsldbgText(arg)));
+            xsldbgGenericErrorFunc(i18n("Error: XPath %1 was not found.\n").tqarg(xsldbgText(arg)));
         }
         if (ctxt->pctxt)
           ctxt->pctxt->node = NULL;
@@ -640,7 +640,7 @@ xslDbgPrintCallStack(const xmlChar * arg)
     callPointPtr callPointItem;
 
     if (arg == NULL) {
-        if (getThreadStatus() == XSLDBG_MSG_THREAD_RUN) {
+        if (getThreadtqStatus() == XSLDBG_MSG_THREAD_RUN) {
             notifyListStart(XSLDBG_MSG_CALLSTACK_CHANGED);
             /* we send the oldest frame stack first */
             for (depth = 1; depth <= callStackGetDepth(); depth++) {
@@ -664,17 +664,17 @@ xslDbgPrintCallStack(const xmlChar * arg)
                         if (rootCopy && (rootCopy->match || rootCopy->name)
                             && curUrl) {			    
 			    xmlChar *rootNameTemp, *rootModeTemp;
-			    rootNameTemp = fullQName(rootCopy->nameURI, rootCopy->name);
-			    rootModeTemp = fullQName(rootCopy->modeURI, rootCopy->mode);
+			    rootNameTemp = fullTQName(rootCopy->nameURI, rootCopy->name);
+			    rootModeTemp = fullTQName(rootCopy->modeURI, rootCopy->mode);
 			    if (rootNameTemp && rootModeTemp){
 			      if (rootCopy->match)
 			        /* display information about the current XSLT template */
-                                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"").arg(depth).arg(xsldbgText(rootCopy->match)).arg(xsldbgText(rootModeTemp)));
+                                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"").tqarg(depth).tqarg(xsldbgText(rootCopy->match)).tqarg(xsldbgText(rootModeTemp)));
 			      else
 			        /* display information about the current XSLT template */
-                                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"").arg(depth).arg(xsldbgText(rootNameTemp)).arg(xsldbgText(rootModeTemp)));
+                                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"").tqarg(depth).tqarg(xsldbgText(rootNameTemp)).tqarg(xsldbgText(rootModeTemp)));
 			      /* display where we are in the source/document file */	
-			      xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").arg(xsldbgUrl(curUrl)).arg(curLine));
+			      xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").tqarg(xsldbgUrl(curUrl)).tqarg(curLine));
 			    }else{
 			      xsldbgGenericErrorFunc(i18n("Error: Out of memory.\n"));
 			      result = 0;
@@ -689,24 +689,24 @@ xslDbgPrintCallStack(const xmlChar * arg)
 			    }
                         } else if (curUrl) {
 			    /* display information about the current XSLT template */
-                            xsldbgGenericErrorFunc(i18n("#%1 template: \"LIBXSLT_DEFAULT\" mode: \"\"").arg(depth));
+                            xsldbgGenericErrorFunc(i18n("#%1 template: \"LIBXSLT_DEFAULT\" mode: \"\"").tqarg(depth));
 			    /* display where we are in the source/document file */	
-                            xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").arg(xsldbgUrl(curUrl)).arg(curLine));
+                            xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").tqarg(xsldbgUrl(curUrl)).tqarg(curLine));
                         }
                         if (curUrl)
                             xmlFree(curUrl);
 
                     }
-		    nameTemp = fullQName(callPointItem->info->templateURI,
+		    nameTemp = fullTQName(callPointItem->info->templateURI,
 					 callPointItem->info->templateName);
-		    modeTemp = fullQName(callPointItem->info->modeURI,
+		    modeTemp = fullTQName(callPointItem->info->modeURI,
 					 callPointItem->info->modeName);
 		    if (nameTemp && modeTemp){
 		      /* display information about the current XSLT template */
-		      xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"").arg(depth - 1).arg(xsldbgText(nameTemp)).arg(xsldbgText(modeTemp)));
+		      xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"").tqarg(depth - 1).tqarg(xsldbgText(nameTemp)).tqarg(xsldbgText(modeTemp)));
 		      if (callPointItem->info->url)
 			/* display where we are in the source/document file */	
-                        xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").arg(xsldbgUrl(callPointItem->info->url)).arg(callPointItem->lineNo));
+                        xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").tqarg(xsldbgUrl(callPointItem->info->url)).tqarg(callPointItem->lineNo));
 		      else
                         xsldbgGenericErrorFunc("\n");
 		    }else{
@@ -740,7 +740,7 @@ xslDbgPrintCallStack(const xmlChar * arg)
         long templateDepth = atol((char *) arg);
 
 
-        if (getThreadStatus() == XSLDBG_MSG_THREAD_RUN) {
+        if (getThreadtqStatus() == XSLDBG_MSG_THREAD_RUN) {
             /* should never happen but just in case, when running as a 
              * thread always provide NO params to the where command */
 #ifdef WITH_XSLDBG_DEBUG_PROCESS
@@ -755,11 +755,11 @@ xslDbgPrintCallStack(const xmlChar * arg)
             callPointItem = callStackGet(templateDepth + 1);
             if (callPointItem && callPointItem->info) {
 		/* display information about the current XSLT template */
-                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\"").arg(templateDepth).arg(xsldbgText(callPointItem->info->templateName)));
+                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\"").tqarg(templateDepth).tqarg(xsldbgText(callPointItem->info->templateName)));
                 /* should alays be present but .. */
                 if (callPointItem->info->url)
 		    /* display where we are in the source/document file */	
-                    xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").arg(xsldbgUrl(callPointItem->info->url)).arg(callPointItem->lineNo));
+                    xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").tqarg(xsldbgUrl(callPointItem->info->url)).tqarg(callPointItem->lineNo));
                 else
                     xsldbgGenericErrorFunc("\n");
             } else {
@@ -1097,15 +1097,15 @@ debugXSLBreak(xmlNodePtr templ, xmlNodePtr node, xsltTemplatePtr root,
     }
     if (root) {
         xmlChar *nameTemp = NULL, *modeTemp = NULL;
-	nameTemp = fullQName(root->nameURI, root->name);
-	modeTemp = fullQName(root->modeURI, root->mode);
+	nameTemp = fullTQName(root->nameURI, root->name);
+	modeTemp = fullTQName(root->modeURI, root->mode);
 	if (!nextCommandActive){
 	  /* we only want messages if we are not
 	    in the process of completing the next command */
 	  if (terminalIO == NULL) {
 
             if (root->match){
-                xsldbgGenericErrorFunc(i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg(xsldbgText(root->match)).arg(xsldbgText(modeTemp)));
+                xsldbgGenericErrorFunc(i18n("\nReached template: \"%1\" mode: \"%2\"\n").tqarg(xsldbgText(root->match)).tqarg(xsldbgText(modeTemp)));
 		if (lastTemplate != root->match && buffer){
 		    xmlBufferCCat(buffer, "\nreached matched template:");
 		    xmlBufferCat(buffer, root->match); 
@@ -1115,7 +1115,7 @@ debugXSLBreak(xmlNodePtr templ, xmlNodePtr node, xsltTemplatePtr root,
 		    lastTemplate = root->match;
 		}
             }else{
-                xsldbgGenericErrorFunc(i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg(xsldbgText(nameTemp)).arg(xsldbgText(modeTemp)));
+                xsldbgGenericErrorFunc(i18n("\nReached template: \"%1\" mode: \"%2\"\n").tqarg(xsldbgText(nameTemp)).tqarg(xsldbgText(modeTemp)));
 		if (lastTemplate != root->name && buffer){
 		    xmlBufferCCat(buffer, "\nreached named template:");
 		    xmlBufferCat(buffer,root->match); 
@@ -1133,9 +1133,9 @@ debugXSLBreak(xmlNodePtr templ, xmlNodePtr node, xsltTemplatePtr root,
                 (xslDebugStatus == DEBUG_WALK)) {
 		TQString message;
                 if (root->match)
-		  message = i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg(xsldbgText(root->match)).arg(xsldbgText(modeTemp));
+		  message = i18n("\nReached template: \"%1\" mode: \"%2\"\n").tqarg(xsldbgText(root->match)).tqarg(xsldbgText(modeTemp));
                 else
-		  message = i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg(xsldbgText(nameTemp)).arg(xsldbgText(modeTemp));
+		  message = i18n("\nReached template: \"%1\" mode: \"%2\"\n").tqarg(xsldbgText(nameTemp)).tqarg(xsldbgText(modeTemp));
 		fprintf(terminalIO, "%s", message.local8Bit().data());
             }
 	  }
@@ -1277,7 +1277,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 
     /* If using a thread and the thread is running then we don't need to 
      * send this as the application will see the XSLDBG_MSG_LINE_CHANGED message */
-    if ((getThreadStatus() == XSLDBG_MSG_THREAD_NOTUSED) ||
+    if ((getThreadtqStatus() == XSLDBG_MSG_THREAD_NOTUSED) ||
         (xslDebugStatus == DEBUG_TRACE)) {
 	TQString messageTxt;
         if (!nextCommandActive && ctxt->node && ctxt->node && ctxt->node->doc
@@ -1292,9 +1292,9 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 breakUri = ctxt->node->doc->URL;
 
             if (xmlGetLineNo(ctxt->node) != -1)
-		messageTxt = i18n("Breakpoint for file \"%1\" at line %2.\n").arg(xsldbgUrl(breakUri)).arg(xmlGetLineNo(ctxt->node));
+		messageTxt = i18n("Breakpoint for file \"%1\" at line %2.\n").tqarg(xsldbgUrl(breakUri)).tqarg(xmlGetLineNo(ctxt->node));
             else
-                messageTxt = i18n("Breakpoint at text node in file \"%1\".\n").arg(xsldbgUrl(breakUri));
+                messageTxt = i18n("Breakpoint at text node in file \"%1\".\n").tqarg(xsldbgUrl(breakUri));
             if (baseUri != NULL) {
                 xmlFree(baseUri);
                 baseUri = NULL;
@@ -1346,8 +1346,8 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
       xsldbgGenericErrorFunc("\n");
     }
 
-    while (!exitShell && (xslDebugStatus != DEBUG_QUIT)) {
-        if (getThreadStatus() != XSLDBG_MSG_THREAD_RUN) {
+    while (!exitShell && (xslDebugStatus != DEBUG_TQUIT)) {
+        if (getThreadtqStatus() != XSLDBG_MSG_THREAD_RUN) {
             if (ctxt->node == (xmlNodePtr) ctxt->doc)
                 snprintf((char *) prompt, DEBUG_BUFFER_SIZE - 1,
                          "(xsldbg) %s > ", "/");
@@ -1464,9 +1464,9 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 /* --- Running related commands --- */
             case DEBUG_BYE_CMD:
             case DEBUG_EXIT_CMD:
-            case DEBUG_QUIT_CMD:
+            case DEBUG_TQUIT_CMD:
                 /* allow the stylesheet to exit */
-                xslDebugStatus = DEBUG_QUIT;
+                xslDebugStatus = DEBUG_TQUIT;
                 exitShell++;
                 cmdResult = 1;
                 break;
@@ -1548,7 +1548,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
             case DEBUG_WHERE_CMD:
                 /* Print the current working directory as well */
                 xslDbgPrintCallStack(NULL);
-                if (getThreadStatus() != XSLDBG_MSG_THREAD_RUN) {
+                if (getThreadtqStatus() != XSLDBG_MSG_THREAD_RUN) {
                     if (!xmlShellPwd(ctxt, (char *) dir, ctxt->node, NULL)){
                         xsldbgGenericErrorFunc((const char*)dir);
                         xsldbgGenericErrorFunc("\n");
@@ -1597,7 +1597,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 break;
 
             case DEBUG_SHOWBREAK_CMD:
-                if (getThreadStatus() == XSLDBG_MSG_THREAD_RUN) {
+                if (getThreadtqStatus() == XSLDBG_MSG_THREAD_RUN) {
                     notifyListStart(XSLDBG_MSG_BREAKPOINT_CHANGED);
                     walkBreakPoints((xmlHashScanner)
                                     xslDbgShellPrintBreakPoint, NULL);
@@ -1706,7 +1706,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 		  if(tempBaseName){
 		    xsldbgGenericErrorFunc("\n");
 		    xsldbgGenericErrorFunc((char*)dir);
-		    xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2").arg(xsldbgUrl(tempBaseName)).arg(xmlGetLineNo(ctxt->node)));
+		    xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2").tqarg(xsldbgUrl(tempBaseName)).tqarg(xmlGetLineNo(ctxt->node)));
 		    xmlFree(tempBaseName);
 		    cmdResult = 1;
 		  }
@@ -1782,7 +1782,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                     notifyXsldbgApp(XSLDBG_MSG_LINE_CHANGED, NULL);
                     if (ctxt->pctxt == NULL) {
                         xmlFree(ctxt);
-                        xslDebugStatus = DEBUG_QUIT;
+                        xslDebugStatus = DEBUG_TQUIT;
                         return;
                     } else
                         break;
@@ -1822,7 +1822,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                     notifyXsldbgApp(XSLDBG_MSG_LINE_CHANGED, NULL);
                     if (ctxt->pctxt == NULL) {
                         xmlFree(ctxt);
-                        xslDebugStatus = DEBUG_QUIT;
+                        xslDebugStatus = DEBUG_TQUIT;
                         return;
                     } else
                         break;
@@ -1885,7 +1885,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 		if (splitString(arg, 1, &systemID) == 1){
 		  cmdResult = xslDbgSystem(systemID);
 		}else{
-		  xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n").arg("system"));
+		  xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n").tqarg("system"));
 		}
 	       }
                 break;
@@ -1898,7 +1898,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 		if (splitString(arg, 1, &publicID) == 1){
 		  cmdResult = xslDbgPublic(publicID);
 		}else{
-		  xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n").arg("public"));
+		  xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n").tqarg("public"));
 		}
 	       }
                 break;
@@ -1908,7 +1908,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 break;
 
             case DEBUG_VALIDATE_CMD:
-                xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled.\n").arg("validate"));
+                xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled.\n").tqarg("validate"));
                 cmdResult = 0;
                 /*
                  * xmlShellValidate(ctxt, arg, NULL, NULL);
@@ -1929,7 +1929,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 break;
 
             case DEBUG_WRITE_CMD:
-                xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled.\n").arg("write"));
+                xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled.\n").tqarg("write"));
                 cmdResult = 0;
                 /*
                  * xmlShellWrite(ctxt, arg, NULL, NULL);
@@ -1937,7 +1937,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 break;
 
             case DEBUG_FREE_CMD:
-                xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled.\n").arg("free"));
+                xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled.\n").tqarg("free"));
                 cmdResult = 0;
                 /*
                  * if (arg[0] == 0) {
@@ -1993,7 +1993,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 		  /* gdb does to say anything after redirecting its 
 		     output */
 		  if (optionsGetIntOption(OPTIONS_GDB) < 2)
-                    xsldbgGenericErrorFunc(i18n("Opening terminal %1.\n").arg(xsldbgText(arg)));
+                    xsldbgGenericErrorFunc(i18n("Opening terminal %1.\n").tqarg(xsldbgText(arg)));
                     cmdResult = 1;
                 } else
                     cmdResult = 0;
@@ -2009,11 +2009,11 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 		    bindtextdomain("kdewebdev/xsldbg", LOCALE_PREFIX);
 		    cmdResult = 1;
 		}else{
-		    xsldbgGenericErrorFunc(i18n("Error: Missing arguments for the command %1.\n").arg("lang"));
+		    xsldbgGenericErrorFunc(i18n("Error: Missing arguments for the command %1.\n").tqarg("lang"));
 		    cmdResult = 0;
 		}
 #else
-	        xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled\n").arg("lang"));
+	        xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled\n").tqarg("lang"));
 		cmdResult = 1;
 #endif
 		break;
@@ -2058,7 +2058,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 	       break;
 
 	     default:
-	        xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n").arg("showmatch")); 
+	        xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n").tqarg("showmatch")); 
 	     }
            break;
  
@@ -2077,7 +2077,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 break;
 
             default:
-                xsldbgGenericErrorFunc(i18n("Error: Unknown command %1. Try help.\n").arg(xsldbgText(command)));
+                xsldbgGenericErrorFunc(i18n("Error: Unknown command %1. Try help.\n").tqarg(xsldbgText(command)));
                 cmdResult = 0;
         }
 
@@ -2088,9 +2088,9 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 		ctxt->node->doc && ctxt->node->doc->URL) {
 
                 if (xmlGetLineNo(ctxt->node) != -1)
-                    xsldbgGenericErrorFunc(i18n("Breakpoint for file \"%1\" at line %2.\n").arg(xsldbgUrl(ctxt->node->doc->URL)).arg(xmlGetLineNo(ctxt->node)));
+                    xsldbgGenericErrorFunc(i18n("Breakpoint for file \"%1\" at line %2.\n").tqarg(xsldbgUrl(ctxt->node->doc->URL)).tqarg(xmlGetLineNo(ctxt->node)));
                 else
-                    xsldbgGenericErrorFunc(i18n("Breakpoint at text node in file \"%1\".\n").arg(xsldbgUrl(ctxt->node->doc->URL)));
+                    xsldbgGenericErrorFunc(i18n("Breakpoint at text node in file \"%1\".\n").tqarg(xsldbgUrl(ctxt->node->doc->URL)));
             }
         }
 
