@@ -112,7 +112,7 @@ static TQString langLookupDir( const TQString &fname )
         langs.remove( "C" );
         TQStringList::ConstIterator lang;
         for (lang = langs.begin(); lang != langs.end(); ++lang)
-            search.append(TQString("%1%2/%3/%4").arg(localDoc[id]).arg(*lang).arg("xsldbg").arg(fname));
+            search.append(TQString("%1%2/%3/%4").tqarg(localDoc[id]).tqarg(*lang).tqarg("xsldbg").tqarg(fname));
     }
 
     // try to locate the file
@@ -125,7 +125,7 @@ static TQString langLookupDir( const TQString &fname )
 	  return baseDir;
     }
 
-    return TQString::null;
+    return TQString();
 }
 
 
@@ -293,10 +293,10 @@ optionsSetIntOption(OptionTypeEnum optionType, int value)
         }
     } else {
 	if ((type >= OPTIONS_FIRST_OPTIONID) && (type <= OPTIONS_LAST_OPTIONID)){
-	     xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid boolean/integer option.\n").arg(xsldbgText(optionNames[type - OPTIONS_FIRST_OPTIONID])));
+	     xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid boolean/integer option.\n").tqarg(xsldbgText(optionNames[type - OPTIONS_FIRST_OPTIONID])));
 	}else{
 #ifdef WITH_XSLDBG_DEBUG_PROCESS
-	    xsldbgGenericErrorFunc(TQString("Error: Invalid arguments for the command %1.\n").arg("setoption"));
+	    xsldbgGenericErrorFunc(TQString("Error: Invalid arguments for the command %1.\n").tqarg("setoption"));
 #endif
 	}
         result = 0;
@@ -323,10 +323,10 @@ optionsGetIntOption(OptionTypeEnum optionType)
         result = intOptions[type - OPTIONS_FIRST_INT_OPTIONID];
     } else {
 	if ((type >= OPTIONS_FIRST_OPTIONID) && (type <= OPTIONS_LAST_OPTIONID)){
-	    xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid boolean/integer option.\n").arg(xsldbgText(optionNames[type - OPTIONS_FIRST_OPTIONID])));
+	    xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid boolean/integer option.\n").tqarg(xsldbgText(optionNames[type - OPTIONS_FIRST_OPTIONID])));
 	}else{
 #ifdef WITH_XSLDBG_DEBUG_PROCESS
-	    xsldbgGenericErrorFunc(TQString("Error: Invalid arguments for the command %1.\n").arg("options"));
+	    xsldbgGenericErrorFunc(TQString("Error: Invalid arguments for the command %1.\n").tqarg("options"));
 #endif
 	}
     }
@@ -365,10 +365,10 @@ optionsSetStringOption(OptionTypeEnum optionType, const xmlChar * value)
         result = 1;
     } else{
 	if ((type >= OPTIONS_FIRST_OPTIONID) && (type <= OPTIONS_LAST_OPTIONID)){
-	    xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid string xsldbg option.\n").arg(xsldbgText(optionNames[type - OPTIONS_LAST_OPTIONID])));
+	    xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid string xsldbg option.\n").tqarg(xsldbgText(optionNames[type - OPTIONS_LAST_OPTIONID])));
 	}else{
 #ifdef WITH_XSLDBG_DEBUG_PROCESS
-	    xsldbgGenericErrorFunc(TQString("Error: Invalid arguments for the command %1.\n").arg("setoption"));
+	    xsldbgGenericErrorFunc(TQString("Error: Invalid arguments for the command %1.\n").tqarg("setoption"));
 #endif
 	}
     }
@@ -396,10 +396,10 @@ optionsGetStringOption(OptionTypeEnum optionType)
         result = stringOptions[optionId];
     } else{
 	if ((type >= OPTIONS_FIRST_OPTIONID) && (type <= OPTIONS_LAST_OPTIONID)){
-	    xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid string xsldbg option.\n").arg(xsldbgText(optionNames[type - OPTIONS_FIRST_OPTIONID])));
+	    xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid string xsldbg option.\n").tqarg(xsldbgText(optionNames[type - OPTIONS_FIRST_OPTIONID])));
 	}else{
 #ifdef WITH_XSLDBG_DEBUG_PROCESS
-	    xsldbgGenericErrorFunc(TQString("Error: Invalid arguments for the command %1.\n").arg("options"));
+	    xsldbgGenericErrorFunc(TQString("Error: Invalid arguments for the command %1.\n").tqarg("options"));
 #endif
 	}
     }
@@ -508,7 +508,7 @@ optionsPrintParam(int paramId)
                                         paramId);
 
     if (paramItem && paramItem->name && paramItem->value) {
-        xsldbgGenericErrorFunc(i18n(" Parameter %1 %2=\"%3\"\n").arg(paramId).arg(xsldbgText(paramItem->name)).arg(xsldbgText(paramItem->value)));
+        xsldbgGenericErrorFunc(i18n(" Parameter %1 %2=\"%3\"\n").tqarg(paramId).tqarg(xsldbgText(paramItem->name)).tqarg(xsldbgText(paramItem->value)));
         result = 1;
     }
     return result;
@@ -530,7 +530,7 @@ optionsPrintParamList(void)
     int paramIndex = 0;
     int itemCount = arrayListCount(optionsGetParamItemList());
 
-    if (getThreadStatus() == XSLDBG_MSG_THREAD_RUN) {
+    if (getThreadtqStatus() == XSLDBG_MSG_THREAD_RUN) {
         if (itemCount > 0) {
             while (result && (paramIndex < itemCount)) {
                 result = optionsPrintParam(paramIndex++);
