@@ -183,7 +183,7 @@ void SetupWizard::setupSearchPage()
 {
    m_searchPage=new TQVBox(this);
    TQLabel *info=new TQLabel(i18n("There are two ways LISa can search hosts on your network."),m_searchPage);
-   info->setTextFormat(Qt::RichText);
+   info->setTextFormat(TQt::RichText);
    m_ping=new TQCheckBox(i18n("Send pings"), m_searchPage);
    info=new TQLabel(i18n("All hosts with TCP/IP will respond,<br>"
                         "whether or not they are samba servers.<br>"
@@ -193,13 +193,13 @@ void SetupWizard::setupSearchPage()
                         "Only samba/windows servers will respond.<br>"
                         "This method is not very reliable.<br>"
                         "You should enable it if you are part of a large network."),m_searchPage);
-   info->setTextFormat(Qt::RichText);
+   info->setTextFormat(TQt::RichText);
    TQWidget *dummy=new TQWidget(m_searchPage);
    m_searchPage->setStretchFactor(dummy,10);
    m_searchPage->setSpacing(KDialog::spacingHint());
    m_searchPage->setMargin(KDialog::marginHint());
    info=new TQLabel(i18n("<b>If unsure, keep it as is.</b>"),m_searchPage);
-   info->setAlignment(AlignRight|AlignVCenter);
+   info->tqsetAlignment(AlignRight|AlignVCenter);
 
    setHelpEnabled( m_searchPage, false );
 }
@@ -210,7 +210,7 @@ void SetupWizard::setupAddressesPage()
    TQLabel *info=new TQLabel(i18n("All IP addresses included in the specified range will be pinged.<br>"
                                 "If you are part of a small network, e.g. with network mask 255.255.255.0<br>"
                                 "use your IP address/network mask.<br>"),m_addressesPage);
-   info->setTextFormat(Qt::RichText);
+   info->setTextFormat(TQt::RichText);
    m_pingAddresses=new KRestrictedLine(m_addressesPage,"0123456789./;-");
    info=new TQLabel(i18n("<br>There are four ways to specify address ranges:<br>"
                         "1. IP address/network mask, like <code>192.168.0.0/255.255.255.0;</code><br>"
@@ -219,13 +219,13 @@ void SetupWizard::setupAddressesPage()
                         "4. ranges for each part of the address, like <code>10-10.1-5.1-25.1-3;</code><br>"
                         "You can also enter combinations of 1 to 4, separated by \";\", like<br>"
                         "<code>192.168.0.0/255.255.255.0;10.0.0.0;10.0.1.1-10.0.1.100;</code><br>"),m_addressesPage);
-   info->setAlignment(AlignLeft|AlignVCenter|WordBreak);
+   info->tqsetAlignment(AlignLeft|AlignVCenter|WordBreak);
    TQWidget *dummy=new TQWidget(m_addressesPage);
    m_addressesPage->setStretchFactor(dummy,10);
    m_addressesPage->setSpacing(KDialog::spacingHint());
    m_addressesPage->setMargin(KDialog::marginHint());
    info=new TQLabel(i18n("<b>If unsure, keep it as is.</b>"), m_addressesPage);
-   info->setAlignment(AlignRight|AlignVCenter);
+   info->tqsetAlignment(AlignRight|AlignVCenter);
 
    setHelpEnabled( m_addressesPage, false );
 }
@@ -238,7 +238,7 @@ void SetupWizard::setupAllowedPage()
                                 "Only hosts which fit into the addresses given here are accepted by LISa as clients. "
                                 "The list of hosts published by LISa will also only contain hosts which fit into this scheme.<br>"
                                 "Usually you enter your IP address/network mask here."),m_allowedAddressesPage);
-   info->setAlignment(AlignLeft|AlignVCenter|WordBreak);
+   info->tqsetAlignment(AlignLeft|AlignVCenter|WordBreak);
    m_allowedAddresses=new KRestrictedLine(m_allowedAddressesPage,"0123456789./-;");
    m_trustedHostsLabel=new TQLabel(m_allowedAddressesPage);
 
@@ -247,7 +247,7 @@ void SetupWizard::setupAllowedPage()
    m_allowedAddressesPage->setSpacing(KDialog::spacingHint());
    m_allowedAddressesPage->setMargin(KDialog::marginHint());
    info=new TQLabel(i18n("<b>If unsure, keep it as is.</b>"), m_allowedAddressesPage);
-   info->setAlignment(AlignRight|AlignVCenter);
+   info->tqsetAlignment(AlignRight|AlignVCenter);
 
    setHelpEnabled( m_allowedAddressesPage, false );
 }
@@ -256,18 +256,18 @@ void SetupWizard::setupBcastPage()
 {
    m_bcastPage=new TQVBox(this);
    TQLabel *info=new TQLabel(i18n("<br>Enter your IP address and network mask here, like <code>192.168.0.1/255.255.255.0</code>"),m_bcastPage);
-   info->setAlignment(AlignLeft|AlignVCenter|WordBreak);
+   info->tqsetAlignment(AlignLeft|AlignVCenter|WordBreak);
    m_bcastAddress=new KRestrictedLine(m_bcastPage,"0123456789./");
    info=new TQLabel(i18n("<br>To reduce the network load, the LISa servers in one network<br>"
                         "cooperate with each other. Therefore you have to enter the broadcast<br>"
                         "address here. If you are connected to more than one network, choose <br>"
                         "one of the broadcast addresses."),m_bcastPage);
-   info->setAlignment(AlignLeft|AlignVCenter|WordBreak);
+   info->tqsetAlignment(AlignLeft|AlignVCenter|WordBreak);
    TQWidget *dummy=new TQWidget(m_bcastPage);
    m_bcastPage->setStretchFactor(dummy,10);
    m_bcastPage->setSpacing(KDialog::spacingHint());
    info=new TQLabel(i18n("<b>If unsure, keep it as is.</b>"), m_bcastPage);
-   info->setAlignment(AlignRight|AlignVCenter);
+   info->tqsetAlignment(AlignRight|AlignVCenter);
 
    m_bcastPage->setSpacing(KDialog::spacingHint());
    m_bcastPage->setMargin(KDialog::marginHint());
@@ -278,7 +278,7 @@ void SetupWizard::setupUpdateIntervalPage()
 {
    m_intervalPage=new TQVBox(this);
    TQLabel *info=new TQLabel(i18n("<br>Enter the interval after which LISa, if busy, will update its host list."),m_intervalPage);
-   info->setTextFormat(Qt::RichText);
+   info->setTextFormat(TQt::RichText);
 
    m_updatePeriod=new TQSpinBox(300,1800,10,m_intervalPage);
    m_updatePeriod->setSuffix(i18n(" sec"));
@@ -287,14 +287,14 @@ void SetupWizard::setupUpdateIntervalPage()
                         "up to 16 times the value you enter here, if nobody accesses the LISa server. "
                         "So if you enter 300 sec = 5 min here, this does not mean that LISa will ping "
                         "your whole network every 5 minutes. The interval will increase up to 16 x 5 min = 80 min."),m_intervalPage);
-   info->setAlignment(AlignLeft|AlignVCenter|WordBreak);
+   info->tqsetAlignment(AlignLeft|AlignVCenter|WordBreak);
    TQWidget *dummy=new TQWidget(m_intervalPage);
    m_intervalPage->setStretchFactor(dummy,10);
    m_intervalPage->setSpacing(KDialog::spacingHint());
    m_intervalPage->setMargin(KDialog::marginHint());
    info=new TQLabel(i18n("<b>If unsure, keep it as is.</b>"), m_intervalPage);
-   info->setAlignment(AlignRight|AlignVCenter);
-   info->setTextFormat(Qt::RichText);
+   info->tqsetAlignment(AlignRight|AlignVCenter);
+   info->setTextFormat(TQt::RichText);
 
    setHelpEnabled( m_intervalPage, false );
 }
@@ -304,7 +304,7 @@ void SetupWizard::setupAdvancedSettingsPage()
    m_advancedPage=new TQVBox(this);
    TQLabel *info=new TQLabel(i18n("This page contains several settings you usually only<br>"
                                 "need if LISa doesn't find all hosts in your network."),m_advancedPage);
-   info->setTextFormat(Qt::RichText);
+   info->setTextFormat(TQt::RichText);
    m_deliverUnnamedHosts=new TQCheckBox(i18n("Re&port unnamed hosts"),m_advancedPage);
    info=new TQLabel(i18n("Should hosts for which LISa can\'t resolve the name be included in the host list?<br>"),m_advancedPage);
 
@@ -318,7 +318,7 @@ void SetupWizard::setupAdvancedSettingsPage()
 
    hbox=new TQHBox(m_advancedPage);
    info=new TQLabel(i18n("Max. number of pings to send at once"),hbox);
-   info->setTextFormat(Qt::RichText);
+   info->setTextFormat(TQt::RichText);
    m_maxPingsAtOnce=new TQSpinBox(8,1024,5,hbox);
    info=new TQLabel(i18n("How many ping packets should LISa send at once?<br>"
                         "If LISa doesn't find all hosts you could try to decrease this value.<br>"),m_advancedPage);
@@ -328,7 +328,7 @@ void SetupWizard::setupAdvancedSettingsPage()
    hbox=new TQHBox(m_advancedPage);
 //   hbox->setSpacing(10); // WTF?
    info=new TQLabel(i18n("Wait for replies after second scan"),hbox);
-   info->setTextFormat(Qt::RichText);
+   info->setTextFormat(TQt::RichText);
    m_secondWait=new TQSpinBox(0,1000,50,hbox);
    m_secondWait->setSuffix(i18n(" ms"));
    info=new TQLabel(i18n("If LISa doesn't find all hosts, enable this option."),m_advancedPage);
@@ -338,7 +338,7 @@ void SetupWizard::setupAdvancedSettingsPage()
    //m_advancedPage->setMargin(KDialog::marginHint());
 
    info=new TQLabel(i18n("<b>If unsure, keep it as is.</b>"), m_advancedPage);
-   info->setAlignment(AlignRight|AlignVCenter);
+   info->tqsetAlignment(AlignRight|AlignVCenter);
 
    connect(m_secondScan,TQT_SIGNAL(toggled(bool)),m_secondWait,TQT_SLOT(setEnabled(bool)));
    setHelpEnabled( m_advancedPage, false );
@@ -356,7 +356,7 @@ void SetupWizard::setupFinalPage()
                                 "The config file will now be saved to <code>/etc/lisarc</code>.<br>"
                                 "To test the server, try <code>lan:/</code> in Konqueror.<br><br>"
                                 "If you have problems or suggestions, visit http://lisa-home.sourceforge.net."),m_finalPage);
-   info->setTextFormat(Qt::RichText);
+   info->setTextFormat(TQt::RichText);
    TQWidget *dummy=new TQWidget(m_finalPage);
    m_finalPage->setStretchFactor(dummy,10);
    m_finalPage->setSpacing(KDialog::spacingHint());
