@@ -187,7 +187,7 @@ int LANProtocol::lanReadDataFromServer()
    if ((bytesRead<0) || (receivedBytes<4))
    {
       delete [] receiveBuffer;
-      error(ERR_INTERNAL_SERVER,i18n("Received unexpected data from %1").arg(m_currentHost));
+      error(ERR_INTERNAL_SERVER,i18n("Received unexpected data from %1").tqarg(m_currentHost));
       return 0;
    }
 
@@ -206,7 +206,7 @@ int LANProtocol::lanReadDataFromServer()
       if ((memchr(currentBuf,0,bytesLeft)==0) || (memchr(currentBuf,int('\n'),bytesLeft)==0))
       {
          delete [] receiveBuffer;
-         error(ERR_INTERNAL_SERVER,i18n("Received unexpected data from %1").arg(m_currentHost));
+         error(ERR_INTERNAL_SERVER,i18n("Received unexpected data from %1").tqarg(m_currentHost));
          return 0;
       }
       kdDebug(7101)<<"LANProtocol::lanReadDataFromServer: processing "<<currentBuf;
@@ -381,7 +381,7 @@ int LANProtocol::rlanReadDataFromServer()
       if ((memchr(currentBuf,0,bytesLeft)==0) || (memchr(currentBuf,int('\n'),bytesLeft)==0))
       {
          delete [] receiveBuffer;
-         error(ERR_INTERNAL_SERVER,i18n("Received unexpected data from %1").arg(socketname));
+         error(ERR_INTERNAL_SERVER,i18n("Received unexpected data from %1").tqarg(socketname.data()));
          return 0;
       }
       kdDebug(7101)<<"RLANProtocol::readDataFromServer: processing "<<currentBuf;
