@@ -25,8 +25,8 @@
 %{APPNAME}PrefPageOne::%{APPNAME}PrefPageOne(TQWidget *parent)
     : TQFrame(parent)
 {
-    TQHBoxLayout *layout = new TQHBoxLayout(this);
-    layout->setAutoAdd(true);
+    TQHBoxLayout *tqlayout = new TQHBoxLayout(this);
+    tqlayout->setAutoAdd(true);
 
     new TQLabel(i18n("Add something here"), this);
 }
@@ -34,8 +34,8 @@
 %{APPNAME}PrefPageTwo::%{APPNAME}PrefPageTwo(TQWidget *parent)
     : TQFrame(parent)
 {
-    TQHBoxLayout *layout = new TQHBoxLayout(this);
-    layout->setAutoAdd(true);
+    TQHBoxLayout *tqlayout = new TQHBoxLayout(this);
+    tqlayout->setAutoAdd(true);
 
     new TQLabel(i18n("Add something here"), this);
 }
