@@ -17,12 +17,13 @@
 class KatePluginFactory : public KLibFactory
 {
   Q_OBJECT
+  TQ_OBJECT
 
   public:
     KatePluginFactory();
     virtual ~KatePluginFactory();
 
-    virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0, const char* name = "TQObject", const TQStringList &args = TQStringList() );
+    virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0, const char* name = TQOBJECT_OBJECT_NAME_STRING, const TQStringList &args = TQStringList() );
 
   private:
     static KInstance* s_instance;
@@ -31,6 +32,7 @@ class KatePluginFactory : public KLibFactory
 class KatePlugin%{APPNAME} : public Kate::Plugin, Kate::PluginViewInterface
 {
   Q_OBJECT
+  TQ_OBJECT
 
   public:
     KatePlugin%{APPNAME}( TQObject* parent = 0, const char* name = 0 );
