@@ -5,9 +5,10 @@
 
 #include <tqvbox.h>
 
-class kmdikonsole : public QVBox
+class kmdikonsole : public TQVBox
 {
 	Q_OBJECT
+  TQ_OBJECT
 
 	public:
 		kmdikonsole( TQWidget* parent, const char* name=0);
