@@ -5,10 +5,11 @@
 class %{APPNAME} : public %{APPNAME}Base
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     static TQString appName() {
-        return TQString::fromLatin1("%{APPNAMELC}" );
+        return TQString::tqfromLatin1("%{APPNAMELC}" );
     }
     %{APPNAME}( TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
     ~%{APPNAME}();
