@@ -3,12 +3,13 @@
 
 #include <tqhbox.h>
 
-#include <qpe/inputmethodinterface.h>
+#include <tqpe/inputmethodinterface.h>
 
 class TQPixmap;
 class TQCheckBox;
 class %{APPNAME} : public TQHBox {
 	Q_OBJECT
+  TQ_OBJECT
 public:
 	%{APPNAME}( TQWidget *par, WFlags f );
 	~%{APPNAME}();
@@ -31,12 +32,12 @@ public:
     %{APPNAME}Impl();
     virtual ~%{APPNAME}Impl();
 
-#ifndef QT_NO_COMPONENT
-    QRESULT queryInterface( const QUuid&, QUnknownInterface** );
-    Q_REFCOUNT
+#ifndef TQT_NO_COMPONENT
+    TQRESULT queryInterface( const TQUuid&, TQUnknownInterface** );
+    TQ_REFCOUNT
 #endif
 
-    virtual TQWidget *inputMethod( TQWidget *parent, Qt::WFlags f );
+    virtual TQWidget *inputMethod( TQWidget *parent, TQt::WFlags f );
     virtual void resetState();
     virtual TQPixmap *icon();
     virtual TQString name();
