@@ -1,7 +1,7 @@
 #ifndef %{APPNAME}_MENU_APPLET_H
 #define %{APPNAME}_MENU_APPLET_H
 
-#include <qpe/menuappletinterface.h>
+#include <tqpe/menuappletinterface.h>
 
 #include <tqobject.h>
 
@@ -9,13 +9,14 @@ class %{APPNAME} : public TQObject, public MenuAppletInterface
 {
 
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     %{APPNAME} ( );
     virtual ~%{APPNAME} ( );
 
-    QRESULT queryInterface( const QUuid&, QUnknownInterface** );
-    Q_REFCOUNT
+    TQRESULT queryInterface( const TQUuid&, TQUnknownInterface** );
+    TQ_REFCOUNT
 
     virtual int position() const;
     
