@@ -12,19 +12,19 @@ public:
     %{APPNAME}Module();
     ~%{APPNAME}Module();
 
-    const TQString type() {return TQString::fromLatin1("vpn" );}
+    const TQString type() {return TQString::tqfromLatin1("vpn" );}
     void setProfile( const TQString& ) {}
     bool isOwner( Interface* );
     TQWidget *configure( Interface* );
     TQWidget *information(  Interface* );
-    QList<Interface> getInterfaces();
+    TQList<Interface> getInterfaces();
     void possibleNewInterfaces( TQMap<TQString, TQString>& );
     Interface *addNewInterface( const TQString& );
     bool remove( Interface* iface );
-    TQString getPixmapName( Interface*  ) {return TQString::fromLatin1("Tux"); }
+    TQString getPixmapName( Interface*  ) {return TQString::tqfromLatin1("Tux"); }
     void receive( const TQCString&, const TQByteArray& ar ) {} // don't listen
 private:
-    QList<Interface> m_interfaces;
+    TQList<Interface> m_interfaces;
 };
 
 extern "C" {
