@@ -19,7 +19,7 @@ double %{APPNAME}::versionNumber() const {
 
 // this sets the image that will be shown on the left side of the plugin
 TQString %{APPNAME}::pixmapNameWidget() const {
-    return TQString::fromLatin1("%{APPNAMELC}/%{APPNAMELC}");
+    return TQString::tqfromLatin1("%{APPNAMELC}/%{APPNAMELC}");
 }
 
 TQWidget* %{APPNAME}::widget( TQWidget * wid ) {
@@ -42,7 +42,7 @@ TodayConfigWidget* %{APPNAME}::configWidget( TQWidget* /*parent*/ ) {
 
 // add the binary name of the app to launch here
 TQString %{APPNAME}::appName() const {
-    return TQString::null;
+    return TQString();
 }
 
 // if the plugin should be excluded form the refresh cycles that can be set in the today app
