@@ -70,12 +70,12 @@ CCConfigWidget::CCConfigWidget( CppSupportPart* part, TQWidget* parent, const ch
 	         this, TQT_SLOT( catalogUnregistered( Catalog* ) ) );
 
 	connect( m_qtDir, TQT_SIGNAL(urlSelected(const TQString &)),
-		 this, TQT_SLOT(isValidQtDir(const TQString &)));
+		 this, TQT_SLOT(isValidTQtDir(const TQString &)));
 	connect( m_qtDir, TQT_SIGNAL(textChanged(const TQString &)),
-		 this, TQT_SLOT(isValidQtDir(const TQString &)));
+		 this, TQT_SLOT(isValidTQtDir(const TQString &)));
 
 	initGeneralTab( );
-	initQtTab();
+	initTQtTab();
 	initCodeCompletionTab( );
 	initGetterSetterTab( );
 	initSplitTab();
@@ -104,7 +104,7 @@ CCConfigWidget::~CCConfigWidget( )
 void CCConfigWidget::accept( )
 {
 	saveFileTemplatesTab();
-	saveQtTab();
+	saveTQtTab();
 	saveCodeCompletionTab();
 	saveGetterSetterTab();
 	saveSplitTab();
@@ -230,7 +230,7 @@ void CCConfigWidget::slotRemovePCS()
 		return ;
 
 	TQString db = advancedOptions->selectedItem() ->text( 0 );
-	TQString question = i18n( "Are you sure you want to delete the \"%1\" database?" ).arg( db );
+	TQString question = i18n( "Are you sure you want to delete the \"%1\" database?" ).tqarg( db );
 
 	KStandardDirs *dirs = m_pPart->instance() ->dirs();
 	TQString dbName = dirs->saveLocation( "data", "kdevcppsupport/pcs" ) + KURL::encode_string_no_slash( db ) + ".db";
@@ -393,7 +393,7 @@ void CCConfigWidget::saveSplitTab( )
 	config->store();
 }
 
-void CCConfigWidget::initQtTab()
+void CCConfigWidget::initTQtTab()
 {
 	m_qtDir->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);
 
@@ -435,7 +435,7 @@ void CCConfigWidget::initQtTab()
 		m_qtStyleVersion3->setChecked( true );
 	}
 	m_qtDir->setURL( c->root() );
-	isValidQtDir(m_qtDir->url());
+	isValidTQtDir(m_qtDir->url());
     m_qmakePath->setURL( c->qmakePath() );
     isExecutable( m_qmakePath->url() );
     m_designerPath->setURL( c->designerPath() );
@@ -460,7 +460,7 @@ bool CCConfigWidget::isExecutable( const TQString& path )
     return ( fi.exists() && fi.isExecutable()  );
 }
 
-void CCConfigWidget::isQMakeExecutable( const TQString& path )
+void CCConfigWidget::isTQMakeExecutable( const TQString& path )
 {
     if( !isExecutable( path ) )
     {
@@ -482,7 +482,7 @@ void CCConfigWidget::isDesignerExecutable( const TQString& path )
     }
 }
 
-void CCConfigWidget::saveQtTab()
+void CCConfigWidget::saveTQtTab()
 {
 	QtBuildConfig* c = m_pPart->qtBuildConfig();
 
@@ -503,7 +503,7 @@ void CCConfigWidget::saveQtTab()
 		c->setIncludeStyle( 3 );
 	}
 	c->setRoot( m_qtDir->url() );
-    c->setQMakePath( m_qmakePath->url() );
+    c->setTQMakePath( m_qmakePath->url() );
     c->setDesignerPath( m_designerPath->url() );
 	if( m_kdevembedded->isChecked() )
 	{
@@ -519,7 +519,7 @@ void CCConfigWidget::saveQtTab()
 	c->store();
 }
 
-void CCConfigWidget::isValidQtDir( const TQString &dir )
+void CCConfigWidget::isValidTQtDir( const TQString &dir )
 {
 	TQFileInfo inc( dir + TQString( TQChar( TQDir::separator() ) )+
 			"include"+TQString( TQChar( TQDir::separator() ) )+
@@ -533,7 +533,7 @@ void CCConfigWidget::isValidQtDir( const TQString &dir )
 	}
 }
 
-void CCConfigWidget::toggleQtVersion( bool )
+void CCConfigWidget::toggleTQtVersion( bool )
 {
   if ( m_versionQt3->isChecked() )
   {
@@ -551,8 +551,8 @@ void CCConfigWidget::toggleQtVersion( bool )
     m_kdevexternal->setEnabled( false );
     pluginPaths->setEnabled( true );
   }
-  isValidQtDir( m_qtDir->url() );
-  isQMakeExecutable( m_qmakePath->url() );
+  isValidTQtDir( m_qtDir->url() );
+  isTQMakeExecutable( m_qmakePath->url() );
   isDesignerExecutable( m_designerPath->url() );
 }
 
@@ -561,7 +561,7 @@ void CCConfigWidget::openPluginPaths()
     kdDebug(9024) << "Plugin paths opened" << endl;
     QtBuildConfig* c = m_pPart->qtBuildConfig();
     KDialog d( this );
-    TQVBoxLayout* mainlayout = new TQVBoxLayout( &d );
+    TQVBoxLayout* maintqlayout = new TQVBoxLayout( &d );
     KPushButton* ok = new KPushButton( KStdGuiItem::ok(), &d );
     connect( ok, TQT_SIGNAL(clicked()), &d, TQT_SLOT(accept()));
     KPushButton* cancel = new KPushButton( KStdGuiItem::cancel(), &d );
@@ -571,13 +571,13 @@ void CCConfigWidget::openPluginPaths()
     btns->addWidget(ok);
     btns->addWidget(cancel);
 
-    d.setCaption( i18n( "Edit Qt4 Designer Plugin Paths" ) );
+    d.setCaption( i18n( "Edit TQt4 Designer Plugin Paths" ) );
     KURLRequester * req = new KURLRequester( &d );
     req->setMode( KFile::Directory );
     KEditListBox* p = new KEditListBox( i18n( "Plugin Paths" ), req->customEditor(), &d );
     p->insertStringList( c->designerPluginPaths() );
-    mainlayout->addWidget( p );
-    mainlayout->addLayout( btns );
+    maintqlayout->addWidget( p );
+    maintqlayout->addLayout( btns );
     d.resize( 450, 250 );
     if( d.exec() == TQDialog::Accepted)
     {
