@@ -26,7 +26,7 @@
 
 K_EXPORT_COMPONENT_FACTORY( libkdevgccoptions, KGenericFactory<GccOptionsPlugin>( "kdevgccoptions" ) )
 
-class GeneralTab : public QWidget
+class GeneralTab : public TQWidget
 {
 public:
 	GeneralTab( GccOptionsPlugin::Type type, TQWidget *parent = 0, const char *name = 0 );
@@ -40,7 +40,7 @@ private:
 };
 
 
-class OptimizationTab : public QWidget
+class OptimizationTab : public TQWidget
 {
 public:
 	OptimizationTab( GccOptionsPlugin::Type type, TQWidget *parent = 0, const char *name = 0 );
@@ -55,7 +55,7 @@ private:
 };
 
 
-class G77Tab : public QWidget
+class G77Tab : public TQWidget
 {
 public:
 	G77Tab( TQWidget *parent = 0, const char *name = 0 );
@@ -69,7 +69,7 @@ private:
 };
 
 
-class Warnings1Tab : public QWidget
+class Warnings1Tab : public TQWidget
 {
 public:
 	Warnings1Tab( GccOptionsPlugin::Type type, TQWidget *parent = 0, const char *name = 0 );
@@ -84,7 +84,7 @@ private:
 };
 
 
-class Warnings2Tab : public QWidget
+class Warnings2Tab : public TQWidget
 {
 public:
 	Warnings2Tab( GccOptionsPlugin::Type type, TQWidget *parent = 0, const char *name = 0 );
@@ -101,9 +101,9 @@ private:
 GeneralTab::GeneralTab( GccOptionsPlugin::Type type, TQWidget *parent, const char *name )
 		: TQWidget( parent, name ), controller( new FlagCheckBoxController )
 {
-	TQBoxLayout * layout = new TQVBoxLayout( this, KDialog::marginHint(), KDialog::spacingHint() );
-	layout->setAutoAdd( true );
-	layout->addSpacing( 10 );
+	TQBoxLayout * tqlayout = new TQVBoxLayout( this, KDialog::marginHint(), KDialog::spacingHint() );
+	tqlayout->setAutoAdd( true );
+	tqlayout->addSpacing( 10 );
 
 	TQVButtonGroup *output_group = new TQVButtonGroup( i18n( "Output" ), this );
 	new FlagCheckBox( output_group, controller,
@@ -114,7 +114,7 @@ GeneralTab::GeneralTab( GccOptionsPlugin::Type type, TQWidget *parent, const cha
 	                  "-save-temps", i18n( "Do not delete intermediate output like assembler files" ) );
 
 	TQApplication::sendPostedEvents( this, TQEvent::ChildInserted );
-	layout->addSpacing( 10 );
+	tqlayout->addSpacing( 10 );
 
 	TQVButtonGroup *codegen_group = new TQVButtonGroup( i18n( "Code Generation" ), this );
 	if ( type != GccOptionsPlugin::GPP )
@@ -142,7 +142,7 @@ GeneralTab::GeneralTab( GccOptionsPlugin::Type type, TQWidget *parent, const cha
 	                  "-short-double", i18n( "Make 'double' the same as 'float'" ) );
 
 	TQApplication::sendPostedEvents( this, TQEvent::ChildInserted );
-	layout->addStretch();
+	tqlayout->addStretch();
 }
 
 
@@ -167,8 +167,8 @@ void GeneralTab::writeFlags( TQStringList *list )
 OptimizationTab::OptimizationTab( GccOptionsPlugin::Type type, TQWidget *parent, const char *name )
 		: TQWidget( parent, name )
 {
-	TQBoxLayout * layout = new TQVBoxLayout( this, KDialog::marginHint(), KDialog::spacingHint() );
-	layout->setAutoAdd( true );
+	TQBoxLayout * tqlayout = new TQVBoxLayout( this, KDialog::marginHint(), KDialog::spacingHint() );
+	tqlayout->setAutoAdd( true );
 
 	TQVButtonGroup *group = new TQVButtonGroup( i18n( "Optimization Level" ), this );
 	Odefault = new TQRadioButton( i18n( "Default" ), group );
@@ -211,7 +211,7 @@ OptimizationTab::OptimizationTab( GccOptionsPlugin::Type type, TQWidget *parent,
 	}
 
 	TQApplication::sendPostedEvents( this, TQEvent::ChildInserted );
-	layout->addStretch();
+	tqlayout->addStretch();
 }
 
 
@@ -264,9 +264,9 @@ void OptimizationTab::writeFlags( TQStringList *list )
 G77Tab::G77Tab( TQWidget *parent, const char *name )
 		: TQWidget( parent, name ), controller( new FlagCheckBoxController )
 {
-	TQBoxLayout * layout = new TQVBoxLayout( this, KDialog::marginHint(), KDialog::spacingHint() );
-	layout->setAutoAdd( true );
-	layout->addSpacing( 10 );
+	TQBoxLayout * tqlayout = new TQVBoxLayout( this, KDialog::marginHint(), KDialog::spacingHint() );
+	tqlayout->setAutoAdd( true );
+	tqlayout->addSpacing( 10 );
 
 	TQVButtonGroup *dialect_group = new TQVButtonGroup( i18n( "Dialect" ), this );
 	new FlagCheckBox( dialect_group, controller,
@@ -283,7 +283,7 @@ G77Tab::G77Tab( TQWidget *parent, const char *name )
 	                  "-fonetrip", i18n( "DO loops are executed at least once" ) );
 
 	TQApplication::sendPostedEvents( this, TQEvent::ChildInserted );
-	layout->addSpacing( 10 );
+	tqlayout->addSpacing( 10 );
 
 	TQVButtonGroup *codegen_group = new TQVButtonGroup( i18n( "Code Generation" ), this );
 	new FlagCheckBox( codegen_group, controller,
@@ -294,7 +294,7 @@ G77Tab::G77Tab( TQWidget *parent, const char *name )
 	                  "-fbounds-check", i18n( "Generate run-time checks for array subscripts" ) );
 
 	TQApplication::sendPostedEvents( this, TQEvent::ChildInserted );
-	layout->addStretch();
+	tqlayout->addStretch();
 }
 
 
@@ -319,8 +319,8 @@ void G77Tab::writeFlags( TQStringList *list )
 Warnings1Tab::Warnings1Tab( GccOptionsPlugin::Type type, TQWidget *parent, const char *name )
 		: TQWidget( parent, name ), controller( new FlagCheckBoxController )
 {
-	TQBoxLayout * layout = new TQVBoxLayout( this, KDialog::marginHint(), KDialog::spacingHint() );
-	layout->setAutoAdd( true );
+	TQBoxLayout * tqlayout = new TQVBoxLayout( this, KDialog::marginHint(), KDialog::spacingHint() );
+	tqlayout->setAutoAdd( true );
 
 	new FlagCheckBox( this, controller,
 	                  "-w", i18n( "Inhibit all warnings" ) );
@@ -417,8 +417,8 @@ void Warnings1Tab::writeFlags( TQStringList *list )
 Warnings2Tab::Warnings2Tab( GccOptionsPlugin::Type type, TQWidget *parent, const char *name )
 		: TQWidget( parent, name )
 {
-	TQBoxLayout * layout = new TQVBoxLayout( this, KDialog::marginHint(), KDialog::spacingHint() );
-	layout->setAutoAdd( true );
+	TQBoxLayout * tqlayout = new TQVBoxLayout( this, KDialog::marginHint(), KDialog::spacingHint() );
+	tqlayout->setAutoAdd( true );
 
 	wrestBox = new FlagListBox( this );
 
@@ -438,7 +438,7 @@ Warnings2Tab::Warnings2Tab( GccOptionsPlugin::Type type, TQWidget *parent, const
 	                                       "qualifier from the target type</qt>" ) );
 	new FlagListItem( wrestBox,
 	                  "-Wcast-align", i18n( "<qt>Warn whenever a pointer is cast such that the required\n"
-	                                        "alignment of the target is increased</qt>" ) );
+	                                        "tqalignment of the target is increased</qt>" ) );
 	new FlagListItem( wrestBox,
 	                  "-Wwrite-strings", i18n( "<qt>Warn when the address of a string constant is cast\n"
 	                                           "into a non-const <i>char *</i> pointer</qt>" ) );
@@ -463,7 +463,7 @@ Warnings2Tab::Warnings2Tab( GccOptionsPlugin::Type type, TQWidget *parent, const
 	                        "deprecated by using the 'deprecated' attribute</qt>" ) );
 	new FlagListItem( wrestBox,
 	                  "-Wpacked", i18n( "<qt>Warn if a structure is given the packed attribute, but the packed\n"
-	                                    "attribute has no effect on the layout or size of the structure</qt>" ) );
+	                                    "attribute has no effect on the tqlayout or size of the structure</qt>" ) );
 	new FlagListItem( wrestBox,
 	                  "-Wpadded", i18n( "<qt>Warn if padding is included in a structure, either to align an\n"
 	                                    "element of the structure or to align the whole structure</qt>" ) );
@@ -683,7 +683,7 @@ TQString GccOptionsPlugin::captionForType( Type type )
 	case G77:
 		return i18n( "GNU Fortran 77 Compiler Options" );
 	default:
-		return TQString::null;
+		return TQString();
 	}
 }
 
@@ -691,7 +691,7 @@ TQString GccOptionsPlugin::captionForType( Type type )
 TQString GccOptionsPlugin::exec( TQWidget *parent, const TQString &flags )
 {
 	if ( gcctype == Unknown )
-		return TQString::null;
+		return TQString();
 	GccOptionsDialog *dlg = new GccOptionsDialog( gcctype, parent, "gcc options dialog" );
 	TQString newFlags = flags;
 	dlg->setFlags( flags );
