@@ -52,24 +52,9 @@
 
 #include "classgeneratorconfig.h"
 
-TQString QRegExp_escape( const TQString& str )
+TQString TQRegExp_escape( const TQString& str )
 {
-#if QT_VERSION >= 0x030100
 	return TQRegExp::escape( str );
-#else
-	// this block is copyrighted by Trolltech AS (GPL)
-	static const char meta[] = "$()*+.?[\\]^{|}";
-	TQString quoted = str;
-	int i = 0;
-
-	while ( i < ( int ) quoted.length() )
-	{
-		if ( strchr( meta, quoted[ i ].latin1() ) != 0 )
-			quoted.insert( i++, "\\" );
-		i++;
-	}
-	return quoted;
-#endif
 }
 
 CppNewClassDialog::CppNewClassDialog( CppSupportPart *part, TQWidget *parent, const char *name )
@@ -175,13 +160,7 @@ void CppNewClassDialog::addCompletionBasenameNamespacesRecursive( const Namespac
 
 	if ( ! namespaceParent.isEmpty() )
 	{
-#if QT_VERSION >= 0x030200
 		classList.gres( TQRegExp( "^" ), namespaceParent + "::" );
-#else
-
-		gres( classList, TQRegExp( "^" ), namespaceParent + "::" );
-#endif
-
 	}
 
 	compBasename -> insertItems( classList );
@@ -286,7 +265,7 @@ void CppNewClassDialog::baseclassname_changed( const TQString &text )
 	{
 		TQString header = text;
 
-		// handle Qt classes in a special way.
+		// handle TQt classes in a special way.
 		if( m_part->qtBuildConfig()->isUsed() && header.startsWith( "Q" ) )
 		{
 			if( m_part->qtBuildConfig()->version() == 3 )
@@ -369,7 +348,7 @@ void CppNewClassDialog::checkObjCInheritance( int val )
 			objc_box->setChecked( false );
 }
 
-void CppNewClassDialog::checkQWidgetInheritance( int val )
+void CppNewClassDialog::checkTQWidgetInheritance( int val )
 {
 	if ( val )
 	{
@@ -395,7 +374,7 @@ void CppNewClassDialog::checkQWidgetInheritance( int val )
 		if ( baseclasses_view->childCount() == 0 )
 		{
 			addBaseClass();
-			basename_edit->setText( "TQWidget" );
+			basename_edit->setText( TQWIDGET_OBJECT_NAME_STRING );
 		}
 		/*        constructors_cpp_edit->append(classname_edit->text() + "::" + classname_edit->text() +
 		            "(TQWidget *parent, const char *name):\n    TQWidget(parent, name)\n{\n}\n");
@@ -417,7 +396,7 @@ void CppNewClassDialog::qobject_box_stateChanged( int val )
 	if ( baseclasses_view->childCount() == 0 )
 	{
 		addBaseClass();
-		basename_edit->setText( "TQObject" );
+		basename_edit->setText( TQOBJECT_OBJECT_NAME_STRING );
 	}
 
 
@@ -482,11 +461,11 @@ void CppNewClassDialog::addBaseClass()
 	if ( baseclasses_view->selectedItem() )
 		baseclasses_view->selectedItem() ->setSelected( false );
 	TQListViewItem* it = new TQListViewItem( baseclasses_view, baseclasses_view->lastItem(),
-	                                       TQString::null, "public", TQString( "%1" ).arg( scope_box->currentItem() ), TQString::null, "false" );
+	                                       TQString(), "public", TQString( "%1" ).tqarg( scope_box->currentItem() ), TQString(), "false" );
 	setStateOfInheritanceEditors( true );
 	public_button->setChecked( true );
 	virtual_box->setChecked( false );
-	basename_edit->setText( TQString::null );
+	basename_edit->setText( TQString() );
 	basename_edit->setFocus();
 	baseclasses_view->setSelected( it, true );
 }
@@ -610,7 +589,7 @@ void CppNewClassDialog::scopeboxActivated( int value )
 {
 	if ( baseclasses_view->selectedItem() )
 	{
-		baseclasses_view->selectedItem() ->setText( 2, TQString( "%1" ).arg( value ) );
+		baseclasses_view->selectedItem() ->setText( 2, TQString( "%1" ).tqarg( value ) );
 	}
 }
 
@@ -776,7 +755,7 @@ void CppNewClassDialog::changeToPublic()
 void CppNewClassDialog::changeToInherited()
 {
 	if ( access_view->selectedItem() )
-		access_view->selectedItem() ->setText( 2, TQString::null );
+		access_view->selectedItem() ->setText( 2, TQString() );
 }
 
 void CppNewClassDialog::newTabSelected( const TQString& /*text*/ )
@@ -870,10 +849,10 @@ void CppNewClassDialog::parseClass( TQString clName, TQString inheritance )
 		PListViewItem<ClassDom> *over = new PListViewItem<ClassDom>( *classIt, methods_view, ( *classIt ) ->name() );
 		over->templateAddition = templateAdd;
 		TQListViewItem *over_methods = new TQListViewItem( over, i18n( "Methods" ) );
-		TQListViewItem *over_slots = new TQListViewItem( over, i18n( "Slots (Qt-specific)" ) );
+		TQListViewItem *over_slots = new TQListViewItem( over, i18n( "Slots (TQt-specific)" ) );
 		PListViewItem<ClassDom> *access = new PListViewItem<ClassDom>( *classIt, access_view, ( *classIt ) ->name() );
 		TQListViewItem *access_methods = new TQListViewItem( access, i18n( "Methods" ) );
-		TQListViewItem *access_slots = new TQListViewItem( access, i18n( "Slots (Qt-specific)" ) );
+		TQListViewItem *access_slots = new TQListViewItem( access, i18n( "Slots (TQt-specific)" ) );
 		TQListViewItem *access_attrs = new TQListViewItem( access, i18n( "Attributes" ) );
 
 		FunctionList functionList = ( *classIt ) ->functionList();
@@ -1029,10 +1008,10 @@ void CppNewClassDialog::parsePCSClass( TQString clName, TQString inheritance )
 		PListViewItem<ClassDom> *over = new PListViewItem<ClassDom>( *classIt, methods_view, ( *classIt ) ->name() );
 		over->templateAddition = templateAdd;
 		TQListViewItem *over_methods = new TQListViewItem( over, i18n( "Methods" ) );
-		TQListViewItem *over_slots = new TQListViewItem( over, i18n( "Slots (Qt-specific)" ) );
+		TQListViewItem *over_slots = new TQListViewItem( over, i18n( "Slots (TQt-specific)" ) );
 		PListViewItem<ClassDom> *access = new PListViewItem<ClassDom>( *classIt, access_view, ( *classIt ) ->name() );
 		TQListViewItem *access_methods = new TQListViewItem( access, i18n( "Methods" ) );
-		TQListViewItem *access_slots = new TQListViewItem( access, i18n( "Slots (Qt-specific)" ) );
+		TQListViewItem *access_slots = new TQListViewItem( access, i18n( "Slots (TQt-specific)" ) );
 		TQListViewItem *access_attrs = new TQListViewItem( access, i18n( "Attributes" ) );
 
 		FunctionList functionList = ( *classIt ) ->functionList();
@@ -1160,9 +1139,9 @@ void CppNewClassDialog::setAccessForItem( TQListViewItem *curr, TQString newAcce
 	if ( !curr->text( 2 ).isEmpty() )
 	{
 		if ( ( curr->text( 2 ) == "private" ) && ( ( newAccess == "public" ) || ( newAccess == "protected" ) ) )
-			curr->setText( 2, TQString::null );
+			curr->setText( 2, TQString() );
 		if ( ( curr->text( 2 ) == "protected" ) && ( ( newAccess == "public" ) && ( isPublic ) ) )
-			curr->setText( 2, TQString::null );
+			curr->setText( 2, TQString() );
 	}
 }
 
@@ -1192,7 +1171,7 @@ void CppNewClassDialog::setAccessForBase( TQString baseclass, TQString newAccess
 
 void CppNewClassDialog::access_view_mouseButtonPressed( int button, TQListViewItem * item, const TQPoint &p, int /*c*/ )
 {
-	if ( item && ( ( button == LeftButton ) || ( button == RightButton ) ) && ( item->depth() > 1 ) )
+	if ( item && ( ( button == Qt::LeftButton ) || ( button == Qt::RightButton ) ) && ( item->depth() > 1 ) )
 	{
 		accessMenu->setItemEnabled( 1, true );
 		accessMenu->setItemEnabled( 2, true );
@@ -1217,7 +1196,7 @@ void CppNewClassDialog::access_view_mouseButtonPressed( int button, TQListViewIt
 
 void CppNewClassDialog::methods_view_mouseButtonPressed( int button , TQListViewItem * item, const TQPoint&p , int /*c*/ )
 {
-	if ( item && ( button == RightButton ) && ( item->depth() > 1 ) && ( ! item->text( 1 ).isEmpty() ) )
+	if ( item && ( button == Qt::RightButton ) && ( item->depth() > 1 ) && ( ! item->text( 1 ).isEmpty() ) )
 	{
 		overMenu->exec( p );
 	}
@@ -1249,7 +1228,7 @@ void CppNewClassDialog::selectall_button_clicked()
 
 void CppNewClassDialog::to_constructors_list_clicked()
 {
-	TQString templateAdd = templateStrFormatted().isEmpty() ? TQString::null : templateStrFormatted() + "\n";
+	TQString templateAdd = templateStrFormatted().isEmpty() ? TQString() : templateStrFormatted() + "\n";
 	TQString constructor_h = classNameFormatted();
 	TQString constructor_cpp = templateAdd + classNameFormatted() + templateParamsFormatted() + "::" + classNameFormatted();
 	constructor_h += "(";
@@ -1289,8 +1268,8 @@ void CppNewClassDialog::to_constructors_list_clicked()
 					cparams += ( *argIt ) ->type() + " ";
 					if ( ( *argIt ) ->name().isEmpty() )
 					{
-						cparams += TQString( "arg%1" ).arg( unnamed );
-						bparams += TQString( "arg%1" ).arg( unnamed++ );
+						cparams += TQString( "arg%1" ).tqarg( unnamed );
+						bparams += TQString( "arg%1" ).tqarg( unnamed++ );
 					}
 					else
 					{
@@ -1335,7 +1314,7 @@ bool CppNewClassDialog::ClassGenerator::validateInput()
 	className = dlg.classname_edit->text().simplifyWhiteSpace();
 	TQString temp = className;
 	className.replace( TQRegExp( "template *<.*> *(class *)?" ), "" );
-	templateStr = temp.replace( TQRegExp( QRegExp_escape( className ) ), "" );
+	templateStr = temp.replace( TQRegExp( TQRegExp_escape( className ) ), "" );
 	templateStr.replace( TQRegExp( " *class *$" ), "" );
 
 	templateParams = templateStr;
@@ -1363,7 +1342,7 @@ bool CppNewClassDialog::ClassGenerator::validateInput()
 	}
 
 	/// \FIXME
-    if ( ( header.find( '/' ) != -1 || implementation.find( '/' ) != -1 ) && !( dlg.m_part->project() ->options() & KDevProject::UsesQMakeBuildSystem) )
+    if ( ( header.find( '/' ) != -1 || implementation.find( '/' ) != -1 ) && !( dlg.m_part->project() ->options() & KDevProject::UsesTQMakeBuildSystem) )
 	{
 		KMessageBox::error( &dlg, i18n( "Generated files will always be added to the "
 		                                "active directory, so you must not give an "
@@ -1397,7 +1376,7 @@ bool CppNewClassDialog::ClassGenerator::generate()
 		return false;
 	}
 
-    if( ( dlg.m_part->project() ->options() & KDevProject::UsesQMakeBuildSystem) )
+    if( ( dlg.m_part->project() ->options() & KDevProject::UsesTQMakeBuildSystem) )
     {
         TQDir dir( TQFileInfo( project->projectDirectory()+TQString( TQChar( TQDir::separator() ) )+project->activeDirectory() + TQString( TQChar( TQDir::separator() ) ) + header ).dirPath() );
         kdDebug(9024) << "Dir for new file:" << dir.absPath() << endl;
@@ -1458,7 +1437,7 @@ void CppNewClassDialog::ClassGenerator::common_text()
 	headeronly = dlg.headeronly_box->isChecked();
 
 	if ( ( dlg.baseclasses_view->childCount() == 0 ) && childClass )
-		new TQListViewItem( dlg.baseclasses_view, "TQWidget", "public" );
+		new TQListViewItem( dlg.baseclasses_view, TQWIDGET_OBJECT_NAME_STRING, "public" );
 	if ( objc && ( dlg.baseclasses_view->childCount() == 0 ) )
 		new TQListViewItem( dlg.baseclasses_view, "NSObject", "public" );
 
@@ -1476,7 +1455,7 @@ void CppNewClassDialog::ClassGenerator::common_text()
 		TQString author = DomUtil::readEntry( *dlg.m_part->projectDom(), "/general/author" );
 		TQString email = DomUtil::readEntry( *dlg.m_part->projectDom(), "/general/email" );
 		if( !email.isEmpty() )
-			author += TQString( " <%1>" ).arg( email );
+			author += TQString( " <%1>" ).tqarg( email );
 
 		if ( dlg.gen_config->author_box->isChecked() )
 			doc.append( "\t@author " + author + "\n" );
@@ -1498,8 +1477,8 @@ void CppNewClassDialog::ClassGenerator::common_text()
 
 	//advanced constructor creation
 
-	advConstructorsHeader = TQString::null;
-	advConstructorsSource = TQString::null;
+	advConstructorsHeader = TQString();
+	advConstructorsSource = TQString();
 	if ( !dlg.constructors_h_edit->text().isEmpty() )
 	{
 		advConstructorsHeader = "    " + dlg.constructors_h_edit->text();
@@ -1509,18 +1488,18 @@ void CppNewClassDialog::ClassGenerator::common_text()
 	{
 		advConstructorsSource = dlg.constructors_cpp_edit->text();
 	}
-	advConstructorsHeader.replace( TQRegExp( "[\\n ]*$" ), TQString::null );
-	advConstructorsSource.replace( TQRegExp( "[\\n ]*$" ), TQString::null );
+	advConstructorsHeader.replace( TQRegExp( "[\\n ]*$" ), TQString() );
+	advConstructorsSource.replace( TQRegExp( "[\\n ]*$" ), TQString() );
 
 	//advanced method overriding
 
-	advH_public = TQString::null;
-	advH_public_slots = TQString::null;
-	advH_protected = TQString::null;
-	advH_protected_slots = TQString::null;
-	advH_private = TQString::null;
-	advH_private_slots = TQString::null;
-	advCpp = TQString::null;
+	advH_public = TQString();
+	advH_public_slots = TQString();
+	advH_protected = TQString();
+	advH_protected_slots = TQString();
+	advH_private = TQString();
+	advH_private_slots = TQString();
+	advCpp = TQString();
 
 	TQListViewItemIterator it( dlg.methods_view );
 	while ( it.current() )
@@ -1602,13 +1581,13 @@ void CppNewClassDialog::ClassGenerator::common_text()
 	}
 
 	TQRegExp e( "[\\n ]*$" );
-	advH_public.replace( e, TQString::null );
-	advH_public_slots.replace( e, TQString::null );
-	advH_protected.replace( e, TQString::null );
-	advH_protected_slots.replace( e, TQString::null );
-	advH_private.replace( e, TQString::null );
-	advH_private_slots.replace( e, TQString::null );
-	advCpp.replace( e, TQString::null );
+	advH_public.replace( e, TQString() );
+	advH_public_slots.replace( e, TQString() );
+	advH_protected.replace( e, TQString() );
+	advH_protected_slots.replace( e, TQString() );
+	advH_private.replace( e, TQString() );
+	advH_private_slots.replace( e, TQString() );
+	advCpp.replace( e, TQString() );
 }
 
 void CppNewClassDialog::ClassGenerator::genMethodDeclaration( FunctionDom method,
@@ -1639,8 +1618,8 @@ void CppNewClassDialog::ClassGenerator::genMethodDeclaration( FunctionDom method
 		cparams += ( *argIt ) ->type() + " ";
 		if ( ( *argIt ) ->name().isEmpty() )
 		{
-			cparams += TQString( "arg%1" ).arg( unnamed );
-			bparams += TQString( "arg%1" ).arg( unnamed++ );
+			cparams += TQString( "arg%1" ).tqarg( unnamed );
+			bparams += TQString( "arg%1" ).tqarg( unnamed++ );
 		}
 		else
 		{
@@ -1841,9 +1820,9 @@ void CppNewClassDialog::ClassGenerator::gen_implementation()
 
 	if ( ( dlg.m_part->project() ) && ( childClass || qobject ) && ( dlg.m_part->project() ->options() & KDevProject::UsesAutotoolsBuildSystem ) )
 	{
-		TQString moc = header;
-		moc.replace( TQRegExp( "\\..*" ), ".moc" );
-		classImpl += "#include \"" + moc + "\"\n";
+		TQString tqmoc = header;
+		tqmoc.replace( TQRegExp( "\\..*" ), ".tqmoc" );
+		classImpl += "#include \"" + tqmoc + "\"\n";
 	}
 
 	if ( dlg.gen_config->reformat_box->isChecked() )
@@ -1912,16 +1891,16 @@ void CppNewClassDialog::ClassGenerator::gen_interface()
 		      + namespaceBeg
 		      + TQString("class $CLASSNAME$$INHERITANCE$\n"
 				"{\n"
-				"$QOBJECT$"
+				"$TQOBJECT$"
 				"public:\n")
 		      + ( advConstructorsHeader.isEmpty() ? TQString("    $CLASSNAME$($ARGS$);\n") : advConstructorsHeader )
 		      + TQString("\n    ~$CLASSNAME$();\n")
 		      + advH_public
-		      + (advH_public_slots.isEmpty() ? TQString::fromLatin1("") : ("\n\npublic slots:" + advH_public_slots))
-		      + (advH_protected.isEmpty() ? TQString::fromLatin1("") : ("\n\nprotected:" + advH_protected))
-		      + (advH_protected_slots.isEmpty() ? TQString::fromLatin1("") : ("\n\nprotected slots:" + advH_protected_slots))
-		      + (advH_private.isEmpty() ? TQString::fromLatin1("") : ("\n\nprivate:" + advH_private))
-		      + (advH_private_slots.isEmpty() ? TQString::fromLatin1("") : ("\n\nprivate slots:" + advH_private_slots))
+		      + (advH_public_slots.isEmpty() ? TQString::tqfromLatin1("") : ("\n\npublic slots:" + advH_public_slots))
+		      + (advH_protected.isEmpty() ? TQString::tqfromLatin1("") : ("\n\nprotected:" + advH_protected))
+		      + (advH_protected_slots.isEmpty() ? TQString::tqfromLatin1("") : ("\n\nprotected slots:" + advH_protected_slots))
+		      + (advH_private.isEmpty() ? TQString::tqfromLatin1("") : ("\n\nprivate:" + advH_private))
+		      + (advH_private_slots.isEmpty() ? TQString::tqfromLatin1("") : ("\n\nprivate slots:" + advH_private_slots))
 		      + TQString("};\n"
 				"\n")
 		      + namespaceEnd
@@ -1983,8 +1962,8 @@ void CppNewClassDialog::ClassGenerator::gen_interface()
 		{
 			if ( !it.current() ->text( 0 ).isEmpty() )
 				if ( !it.current() ->text( 3 ).isEmpty() )
-					//          if ((!childClass) || (it.current()->text(0) != "TQWidget"))
-					includeBaseHeader += ( includeBaseHeader.isEmpty() ? TQString( "" ) : TQString( "\n" ) ) + TQString::fromLatin1( "#include " ) +
+					//          if ((!childClass) || (it.current()->text(0) != TQWIDGET_OBJECT_NAME_STRING))
+					includeBaseHeader += ( includeBaseHeader.isEmpty() ? TQString( "" ) : TQString( "\n" ) ) + TQString::tqfromLatin1( "#include " ) +
 					                     ( it.current() ->text( 2 ).toInt() == 0 ? TQString( "<" ) : TQString( "\"" ) )
 					                     + it.current() ->text( 3 )
 					                     + ( it.current() ->text( 2 ).toInt() == 0 ? TQString( ">" ) : TQString( "\"" ) );
@@ -1995,7 +1974,7 @@ void CppNewClassDialog::ClassGenerator::gen_interface()
 	TQString author = DomUtil::readEntry( *dlg.m_part->projectDom(), "/general/author" );
 	TQString email = DomUtil::readEntry( *dlg.m_part->projectDom(), "/general/email" );
 	if( !email.isEmpty() )
-		author += TQString( " <%1>" ).arg( email );
+		author += TQString( " <%1>" ).tqarg( email );
 
 	TQString inheritance;
 	if ( dlg.baseclasses_view->childCount() > 0 )
@@ -2034,7 +2013,7 @@ void CppNewClassDialog::ClassGenerator::gen_interface()
 
 	TQString qobjectStr;
 	if ( childClass || qobject )
-		qobjectStr = "Q_OBJECT";
+		qobjectStr = "Q_OBJECT\nTQ_OBJECT";
 
 
 	TQString baseclass;
@@ -2056,7 +2035,7 @@ void CppNewClassDialog::ClassGenerator::gen_interface()
 	if ( dlg.baseclasses_view->childCount() > 0 )
 		classIntf.replace( TQRegExp( "\\$BASECLASS\\$" ), dlg.baseclasses_view->firstChild() ->text( 0 ) );
 	classIntf.replace( TQRegExp( "\\$INHERITANCE\\$" ), inheritance );
-	classIntf.replace( TQRegExp( "\\$QOBJECT\\$" ), qobjectStr );
+	classIntf.replace( TQRegExp( "\\$TQOBJECT\\$" ), qobjectStr );
 	classIntf.replace( TQRegExp( "\\$ARGS\\$" ), argsH );
 	classIntf.replace( TQRegExp( "\\$FILENAME\\$" ), header );
 	classIntf.replace( TQRegExp( "\\$NAMESPACEBEG\\$" ), namespaceBeg );
@@ -2102,45 +2081,45 @@ void CppNewClassDialog::ClassGenerator::beautifyHeader( TQString &templ, TQStrin
         TQString &namespaceEnd )
 {
 	if ( headerGuard.isEmpty() )
-		templ.replace( TQRegExp( "\\$HEADERGUARD\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$HEADERGUARD\\$[\\n ]*" ), TQString() );
 	if ( includeBaseHeader.isEmpty() )
-		templ.replace( TQRegExp( "\\$INCLUDEBASEHEADER\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$INCLUDEBASEHEADER\\$[\\n ]*" ), TQString() );
 	if ( author.isEmpty() )
-		templ.replace( TQRegExp( "\\$AUTHOR\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$AUTHOR\\$[\\n ]*" ), TQString() );
 	if ( doc.isEmpty() )
-		templ.replace( TQRegExp( "\\$DOC\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$DOC\\$[\\n ]*" ), TQString() );
 	if ( className.isEmpty() )
-		templ.replace( TQRegExp( "\\$CLASSNAME\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$CLASSNAME\\$[\\n ]*" ), TQString() );
 	if ( templateStr.isEmpty() )
-		templ.replace( TQRegExp( "\\$TEMPLATE\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$TEMPLATE\\$[\\n ]*" ), TQString() );
 	if ( baseclass.isEmpty() )
-		templ.replace( TQRegExp( "\\$BASECLASS\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$BASECLASS\\$[\\n ]*" ), TQString() );
 	if ( inheritance.isEmpty() )
-		templ.replace( TQRegExp( "\\$INHERITANCE\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$INHERITANCE\\$[\\n ]*" ), TQString() );
 	if ( qobjectStr.isEmpty() )
-		templ.replace( TQRegExp( "\\$QOBJECT\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$TQOBJECT\\$[\\n ]*" ), TQString() );
 	if ( args.isEmpty() )
-		templ.replace( TQRegExp( "\\$ARGS\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$ARGS\\$[\\n ]*" ), TQString() );
 	if ( header.isEmpty() )
-		templ.replace( TQRegExp( "\\$FILENAME\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$FILENAME\\$[\\n ]*" ), TQString() );
 	if ( namespaceBeg.isEmpty() )
-		templ.replace( TQRegExp( "\\$NAMESPACEBEG\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$NAMESPACEBEG\\$[\\n ]*" ), TQString() );
 	if ( constructors.isEmpty() )
-		templ.replace( TQRegExp( "\\$CONSTRUCTORDECLARATIONS\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$CONSTRUCTORDECLARATIONS\\$[\\n ]*" ), TQString() );
 	if ( advH_public.isEmpty() )
-		templ.replace( TQRegExp( "\\$PUBLICDECLARATIONS\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$PUBLICDECLARATIONS\\$[\\n ]*" ), TQString() );
 	if ( advH_public_slots.isEmpty() )
-		templ.replace( TQRegExp( "\\$PUBLICSLOTS\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$PUBLICSLOTS\\$[\\n ]*" ), TQString() );
 	if ( advH_protected.isEmpty() )
-		templ.replace( TQRegExp( "\\$PROTECTEDDECLARATIONS\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$PROTECTEDDECLARATIONS\\$[\\n ]*" ), TQString() );
 	if ( advH_protected_slots.isEmpty() )
-		templ.replace( TQRegExp( "\\$PROTECTEDSLOTS\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$PROTECTEDSLOTS\\$[\\n ]*" ), TQString() );
 	if ( advH_private.isEmpty() )
-		templ.replace( TQRegExp( "\\$PRIVATEDECLARATIONS\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$PRIVATEDECLARATIONS\\$[\\n ]*" ), TQString() );
 	if ( advH_private_slots.isEmpty() )
-		templ.replace( TQRegExp( "\\$PRIVATESLOTS\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$PRIVATESLOTS\\$[\\n ]*" ), TQString() );
 	if ( namespaceEnd.isEmpty() )
-		templ.replace( TQRegExp( "\\$NAMESPACEEND\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$NAMESPACEEND\\$[\\n ]*" ), TQString() );
 }
 
 
@@ -2148,19 +2127,19 @@ void CppNewClassDialog::ClassGenerator::beautifySource( TQString &templ, TQStrin
         TQString &constructors, TQString &advCpp, TQString &namespaceEnd, TQString &implementation )
 {
 	if ( header.isEmpty() )
-		templ.replace( TQRegExp( "\\$HEADER\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$HEADER\\$[\\n ]*" ), TQString() );
 	if ( className.isEmpty() )
-		templ.replace( TQRegExp( "\\$CLASSNAME\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$CLASSNAME\\$[\\n ]*" ), TQString() );
 	if ( namespaceBeg.isEmpty() )
-		templ.replace( TQRegExp( "\\$NAMESPACEBEG\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$NAMESPACEBEG\\$[\\n ]*" ), TQString() );
 	if ( constructors.isEmpty() )
-		templ.replace( TQRegExp( "\\$CONSTRUCTORDEFINITIONS\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$CONSTRUCTORDEFINITIONS\\$[\\n ]*" ), TQString() );
 	if ( advCpp.isEmpty() )
-		templ.replace( TQRegExp( "\\$DEFINITIONS\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$DEFINITIONS\\$[\\n ]*" ), TQString() );
 	if ( namespaceEnd.isEmpty() )
-		templ.replace( TQRegExp( "\\$NAMESPACEEND\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$NAMESPACEEND\\$[\\n ]*" ), TQString() );
 	if ( implementation.isEmpty() )
-		templ.replace( TQRegExp( "\\$FILENAME\\$[\\n ]*" ), TQString::null );
+		templ.replace( TQRegExp( "\\$FILENAME\\$[\\n ]*" ), TQString() );
 }
 
 TQString CppNewClassDialog::classNameFormatted( )
@@ -2185,7 +2164,7 @@ TQString CppNewClassDialog::templateStrFormatted( const TQString &name )
 	TQString className = name.simplifyWhiteSpace();
 	TQString temp = className;
 	className.replace( TQRegExp( "template *<.*> *(class *)?" ), "" );
-	TQString templateStr = temp.replace( TQRegExp( QRegExp_escape( className ) ), "" );
+	TQString templateStr = temp.replace( TQRegExp( TQRegExp_escape( className ) ), "" );
 	templateStr.replace( TQRegExp( " *class *$" ), "" );
 	return templateStr;
 }
@@ -2200,7 +2179,7 @@ TQString CppNewClassDialog::templateParamsFormatted( const TQString &name )
 	TQString className = name.simplifyWhiteSpace();
 	TQString temp = className;
 	className.replace( TQRegExp( "template *<.*> *(class *)?" ), "" );
-	TQString templateStr = temp.replace( TQRegExp( QRegExp_escape( className ) ), "" );
+	TQString templateStr = temp.replace( TQRegExp( TQRegExp_escape( className ) ), "" );
 	templateStr.replace( TQRegExp( " *class *$" ), "" );
 
 	TQString templateParams = templateStr;
@@ -2216,7 +2195,7 @@ TQString CppNewClassDialog::templateActualParamsFormatted( const TQString & name
 	TQString className = name.simplifyWhiteSpace();
 	TQString temp = className;
 	className.replace( TQRegExp( "<.*> *" ), "" );
-	TQString templateStr = temp.replace( TQRegExp( QRegExp_escape( className ) ), "" );
+	TQString templateStr = temp.replace( TQRegExp( TQRegExp_escape( className ) ), "" );
 	return templateStr;
 }
 
