@@ -92,7 +92,7 @@ DebuggerPart::DebuggerPart( TQObject *parent, const char *name, const TQStringLi
     statusBarIndicator = new LabelWithDoubleClick(
         " ", mainWindow()->statusBar());
     statusBarIndicator->setFixedWidth(15);
-    statusBarIndicator->setAlignment(Qt::AlignCenter);
+    statusBarIndicator->tqsetAlignment(TQt::AlignCenter);
     mainWindow()->statusBar()->addWidget(statusBarIndicator, 0, true);
     statusBarIndicator->show();
 
@@ -491,7 +491,7 @@ void DebuggerPart::contextMenu(TQPopupMenu *popup, const Context *context)
     int index = running ? 0 : -1;
     if (running)
     {
-        // Too bad we can't add TQAction to popup menu in Qt3.
+        // Too bad we can't add TQAction to popup menu in TQt3.
         KAction* act = actionCollection()->action("debug_runtocursor");
         Q_ASSERT(act);
         if (act)
@@ -500,7 +500,7 @@ void DebuggerPart::contextMenu(TQPopupMenu *popup, const Context *context)
                                         this, TQT_SLOT(slotRunToCursor()),
                                         0, -1, index);
 
-            popup->setWhatsThis(id, act->whatsThis());
+            popup->tqsetWhatsThis(id, act->whatsThis());
             index += running;
         }
     }
@@ -510,21 +510,21 @@ void DebuggerPart::contextMenu(TQPopupMenu *popup, const Context *context)
                                     this, TQT_SLOT(toggleBreakpoint()),
                                     0, -1, index);
         index += running;
-        popup->setWhatsThis(id, i18n("<b>Toggle breakpoint</b><p>Toggles breakpoint at the current line."));
+        popup->tqsetWhatsThis(id, i18n("<b>Toggle breakpoint</b><p>Toggles breakpoint at the current line."));
     }
     if (!m_contextIdent.isEmpty())
     {
         TQString squeezed = KStringHandler::csqueeze(m_contextIdent, 30);
-        int id = popup->insertItem( i18n("Evaluate: %1").arg(squeezed),
+        int id = popup->insertItem( i18n("Evaluate: %1").tqarg(squeezed),
                                     this, TQT_SLOT(contextEvaluate()),
                                     0, -1, index);
         index += running;
-        popup->setWhatsThis(id, i18n("<b>Evaluate expression</b><p>Shows the value of the expression under the cursor."));
-        int id2 = popup->insertItem( i18n("Watch: %1").arg(squeezed),
+        popup->tqsetWhatsThis(id, i18n("<b>Evaluate expression</b><p>Shows the value of the expression under the cursor."));
+        int id2 = popup->insertItem( i18n("Watch: %1").tqarg(squeezed),
                                      this, TQT_SLOT(contextWatch()),
                                     0, -1, index);
         index += running;
-        popup->setWhatsThis(id2, i18n("<b>Watch expression</b><p>Adds an expression under the cursor to the Variables/Watch list."));
+        popup->tqsetWhatsThis(id2, i18n("<b>Watch expression</b><p>Adds an expression under the cursor to the Variables/Watch list."));
     }
     if (running)
         popup->insertSeparator(index);
@@ -589,8 +589,8 @@ void DebuggerPart::setupController()
              disassembleWidget,     TQT_SLOT(slotShowStepInSource(const TQString&, int, const TQString&)));
 
     // controller -> this
-    connect( controller,            TQT_SIGNAL(dbgStatus(const TQString&, int)),
-             this,                  TQT_SLOT(slotStatus(const TQString&, int)));
+    connect( controller,            TQT_SIGNAL(dbgtqStatus(const TQString&, int)),
+             this,                  TQT_SLOT(slottqStatus(const TQString&, int)));
     connect( controller,            TQT_SIGNAL(showStepInSource(const TQString&, int, const TQString&)),
              this,                  TQT_SLOT(slotShowStep(const TQString&, int)));
     connect( controller,            TQT_SIGNAL(debuggerAbnormalExit()),
@@ -613,16 +613,16 @@ void DebuggerPart::setupController()
 
     connect( controller,            TQT_SIGNAL(gdbStderr(const char*)),
              gdbOutputWidget,       TQT_SLOT(slotReceivedStderr(const char*)) );
-    connect( controller,            TQT_SIGNAL(dbgStatus(const TQString&, int)),
-             gdbOutputWidget,       TQT_SLOT(slotDbgStatus(const TQString&, int)));
+    connect( controller,            TQT_SIGNAL(dbgtqStatus(const TQString&, int)),
+             gdbOutputWidget,       TQT_SLOT(slotDbgtqStatus(const TQString&, int)));
 
     // controller -> viewerWidget
-    connect( controller, TQT_SIGNAL(dbgStatus(const TQString&, int)),
+    connect( controller, TQT_SIGNAL(dbgtqStatus(const TQString&, int)),
              viewerWidget, TQT_SLOT(slotDebuggerState(const TQString&, int)));
 
 
     connect(statusBarIndicator, TQT_SIGNAL(doubleClicked()),
-            controller, TQT_SLOT(explainDebuggerStatus()));
+            controller, TQT_SLOT(explainDebuggertqStatus()));
 
 }
 
@@ -659,7 +659,7 @@ bool DebuggerPart::startDebugger()
         {
             KMessageBox::information(
                 mainWindow()->main(),
-                i18n("Could not locate the debugging shell '%1'.").arg( shell_without_args ),
+                i18n("Could not locate the debugging shell '%1'.").tqarg( shell_without_args ),
                 i18n("Debugging Shell Not Found"), "gdb_error" );
             return false;
         }
@@ -697,7 +697,7 @@ bool DebuggerPart::startDebugger()
 
         if (DomUtil::readBoolEntry(*projectDom(), "/kdevdebugger/general/floatingtoolbar", false))
         {
-#ifndef QT_MAC
+#ifndef TQT_MAC
             floatingToolBar = new DbgToolBar(this, mainWindow()->main());
             floatingToolBar->show();
 #endif
@@ -955,7 +955,7 @@ void DebuggerPart::slotExamineCore()
     if (coreFile.isNull())
         return;
 
-    mainWindow()->statusBar()->message(i18n("Examining core file %1").arg(coreFile), 1000);
+    mainWindow()->statusBar()->message(i18n("Examining core file %1").tqarg(coreFile), 1000);
 
     startDebugger();
     controller->slotCoreFile(coreFile);
@@ -976,7 +976,7 @@ void DebuggerPart::slotAttachProcess()
 
 bool DebuggerPart::attachProcess(int pid)
 {
-    mainWindow()->statusBar()->message(i18n("Attaching to process %1").arg(pid), 1000);
+    mainWindow()->statusBar()->message(i18n("Attaching to process %1").tqarg(pid), 1000);
 
     bool ret = startDebugger();
     controller->slotAttachTo(pid);
@@ -1092,7 +1092,7 @@ void DebuggerPart::slotRefreshBPState( const Breakpoint& BP)
     }
 }
 
-void DebuggerPart::slotStatus(const TQString &msg, int state)
+void DebuggerPart::slottqStatus(const TQString &msg, int state)
 {
     TQString stateIndicator, stateIndicatorFull;
 
