@@ -49,9 +49,9 @@ FramestackWidget::FramestackWidget(GDBController* controller,
     setRootIsDecorated(true);
     setSorting(-1);
     setSelectionMode(Single);
-    addColumn(TQString::null); // Frame number
-    addColumn(TQString::null); // function name/address
-    addColumn(TQString::null); // source
+    addColumn(TQString()); // Frame number
+    addColumn(TQString()); // function name/address
+    addColumn(TQString()); // source
     header()->hide();
 
 
@@ -111,7 +111,7 @@ void FramestackWidget::slotSelectionChanged(TQListViewItem *thisItem)
                 if (frame->threadNo() != -1)
                     controller_->addCommand(
                         new GDBCommand(TQString("-thread-select %1")
-                                       .arg(frame->threadNo()).ascii()));
+                                       .tqarg(frame->threadNo()).ascii()));
 
                viewedThread_ = findThread(frame->threadNo());
                getBacktrace(frame->frameNo(), frame->frameNo() + frameChunk_);
@@ -208,7 +208,7 @@ void FramestackWidget::getBacktrace(int min_frame, int max_frame)
     maxFrame_ = max_frame;
 
     controller_->addCommand(
-        new GDBCommand(TQString("-stack-info-depth %1").arg(max_frame+1),
+        new GDBCommand(TQString("-stack-info-depth %1").tqarg(max_frame+1),
                        this, 
                        &FramestackWidget::handleStackDepth));        
 }
@@ -224,7 +224,7 @@ void FramestackWidget::handleStackDepth(const GDBMI::ResultRecord& r)
     //add the following command to the front, so noone switches threads in between
     controller_->addCommandToFront(
         new GDBCommand(TQString("-stack-list-frames %1 %2")
-                       .arg(minFrame_).arg(maxFrame_),
+                       .tqarg(minFrame_).tqarg(maxFrame_),
                        this, &FramestackWidget::parseGDBBacktraceList));    
 }
 
@@ -236,7 +236,7 @@ void FramestackWidget::getBacktraceForThread(int threadNo)
         // Switch to the target thread.
         controller_->addCommand(
             new GDBCommand(TQString("-thread-select %1")
-                           .arg(threadNo).ascii()));
+                           .tqarg(threadNo).ascii()));
 
         viewedThread_ = findThread(threadNo);
     }
@@ -248,7 +248,7 @@ void FramestackWidget::getBacktraceForThread(int threadNo)
         // Switch back to the original thread.
         controller_->addCommand(
             new GDBCommand(TQString("-thread-select %1")
-                           .arg(currentThread).ascii()));
+                           .tqarg(currentThread).ascii()));
     }
 }
 
@@ -274,13 +274,13 @@ void FramestackWidget::handleThreadList(const GDBMI::ResultRecord& r)
             TQString id = ids.results[i]->value->literal();
 
             controller_->addCommand(
-                new GDBCommand(TQString("-thread-select %1").arg(id).ascii(), 
+                new GDBCommand(TQString("-thread-select %1").tqarg(id).ascii(), 
                                this, &FramestackWidget::handleThread));
         }
 
         controller_->addCommand(
             new GDBCommand(TQString("-thread-select %1")
-                           .arg(controller_->currentThread()).ascii()));
+                           .tqarg(controller_->currentThread()).ascii()));
     }
 
     // Get backtrace for the current thread. We need to do this
@@ -558,7 +558,7 @@ ThreadStackItem::ThreadStackItem(FramestackWidget *parent, unsigned threadNo)
 : TQListViewItem(parent),
   threadNo_(threadNo)
 {
-    setText(0, i18n("Thread %1").arg(threadNo_));
+    setText(0, i18n("Thread %1").tqarg(threadNo_));
     setExpandable(true);
 }
 
