@@ -56,7 +56,7 @@ enum Column {
     Control     = 0,
     Enable      = 1,
     Type        = 2,
-    Status      = 3,
+    tqStatus      = 3,
     Location    = 4,
     Condition   = 5,
     IgnoreCount = 6,
@@ -76,7 +76,7 @@ static int m_activeFlag = 0;
 /***************************************************************************/
 /***************************************************************************/
 
-class BreakpointTableRow : public QTableItem
+class BreakpointTableRow : public TQTableItem
 {
 public:
 
@@ -161,7 +161,7 @@ void BreakpointTableRow::setRow()
 
         TQString status=m_breakpoint->statusDisplay(m_activeFlag);
 
-        table()->setText(row(), Status, status);
+        table()->setText(row(), tqStatus, status);
         table()->setText(row(), Condition, m_breakpoint->conditional());
         table()->setText(row(), IgnoreCount, TQString::number(m_breakpoint->ignoreCount() ));
         table()->setText(row(), Hits, TQString::number(m_breakpoint->hits() ));
@@ -183,7 +183,7 @@ void BreakpointTableRow::setRow()
 
         table()->setText(row(), Type, displayType);
         table()->adjustColumn(Type);
-        table()->adjustColumn(Status);
+        table()->adjustColumn(tqStatus);
         table()->adjustColumn(Location);
         table()->adjustColumn(Hits);
         table()->adjustColumn(IgnoreCount);
@@ -208,7 +208,7 @@ controller_(controller)
 
     m_table->hideColumn(Control);
     m_table->setColumnReadOnly(Type, true);
-    m_table->setColumnReadOnly(Status, true);
+    m_table->setColumnReadOnly(tqStatus, true);
     m_table->setColumnReadOnly(Hits, true);
     m_table->setColumnWidth( Enable, 20);
 
@@ -216,7 +216,7 @@ controller_(controller)
 
     header->setLabel( Enable,       "" );
     header->setLabel( Type,         i18n("Type") );
-    header->setLabel( Status,       i18n("Status") );
+    header->setLabel( tqStatus,       i18n("Status") );
     header->setLabel( Location,     i18n("Location") );
     header->setLabel( Condition,    i18n("Condition") );
     header->setLabel( IgnoreCount,  i18n("Ignore Count") );
@@ -238,12 +238,12 @@ controller_(controller)
     m_ctxMenu->insertItem( i18n( "Show text" ),    BW_ITEM_Show );
     int edit_id =
         m_ctxMenu->insertItem( i18n( "Edit" ),    BW_ITEM_Edit );
-    m_ctxMenu->setAccel(Qt::Key_Enter, edit_id);
+    m_ctxMenu->setAccel(TQt::Key_Enter, edit_id);
     m_ctxMenu->insertItem( i18n( "Disable" ), BW_ITEM_Disable );
     int del_id =
         m_ctxMenu->insertItem( SmallIcon("breakpoint_delete"),
                                i18n( "Delete" ),  BW_ITEM_Delete );
-    m_ctxMenu->setAccel(Qt::Key_Delete, del_id);
+    m_ctxMenu->setAccel(TQt::Key_Delete, del_id);
     m_ctxMenu->insertSeparator();
     m_ctxMenu->insertItem( i18n( "Disable all"), BW_ITEM_DisableAll );
     m_ctxMenu->insertItem( i18n( "Enable all"), BW_ITEM_EnableAll );
@@ -377,10 +377,10 @@ void GDBBreakpointWidget::slotWatchpointHit(int id,
              "Address: 0x%2<br>"
              "Old value: %3<br>"
              "New value: %4")
-        .arg(b->varName())
-        .arg(b->address(), 0, 16)
-        .arg(oldValue)
-        .arg(newValue));
+        .tqarg(b->varName())
+        .tqarg(b->address(), 0, 16)
+        .tqarg(oldValue)
+        .tqarg(newValue));
 }
 
 /***************************************************************************/
@@ -557,7 +557,7 @@ void GDBBreakpointWidget::handleBreakpointList(const GDBMI::ResultRecord& r)
             if (b.hasField("cond"))
                 bp->setConditional(b["cond"].literal());
             else
-                bp->setConditional(TQString::null);
+                bp->setConditional(TQString());
             btr->setRow();
             emit publishBPState(*bp);
         }
@@ -1031,7 +1031,7 @@ void GDBBreakpointWidget::editTracing(TQTableItem* item)
 
     // Note: change cell text here and explicitly call slotNewValue here.
     // We want this signal to be emitted when we close the tracing dialog
-    // and not when we select some other cell, as happens in Qt by default.
+    // and not when we select some other cell, as happens in TQt by default.
     if (r == TQDialog::Accepted)
     {
         // The dialog has modified "btr->breakpoint()" already.
@@ -1191,7 +1191,7 @@ void GDBBreakpointWidget::focusInEvent( TQFocusEvent */* e*/ )
     // Without the following 'if', when we first open the breakpoints
     // widget, the background is all black. This happens only with
     //    m_table->setFocusStyle(TQTable::FollowStyle);
-    // in constructor, so I suspect Qt bug. But anyway, without
+    // in constructor, so I suspect TQt bug. But anyway, without
     // current cell keyboard actions like Enter for edit won't work,
     // so keyboard focus does not makes much sense.
     if (m_table->currentRow() == -1 ||
@@ -1213,28 +1213,28 @@ TQWidget* ComplexEditCell::createEditor() const
 {
     TQHBox* box = new TQHBox( table()->viewport() );
     box->setPaletteBackgroundColor(
-               table()->palette().active().highlight());
+               table()->tqpalette().active().highlight());
 
     label_ = new TQLabel(text(), box, "label");
-    label_->setBackgroundMode(Qt::PaletteHighlight);
+    label_->setBackgroundMode(TQt::PaletteHighlight);
     // Sorry for hardcode, but '2' is already hardcoded in
-    // Qt source, in TQTableItem::paint. Since I don't want the
+    // TQt source, in TQTableItem::paint. Since I don't want the
     // text to jump 2 pixels to the right when editor is activated,
     // need to set the same indent for label.
     label_->setIndent(2);
     TQPalette p = label_->palette();
 
     p.setColor(TQPalette::Active, TQColorGroup::Foreground,
-               table()->palette().active().highlightedText());
+               table()->tqpalette().active().highlightedText());
     p.setColor(TQPalette::Inactive, TQColorGroup::Foreground,
-               table()->palette().active().highlightedText());
+               table()->tqpalette().active().highlightedText());
 
     label_->setPalette(p);
 
     TQPushButton* b = new TQPushButton("...", box);
-    // This is exactly what is done in QDesigner source in the
+    // This is exactly what is done in TQDesigner source in the
     // similar context. Haven't had any success making the good look
-    // with layout, I suppose that sizeHint for button is always larger
+    // with tqlayout, I suppose that tqsizeHint for button is always larger
     // than 20.
     b->setFixedWidth( 20 );
 
