@@ -4,9 +4,10 @@
 
 #include <tqlabel.h>
 
-class LabelWithDoubleClick : public QLabel
+class LabelWithDoubleClick : public TQLabel
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     LabelWithDoubleClick(const TQString& s, TQWidget* parent);
 
