@@ -9,8 +9,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef KDEVQTIMPORTER_H
-#define KDEVQTIMPORTER_H
+#ifndef KDEVTQTIMPORTER_H
+#define KDEVTQTIMPORTER_H
 
 #include <kdevpcsimporter.h>
 #include <tqguardedptr.h>
@@ -21,11 +21,12 @@ class KTempFile;
 class KDevQt4Importer : public KDevPCSImporter
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     KDevQt4Importer( TQObject* parent=0, const char* name=0, const TQStringList& args=TQStringList() );
     virtual ~KDevQt4Importer();
 
-    virtual TQString dbName() const { return TQString::fromLatin1("Qt4"); }
+    virtual TQString dbName() const { return TQString::tqfromLatin1("TQt4"); }
     virtual TQStringList fileList();
     virtual TQStringList includePaths();
 
