@@ -9,8 +9,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef KDEVQTIMPORTER_H
-#define KDEVQTIMPORTER_H
+#ifndef KDEVTQTIMPORTER_H
+#define KDEVTQTIMPORTER_H
 
 #include <kdevpcsimporter.h>
 #include <tqguardedptr.h>
@@ -20,11 +20,12 @@ class SettingsDialog;
 class KDevQtImporter : public KDevPCSImporter
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     KDevQtImporter( TQObject* parent=0, const char* name=0, const TQStringList& args=TQStringList() );
     virtual ~KDevQtImporter();
 
-    virtual TQString dbName() const { return TQString::fromLatin1("Qt"); }
+    virtual TQString dbName() const { return TQString::tqfromLatin1("TQt"); }
     virtual TQStringList fileList();
     virtual TQStringList includePaths();
 
