@@ -47,7 +47,7 @@ TQString BuiltinTypes::comment( const TypeDesc& desc ) {
   if( it != m_types.end() ) {
     return *it;
   } else {
-    return TQString::null;
+    return TQString();
   }
 }
 
@@ -301,7 +301,7 @@ TQString SimpleTypeImpl::operatorToString( Operator op ) {
     case ParenOp:
     return "paren-operator";
     default:
-    return TQString( "%1" ).arg( ( long ) op );
+    return TQString( "%1" ).tqarg( ( long ) op );
   };
 }
 
