@@ -214,7 +214,7 @@ class SimpleTypeConfiguration {
         SimpleType::destroyStore();
       }
     }
-    void invalidate() {
+    void tqinvalidate() {
       m_invalid = true;
     }
 };
@@ -251,7 +251,7 @@ class SimpleTypeImpl : public KShared {
 
 	///Returns the template-specialization-string for classes
 	virtual TQString specialization() const {
-		return TQString::null;
+		return TQString();
 	}
 
     class TemplateParamInfo {
@@ -786,24 +786,24 @@ class SimpleTypeImpl : public KShared {
 
 
 class TypeTrace {
-    TQValueList<QPair< SimpleTypeImpl::MemberInfo, TypeDesc> > m_trace;
+    TQValueList<TQPair< SimpleTypeImpl::MemberInfo, TypeDesc> > m_trace;
   public:
 
-    TQValueList<QPair< SimpleTypeImpl::MemberInfo, TypeDesc> >& trace() {
+    TQValueList<TQPair< SimpleTypeImpl::MemberInfo, TypeDesc> >& trace() {
       return m_trace;
     };
 
     void prepend( const SimpleTypeImpl::MemberInfo& t, const TypeDesc& tail = TypeDesc() ) {
-      m_trace.push_front( QPair< SimpleTypeImpl::MemberInfo, TypeDesc>( t, tail ) );
+      m_trace.push_front( TQPair< SimpleTypeImpl::MemberInfo, TypeDesc>( t, tail ) );
     }
 
 	void prepend( const TypeTrace& trace, int indent = 0 ) {
 /*		if( indent != 0 ) {
 		TQString ind;
 			for( int a = 0; a < indent; a++ ) ind += " ";
-			for( TQValueList<QPair< SimpleTypeImpl::MemberInfo, TypeDesc> >::const_iterator it = trace.m_trace.end(); it != trace.m_trace.begin(); ) {
+			for( TQValueList<TQPair< SimpleTypeImpl::MemberInfo, TypeDesc> >::const_iterator it = trace.m_trace.end(); it != trace.m_trace.begin(); ) {
 				--it;
-				QPair<SimpleTypeImpl::MemberInfo, TypeDesc> item = *it;
+				TQPair<SimpleTypeImpl::MemberInfo, TypeDesc> item = *it;
 				item.second.prependDecoration( ind );
 				m_trace.push_front( item );
 			}
