@@ -59,7 +59,7 @@ void TagCreator::parseDeclaration( DeclarationAST* ast )
 void TagCreator::parseTranslationUnit( const ParsedFile& ast )
 {
 	m_currentScope.clear();
-	m_currentAccess = TQString::null;
+	m_currentAccess = TQString();
 	m_inSlots = false;
 	m_inSignals = false;
 	m_anon = 0;
@@ -78,9 +78,9 @@ void TagCreator::parseTranslationUnit( const ParsedFile& ast )
 	ast.write( stream );
 	tag.setAttribute( "cppparsedfile", data );
 	tag.setAttribute( "includedFrom", ast.includedFrom() );
-	tag.setAttribute( "skippedLines", TQString("%1").arg( ast.skippedLines()) );
-	tag.setAttribute( "macroValueHash", TQString("%1").arg( ast.usedMacros().valueHash()) );
-	tag.setAttribute( "macroIdHash", TQString("%1").arg( ast.usedMacros().idHash() ) );
+	tag.setAttribute( "skippedLines", TQString("%1").tqarg( ast.skippedLines()) );
+	tag.setAttribute( "macroValueHash", TQString("%1").tqarg( ast.usedMacros().valueHash()) );
+	tag.setAttribute( "macroIdHash", TQString("%1").tqarg( ast.usedMacros().idHash() ) );
 	
   	tag.setScope( m_currentScope );
   	if( !ast->comment().isEmpty() )
@@ -748,7 +748,7 @@ void TagCreator::parseFunctionArguments( Tag& tag, DeclaratorAST* declarator )
 			
 			TQString name;
 			if( param->declarator() ){
-				name = declaratorToString(param->declarator(), TQString::null, true );
+				name = declaratorToString(param->declarator(), TQString(), true );
 			}
 			
 			TQString type = typeOfDeclaration( param->typeSpec(), param->declarator() );
@@ -773,7 +773,7 @@ void TagCreator::parseFunctionArguments( Tag& tag, DeclaratorAST* declarator )
 TQString TagCreator::typeOfDeclaration( TypeSpecifierAST* typeSpec, DeclaratorAST* declarator )
 {
 	if( !typeSpec || !declarator )
-		return TQString::null;
+		return TQString();
 	
 	TQString text;
 	
@@ -878,7 +878,7 @@ TQString TagUtils::accessToString( int id )
 	if( l.at(id-1) != l.end() )
 		return l[ id-1 ];
 	
-	return TQString::null;
+	return TQString();
 }
 
 //kate: indent-mode csands; tab-width 4; space-indent off;
