@@ -103,7 +103,7 @@
  *		o  supports UNICODE?
  *		   Using Unicode charVocabulay makes code file big, but only
  *		   in the bitsets at the end. I need to make ANTLR generate
- *		   unicode bitsets more efficiently.
+ *		   tqunicode bitsets more efficiently.
  * Version 1.19 (April 25, 2002)
  *		Terence added in nice fixes by John Pybus concerning floating
  *		constants and problems with super() calls.  John did a nice
@@ -131,7 +131,7 @@
  *
  * Version tracking now done with following ID:
  *
- * $Id: JavaRecognizer.hpp 1157658 2010-07-31 19:56:07Z tpearson $
+ * $Id: JavaRecognizer.hpp 1236710 2011-06-14 16:45:05Z tpearson $
  *
  * This grammar is in the PUBLIC DOMAIN
  */
