@@ -267,7 +267,7 @@ void JavaSupportPart::activePartChanged(KParts::Part *part)
     m_activeSelection = dynamic_cast<KTextEditor::SelectionInterface*>( part );
     m_activeViewCursor = part ? dynamic_cast<KTextEditor::ViewCursorInterface*>( m_activeView ) : 0;
 
-    m_activeFileName = TQString::null;
+    m_activeFileName = TQString();
 
     if (m_activeDocument) {
 	m_activeFileName = URLUtil::canonicalPath( m_activeDocument->url().path() );
@@ -481,25 +481,6 @@ void JavaSupportPart::initialParse( )
     return;
 }
 
-#if QT_VERSION < 0x030100
-// Taken from qt-3.2/tools/qdatetime.java/TQDateTime::toTime_t() and modified for normal function
-uint toTime_t(TQDateTime t)
-{
-    tm brokenDown;
-    brokenDown.tm_sec = t.time().second();
-    brokenDown.tm_min = t.time().minute();
-    brokenDown.tm_hour = t.time().hour();
-    brokenDown.tm_mday = t.date().day();
-    brokenDown.tm_mon = t.date().month() - 1;
-    brokenDown.tm_year = t.date().year() - 1900;
-    brokenDown.tm_isdst = -1;
-    int secsSince1Jan1970UTC = (int) mktime( &brokenDown );
-    if ( secsSince1Jan1970UTC < -1 )
-    secsSince1Jan1970UTC = -1;
-    return (uint) secsSince1Jan1970UTC;
-}
-#endif
-
 bool
 JavaSupportPart::parseProject( )
 {
@@ -524,7 +505,7 @@ JavaSupportPart::parseProject( )
     TQDir d( m_projectDirectory );
 
     TQDataStream stream;
-    TQMap< TQString, QPair<uint, uint> > pcs;
+    TQMap< TQString, TQPair<uint, uint> > pcs;
 
     if( TQFileInfo( project()->projectDirectory() + "/" +
 			    project()->projectName().lower() + ".kdevelop.pcs" ).exists() )
@@ -550,7 +531,7 @@ JavaSupportPart::parseProject( )
 		uint offset;
 
 		stream >> fn >> ts >> offset;
-		pcs[ fn ] = qMakePair( ts, offset );
+		pcs[ fn ] = tqMakePair( ts, offset );
 	    }
 	}
     }
@@ -578,12 +559,8 @@ JavaSupportPart::parseProject( )
 		if( m_timestamp.contains(absFilePath) && m_timestamp[absFilePath] == t )
 		    continue;
 
-#if QT_VERSION >= 0x030100
 		if( pcs.contains(absFilePath) && t.toTime_t() == pcs[absFilePath].first ){
-#else
-		if( pcs.contains(absFilePath) && toTime_t(t) == pcs[absFilePath].first ){
-#endif
-		    stream.device()->at( pcs[absFilePath].second );
+		    stream.tqdevice()->at( pcs[absFilePath].second );
 		    FileDom file = codeModel()->create<FileModel>();
 		    file->read( stream );
 		    codeModel()->addFile( file );
@@ -792,7 +769,7 @@ void JavaSupportPart::setPcsVersion( int version )
 
 TQString JavaSupportPart::formatTag( const Tag & /*inputTag*/ )
 {
-    return TQString::null;
+    return TQString();
 }
 
 void JavaSupportPart::removeWithReferences( const TQString & fileName )
@@ -882,26 +859,22 @@ void JavaSupportPart::saveProjectSourceInfo( )
     stream << int( fileList.size() );
     for( FileList::ConstIterator it=fileList.begin(); it!=fileList.end(); ++it ){
 	const FileDom dom = (*it);
-#if QT_VERSION >= 0x030100
   stream << dom->name() << m_timestamp[ dom->name() ].toTime_t();
-#else
-  stream << dom->name() << toTime_t(m_timestamp[ dom->name() ]);
-#endif
-	offsets.insert( dom->name(), stream.device()->at() );
+	offsets.insert( dom->name(), stream.tqdevice()->at() );
 	stream << (uint)0; // dummy offset
     }
 
     for( FileList::ConstIterator it=fileList.begin(); it!=fileList.end(); ++it ){
 	const FileDom dom = (*it);
-	int offset = stream.device()->at();
+	int offset = stream.tqdevice()->at();
 
 	dom->write( stream );
 
-	int end = stream.device()->at();
+	int end = stream.tqdevice()->at();
 
-	stream.device()->at( offsets[dom->name()] );
+	stream.tqdevice()->at( offsets[dom->name()] );
 	stream << offset;
-	stream.device()->at( end );
+	stream.tqdevice()->at( end );
     }
 }
 
