@@ -26,9 +26,10 @@ The code completion engine for Javascript.
  
 @author ian reinhart geiser
 */
-class JSCodeCompletion : public QObject
+class JSCodeCompletion : public TQObject
 {
 		Q_OBJECT
+  TQ_OBJECT
 	public:
 		JSCodeCompletion(TQObject *parent = 0, const char *name = 0);
 
