@@ -234,7 +234,7 @@ bool PHPCodeCompletion::checkForStaticFunction(TQString line, int col) {
 
          for (funcIt = funcList.begin(); funcIt != funcList.end(); ++funcIt) {
             FunctionDom nFunc = *funcIt;
-            if ((function.isEmpty() || nFunc->name().startsWith(function, FALSE)) && nFunc->isStatic()) {
+            if ((function.isEmpty() || nFunc->name().tqstartsWith(function, FALSE)) && nFunc->isStatic()) {
                KTextEditor::CompletionEntry e;
                e.prefix = nClass->name() + " ::";
                e.text = nFunc->name();
@@ -362,7 +362,7 @@ TQValueList<KTextEditor::CompletionEntry> PHPCodeCompletion::getClasses(TQString
    ClassList::Iterator classIt;
    for (classIt = classList.begin(); classIt != classList.end(); ++classIt) {
       ClassDom nClass = *classIt;
-      if (name == NULL || name.isEmpty() || nClass->name().startsWith(name, FALSE)) {
+      if (name == NULL || name.isEmpty() || nClass->name().tqstartsWith(name, FALSE)) {
          KTextEditor::CompletionEntry e;
 
          TQStringList::Iterator it = added.find(nClass->name());
@@ -383,7 +383,7 @@ TQValueList<KTextEditor::CompletionEntry> PHPCodeCompletion::getFunctionsAndVars
    if (classname.isEmpty()) {
       TQValueList<FunctionCompletionEntry>::Iterator it;
       for( it = m_globalFunctions.begin(); it != m_globalFunctions.end(); ++it ) {
-         if((*it).text.startsWith(function, FALSE)){
+         if((*it).text.tqstartsWith(function, FALSE)){
             KTextEditor::CompletionEntry e;
             e = (*it);
             list.append(e);
@@ -393,7 +393,7 @@ TQValueList<KTextEditor::CompletionEntry> PHPCodeCompletion::getFunctionsAndVars
       FunctionList methodList = m_model->globalNamespace()->functionList();
       FunctionList::Iterator methodIt;
       for (methodIt = methodList.begin(); methodIt != methodList.end(); ++methodIt) {
-         if ((*methodIt)->name().startsWith(function, FALSE)){
+         if ((*methodIt)->name().tqstartsWith(function, FALSE)){
             KTextEditor::CompletionEntry e;
             e.text = (*methodIt)->name();
             ArgumentDom pArg = (*methodIt)->argumentList().first();
@@ -416,7 +416,7 @@ TQValueList<KTextEditor::CompletionEntry> PHPCodeCompletion::getFunctionsAndVars
       FunctionList::Iterator methodIt;
       for (methodIt = methodList.begin(); methodIt != methodList.end(); ++methodIt) {
          FunctionDom pMethod = *methodIt;
-         if (function.isEmpty() || pMethod->name().startsWith(function, FALSE)) {
+         if (function.isEmpty() || pMethod->name().tqstartsWith(function, FALSE)) {
             KTextEditor::CompletionEntry e;
             ArgumentDom arg = pMethod->argumentList().first();
 
@@ -430,7 +430,7 @@ TQValueList<KTextEditor::CompletionEntry> PHPCodeCompletion::getFunctionsAndVars
       VariableList::Iterator attrIt;
       for (attrIt = attrList.begin(); attrIt != attrList.end(); ++attrIt) {
          VariableDom pVar = *attrIt;
-         if (function.isEmpty() || pVar->name().startsWith(function, FALSE)) {
+         if (function.isEmpty() || pVar->name().tqstartsWith(function, FALSE)) {
             KTextEditor::CompletionEntry e;
             e.prefix = nClass->name() + " ::";
             e.text = pVar->name();
@@ -526,7 +526,7 @@ TQString PHPCodeCompletion::getCurrentClassName() {
             return Class.cap(2);
       }
    }
-   return TQString::null;
+   return TQString();
 }
 
 TQString PHPCodeCompletion::getClassName(TQString varName, TQString classname) {
@@ -706,7 +706,7 @@ kdDebug(9018) << "checkForArgHint 0 " << line <<  endl;
 }
 
 void PHPCodeCompletion::setStatusBar(TQString expr, TQString type) {
-   m_phpSupport->mainWindow()->statusBar()->message( i18n("Type of %1 is %2").arg(expr).arg(type), 1000 );
+   m_phpSupport->mainWindow()->statusBar()->message( i18n("Type of %1 is %2").tqarg(expr).tqarg(type), 1000 );
 }
 
 #include "phpcodecompletion.moc"
