@@ -312,16 +312,16 @@ void RubyDebuggerPart::contextMenu(TQPopupMenu *popup, const Context *context)
     if (econtext->url().isLocalFile())
     {
         int id = popup->insertItem( i18n("Toggle Breakpoint"), this, TQT_SLOT(toggleBreakpoint()) );
-        popup->setWhatsThis(id, i18n("<b>Toggle breakpoint</b><p>Toggles breakpoint at the current line."));
+        popup->tqsetWhatsThis(id, i18n("<b>Toggle breakpoint</b><p>Toggles breakpoint at the current line."));
     }
     if (!m_contextIdent.isEmpty())
     {
         TQString squeezed = KStringHandler::csqueeze(m_contextIdent, 30);
-        int id = popup->insertItem( i18n("Watch: %1").arg(squeezed), this, TQT_SLOT(contextWatch()) );
-        popup->setWhatsThis(id, i18n("<b>Watch</b><p>Adds an expression under the cursor to the Variables/Watch list."));
+        int id = popup->insertItem( i18n("Watch: %1").tqarg(squeezed), this, TQT_SLOT(contextWatch()) );
+        popup->tqsetWhatsThis(id, i18n("<b>Watch</b><p>Adds an expression under the cursor to the Variables/Watch list."));
         
-		id = popup->insertItem( i18n("Inspect: %1").arg(squeezed), this, TQT_SLOT(contextRubyInspect()) );
-        popup->setWhatsThis(id, i18n("<b>Inspect</b><p>Evaluates an expression under the cursor."));
+		id = popup->insertItem( i18n("Inspect: %1").tqarg(squeezed), this, TQT_SLOT(contextRubyInspect()) );
+        popup->tqsetWhatsThis(id, i18n("<b>Inspect</b><p>Evaluates an expression under the cursor."));
     }
 }
 
@@ -412,8 +412,8 @@ void RubyDebuggerPart::setupController()
 
 
     // controller -> this
-    connect( controller,            TQT_SIGNAL(dbgStatus(const TQString&, int)),
-             this,                  TQT_SLOT(slotStatus(const TQString&, int)));
+    connect( controller,            TQT_SIGNAL(dbgtqStatus(const TQString&, int)),
+             this,                  TQT_SLOT(slottqStatus(const TQString&, int)));
     connect( controller,            TQT_SIGNAL(showStepInSource(const TQString&, int, const TQString&)),
              this,                  TQT_SLOT(slotShowStep(const TQString&, int)));
 
@@ -428,8 +428,8 @@ void RubyDebuggerPart::setupController()
              rdbOutputWidget,       TQT_SLOT(slotReceivedStdout(const char*)) );
     connect( controller,            TQT_SIGNAL(rdbStderr(const char*)),
              rdbOutputWidget,       TQT_SLOT(slotReceivedStderr(const char*)) );
-    connect( controller,            TQT_SIGNAL(dbgStatus(const TQString&, int)),
-             rdbOutputWidget,       TQT_SLOT(slotDbgStatus(const TQString&, int)));
+    connect( controller,            TQT_SIGNAL(dbgtqStatus(const TQString&, int)),
+             rdbOutputWidget,       TQT_SLOT(slotDbgtqStatus(const TQString&, int)));
 
 }
 
@@ -478,7 +478,7 @@ bool RubyDebuggerPart::startDebugger()
         {
             KMessageBox::error(
                 mainWindow()->main(),
-                i18n("Could not locate the debugging shell '%1'.").arg( shell ),
+                i18n("Could not locate the debugging shell '%1'.").tqarg( shell ),
                 i18n("Debugging Shell Not Found") );
             return false;
         }
@@ -683,7 +683,7 @@ void RubyDebuggerPart::slotRefreshBPState( const Breakpoint& BP)
 }
 
 
-void RubyDebuggerPart::slotStatus(const TQString &msg, int state)
+void RubyDebuggerPart::slottqStatus(const TQString &msg, int state)
 {
     TQString stateIndicator;
 
