@@ -56,7 +56,7 @@ enum Column {
     Control     = 0,
     Enable      = 1,
     Type        = 2,
-    Status      = 3,
+    tqStatus      = 3,
     Location    = 4
 };
 
@@ -69,7 +69,7 @@ static int m_activeFlag = 0;
 /***************************************************************************/
 /***************************************************************************/
 
-class BreakpointTableRow : public QTableItem
+class BreakpointTableRow : public TQTableItem
 {
 public:
 
@@ -149,7 +149,7 @@ void BreakpointTableRow::setRow()
 
         TQString status=m_breakpoint->statusDisplay(m_activeFlag);
 
-        table()->setText(row(), Status, status);
+        table()->setText(row(), tqStatus, status);
 
         TQString displayType = m_breakpoint->displayType();
         table()->setText(row(), Location, m_breakpoint->location());
@@ -159,7 +159,7 @@ void BreakpointTableRow::setRow()
 
         table()->setText(row(), Type, displayType);
         table()->adjustColumn(Type);
-        table()->adjustColumn(Status);
+        table()->adjustColumn(tqStatus);
         table()->adjustColumn(Location);
     }
 }
@@ -221,14 +221,14 @@ RDBBreakpointWidget::RDBBreakpointWidget(TQWidget *parent, const char *name) :
 
     m_table->hideColumn(Control);
     m_table->setColumnReadOnly(Type, true);
-    m_table->setColumnReadOnly(Status, true);
+    m_table->setColumnReadOnly(tqStatus, true);
     m_table->setColumnWidth( Enable, 20);
 
     TQHeader *header = m_table->horizontalHeader();
 
     header->setLabel( Enable,       "" );
     header->setLabel( Type,         i18n("Type") );
-    header->setLabel( Status,       i18n("Status") );
+    header->setLabel( tqStatus,       i18n("Status") );
     header->setLabel( Location,     i18n("Location") );
 
     m_table->show();
@@ -773,7 +773,7 @@ void RDBBreakpointWidget::slotNewValue(int row, int col)
         }
 
         case Type:
-        case Status:
+        case tqStatus:
         default:
             break;
         }
@@ -904,7 +904,7 @@ void RDBBreakpointWidget::slotAddBreakpoint( )
 {
     if (m_add->popup())
     {
-        m_add->popup()->popup(mapToGlobal(this->geometry().topLeft()));
+        m_add->popup()->popup(mapToGlobal(this->tqgeometry().topLeft()));
     }
 }
 
