@@ -115,7 +115,7 @@ RDBController::RDBController(VariableTree *varTree, FramestackWidget *frameStack
 {
     struct sockaddr_un	sockaddr;
 	unixSocketPath_.sprintf("/tmp/.rubydebugger%d", getpid());
-	QFileInfo			unixSocket(unixSocketPath_);
+	TQFileInfo			unixSocket(unixSocketPath_);
 	
     stdoutSizeofBuf_ = sizeof(stdoutOutput_);
     rdbSizeofBuf_ = sizeof(rdbOutput_);
@@ -236,7 +236,7 @@ void RDBController::executeCmd()
     emit rdbStdout( prettyCmd.latin1() );
 	
     if (!stateIsOn(s_silent))
-        emit dbgStatus("", state_);
+        emit dbgtqStatus("", state_);
 }
 
 // **************************************************************************
@@ -301,7 +301,7 @@ void RDBController::actOnProgramPause(const TQString &msg)
         if (stateIsOn(s_silent))
             return;
 
-        emit dbgStatus (msg, state_);
+        emit dbgtqStatus (msg, state_);
 
         // We're always at frame one when the program stops
         // and we must reset the active flag
@@ -341,14 +341,14 @@ void RDBController::programNoApp(const TQString &msg, bool msgBox)
     varTree_->viewport()->setUpdatesEnabled(false);
     varTree_->prune();
     varTree_->viewport()->setUpdatesEnabled(true);
-    varTree_->repaint();
+    varTree_->tqrepaint();
 
     frameStack_->clear();
 
     if (msgBox)
         KMessageBox::error(0, i18n("rdb message:\n")+msg);
 
-    emit dbgStatus (msg, state_);
+    emit dbgtqStatus (msg, state_);
 }
 
 // **************************************************************************
@@ -394,9 +394,9 @@ void RDBController::parseProgramLocation(char *buf)
 	}
 	
     if (stateIsOn(s_appBusy))
-        actOnProgramPause(i18n("No source: %1").arg(sourceFile));
+        actOnProgramPause(i18n("No source: %1").tqarg(sourceFile));
     else
-        emit dbgStatus (i18n("No source: %1").arg(sourceFile), state_);
+        emit dbgtqStatus (i18n("No source: %1").tqarg(sourceFile), state_);
 }
 
 // **************************************************************************
@@ -458,7 +458,7 @@ void RDBController::parseFrameMove(char *buf)
 		}
 	}
 	
-	emit dbgStatus(i18n("No source: %1").arg(sourceFile), state_);
+	emit dbgtqStatus(i18n("No source: %1").tqarg(sourceFile), state_);
 }
 
 // **************************************************************************
@@ -492,7 +492,7 @@ void RDBController::parseRequestedData(char *buf)
         varTree_->viewport()->setUpdatesEnabled(false);
         item->expandValue(buf);
         varTree_->viewport()->setUpdatesEnabled(true);
-        varTree_->repaint();
+        varTree_->tqrepaint();
     }
 }
 
@@ -505,7 +505,7 @@ void RDBController::parseFrameSelected(char *buf)
 {
     if (!stateIsOn(s_silent)) {
         emit showStepInSource("", -1, "");
-        emit dbgStatus (i18n("No source: %1").arg(TQString(buf)), state_);
+        emit dbgtqStatus (i18n("No source: %1").tqarg(TQString(buf)), state_);
     }
 }
 
@@ -517,7 +517,7 @@ void RDBController::parseDisplay(char *buf, char * expr)
     varTree_->viewport()->setUpdatesEnabled(false);
     varTree_->watchRoot()->setWatchExpression(buf, expr);
     varTree_->viewport()->setUpdatesEnabled(true);
-    varTree_->repaint();
+    varTree_->tqrepaint();
 }
 
 // **************************************************************************
@@ -538,7 +538,7 @@ void RDBController::parseUpdateDisplay(char *buf)
 	}
 
     varTree_->viewport()->setUpdatesEnabled(true);
-    varTree_->repaint();
+    varTree_->tqrepaint();
 }
 
 // **************************************************************************
@@ -549,7 +549,7 @@ void RDBController::parseGlobals(char *buf)
     varTree_->viewport()->setUpdatesEnabled(false);
     varTree_->globalRoot()->setGlobals(buf);
     varTree_->viewport()->setUpdatesEnabled(true);
-    varTree_->repaint();
+    varTree_->tqrepaint();
 }
 
 // **************************************************************************
@@ -584,7 +584,7 @@ void RDBController::parseLocals(char type, char *buf)
 	}
 
     varTree_->viewport()->setUpdatesEnabled(true);
-    varTree_->repaint();
+    varTree_->tqrepaint();
 }
 
 
@@ -601,27 +601,27 @@ void RDBController::parse(char *buf)
         parseProgramLocation(buf);
 	} else if (currentCmd_->rawDbgCommand() == "break") {
         emit rawRDBBreakpointList(buf);
-	} else if (qstrncmp(currentCmd_->rawDbgCommand(), "break ", strlen("break ")) == 0) {
+	} else if (tqstrncmp(currentCmd_->rawDbgCommand(), "break ", strlen("break ")) == 0) {
 		parseBreakpointSet(buf); 
-	} else if (qstrncmp(currentCmd_->rawDbgCommand(), "watch ", strlen("watch ")) == 0) {
+	} else if (tqstrncmp(currentCmd_->rawDbgCommand(), "watch ", strlen("watch ")) == 0) {
 		parseBreakpointSet(buf); 
-	} else if (qstrncmp(currentCmd_->rawDbgCommand(), "display ", strlen("display ")) == 0) {
+	} else if (tqstrncmp(currentCmd_->rawDbgCommand(), "display ", strlen("display ")) == 0) {
 		parseDisplay(buf, currentCmd_->rawDbgCommand().data() + strlen("display "));
 	} else if (currentCmd_->rawDbgCommand() == "display") {
 		parseUpdateDisplay(buf);
-	} else if (qstrncmp(currentCmd_->rawDbgCommand(), "undisplay ", strlen("undisplay ")) == 0) {
+	} else if (tqstrncmp(currentCmd_->rawDbgCommand(), "undisplay ", strlen("undisplay ")) == 0) {
 		;
-	} else if (qstrncmp(currentCmd_->rawDbgCommand(), "method instance ", strlen("method instance ")) == 0) { 
-	} else if (qstrncmp(currentCmd_->rawDbgCommand(), "method ", strlen("method ")) == 0) {
-	} else if (qstrncmp(currentCmd_->rawDbgCommand(), "pp ", strlen("pp ")) == 0) {
+	} else if (tqstrncmp(currentCmd_->rawDbgCommand(), "method instance ", strlen("method instance ")) == 0) { 
+	} else if (tqstrncmp(currentCmd_->rawDbgCommand(), "method ", strlen("method ")) == 0) {
+	} else if (tqstrncmp(currentCmd_->rawDbgCommand(), "pp ", strlen("pp ")) == 0) {
 		parseRequestedData(buf);
 	} else if (currentCmd_->rawDbgCommand() == "thread list") {
 		parseThreadList(buf);
-	} else if (	qstrncmp(currentCmd_->rawDbgCommand(), "up ", strlen("up ")) == 0
-				|| qstrncmp(currentCmd_->rawDbgCommand(), "down ", strlen("down ")) == 0 ) 
+	} else if (	tqstrncmp(currentCmd_->rawDbgCommand(), "up ", strlen("up ")) == 0
+				|| tqstrncmp(currentCmd_->rawDbgCommand(), "down ", strlen("down ")) == 0 ) 
 	{
 		parseFrameMove(buf);
-	} else if (qstrncmp(currentCmd_->rawDbgCommand(), "thread switch ", strlen("thread switch ")) == 0) {
+	} else if (tqstrncmp(currentCmd_->rawDbgCommand(), "thread switch ", strlen("thread switch ")) == 0) {
 		parseSwitchThread(buf);
 	} else if (currentCmd_->rawDbgCommand() == "thread current") {
 		parseThreadList(buf);
@@ -631,11 +631,11 @@ void RDBController::parse(char *buf)
 		parseGlobals(buf);
 	} else if (currentCmd_->rawDbgCommand() == "var local") {
 		parseLocals(LOCALS, buf);
-	} else if (qstrncmp(currentCmd_->rawDbgCommand(), "var instance ", strlen("var instance ")) == 0) {
+	} else if (tqstrncmp(currentCmd_->rawDbgCommand(), "var instance ", strlen("var instance ")) == 0) {
 		parseLocals(IVARS, buf);
-	} else if (qstrncmp(currentCmd_->rawDbgCommand(), "var class ", strlen("var class ")) == 0) {
+	} else if (tqstrncmp(currentCmd_->rawDbgCommand(), "var class ", strlen("var class ")) == 0) {
 		parseLocals(CVARS, buf);
-	} else if (qstrncmp(currentCmd_->rawDbgCommand(), "var const ", strlen("var const ")) == 0) {
+	} else if (tqstrncmp(currentCmd_->rawDbgCommand(), "var const ", strlen("var const ")) == 0) {
 		parseLocals(CONSTANTS, buf);
 	}
 
@@ -766,9 +766,9 @@ void RDBController::slotStart(const TQString& ruby_interpreter, const TQString&
     // BUT the app hasn't been started yet! A run command is about to be issued
     // by whoever is controlling us.
 	
-    if (!dbgProcess_->writeStdin(TQString("%1\n").arg(unixSocketPath_).latin1(), strlen(unixSocketPath_) + 1)) {
+    if (!dbgProcess_->writeStdin(TQString("%1\n").tqarg(unixSocketPath_.data()).latin1(), strlen(unixSocketPath_) + 1)) {
         kdDebug(9012) << "failed to write Unix domain socket path to rdb " 
-		<< TQString("%1\n").arg(unixSocketPath_).latin1() << endl;
+		<< TQString("%1\n").tqarg(unixSocketPath_.data()).latin1() << endl;
 	}
 	
 	setStateOff(s_programExited);
@@ -797,7 +797,7 @@ void RDBController::slotStopDebugger()
         start = TQTime::currentTime();
         while (-1)
         {
-            kapp->processEvents(20);
+            kapp->tqprocessEvents(20);
             now = TQTime::currentTime();
             if (!stateIsOn(s_appBusy) || start.msecsTo( now ) > 2000)
                 break;
@@ -816,7 +816,7 @@ void RDBController::slotStopDebugger()
     start = TQTime::currentTime();
     while (-1)
     {
-         kapp->processEvents(20);
+         kapp->tqprocessEvents(20);
          now = TQTime::currentTime();
          if (stateIsOn(s_programExited) || start.msecsTo( now ) > 2000)
              break;
@@ -833,7 +833,7 @@ void RDBController::slotStopDebugger()
     delete tty_;           tty_ = 0;
 
     state_ = s_dbgNotStarted | s_appNotStarted | s_silent;
-    emit dbgStatus (i18n("Debugger stopped"), state_);
+    emit dbgtqStatus (i18n("Debugger stopped"), state_);
 }
 
 
@@ -1175,7 +1175,7 @@ void RDBController::slotDbgWroteStdin(KProcess *)
 {
 //    setStateOff(s_waitForWrite);
     //  if (!stateIsOn(s_silent))
-    //    emit dbgStatus ("", state_);
+    //    emit dbgtqStatus ("", state_);
 //    executeCmd();
 }
 
@@ -1203,7 +1203,7 @@ void RDBController::slotAcceptConnection(int masterSocket)
                           this, TQT_SLOT(slotReadFromSocket(int)) );	
     
 	setStateOff(s_dbgNotStarted);
-    emit dbgStatus ("", state_);
+    emit dbgtqStatus ("", state_);
     
 	cmdList_.clear();
 	rdbOutputLen_ = 0;	
@@ -1283,7 +1283,7 @@ void RDBController::slotDbgProcessExited(KProcess*)
 {
     destroyCmds();
     state_ = s_appNotStarted|s_programExited|(state_&(s_shuttingDown));
-    emit dbgStatus (i18n("Process exited"), state_);
+    emit dbgtqStatus (i18n("Process exited"), state_);
     emit rdbStdout("(rdb:1) Process exited\n");
 	frameStack_->clear();
 	varTree_->clear();	
