@@ -202,11 +202,11 @@ void VariableTree::slotContextMenu(KListView *, TQListViewItem *item)
 			emit removeWatchExpression(((WatchVarItem*)item)->displayId());
             delete item;
         } else if (res == idCopyToClipboard) {
-            QClipboard *qb = KApplication::clipboard();
+            TQClipboard *qb = KApplication::tqclipboard();
             TQString text = "{ \"" + item->text( VAR_NAME_COLUMN ) + "\", " +
                             "\"" + item->text( VALUE_COLUMN ) + "\" }";
 
-            qb->setText( text, QClipboard::Clipboard );
+            qb->setText( text, TQClipboard::Clipboard );
         }
     }
 }
@@ -280,7 +280,7 @@ void VariableTree::prune()
 
 // **************************************************************************
 
-// The debugger has moved onto the next program pause, so invalidate 
+// The debugger has moved onto the next program pause, so tqinvalidate 
 // everything in the Variable Tree
 void VariableTree::nextActivationId() 
 { 
@@ -329,7 +329,7 @@ bool VariableTree::schedule()
 			
 			if (frame->needsVariables()) {
 				if (TQApplication::overrideCursor() == 0) {
-					TQApplication::setOverrideCursor(TQCursor(Qt::WaitCursor));
+					TQApplication::setOverrideCursor(TQCursor(TQt::WaitCursor));
 				}
 				
 				// Tell the controller to fetch the variable values
@@ -428,7 +428,7 @@ void VariableTree::maybeTip(const TQPoint &p)
 {
     VarItem * item = dynamic_cast<VarItem*>( itemAt(p) );
     if (item != 0) {
-        TQRect r = itemRect(item);
+        TQRect r = tqitemRect(item);
         if (r.isValid()) {
             tip(r, item->tipText());
 		}
@@ -635,7 +635,7 @@ void VarItem::setText(int column, const TQString &data)
     }
 
     TQListViewItem::setText(column, data);
-    repaint();
+    tqrepaint();
 }
 
 // **************************************************************************
