@@ -532,12 +532,12 @@ void RubySupportPart::slotRun ()
             appFrontend->startAppCommand(project()->projectDirectory(), cmd, false);
     } else {
         TQString cmd = TQString("%1 -K%2 -C\"%3\" -I\"%4\" \"%5\" %6")
-                          .arg(interpreter())
-                          .arg(characterCoding())
-                          .arg(runDirectory())
-                          .arg(program.dirPath())
-                          .arg(program.fileName())
-                          .arg(programArgs());
+                          .tqarg(interpreter())
+                          .tqarg(characterCoding())
+                          .tqarg(runDirectory())
+                          .tqarg(program.dirPath())
+                          .tqarg(program.fileName())
+                          .tqarg(programArgs());
         startApplication(cmd);
     }
 }
@@ -614,7 +614,7 @@ TQString RubySupportPart::characterCoding() {
 void RubySupportPart::startApplication(const TQString &program) {
 	bool inTerminal = DomUtil::readBoolEntry(*projectDom(), "/kdevrubysupport/run/terminal");
     if (KDevAppFrontend *appFrontend = extension<KDevAppFrontend>("KDevelop/AppFrontend"))
-        appFrontend->startAppCommand(TQString::TQString(), program, inTerminal);
+        appFrontend->startAppCommand(TQString(), program, inTerminal);
 }
 
 
@@ -632,7 +632,7 @@ KDevDesignerIntegration *RubySupportPart::designer(KInterfaceDesigner::DesignerT
     KDevDesignerIntegration *des = 0;
     switch (type)
     {
-        case KInterfaceDesigner::QtDesigner:
+        case KInterfaceDesigner::TQtDesigner:
             des = m_designers[type];
             if (des == 0)
             {
@@ -669,7 +669,7 @@ void RubySupportPart::contextMenu( TQPopupMenu * popup, const Context * context
         {
             m_contextFileName = url.fileName();
             int id = popup->insertItem(i18n("Create or Select Implementation..."), this, TQT_SLOT(slotCreateSubclass()));
-            popup->setWhatsThis(id, i18n("<b>Create or select implementation</b><p>Creates or selects a subclass of selected form for use with integrated KDevDesigner."));
+            popup->tqsetWhatsThis(id, i18n("<b>Create or select implementation</b><p>Creates or selects a subclass of selected form for use with integrated KDevDesigner."));
         }
     }
 }
@@ -679,7 +679,7 @@ void RubySupportPart::slotCreateSubclass()
     TQFileInfo fi(m_contextFileName);
     if (fi.extension(false) != "ui")
         return;
-    QtDesignerRubyIntegration *des = dynamic_cast<QtDesignerRubyIntegration*>(designer(KInterfaceDesigner::QtDesigner));
+    QtDesignerRubyIntegration *des = dynamic_cast<QtDesignerRubyIntegration*>(designer(KInterfaceDesigner::TQtDesigner));
     if (des)
         des->selectImplementation(m_contextFileName);
 }
@@ -896,12 +896,12 @@ void RubySupportPart::slotRunTestUnderCursor()
 
     TQFileInfo program(prog);
     TQString cmd = TQString("%1 -K%2 -C\"%3\" -I\"%4\" \"%5\" %6")
-                          .arg(interpreter())
-                          .arg(characterCoding())
-                          .arg(runDirectory())
-                          .arg(program.dirPath())
-                          .arg(program.fileName())
-                          .arg(" -n " + fun->name());
+                          .tqarg(interpreter())
+                          .tqarg(characterCoding())
+                          .tqarg(runDirectory())
+                          .tqarg(program.dirPath())
+                          .tqarg(program.fileName())
+                          .tqarg(" -n " + fun->name());
     startApplication(cmd);
 }
 
