@@ -43,7 +43,7 @@
 #include <kglobalsettings.h>
 
 #include "config.h"
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 #include <X11/X.h>
 #include <X11/Xlib.h>
 #endif
@@ -122,7 +122,7 @@ void KDockMainWindow::setMainDockWidget( KDockWidget* mdw )
 void KDockMainWindow::setView( TQWidget *view )
 {
   if ( view->isA("KDockWidget") ){
-    if ( view->parent() != this ) ((KDockWidget*)view)->applyToWidget( this );
+    if ( TQT_BASE_OBJECT(view->parent()) != TQT_BASE_OBJECT(this) ) ((KDockWidget*)view)->applyToWidget( this );
   }
 
 #ifndef NO_KDE2
@@ -203,7 +203,7 @@ void KDockWidgetHeaderDrag::paintEvent( TQPaintEvent* )
 
   paint.begin( this );
 
-  style().drawPrimitive (TQStyle::PE_DockWindowHandle, &paint, TQRect(0,0,width(), height()), colorGroup());
+  tqstyle().tqdrawPrimitive (TQStyle::PE_DockWindowHandle, &paint, TQRect(0,0,width(), height()), tqcolorGroup());
 
   paint.end();
 }
@@ -219,22 +219,22 @@ KDockWidgetHeader::KDockWidgetHeader( KDockWidget* parent, const char* name )
 #ifdef BORDERLESS_WINDOWS
   setCursor(TQCursor(ArrowCursor));
 #endif
-  d = new KDockWidgetHeaderPrivate( this );
+  d = new KDockWidgetHeaderPrivate( TQT_TQOBJECT(this) );
 
-  layout = new TQHBoxLayout( this );
-  layout->setResizeMode( TQLayout::Minimum );
+  tqlayout = new TQHBoxLayout( this );
+  tqlayout->setResizeMode( TQLayout::Minimum );
 
   drag = new KDockWidgetHeaderDrag( this, parent );
 
   closeButton = new KDockButton_Private( this, "DockCloseButton" );
   TQToolTip::add( closeButton, i18n("Close") );
-  closeButton->setPixmap( style().stylePixmap (TQStyle::SP_TitleBarCloseButton , this));
+  closeButton->setPixmap( tqstyle().stylePixmap (TQStyle::SP_TitleBarCloseButton , this));
   closeButton->setFixedSize(closeButton->pixmap()->width(),closeButton->pixmap()->height());
   connect( closeButton, TQT_SIGNAL(clicked()), parent, TQT_SIGNAL(headerCloseButtonClicked()));
   connect( closeButton, TQT_SIGNAL(clicked()), parent, TQT_SLOT(undock()));
 
   stayButton = new KDockButton_Private( this, "DockStayButton" );
-  TQToolTip::add( stayButton, i18n("Freeze the window geometry", "Freeze") );
+  TQToolTip::add( stayButton, i18n("Freeze the window tqgeometry", "Freeze") );
   stayButton->setToggleButton( true );
   stayButton->setPixmap( const_cast< const char** >(not_close_xpm) );
   stayButton->setFixedSize(closeButton->pixmap()->width(),closeButton->pixmap()->height());
@@ -258,15 +258,15 @@ KDockWidgetHeader::KDockWidgetHeader( KDockWidget* parent, const char* name )
   d->dummy->setFixedSize( 1,closeButton->pixmap()->height() );
 
 
-  layout->addWidget( drag );
-  layout->addWidget( dockbackButton );
-  layout->addWidget( d->toDesktopButton );
-  layout->addWidget( d->dummy);
-  layout->addWidget( stayButton );
-  layout->addWidget( closeButton );
-  layout->activate();
+  tqlayout->addWidget( drag );
+  tqlayout->addWidget( dockbackButton );
+  tqlayout->addWidget( d->toDesktopButton );
+  tqlayout->addWidget( d->dummy);
+  tqlayout->addWidget( stayButton );
+  tqlayout->addWidget( closeButton );
+  tqlayout->activate();
   d->dummy->hide();
-  drag->setFixedHeight( layout->minimumSize().height() );
+  drag->setFixedHeight( tqlayout->tqminimumSize().height() );
 }
 
 void KDockWidgetHeader::setTopLevel( bool isTopLevel )
@@ -291,7 +291,7 @@ void KDockWidgetHeader::setTopLevel( bool isTopLevel )
     if( d->showToDesktopButton )
       d->toDesktopButton->show();
   }
-  layout->activate();
+  tqlayout->activate();
 
    bool dontShowDummy=drag->isVisibleTo(this) || dockbackButton->isVisibleTo(this) ||
         d->toDesktopButton->isVisibleTo(this) || stayButton->isVisibleTo(this) ||
@@ -318,9 +318,9 @@ void KDockWidgetHeader::setDragPanel( KDockWidgetHeaderDrag* nd )
 {
   if ( !nd ) return;
 
-  delete layout;
-  layout = new TQHBoxLayout( this );
-  layout->setResizeMode( TQLayout::Minimum );
+  delete tqlayout;
+  tqlayout = new TQHBoxLayout( this );
+  tqlayout->setResizeMode( TQLayout::Minimum );
 
   delete drag;
   drag = nd;
@@ -329,26 +329,26 @@ void KDockWidgetHeader::setDragPanel( KDockWidgetHeaderDrag* nd )
   }
 
 
-  layout->addWidget( drag );
-  layout->addWidget( dockbackButton );
-  layout->addWidget( d->dummy );
-  layout->addWidget( d->toDesktopButton );
-  layout->addWidget( stayButton );
+  tqlayout->addWidget( drag );
+  tqlayout->addWidget( dockbackButton );
+  tqlayout->addWidget( d->dummy );
+  tqlayout->addWidget( d->toDesktopButton );
+  tqlayout->addWidget( stayButton );
   bool dontShowDummy=drag->isVisibleTo(this) || dockbackButton->isVisibleTo(this) ||
 	d->toDesktopButton->isVisibleTo(this) || stayButton->isVisibleTo(this) ||
 	closeButton->isVisibleTo(this);
   for (TQPtrListIterator<KDockButton_Private> it( d->btns );it.current();++it) {
-      layout->addWidget(it.current());
+      tqlayout->addWidget(it.current());
 	dontShowDummy=dontShowDummy || (it.current()->isVisibleTo(this));
   }
   if (dontShowDummy) d->dummy->hide(); else d->dummy->show();
-  layout->addWidget( closeButton );
-  layout->activate();
-  kdDebug(282)<<"KdockWidgetHeader::setDragPanel:minimum height="<<layout->minimumSize().height()<<endl;
+  tqlayout->addWidget( closeButton );
+  tqlayout->activate();
+  kdDebug(282)<<"KdockWidgetHeader::setDragPanel:minimum height="<<tqlayout->tqminimumSize().height()<<endl;
 #ifdef __GNUC__
 #warning FIXME
 #endif
-  drag->setFixedHeight( closeButton->height()); // /*layout->minimumS*/sizeHint().height() );
+  drag->setFixedHeight( closeButton->height()); // /*tqlayout->minimumS*/tqsizeHint().height() );
 }
 
 void KDockWidgetHeader::addButton(KDockButton_Private* btn) {
@@ -362,26 +362,26 @@ void KDockWidgetHeader::addButton(KDockButton_Private* btn) {
 
 	btn->show();
 
-	delete layout;
-	layout = new TQHBoxLayout( this );
-	layout->setResizeMode( TQLayout::Minimum );
+	delete tqlayout;
+	tqlayout = new TQHBoxLayout( this );
+	tqlayout->setResizeMode( TQLayout::Minimum );
 
-	layout->addWidget( drag );
- 	layout->addWidget( dockbackButton );
-	layout->addWidget( d->toDesktopButton );
-	layout->addWidget( d->dummy);
-	layout->addWidget( stayButton );
+	tqlayout->addWidget( drag );
+ 	tqlayout->addWidget( dockbackButton );
+	tqlayout->addWidget( d->toDesktopButton );
+	tqlayout->addWidget( d->dummy);
+	tqlayout->addWidget( stayButton );
 	 bool dontShowDummy=drag->isVisibleTo(this) || dockbackButton->isVisibleTo(this) ||
 	        d->toDesktopButton->isVisibleTo(this) || stayButton->isVisibleTo(this) ||
         	closeButton->isVisibleTo(this);
 	 for (TQPtrListIterator<KDockButton_Private> it( d->btns );it.current();++it) {
-	        layout->addWidget(it.current());
+	        tqlayout->addWidget(it.current());
 		dontShowDummy=dontShowDummy || (it.current()->isVisibleTo(this));
    	}
   	if (dontShowDummy) d->dummy->hide(); else d->dummy->show();
-	layout->addWidget( closeButton );
-	layout->activate();
-	drag->setFixedHeight( layout->minimumSize().height() );
+	tqlayout->addWidget( closeButton );
+	tqlayout->activate();
+	drag->setFixedHeight( tqlayout->tqminimumSize().height() );
 }
 
 void KDockWidgetHeader::removeButton(KDockButton_Private* btn) {
@@ -425,12 +425,12 @@ void KDockWidgetHeader::setDragEnabled(bool b)
 #ifndef NO_KDE2
 void KDockWidgetHeader::saveConfig( KConfig* c )
 {
-  c->writeEntry( TQString("%1%2").arg(parent()->name()).arg(":stayButton"), stayButton->isOn() );
+  c->writeEntry( TQString("%1%2").tqarg(parent()->name()).tqarg(":stayButton"), stayButton->isOn() );
 }
 
 void KDockWidgetHeader::loadConfig( KConfig* c )
 {
-  setDragEnabled( !c->readBoolEntry( TQString("%1%2").arg(parent()->name()).arg(":stayButton"), false ) );
+  setDragEnabled( !c->readBoolEntry( TQString("%1%2").tqarg(parent()->name()).tqarg(":stayButton"), false ) );
 }
 #endif
 
@@ -497,11 +497,11 @@ KDockWidget::KDockWidget( KDockManager* dockManager, const char* name, const TQP
 
   d->_parent = parent;
 
-  layout = new TQVBoxLayout( this );
-  layout->setResizeMode( TQLayout::Minimum );
+  tqlayout = new TQVBoxLayout( this );
+  tqlayout->setResizeMode( TQLayout::Minimum );
 
   manager = dockManager;
-  manager->childDock->append( this );
+  manager->childDock->append( TQT_TQOBJECT(this) );
   installEventFilter( manager );
 
   eDocking = DockFullDocking;
@@ -565,8 +565,8 @@ KDockWidget::~KDockWidget()
     }
   }
   emit iMBeingClosed();
-  if (manager->d) manager->d->containerDocks.remove(this);
-  manager->childDock->remove( this );
+  if (manager->d) manager->d->containerDocks.remove(TQT_TQOBJECT(this));
+  manager->childDock->remove( TQT_TQOBJECT(this) );
   delete pix;
   delete d; // destroy private data
   d=0;
@@ -577,7 +577,7 @@ void KDockWidget::paintEvent(TQPaintEvent* pe)
 	TQWidget::paintEvent(pe);
         TQPainter paint;
         paint.begin( this );
-        style().drawPrimitive (TQStyle::PE_Panel, &paint, TQRect(0,0,width(), height()), colorGroup());
+        tqstyle().tqdrawPrimitive (TQStyle::PE_Panel, &paint, TQRect(0,0,width(), height()), tqcolorGroup());
         paint.end();
 }
 
@@ -604,7 +604,7 @@ void KDockWidget::mousePressEvent(TQMouseEvent* mme)
 		int styleheight;
 		TQPoint mp;
 		mp=mme->pos();
-      		styleheight=2*style().pixelMetric(TQStyle::PM_DefaultFrameWidth,this);
+      		styleheight=2*tqstyle().tqpixelMetric(TQStyle::PM_DefaultFrameWidth,this);
 		bbottom=mp.y()>=height()-styleheight;
 		btop=mp.y()<=styleheight;
 		bleft=mp.x()<=styleheight;
@@ -692,7 +692,7 @@ void  KDockWidget::mouseMoveEvent(TQMouseEvent* mme)
 	int styleheight;
 	TQPoint mp;
 	mp=mme->pos();
-      	styleheight=2*style().pixelMetric(TQStyle::PM_DefaultFrameWidth,this);
+      	styleheight=2*tqstyle().tqpixelMetric(TQStyle::PM_DefaultFrameWidth,this);
 	bbottom=mp.y()>=height()-styleheight;
 	btop=mp.y()<=styleheight;
 	bleft=mp.x()<=styleheight;
@@ -748,15 +748,15 @@ void KDockWidget::setHeader( KDockWidgetAbstractHeader* h )
 
   if ( header ){
     delete header;
-    delete layout;
+    delete tqlayout;
     header = h;
-    layout = new TQVBoxLayout( this );
-    layout->setResizeMode( TQLayout::Minimum );
-    layout->addWidget( header );
+    tqlayout = new TQVBoxLayout( this );
+    tqlayout->setResizeMode( TQLayout::Minimum );
+    tqlayout->addWidget( header );
      setWidget( widget );
   } else {
     header = h;
-    layout->addWidget( header );
+    tqlayout->addWidget( header );
   }
   kdDebug(282)<<caption()<<": KDockWidget::setHeader"<<endl;
   setEnableDocking(eDocking);
@@ -774,12 +774,12 @@ void KDockWidget::updateHeader()
 {
   if ( parent() ){
 #ifdef BORDERLESS_WINDOWS
-      layout->setMargin(0);
+      tqlayout->setMargin(0);
       setMouseTracking(false);
       setCursor(TQCursor(ArrowCursor));
 #endif
 
-    if ( (parent() == manager->main) || isGroup || (eDocking == KDockWidget::DockNone) ){
+    if ( (TQT_BASE_OBJECT(parent()) == TQT_BASE_OBJECT(manager->main)) || isGroup || (eDocking == KDockWidget::DockNone) ){
       header->hide();
     } else {
       header->setTopLevel( false );
@@ -792,7 +792,7 @@ void KDockWidget::updateHeader()
     header->setTopLevel( true );
     header->show();
 #ifdef BORDERLESS_WINDOWS
-      layout->setMargin(2*style().pixelMetric(TQStyle::PM_DefaultFrameWidth,this));
+      tqlayout->setMargin(2*tqstyle().tqpixelMetric(TQStyle::PM_DefaultFrameWidth,this));
       setMouseTracking(true);
 #endif
   }
@@ -800,7 +800,7 @@ void KDockWidget::updateHeader()
 
 void KDockWidget::applyToWidget( TQWidget* s, const TQPoint& p )
 {
-  if ( parent() != s )
+  if ( TQT_BASE_OBJECT(parent()) != TQT_BASE_OBJECT(s) )
   {
     hide();
     reparent(s, 0, TQPoint(0,0), false);
@@ -811,7 +811,7 @@ void KDockWidget::applyToWidget( TQWidget* s, const TQPoint& p )
   }
 
   if ( manager && s == manager->main ){
-      setGeometry( TQRect(TQPoint(0,0), manager->main->geometry().size()) );
+      setGeometry( TQRect(TQPoint(0,0), manager->main->tqgeometry().size()) );
   }
 
   if ( !s )
@@ -819,7 +819,7 @@ void KDockWidget::applyToWidget( TQWidget* s, const TQPoint& p )
     move(p);
 
 #ifndef NO_KDE2
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     if (d->transient && d->_parent)
       XSetTransientForHint( qt_xdisplay(), winId(), d->_parent->winId() );
 
@@ -829,7 +829,7 @@ void KDockWidget::applyToWidget( TQWidget* s, const TQPoint& p )
 #else
     KWin::setType( winId(), d->windowType );
 #endif // BORDERLESS_WINDOW
-#endif // Q_WS_X11
+#endif // TQ_WS_X11
 #endif
 
   }
@@ -922,7 +922,7 @@ KDockWidget *KDockWidget::findNearestDockWidget(DockPosition pos)
 {
 	if (!parent()) return 0;
 	if (!parent()->inherits("KDockSplitter")) return 0;
-	Orientation orientation=((pos==DockLeft) || (pos==DockRight)) ? Vertical:Horizontal;
+	Qt::Orientation orientation=((pos==DockLeft) || (pos==DockRight)) ?Qt::Vertical:Qt::Horizontal;
 		if (((KDockSplitter*)(parent()))->orientation()==orientation)
 		{
 			KDockWidget *neighbor=
@@ -931,7 +931,7 @@ KDockWidget *KDockWidget::findNearestDockWidget(DockPosition pos)
 				static_cast<KDockWidget*>(((KDockSplitter*)(parent()))->getLast());
 
 			if (neighbor==this)
-			return (static_cast<KDockWidget*>(parent()->parent())->findNearestDockWidget(pos));
+			return (static_cast<KDockWidget*>(TQT_TQWIDGET(parent()->parent()))->findNearestDockWidget(pos));
 			else
 			if (neighbor->getWidget() && (neighbor->getWidget()->qt_cast("KDockTabGroup")))
 				return (KDockWidget*)(((KDockTabGroup*)neighbor->getWidget())->page(0));
@@ -939,7 +939,7 @@ KDockWidget *KDockWidget::findNearestDockWidget(DockPosition pos)
 			return neighbor;
 		}
 		else
-		return (static_cast<KDockWidget*>(parent()->parent())->findNearestDockWidget(pos));
+		return (static_cast<KDockWidget*>(TQT_TQWIDGET(parent()->parent()))->findNearestDockWidget(pos));
 
 	return 0;
 }
@@ -1074,7 +1074,7 @@ KDockWidget* KDockWidget::manualDock( KDockWidget* target, DockPosition dockPos,
 
   // create a new dockwidget that will contain the target and this
   TQWidget* parentDock = target->parentWidget();
-  KDockWidget* newDock = new KDockWidget( manager, "tempName", TQPixmap(""), parentDock );
+  KDockWidget* newDock = new KDockWidget( manager, "tempName", TQPixmap(TQString("")), parentDock );
   newDock->currentDockPos = target->currentDockPos;
 
   if ( dockPos == KDockWidget::DockCenter ){
@@ -1089,7 +1089,7 @@ KDockWidget* KDockWidget::manualDock( KDockWidget* target, DockPosition dockPos,
   if ( !parentDock ){
     // dock to a toplevel dockwidget means newDock is toplevel now
     newDock->move( target->frameGeometry().topLeft() );
-    newDock->resize( target->geometry().size() );
+    newDock->resize( target->tqgeometry().size() );
     if ( target->isVisibleToTLW() ) newDock->show();
   }
 
@@ -1124,7 +1124,7 @@ KDockWidget* KDockWidget::manualDock( KDockWidget* target, DockPosition dockPos,
     tab->insertTab( this, icon() ? *icon() : TQPixmap(),
                     tabPageLabel(), tabIndex );
 
-    TQRect geom=newDock->geometry();
+    TQRect geom=newDock->tqgeometry();
     TQWidget *wantTransient=tab->transientTo();
     newDock->setDockWindowTransient(wantTransient,wantTransient);
     newDock->setGeometry(geom);
@@ -1143,13 +1143,13 @@ KDockWidget* KDockWidget::manualDock( KDockWidget* target, DockPosition dockPos,
     // if to dock not to the center of the target dockwidget,
     // dock to newDock
     KDockSplitter* panner = 0L;
-    if ( dockPos == KDockWidget::DockTop  || dockPos == KDockWidget::DockBottom ) panner = new KDockSplitter( newDock, "_dock_split_", Horizontal, spliPos, manager->splitterHighResolution() );
-    if ( dockPos == KDockWidget::DockLeft || dockPos == KDockWidget::DockRight  ) panner = new KDockSplitter( newDock, "_dock_split_", Vertical , spliPos, manager->splitterHighResolution() );
+    if ( dockPos == KDockWidget::DockTop  || dockPos == KDockWidget::DockBottom ) panner = new KDockSplitter( newDock, "_dock_split_",Qt::Horizontal, spliPos, manager->splitterHighResolution() );
+    if ( dockPos == KDockWidget::DockLeft || dockPos == KDockWidget::DockRight  ) panner = new KDockSplitter( newDock, "_dock_split_",Qt::Vertical , spliPos, manager->splitterHighResolution() );
     newDock->setWidget( panner );
 
     panner->setOpaqueResize(manager->splitterOpaqueResize());
     panner->setKeepSize(manager->splitterKeepSize());
-    panner->setFocusPolicy( NoFocus );
+    panner->setFocusPolicy( TQ_NoFocus );
     target->applyToWidget( panner );
     applyToWidget( panner );
     target->formerDockPos = target->currentDockPos;
@@ -1328,13 +1328,13 @@ void KDockWidget::undock()
           split->deactivate();
           if ( split->getFirst() == parentOfTab ){
             split->activate( lastTab );
-            if ( ((KDockWidget*)split->parent())->splitterOrientation == Vertical )
+            if ( ((KDockWidget*)split->parent())->splitterOrientation ==Qt::Vertical )
               emit ((KDockWidget*)split->getAnother(parentOfTab))->docking( parentOfTab, KDockWidget::DockLeft );
             else
               emit ((KDockWidget*)split->getAnother(parentOfTab))->docking( parentOfTab, KDockWidget::DockTop );
           } else {
             split->activate( 0L, lastTab );
-            if ( ((KDockWidget*)split->parent())->splitterOrientation == Vertical )
+            if ( ((KDockWidget*)split->parent())->splitterOrientation ==Qt::Vertical )
               emit ((KDockWidget*)split->getAnother(parentOfTab))->docking( parentOfTab, KDockWidget::DockRight );
             else
               emit ((KDockWidget*)split->getAnother(parentOfTab))->docking( parentOfTab, KDockWidget::DockBottom );
@@ -1430,7 +1430,7 @@ void KDockWidget::setWidget( TQWidget* mw )
 {
   if ( !mw ) return;
 
-  if ( mw->parent() != this ){
+  if ( TQT_BASE_OBJECT(mw->parent()) != TQT_BASE_OBJECT(this) ){
     mw->reparent(this, 0, TQPoint(0,0), false);
   }
 
@@ -1438,16 +1438,16 @@ void KDockWidget::setWidget( TQWidget* mw )
   if (!mw->ownCursor()) mw->setCursor(TQCursor(ArrowCursor));
 #endif
   widget = mw;
-  delete layout;
+  delete tqlayout;
 
-  layout = new TQVBoxLayout( this );
-  layout->setResizeMode( TQLayout::Minimum );
+  tqlayout = new TQVBoxLayout( this );
+  tqlayout->setResizeMode( TQLayout::Minimum );
 
   KDockContainer* dc = dynamic_cast<KDockContainer*>(widget);
   if (dc)
   {
     d->isContainer=true;
-    manager->d->containerDocks.append(this);
+    manager->d->containerDocks.append(TQT_TQOBJECT(this));
   }
   else
   {
@@ -1456,8 +1456,8 @@ void KDockWidget::setWidget( TQWidget* mw )
 
   {
      header->show();
-     layout->addWidget( header );
-     layout->addWidget( widget,1 );
+     tqlayout->addWidget( header );
+     tqlayout->addWidget( widget,1 );
   }
   updateHeader();
   emit widgetSet(mw);
@@ -1478,7 +1478,7 @@ void KDockWidget::setDockTabName( KDockTabGroup* tab )
   tab->parentWidget()->setName( listOfName.utf8() );
   tab->parentWidget()->setCaption( listOfCaption );
 
-  tab->parentWidget()->repaint( false ); // KDockWidget->repaint
+  tab->parentWidget()->tqrepaint( false ); // KDockWidget->tqrepaint
   if ( tab->parentWidget()->parent() )
     if ( tab->parentWidget()->parent()->inherits("KDockSplitter") )
       ((KDockSplitter*)(tab->parentWidget()->parent()))->updateName();
@@ -1486,13 +1486,13 @@ void KDockWidget::setDockTabName( KDockTabGroup* tab )
 
 bool KDockWidget::mayBeHide() const
 {
-  bool f = (parent() != manager->main);
+  bool f = (TQT_BASE_OBJECT(parent()) != TQT_BASE_OBJECT(manager->main));
   return ( !isGroup && !isTabGroup && f && isVisible() && ( eDocking != (int)KDockWidget::DockNone ) );
 }
 
 bool KDockWidget::mayBeShow() const
 {
-  bool f = (parent() != manager->main);
+  bool f = (TQT_BASE_OBJECT(parent()) != TQT_BASE_OBJECT(manager->main));
   return ( !isGroup && !isTabGroup && f && !isVisible() );
 }
 
@@ -1551,13 +1551,13 @@ void KDockWidget::loseFormerBrotherDockWidget()
     TQObject::disconnect( formerBrotherDockWidget, TQT_SIGNAL(iMBeingClosed()),
                          this, TQT_SLOT(loseFormerBrotherDockWidget()) );
   formerBrotherDockWidget = 0L;
-  repaint();
+  tqrepaint();
 }
 
 void KDockWidget::dockBack()
 {
   if( formerBrotherDockWidget) {
-    // search all children if it tries to dock back to a child
+    // search all tqchildren if it tries to dock back to a child
     bool found = false;
     TQObjectList* cl = queryList("KDockWidget");
     TQObjectListIt it( *cl );
@@ -1680,7 +1680,7 @@ void KDockManager::activate()
         obj->show();
     }
   }
-  if ( !main->inherits("TQDialog") ) main->show();
+  if ( !main->inherits(TQDIALOG_OBJECT_NAME_STRING) ) main->show();
 }
 
 bool KDockManager::eventFilter( TQObject *obj, TQEvent *event )
@@ -1700,11 +1700,11 @@ bool KDockManager::eventFilter( TQObject *obj, TQEvent *event )
         break;
 
       case TQEvent::MouseButtonPress:
-        if ( ((TQMouseEvent*)event)->button() == LeftButton ){
+        if ( ((TQMouseEvent*)event)->button() == Qt::LeftButton ){
           if ( curdw->eDocking != (int)KDockWidget::DockNone ){
             dropCancel = true;
             curdw->setFocus();
-            qApp->processOneEvent();
+            tqApp->processOneEvent();
 
             currentDragWidget = curdw;
             currentMoveWidget = 0L;
@@ -1713,7 +1713,7 @@ bool KDockManager::eventFilter( TQObject *obj, TQEvent *event )
             findChildDockWidget( curdw, childDockWidgetList );
 
             //d->oldDragRect = TQRect(); should fix rectangle not erased problem
-            d->dragRect = TQRect(curdw->geometry());
+            d->dragRect = TQRect(curdw->tqgeometry());
             TQPoint p = curdw->mapToGlobal(TQPoint(0,0));
             d->dragRect.moveTopLeft(p);
             drawDragRectangle();
@@ -1725,7 +1725,7 @@ bool KDockManager::eventFilter( TQObject *obj, TQEvent *event )
         }
         break;
       case TQEvent::MouseButtonRelease:
-        if ( ((TQMouseEvent*)event)->button() == LeftButton ){
+        if ( ((TQMouseEvent*)event)->button() == Qt::LeftButton ){
           if ( dragging ){
             if ( !dropCancel )
               drop();
@@ -1735,7 +1735,7 @@ bool KDockManager::eventFilter( TQObject *obj, TQEvent *event )
           if (d->readyToDrag) {
               d->readyToDrag = false;
               //d->oldDragRect = TQRect(); should fix rectangle not erased problem
-              d->dragRect = TQRect(curdw->geometry());
+              d->dragRect = TQRect(curdw->tqgeometry());
               TQPoint p = curdw->mapToGlobal(TQPoint(0,0));
               d->dragRect.moveTopLeft(p);
               drawDragRectangle();
@@ -1775,7 +1775,7 @@ bool KDockManager::eventFilter( TQObject *obj, TQEvent *event )
             break;
           } else {
             if (dropCancel && curdw) {
-              d->dragRect = TQRect(curdw->geometry());
+              d->dragRect = TQRect(curdw->tqgeometry());
               TQPoint p = curdw->mapToGlobal(TQPoint(0,0));
               d->dragRect.moveTopLeft(p);
             }else
@@ -1803,7 +1803,7 @@ bool KDockManager::eventFilter( TQObject *obj, TQEvent *event )
           if (d->readyToDrag) {
             d->readyToDrag = false;
           }
-          if ( (((TQMouseEvent*)event)->state() == LeftButton) &&
+          if ( (((TQMouseEvent*)event)->state() == Qt::LeftButton) &&
                (curdw->eDocking != (int)KDockWidget::DockNone) ) {
             startDrag( curdw);
           }
@@ -1831,7 +1831,7 @@ KDockWidget* KDockManager::findDockWidgetAt( const TQPoint& pos )
     return 0L;
   }
 #if defined(_OS_WIN32_) || defined(Q_OS_WIN32)
-  p = p->topLevelWidget();
+  p = p->tqtopLevelWidget();
 #endif
   TQWidget* w = 0L;
   findChildDockWidget( w, p, p->mapFromGlobal(pos) );
@@ -1841,8 +1841,8 @@ KDockWidget* KDockManager::findDockWidgetAt( const TQPoint& pos )
     }
     w = p;
   }
-  if ( qt_find_obj_child( w, "KDockSplitter", "_dock_split_" ) ) return 0L;
-  if ( qt_find_obj_child( w, "KDockTabGroup", "_dock_tab" ) ) return 0L;
+  if ( qt_find_obj_child( TQT_TQOBJECT(w), "KDockSplitter", "_dock_split_" ) ) return 0L;
+  if ( qt_find_obj_child( TQT_TQOBJECT(w), "KDockTabGroup", "_dock_tab" ) ) return 0L;
   if (dynamic_cast<KDockContainer*>(w)) return 0L;
 
   if (!childDockWidgetList) return 0L;
@@ -1884,14 +1884,15 @@ KDockWidget* KDockManager::findDockWidgetAt( const TQPoint& pos )
 
 void KDockManager::findChildDockWidget( TQWidget*& ww, const TQWidget* p, const TQPoint& pos )
 {
-  if ( p->children() ) {
+  TQObjectList clo = p->childrenListObject();
+  if ( !clo.isEmpty() ) {
     TQWidget *w;
-    TQObjectListIt it( *p->children() );
+    TQObjectListIt it( clo );
     it.toLast();
     while ( it.current() ) {
       if ( it.current()->isWidgetType() ) {
         w = (TQWidget*)it.current();
-        if ( w->isVisible() && w->geometry().contains(pos) ) {
+        if ( w->isVisible() && w->tqgeometry().contains(pos) ) {
           if ( w->inherits("KDockWidget") ) ww = w;
           findChildDockWidget( ww, w, w->mapFromParent(pos) );
           return;
@@ -1905,9 +1906,10 @@ void KDockManager::findChildDockWidget( TQWidget*& ww, const TQWidget* p, const
 
 void KDockManager::findChildDockWidget( const TQWidget* p, TQWidgetList*& list )
 {
-  if ( p->children() ) {
+  TQObjectList clo = p->childrenListObject();
+  if ( !clo.isEmpty() ) {
     TQWidget *w;
-    TQObjectListIt it( *p->children() );
+    TQObjectListIt it( clo );
     it.toLast();
     while ( it.current() ) {
       if ( it.current()->isWidgetType() ) {
@@ -2049,7 +2051,7 @@ static TQDomElement createStringEntry(TQDomDocument &doc, const TQString &tagNam
 
 static TQDomElement createBoolEntry(TQDomDocument &doc, const TQString &tagName, bool b)
 {
-    return createStringEntry(doc, tagName, TQString::fromLatin1(b? "true" : "false"));
+    return createStringEntry(doc, tagName, TQString::tqfromLatin1(b? "true" : "false"));
 }
 
 
@@ -2088,7 +2090,7 @@ static TQDomElement createListEntry(TQDomDocument &doc, const TQString &tagName,
     TQStrListIterator it(list);
     for (; it.current(); ++it) {
         TQDomElement subel = doc.createElement(subTagName);
-        subel.appendChild(doc.createTextNode(TQString::fromLatin1(it.current())));
+        subel.appendChild(doc.createTextNode(TQString::tqfromLatin1(it.current())));
         el.appendChild(subel);
     }
 
@@ -2157,8 +2159,8 @@ void KDockManager::writeConfig(TQDomElement &base)
     TQObjectListIt it(*childDock);
     KDockWidget *obj1;
     while ( (obj1=(KDockWidget*)it.current()) ) {
-        if ( obj1->parent() == main )
-            mainWidgetStr = TQString::fromLatin1(obj1->name());
+        if ( TQT_BASE_OBJECT(obj1->parent()) == TQT_BASE_OBJECT(main) )
+            mainWidgetStr = TQString::tqfromLatin1(obj1->name());
         nList.append(obj1->name());
         ++it;
     }
@@ -2176,7 +2178,7 @@ void KDockManager::writeConfig(TQDomElement &base)
         KDockWidget *obj = getDockWidgetFromName( *nListIt);
         if ((obj->isGroup && (!obj->d->isContainer)) && (nameList.find( obj->firstName.latin1() ) == -1
                              || nameList.find(obj->lastName.latin1()) == -1)) {
-            // Skip until children are saved (why?)
+            // Skip until tqchildren are saved (why?)
             ++nListIt;
 //            nList.next();
 //falk?            if ( !nList.current() ) nList.first();
@@ -2223,7 +2225,7 @@ void KDockManager::writeConfig(TQDomElement &base)
             }
         }
 
-        groupEl.appendChild(createStringEntry(doc, "name", TQString::fromLatin1(obj->name())));
+        groupEl.appendChild(createStringEntry(doc, "name", TQString::tqfromLatin1(obj->name())));
         groupEl.appendChild(createBoolEntry(doc, "hasParent", obj->parent()));
         if ( !obj->parent() ) {
             groupEl.appendChild(createRectEntry(doc, "geometry", TQRect(main->frameGeometry().topLeft(), main->size())));
@@ -2345,7 +2347,7 @@ void KDockManager::readConfig(TQDomElement &base)
             KDockWidget *second = getDockWidgetFromName(secondName);
             if (first && second) {
                 obj = first->manualDock(second,
-                                        (orientation == (int)Vertical)? KDockWidget::DockLeft : KDockWidget::DockTop,
+				(orientation == (int)Qt::Vertical)? KDockWidget::DockLeft : KDockWidget::DockTop,
                                         separatorPos);
                 if (obj)
                     obj->setName(name.latin1());
@@ -2456,7 +2458,7 @@ void KDockManager::removeFromAutoCreateList(KDockWidget* pDockWidget)
 {
     if (!autoCreateDock) return;
     autoCreateDock->setAutoDelete(false);
-    autoCreateDock->removeRef(pDockWidget);
+    autoCreateDock->removeRef(TQT_TQOBJECT(pDockWidget));
     autoCreateDock->setAutoDelete(true);
 }
 
@@ -2492,11 +2494,11 @@ void KDockManager::writeConfig( KConfig* c, TQString group )
     ++it;
     //debug("  +Add subdock %s", obj->name());
     nList.append( obj->name() );
-    if ( obj->parent() == main )
+    if ( TQT_BASE_OBJECT(obj->parent()) == TQT_BASE_OBJECT(main) )
       c->writeEntry( "Main:view", obj->name() );
   }
 
-//  kdDebug(282)<<TQString("list size: %1").arg(nList.count())<<endl;
+//  kdDebug(282)<<TQString("list size: %1").tqarg(nList.count())<<endl;
   for (TQObjectListIt it(d->containerDocks);it.current();++it)
   {
   	KDockContainer* dc = dynamic_cast<KDockContainer*>(((KDockWidget*)it.current())->widget);
@@ -2504,7 +2506,7 @@ void KDockManager::writeConfig( KConfig* c, TQString group )
 		dc->prepareSave(nList);
 	}
   }
-//  kdDebug(282)<<TQString("new list size: %1").arg(nList.count())<<endl;
+//  kdDebug(282)<<TQString("new list size: %1").tqarg(nList.count())<<endl;
 
   TQStringList::Iterator nListIt=nList.begin();
   while ( nListIt!=nList.end() ){
@@ -2527,7 +2529,7 @@ void KDockManager::writeConfig( KConfig* c, TQString group )
         c->writeEntry( cname+":type", "GROUP");
         if ( !obj->parent() ){
           c->writeEntry( cname+":parent", "___null___");
-          c->writeEntry( cname+":geometry", TQRect(obj->frameGeometry().topLeft(), obj->size()) );
+          c->writeEntry( cname+":tqgeometry", TQRect(obj->frameGeometry().topLeft(), obj->size()) );
           c->writeEntry( cname+":visible", obj->isVisible());
         } else {
           c->writeEntry( cname+":parent", "yes");
@@ -2559,7 +2561,7 @@ void KDockManager::writeConfig( KConfig* c, TQString group )
         c->writeEntry( cname+":type", "TAB_GROUP");
         if ( !obj->parent() ){
           c->writeEntry( cname+":parent", "___null___");
-          c->writeEntry( cname+":geometry", TQRect(obj->frameGeometry().topLeft(), obj->size()) );
+          c->writeEntry( cname+":tqgeometry", TQRect(obj->frameGeometry().topLeft(), obj->size()) );
           c->writeEntry( cname+":visible", obj->isVisible());
           c->writeEntry( cname+":dockBackTo", obj->formerBrotherDockWidget ? obj->formerBrotherDockWidget->name() : "");
           c->writeEntry( cname+":dockBackToPos", obj->formerDockPos);
@@ -2583,7 +2585,7 @@ void KDockManager::writeConfig( KConfig* c, TQString group )
         c->writeEntry( cname+":tabToolTip", obj->toolTipString());
         if ( !obj->parent() ){
           c->writeEntry( cname+":type", "NULL_DOCK");
-          c->writeEntry( cname+":geometry", TQRect(obj->frameGeometry().topLeft(), obj->size()) );
+          c->writeEntry( cname+":tqgeometry", TQRect(obj->frameGeometry().topLeft(), obj->size()) );
           c->writeEntry( cname+":visible", obj->isVisible());
           c->writeEntry( cname+":dockBackTo", obj->formerBrotherDockWidget ? obj->formerBrotherDockWidget->name() : "");
           c->writeEntry( cname+":dockBackToPos", obj->formerDockPos);
@@ -2658,7 +2660,7 @@ void KDockManager::readConfig( KConfig* c, TQString group )
     obj = 0L;
 
     if ( type == "NULL_DOCK" || c->readEntry( oname + ":parent") == "___null___" ){
-      TQRect r = c->readRectEntry( oname + ":geometry" );
+      TQRect r = c->readRectEntry( oname + ":tqgeometry" );
       obj = getDockWidgetFromName( oname );
       obj->applyToWidget( 0L );
       obj->setGeometry(r);
@@ -2700,9 +2702,9 @@ void KDockManager::readConfig( KConfig* c, TQString group )
       KDockWidget* last  = getDockWidgetFromName( c->readEntry( oname + ":last_name"  ) );
       int sepPos = c->readNumEntry( oname + ":sepPos" );
 
-      Orientation p = (Orientation)c->readNumEntry( oname + ":orientation" );
+      Qt::Orientation p = (Qt::Orientation)c->readNumEntry( oname + ":orientation" );
       if ( first  && last ){
-        obj = first->manualDock( last, ( p == Vertical ) ? KDockWidget::DockLeft : KDockWidget::DockTop, sepPos );
+        obj = first->manualDock( last, ( p ==Qt::Vertical ) ? KDockWidget::DockLeft : KDockWidget::DockTop, sepPos );
         if (obj){
           obj->setName( oname.latin1() );
         }
@@ -2828,8 +2830,8 @@ KDockWidget* KDockManager::getDockWidgetFromName( const TQString& dockName )
   KDockWidget* autoCreate = 0L;
   if ( autoCreateDock ){
     kdDebug(282)<<"Autocreating dock: "<<dockName<<endl;
-    autoCreate = new KDockWidget( this, dockName.latin1(), TQPixmap("") );
-    autoCreateDock->append( autoCreate );
+    autoCreate = new KDockWidget( this, dockName.latin1(), TQPixmap(TQString("")) );
+    autoCreateDock->append( TQT_TQOBJECT(autoCreate) );
   }
   return autoCreate;
 }
@@ -2875,13 +2877,13 @@ void KDockManager::slotMenuPopup()
     ++it;
     if ( obj->mayBeHide() )
     {
-      menu->insertItem( obj->icon() ? *(obj->icon()) : TQPixmap(), i18n("Hide %1").arg(obj->caption()), numerator++ );
+      menu->insertItem( obj->icon() ? *(obj->icon()) : TQPixmap(), i18n("Hide %1").tqarg(obj->caption()), numerator++ );
       menuData->append( new MenuDockData( obj, true ) );
     }
 
     if ( obj->mayBeShow() )
     {
-      menu->insertItem( obj->icon() ? *(obj->icon()) : TQPixmap(), i18n("Show %1").arg(obj->caption()), numerator++ );
+      menu->insertItem( obj->icon() ? *(obj->icon()) : TQPixmap(), i18n("Show %1").tqarg(obj->caption()), numerator++ );
       menuData->append( new MenuDockData( obj, false ) );
     }
   }
@@ -2933,14 +2935,14 @@ void KDockManager::drawDragRectangle()
     KDockMainWindow* pMain = 0L;
     KDockWidget* pTLDockWdg = 0L;
     TQWidget* topWdg;
-    if (pDockWdgAtRect->topLevelWidget() == main) {
+    if (pDockWdgAtRect->tqtopLevelWidget() == main) {
       isOverMainWdg = true;
       topWdg = pMain = (KDockMainWindow*) main;
       unclipped = pMain->testWFlags( WPaintUnclipped );
       pMain->setWFlags( WPaintUnclipped );
     }
     else {
-      topWdg = pTLDockWdg = (KDockWidget*) pDockWdgAtRect->topLevelWidget();
+      topWdg = pTLDockWdg = (KDockWidget*) pDockWdgAtRect->tqtopLevelWidget();
       unclipped = pTLDockWdg->testWFlags( WPaintUnclipped );
       pTLDockWdg->setWFlags( WPaintUnclipped );
     }
@@ -2955,7 +2957,7 @@ void KDockManager::drawDragRectangle()
           pTLDockWdg->clearWFlags(WPaintUnclipped);
       }
       // draw the rectangle
-      p.setRasterOp(Qt::NotXorROP);
+      p.setRasterOp(TQt::NotXorROP);
       TQRect r = oldAndNewDragRect[i];
       r.moveTopLeft( r.topLeft() - topWdg->mapToGlobal(TQPoint(0,0)) );
       p.drawRect(r.x(), r.y(), r.width(), r.height());
@@ -3040,11 +3042,11 @@ void KDockArea::slotDockWidgetUndocked()
 void KDockArea::resizeEvent(TQResizeEvent *rsize)
 {
   TQWidget::resizeEvent(rsize);
-  if (children()){
+  if (!childrenListObject().isEmpty()){
 #ifndef NO_KDE2
 //    kdDebug(282)<<"KDockArea::resize"<<endl;
 #endif
-    TQObjectList *list=queryList("TQWidget",0,false);
+    TQObjectList *list=queryList(TQWIDGET_OBJECT_NAME_STRING,0,false);
 
     TQObjectListIt it( *list ); // iterate over the buttons
     TQObject *obj;
@@ -3057,11 +3059,11 @@ void KDockArea::resizeEvent(TQResizeEvent *rsize)
     delete list;
 #if 0
     KDockSplitter *split;
-//    for (unsigned int i=0;i<children()->count();i++)
+//    for (unsigned int i=0;i<tqchildren()->count();i++)
     {
-//    	TQPtrList<TQObject> list(children());
-//       TQObject *obj=((TQPtrList<TQObject*>)children())->at(i);
-	TQObject *obj=children()->getFirst();
+//    	TQPtrList<TQObject> list(tqchildren());
+//       TQObject *obj=((TQPtrList<TQObject*>)tqchildren())->at(i);
+	TQObject *obj=tqchildren()->getFirst();
        if (split = dynamic_cast<KDockSplitter*>(obj))
        {
           split->setGeometry( TQRect(TQPoint(0,0), size() ));
@@ -3094,12 +3096,12 @@ void KDockArea::setMainDockWidget( KDockWidget* mdw )
 
 
 // KDOCKCONTAINER - AN ABSTRACTION OF THE KDOCKTABWIDGET
-KDockContainer::KDockContainer(){m_overlapMode=false; m_childrenListBegin=0; m_childrenListEnd=0;}
+KDockContainer::KDockContainer(){m_overlapMode=false; m_tqchildrenListBegin=0; m_tqchildrenListEnd=0;}
 KDockContainer::~KDockContainer(){
 
-	if (m_childrenListBegin)
+	if (m_tqchildrenListBegin)
 	{
-		struct ListItem *tmp=m_childrenListBegin;
+		struct ListItem *tmp=m_tqchildrenListBegin;
 		while (tmp)
 		{
 			struct ListItem *tmp2=tmp->next;
@@ -3107,8 +3109,8 @@ KDockContainer::~KDockContainer(){
 			delete tmp;
 			tmp=tmp2;
 		}
-		m_childrenListBegin=0;
-		m_childrenListEnd=0;
+		m_tqchildrenListBegin=0;
+		m_tqchildrenListEnd=0;
 	}
 
 }
@@ -3154,7 +3156,7 @@ KDockWidget *KDockContainer::parentDockWidget(){return 0;}
 
 TQStringList KDockContainer::containedWidgets() const {
 	TQStringList tmp;
-	for (struct ListItem *it=m_childrenListBegin;it;it=it->next) {
+	for (struct ListItem *it=m_tqchildrenListBegin;it;it=it->next) {
 		tmp<<TQString(it->data);
 	}
 
@@ -3170,36 +3172,36 @@ void KDockContainer::insertWidget (KDockWidget *dw, TQPixmap, const TQString &,
 		it->data=strdup(dw->name());
 		it->next=0;
 
-		if (m_childrenListEnd)
+		if (m_tqchildrenListEnd)
 		{
-			m_childrenListEnd->next=it;
-			it->prev=m_childrenListEnd;
-			m_childrenListEnd=it;
+			m_tqchildrenListEnd->next=it;
+			it->prev=m_tqchildrenListEnd;
+			m_tqchildrenListEnd=it;
 		}
 		else
 		{
 			it->prev=0;
-			m_childrenListEnd=it;
-			m_childrenListBegin=it;
+			m_tqchildrenListEnd=it;
+			m_tqchildrenListBegin=it;
 		}
 	}
 void KDockContainer::removeWidget (KDockWidget *dw){
-	for (struct ListItem *tmp=m_childrenListBegin;tmp;tmp=tmp->next)
+	for (struct ListItem *tmp=m_tqchildrenListBegin;tmp;tmp=tmp->next)
 	{
 		if (!strcmp(tmp->data,dw->name()))
 		{
 			free(tmp->data);
 			if (tmp->next) tmp->next->prev=tmp->prev;
 			if (tmp->prev) tmp->prev->next=tmp->next;
-			if (tmp==m_childrenListBegin) m_childrenListBegin=tmp->next;
-			if (tmp==m_childrenListEnd) m_childrenListEnd=tmp->prev;
+			if (tmp==m_tqchildrenListBegin) m_tqchildrenListBegin=tmp->next;
+			if (tmp==m_tqchildrenListEnd) m_tqchildrenListEnd=tmp->prev;
 			delete tmp;
 			break;
 		}
 	}
 }
 
-//m_children.remove(dw->name());}
+//m_tqchildren.remove(dw->name());}
 void KDockContainer::undockWidget (KDockWidget *){;}
 void KDockContainer::setToolTip(KDockWidget *, TQString &){;}
 void KDockContainer::setPixmap(KDockWidget*,const TQPixmap&){;}
@@ -3210,11 +3212,11 @@ void KDockContainer::save (TQDomElement&){;}
 void KDockContainer::prepareSave(TQStringList &names)
 {
 
-	for (struct ListItem *tmp=m_childrenListBegin;tmp; tmp=tmp->next)
+	for (struct ListItem *tmp=m_tqchildrenListBegin;tmp; tmp=tmp->next)
 		names.remove(tmp->data);
-//	for (uint i=0;i<m_children.count();i++)
+//	for (uint i=0;i<m_tqchildren.count();i++)
 //	{
-//		names.remove(m_children.at(i));
+//		names.remove(m_tqchildren.at(i));
 //	}
 }
 
@@ -3268,6 +3270,6 @@ void KDockArea::virtual_hook( int, void* )
 { /*KMainWindow::virtual_hook( id, data );*/ }
 
 
-#ifndef NO_INCLUDE_MOCFILES // for Qt-only projects, because tmake doesn't take this name
+#ifndef NO_INCLUDE_TQMOCFILES // for TQt-only projects, because tmake doesn't take this name
 #include "kdockwidget.moc"
 #endif
