@@ -37,9 +37,9 @@
    - KDockWidget                   - IMPORTANT CLASS: the one and only dockwidget class
    - KDockManager                  - helper class
    - KDockMainWindow               - IMPORTANT CLASS: a special KMainWindow that can have dockwidgets
-   - KDockArea                     - like KDockMainWindow but inherits just QWidget
+   - KDockArea                     - like KDockMainWindow but inherits just TQWidget
 
-   IMPORTANT Note: This file compiles also in Qt-only mode by using the NO_KDE2 precompiler definition!
+   IMPORTANT Note: This file compiles also in TQt-only mode by using the NO_KDE2 precompiler definition!
 */
 
 
@@ -102,9 +102,10 @@ namespace KMDI
  *
  * @author Max Judin (documentation: Falk Brettschneider).
  */
-class KDockWidgetAbstractHeader : public QFrame
+class KDockWidgetAbstractHeader : public TQFrame
 {
   Q_OBJECT
+  TQ_OBJECT
 public:
 
   /**
@@ -151,9 +152,10 @@ private:
  *
  * @author Max Judin (documentation: Falk Brettschneider).
  */
-class KDEUI_EXPORT KDockWidgetAbstractHeaderDrag : public QFrame
+class KDEUI_EXPORT KDockWidgetAbstractHeaderDrag : public TQFrame
 {
   Q_OBJECT
+  TQ_OBJECT
 public:
 
   /**
@@ -199,6 +201,7 @@ private:
 class KDEUI_EXPORT KDockWidgetHeaderDrag : public KDockWidgetAbstractHeaderDrag
 {
   Q_OBJECT
+  TQ_OBJECT
 public:
 
   /**
@@ -240,6 +243,7 @@ private:
 class KDEUI_EXPORT KDockWidgetHeader : public KDockWidgetAbstractHeader
 {
   Q_OBJECT
+  TQ_OBJECT
 public:
 
   /**
@@ -324,9 +328,9 @@ protected slots:
 protected:
 
   /**
-   * A layout manager for placing the embedded buttons (close and stay)
+   * A tqlayout manager for placing the embedded buttons (close and stay)
    */
-  TQHBoxLayout* layout;
+  TQHBoxLayout* tqlayout;
 
   /**
    * a little button for closing (undocking and hiding) the dockwidget
@@ -362,9 +366,10 @@ private:
  *
  * @author Max Judin (documentation: Falk Brettschneider).
  */
-class KDEUI_EXPORT KDockTabGroup : public QTabWidget
+class KDEUI_EXPORT KDockTabGroup : public TQTabWidget
 {
   Q_OBJECT
+  TQ_OBJECT
 public:
   /**
    * Constructs this. It just calls the method of the base class.
@@ -422,9 +427,10 @@ private:
  *
  * @author Max Judin (documentation: Falk Brettschneider).
  */
-class KDEUI_EXPORT KDockWidget: public QWidget
+class KDEUI_EXPORT KDockWidget: public TQWidget
 {
   Q_OBJECT
+  TQ_OBJECT
 friend class KDockManager;
 friend class KDockSplitter;
 friend class KDockMainWindow;
@@ -444,11 +450,11 @@ public:
    * @param parent      Parent widget
    * @param strCaption  Title of the dockwidget window (shown when toplevel)
    * @param strTabPageLabel The title of the tab page (shown when in tab page mode), if it is "", only the icon will be shown, if it is 0L, the label is set to strCaption
-   * @param f Qt::WidgetFlags widget flags
+   * @param f TQt::WidgetFlags widget flags
    */
   KDockWidget( KDockManager* dockManager, const char* name,
-               const TQPixmap &pixmap, TQWidget* parent = 0L, const TQString& strCaption = TQString::null,
-               const TQString& strTabPageLabel = TQString::fromLatin1( " " ), WFlags f = 0);
+               const TQPixmap &pixmap, TQWidget* parent = 0L, const TQString& strCaption = TQString(),
+               const TQString& strTabPageLabel = TQString::tqfromLatin1( " " ), WFlags f = 0);
 
   /**
    * Destructs a dockwidget.
@@ -850,9 +856,9 @@ private:
   TQWidget* widget;
 
   /**
-   * the layout manager that takes care about proper resizing and moving the embedded widget and the header
+   * the tqlayout manager that takes care about proper resizing and moving the embedded widget and the header
    */
-  TQVBoxLayout* layout;
+  TQVBoxLayout* tqlayout;
 
   /**
    * the responsible dockmanager
@@ -882,7 +888,7 @@ private:
   // GROUP data
   TQString firstName;
   TQString lastName;
-  Orientation splitterOrientation;
+  Qt::Orientation splitterOrientation;
   bool isGroup;
   bool isTabGroup;
 protected:
@@ -903,9 +909,10 @@ private:
  *
  * @author Max Judin (documentation: Falk Brettschneider).
  */
-class KDEUI_EXPORT KDockManager: public QObject
+class KDEUI_EXPORT KDockManager: public TQObject
 {
   Q_OBJECT
+  TQ_OBJECT
 friend class KDockWidget;
 friend class KDockMainWindow;
 
@@ -925,7 +932,7 @@ public:
    * @li Some state variables are set
    *
    * @param mainWindow the main window controlled by this
-   * @param name the internal QOject name
+   * @param name the internal TQOject name
    */
   KDockManager( TQWidget* mainWindow, const char* name = 0L );
 
@@ -939,14 +946,14 @@ public:
 #ifndef NO_KDE2
   /**
    * Saves the current state of the dockmanager and of all controlled widgets.
-   * State means here to save the geometry, visibility, parents, internal object names, orientation,
+   * State means here to save the tqgeometry, visibility, parents, internal object names, orientation,
    * separator positions, dockwidget-group information, tab widget states (if it is a tab group) and
    * last but not least some necessary things for recovering the dockmainwindow state.
    *
    * @param c the KDE configuration saver
    * @param group the name of the section in KConfig
    */
-  void writeConfig( KConfig* c = 0L, TQString group = TQString::null );
+  void writeConfig( KConfig* c = 0L, TQString group = TQString() );
 
   /**
    * Like writeConfig but reads the whole stuff in.
@@ -956,7 +963,7 @@ public:
    * (TQObject::name) in the childDock variable of
    * KDockManager. This list in turn contains all
    * KDockWidgets (according to the KDockWidget constructor).
-   * So in principle, in order to restore a window layout,
+   * So in principle, in order to restore a window tqlayout,
    * one must first construct all widgets, put each of them in a
    * KDockWidget and then call readConfig(). And for all that
    * to work, each widget must have a unique name.
@@ -964,18 +971,18 @@ public:
    * @param c the KDE configuration saver
    * @param group the name of the section in KConfig
    */
-  void readConfig ( KConfig* c = 0L, TQString group = TQString::null );
+  void readConfig ( KConfig* c = 0L, TQString group = TQString() );
 #endif
 
   /// @since 3.1
   void setMainDockWidget2(KDockWidget *);
 
   /**
-   * Saves the current dock window layout into a DOM tree below the given element.
+   * Saves the current dock window tqlayout into a DOM tree below the given element.
    */
   void writeConfig(TQDomElement &base);
   /**
-   * Reads the current dock window layout from a DOM tree below the given element.
+   * Reads the current dock window tqlayout from a DOM tree below the given element.
    */
   void readConfig(TQDomElement &base);
 
@@ -1202,7 +1209,7 @@ private:
   KDockWidget::DockPosition curPos;
 
   /**
-   * A QList of all objects that are important for docking.
+   * A TQList of all objects that are important for docking.
    * Some serve as group widgets of dockwidgets, others encapsulate normal widgets.
    */
   TQObjectList* childDock;
@@ -1302,6 +1309,7 @@ private:
 class KDEUI_EXPORT KDockMainWindow : public KMainWindow
 {
   Q_OBJECT
+  TQ_OBJECT
 
 friend class KDockManager;
 
@@ -1310,14 +1318,14 @@ public:
   /**
    * Constructs a dockmainwindow. It calls its base class constructor and does additional things concerning
    * to the dock stuff:
-   * @li information about the dock state of this' children gets initialized
+   * @li information about the dock state of this' tqchildren gets initialized
    * @li a dockmanager is created...
    * @li ...and gets initialized
    * @li the main dockwidget is set to 0
    *
    * @param parent Parent widget for the dock main widget
    * @param name internal object name
-   * @param f Qt::WidgetFlags widget flags
+   * @param f TQt::WidgetFlags widget flags
    */
   KDockMainWindow( TQWidget* parent = 0L, const char *name = 0L, WFlags f = WType_TopLevel | WDestructiveClose );
 
@@ -1360,14 +1368,14 @@ public:
    * @return    a pointer to the new created dockwidget
    */
   KDockWidget* createDockWidget( const TQString& name, const TQPixmap &pixmap, TQWidget* parent = 0L,
-    const TQString& strCaption = TQString::null, const TQString& strTabPageLabel = TQString::fromLatin1( " " ) );
+    const TQString& strCaption = TQString(), const TQString& strTabPageLabel = TQString::tqfromLatin1( " " ) );
 
   /**
-   * Saves the current dock window layout into a DOM tree below the given element.
+   * Saves the current dock window tqlayout into a DOM tree below the given element.
    */
   void writeDockConfig(TQDomElement &base);
   /**
-   * Reads the current dock window layout from a DOM tree below the given element.
+   * Reads the current dock window tqlayout from a DOM tree below the given element.
    */
   void readDockConfig(TQDomElement &base);
 
@@ -1378,7 +1386,7 @@ public:
    * @param c     KDE class for saving configurations
    * @param group name of section to write to
    */
-  void writeDockConfig( KConfig* c = 0L, TQString group = TQString::null );
+  void writeDockConfig( KConfig* c = 0L, TQString group = TQString() );
 
   /**
    * It reads the current dock state from the given section of KConfig.
@@ -1386,7 +1394,7 @@ public:
    * @param c     KDE class for saving configurations
    * @param group name of section to read from
    */
-  void readDockConfig ( KConfig* c = 0L, TQString group = TQString::null );
+  void readDockConfig ( KConfig* c = 0L, TQString group = TQString() );
 #endif
 
   /**
@@ -1465,9 +1473,10 @@ private:
   KDockMainWindowPrivate *d;
 };
 
-class KDEUI_EXPORT KDockArea : public QWidget
+class KDEUI_EXPORT KDockArea : public TQWidget
 {
   Q_OBJECT
+  TQ_OBJECT
 
 friend class KDockManager;
 
@@ -1485,14 +1494,14 @@ public:
   KDockWidget* getMainDockWidget(){ return mainDockWidget; }
 
   KDockWidget* createDockWidget( const TQString& name, const TQPixmap &pixmap, TQWidget* parent = 0L,
-    const TQString& strCaption = TQString::null, const TQString& strTabPageLabel = TQString::fromLatin1( " " ) );
+    const TQString& strCaption = TQString(), const TQString& strTabPageLabel = TQString::tqfromLatin1( " " ) );
 
   void writeDockConfig(TQDomElement &base);
   void readDockConfig(TQDomElement &base);
 
 #ifndef NO_KDE2
-  void writeDockConfig( KConfig* c = 0L, TQString group = TQString::null );
-  void readDockConfig ( KConfig* c = 0L, TQString group = TQString::null );
+  void writeDockConfig( KConfig* c = 0L, TQString group = TQString() );
+  void readDockConfig ( KConfig* c = 0L, TQString group = TQString() );
 #endif
 
 
