@@ -6,8 +6,8 @@
 //    begin                : 07/1999       by Szymon Stefanek as part of kvirc
 //                                         (an IRC application)
 //    changes              : 09/1999       by Falk Brettschneider to create an
-//                           - 06/2000     stand-alone Qt extension set of
-//                                         classes and a Qt-based library
+//                           - 06/2000     stand-alone TQt extension set of
+//                                         classes and a TQt-based library
 //                           2000-2003     maintained by the KDevelop project
 //    patches              : 02/2000       by Massimo Morin (mmorin@schedsys.com)
 //                           */2000        by Lars Beikirch (Lars.Beikirch@gmx.net)
@@ -71,7 +71,7 @@ class KMdiChildViewPrivate;
   *   KMdiChildView* pMDICover = new KMdiChildView( pNewView->caption());
   *   pMDICover->setIcon(icon);
   *   m_MDICoverList.append( pMDICover);
-  *   TQBoxLayout* pLayout = new TQHBoxLayout( pMDICover, 0, -1, "layout");
+  *   TQBoxLayout* pLayout = new TQHBoxLayout( pMDICover, 0, -1, "tqlayout");
   *   pNewView->reparent( pMDICover, TQPoint(0,0));
   *   pLayout->addWidget( pNewView);
   *   pMDICover->setName( pNewView->name());
@@ -105,11 +105,12 @@ class KMdiChildViewPrivate;
   *
   */
 
-class KMDI_EXPORT KMdiChildView : public QWidget
+class KMDI_EXPORT KMdiChildView : public TQWidget
 {
 	friend class KMdiMainFrm;
 	friend class KMdiChildFrm;
 	Q_OBJECT
+  TQ_OBJECT
 
 	// attributes
 protected:
@@ -270,12 +271,12 @@ public:
 	bool isMaximized() const;
 	
 	/**
-	 * Returns the geometry of this MDI child window as TQWidget::geometry() does.
+	 * Returns the tqgeometry of this MDI child window as TQWidget::tqgeometry() does.
 	 */
 	TQRect internalGeometry() const;
 	
 	/**
-	 * Sets the geometry of the client area of this MDI child window. The
+	 * Sets the tqgeometry of the client area of this MDI child window. The
 	 * top left position of the argument is the position of the top left point
 	 * of the client area in its parent coordinates and the arguments width
 	 * and height is the width and height of the client area. Please note: This
@@ -284,12 +285,12 @@ public:
 	void setInternalGeometry( const TQRect& newGeomety );
 	
 	/**
-	 * Returns the frame geometry of this window or of the parent if there is any...
+	 * Returns the frame tqgeometry of this window or of the parent if there is any...
 	 */
 	TQRect externalGeometry() const;
 	
 	/**
-	 * Sets the geometry of the frame of this MDI child window. The top left
+	 * Sets the tqgeometry of the frame of this MDI child window. The top left
 	 * position of the argument is the position of the top left point of the
 	 * frame in its parent coordinates and the arguments width and height is
 	 * the width and height of the widget frame. Please note: This differs
@@ -315,12 +316,12 @@ public:
 	virtual void maximize( bool bAnimate );
 	
 	/**
-	 * Returns the geometry that will be restored by calling restore().
+	 * Returns the tqgeometry that will be restored by calling restore().
 	 */
 	TQRect restoreGeometry();
 	
 	/**
-	 * Sets the geometry that will be restored by calling restore().
+	 * Sets the tqgeometry that will be restored by calling restore().
 	 */
 	void setRestoreGeometry( const TQRect& newRestGeo );
 	
@@ -358,7 +359,7 @@ public:
 	 */
 	inline void updateTimeStamp()
 	{
-		m_time.setDate( TQDate::currentDate() );
+		m_time.setDate( TQDate::tqcurrentDate() );
 		m_time.setTime( TQTime::currentTime() );
 	}
 	
@@ -465,7 +466,7 @@ protected:
 	virtual void closeEvent( TQCloseEvent *e );
 	
 	/**
-	 * It only catches TQEvent::KeyPress events there. If a Qt::Key_Tab is pressed, the internal MDI focus
+	 * It only catches TQEvent::KeyPress events there. If a TQt::Key_Tab is pressed, the internal MDI focus
 	 * handling is called. That means if the last focusable child widget of this is called, it will jump to the
 	 * first focusable child widget of this.
 	 * See KMdiChildView::setFirstFocusableChildWidget and KMdiChildView::lastFirstFocusableChildWidget
