@@ -70,9 +70,9 @@ KMdiDockContainer::KMdiDockContainer( TQWidget *parent, TQWidget *win, int posit
 
 
 	if ( m_horizontal )
-		l = new TQVBoxLayout( this ); //vertical layout for top and bottom docks
+		l = new TQVBoxLayout( this ); //vertical tqlayout for top and bottom docks
 	else
-		l = new TQHBoxLayout( this ); //horizontal layout for left and right docks
+		l = new TQHBoxLayout( this ); //horizontal tqlayout for left and right docks
 
 	l->setAutoAdd( false );
 
@@ -104,9 +104,9 @@ KMdiDockContainer::KMdiDockContainer( TQWidget *parent, TQWidget *win, int posit
 
 	m_ws = new TQWidgetStack( this );
 
-	m_ws->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
+	m_ws->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
 
-	//layout the tabbar
+	//tqlayout the tabbar
 	if ( position == KDockWidget::DockLeft || position == KDockWidget::DockTop )
 	{
 		//add the tabbar then the widget stack
@@ -277,7 +277,7 @@ bool KMdiDockContainer::eventFilter( TQObject *obj, TQEvent *event )
 		}
 		
 		m_dockManager = w->dockManager();
-		m_dragPanel = hdr->dragPanel();
+		m_dragPanel = TQT_TQOBJECT(hdr->dragPanel());
 		
 		if ( m_dragPanel )
 			m_movingState = WaitingForMoveStart;
@@ -300,7 +300,7 @@ bool KMdiDockContainer::eventFilter( TQObject *obj, TQEvent *event )
 			TQPoint p( ( ( TQMouseEvent* ) event )->pos() - m_startEvent->pos() );
 			if ( p.manhattanLength() > KGlobalSettings::dndEventDelay() )
 			{
-				m_dockManager->eventFilter( m_dragPanel, m_startEvent );
+				m_dockManager->eventFilter( m_dragPanel, TQT_TQEVENT(m_startEvent) );
 				m_dockManager->eventFilter( m_dragPanel, event );
 				m_movingState = Moving;
 			}
@@ -514,7 +514,7 @@ void KMdiDockContainer::save( TQDomElement& dockEl )
 	TQDomDocument doc = dockEl.ownerDocument();
 	TQDomElement el;
 	el = doc.createElement( "name" );
-	el.appendChild( doc.createTextNode( TQString( "%1" ).arg( parent() ->name() ) ) );
+	el.appendChild( doc.createTextNode( TQString( "%1" ).tqarg( parent() ->name() ) ) );
 	dockEl.appendChild( el );
 	el = doc.createElement( "overlapMode" );
 	el.appendChild( doc.createTextNode( isOverlapMode() ? "true" : "false" ) );
@@ -526,7 +526,7 @@ void KMdiDockContainer::save( TQDomElement& dockEl )
 	for ( ;it.current() != 0;++it, ++it2 )
 	{
 		el = doc.createElement( "child" );
-		el.setAttribute( "pos", TQString( "%1" ).arg( i ) );
+		el.setAttribute( "pos", TQString( "%1" ).tqarg( i ) );
 		TQString s = tabCaptions[ *it2 ];
 		if ( !s.isEmpty() )
 		{
@@ -624,8 +624,8 @@ void KMdiDockContainer::load( TQDomElement& dockEl )
 void KMdiDockContainer::save( KConfig* cfg, const TQString& group_or_prefix )
 {
 	TQString grp = cfg->group();
-	cfg->deleteGroup( group_or_prefix + TQString( "::%1" ).arg( parent() ->name() ) );
-	cfg->setGroup( group_or_prefix + TQString( "::%1" ).arg( parent() ->name() ) );
+	cfg->deleteGroup( group_or_prefix + TQString( "::%1" ).tqarg( parent() ->name() ) );
+	cfg->setGroup( group_or_prefix + TQString( "::%1" ).tqarg( parent() ->name() ) );
 
 	if ( isOverlapMode() )
 		cfg->writeEntry( "overlapMode", "true" );
@@ -647,17 +647,17 @@ void KMdiDockContainer::save( KConfig* cfg, const TQString& group_or_prefix )
 	int i = 0;
 	for ( ;it.current() != 0;++it, ++it2 )
 	{
-		//    cfg->writeEntry(TQString("widget%1").arg(i),m_ws->widget(it.current()->id())->name());
-		cfg->writeEntry( TQString( "widget%1" ).arg( i ), ( *it2 ) );
+		//    cfg->writeEntry(TQString("widget%1").tqarg(i),m_ws->widget(it.current()->id())->name());
+		cfg->writeEntry( TQString( "widget%1" ).tqarg( i ), ( *it2 ) );
 		TQString s = tabCaptions[ *it2 ];
 		if ( !s.isEmpty() )
 		{
-			cfg->writeEntry( TQString( "widget%1-tabCaption" ).arg( i ), s );
+			cfg->writeEntry( TQString( "widget%1-tabCaption" ).tqarg( i ), s );
 		}
 		s = tabTooltips[ *it2 ];
 		if ( !s.isEmpty() )
 		{
-			cfg->writeEntry( TQString( "widget%1-tabTooltip" ).arg( i ), s );
+			cfg->writeEntry( TQString( "widget%1-tabTooltip" ).tqarg( i ), s );
 		}
 		//    kdDebug(760)<<"****************************************Saving: "<<m_ws->widget(it.current()->id())->name()<<endl;
 		if ( m_tb->isTabRaised( it.current() ->id() ) )
@@ -672,7 +672,7 @@ void KMdiDockContainer::save( KConfig* cfg, const TQString& group_or_prefix )
 void KMdiDockContainer::load( KConfig* cfg, const TQString& group_or_prefix )
 {
 	TQString grp = cfg->group();
-	cfg->setGroup( group_or_prefix + TQString( "::%1" ).arg( parent() ->name() ) );
+	cfg->setGroup( group_or_prefix + TQString( "::%1" ).tqarg( parent() ->name() ) );
 
 	if ( cfg->readEntry( "overlapMode" ) != "false" )
 		activateOverlapMode( m_tb->width() );
@@ -685,19 +685,19 @@ void KMdiDockContainer::load( KConfig* cfg, const TQString& group_or_prefix )
 	TQString raise;
 	while ( true )
 	{
-		TQString dwn = cfg->readEntry( TQString( "widget%1" ).arg( i ) );
+		TQString dwn = cfg->readEntry( TQString( "widget%1" ).tqarg( i ) );
 		if ( dwn.isEmpty() )
 			break;
 		kdDebug( 760 ) << k_funcinfo << "configuring dockwidget :" << dwn << endl;
 		KDockWidget *dw = ( ( KDockWidget* ) parent() ) ->dockManager() ->getDockWidgetFromName( dwn );
 		if ( dw )
 		{
-			TQString s = cfg->readEntry( TQString( "widget%1-tabCaption" ).arg( i ) );
+			TQString s = cfg->readEntry( TQString( "widget%1-tabCaption" ).tqarg( i ) );
 			if ( !s.isEmpty() )
 			{
 				dw->setTabPageLabel( s );
 			}
-			s = cfg->readEntry( TQString( "widget%1-tabTooltip" ).arg( i ) );
+			s = cfg->readEntry( TQString( "widget%1-tabTooltip" ).tqarg( i ) );
 			if ( !s.isEmpty() )
 			{
 				dw->setToolTipString( s );
