@@ -6,8 +6,8 @@
 //    begin                : 07/1999       by Szymon Stefanek as part of kvirc
 //                                         (an IRC application)
 //    changes              : 09/1999       by Falk Brettschneider to create an
-//                           - 06/2000     stand-alone Qt extension set of
-//                                         classes and a Qt-based library
+//                           - 06/2000     stand-alone TQt extension set of
+//                                         classes and a TQt-based library
 //                           2000-2003     maintained by the KDevelop project
 //    patches              : 02/2000       by Massimo Morin (mmorin@schedsys.com)
 //                           */2000        by Lars Beikirch (Lars.Beikirch@gmx.net)
@@ -92,7 +92,7 @@
 #include "kde2laptop_closebutton.xpm"
 #include "kde2laptop_closebutton_menu.xpm"
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 #ifndef NO_KDE
 #include <X11/X.h> // schroder
 #include <X11/Xlib.h> // schroder
@@ -107,7 +107,7 @@
 /* I hate the defines in the X11 header files. Get rid of one of them */
 #undef KeyPress
 #endif
-#endif // Q_WS_X11 && ! K_WS_QTONLY
+#endif // TQ_WS_X11 && ! K_WS_TQTONLY
 
 using namespace KParts;
 
@@ -182,8 +182,8 @@ KMdiMainFrm::KMdiMainFrm( TQWidget* parentWidget, const char* name, KMdi::MdiMod
 	m_pDocumentViews->setAutoDelete( false );
 	m_pToolViews = new TQMap<TQWidget*, KMdiToolViewAccessor*>;
 
-	// This seems to be needed (re-check it after Qt2.0 comed out)
-	setFocusPolicy( ClickFocus );
+	// This seems to be needed (re-check it after TQt2.0 comed out)
+	setFocusPolicy( TQ_ClickFocus );
 
 	// create the central widget
 	createMdiManager();
@@ -217,12 +217,12 @@ KMdiMainFrm::KMdiMainFrm( TQWidget* parentWidget, const char* name, KMdi::MdiMod
 	m_pPlacingMenu = new TQPopupMenu( this, "placing_menu" );
 
 	d->closeWindowAction = new KAction(i18n("&Close"),
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
 		CTRL|Key_F4,
 #else
 		0,
 #endif
-		this, TQT_SLOT(closeActiveView()), actionCollection(), "window_close");
+	    TQT_TQOBJECT(this), TQT_SLOT(closeActiveView()), actionCollection(), "window_close");
 
 	// the MDI view taskbar
 	createTaskBar();
@@ -298,16 +298,16 @@ void KMdiMainFrm::setStandardMDIMenuEnabled( bool showModeMenu )
 //============ ~KMdiMainFrm ============//
 KMdiMainFrm::~KMdiMainFrm()
 {
-	//save the children first to a list, as removing invalidates our iterator
-	TQValueList<KMdiChildView*> children;
+	//save the tqchildren first to a list, as removing invalidates our iterator
+	TQValueList<KMdiChildView*> tqchildren;
 	for ( KMdiChildView * w = m_pDocumentViews->first();w;w = m_pDocumentViews->next() )
-		children.append( w );
+		tqchildren.append( w );
 
 	// safely close the windows so properties are saved...
 	TQValueListIterator<KMdiChildView*> childIt;
-	for ( childIt = children.begin(); childIt != children.end(); ++childIt )
+	for ( childIt = tqchildren.begin(); childIt != tqchildren.end(); ++childIt )
 	{
-		closeWindow( *childIt, false ); // without re-layout taskbar!
+		closeWindow( *childIt, false ); // without re-tqlayout taskbar!
 	}
 
 	emit lastChildViewClosed();
@@ -423,7 +423,7 @@ KMdiChildView* KMdiMainFrm::createWrapper( TQWidget *view, const TQString& name,
 
 	KMdiChildView* pMDICover = new KMdiChildView( name /*caption*/, 0L /*parent*/,
 	                                              name.latin1() );
-	TQBoxLayout* pLayout = new TQHBoxLayout( pMDICover, 0, -1, "layout" );
+	TQBoxLayout* pLayout = new TQHBoxLayout( pMDICover, 0, -1, "tqlayout" );
 	view->reparent( pMDICover, TQPoint( 0, 0 ) );
 	pLayout->addWidget( view );
 	//  pMDICover->setName(name);
@@ -586,7 +586,7 @@ KMdiToolViewAccessor *KMdiMainFrm::addToolWindow( TQWidget* pWnd, KDockWidget::D
 		pWnd = pDW;
 	}
 
-	TQRect r = pWnd->geometry();
+	TQRect r = pWnd->tqgeometry();
 
 	KMdiToolViewAccessor *mtva = new KMdiToolViewAccessor( this, pWnd, tabToolTip, ( tabCaption == 0 ) ? pWnd->caption() : tabCaption );
 	m_pToolViews->insert( tvta, mtva );
@@ -594,7 +594,7 @@ KMdiToolViewAccessor *KMdiMainFrm::addToolWindow( TQWidget* pWnd, KDockWidget::D
 	if ( pos == KDockWidget::DockNone )
 	{
 		mtva->d->widgetContainer->setEnableDocking( KDockWidget::DockNone );
-		mtva->d->widgetContainer->reparent( this, Qt::WType_TopLevel | Qt::WType_Dialog, r.topLeft(), true ); //pToolView->isVisible());
+		mtva->d->widgetContainer->reparent( this, TQt::WType_TopLevel | TQt::WType_Dialog, r.topLeft(), true ); //pToolView->isVisible());
 	}
 	else //add and dock the toolview as a dockwidget view
 		mtva->place( pos, pTargetWnd, percent );
@@ -614,7 +614,7 @@ void KMdiMainFrm::attachWindow( KMdiChildView *pWnd, bool bShow, bool bAutomatic
 	TQRect frameGeo = pWnd->frameGeometry();
 	TQPoint topLeftScreen = pWnd->mapToGlobal( TQPoint( 0, 0 ) );
 	TQPoint topLeftMdiChildArea = m_pMdi->mapFromGlobal( topLeftScreen );
-	TQRect childAreaGeo = m_pMdi->geometry();
+	TQRect childAreaGeo = m_pMdi->tqgeometry();
 	if ( topLeftMdiChildArea.x() < 0 || topLeftMdiChildArea.y() < 0 ||
 	     ( topLeftMdiChildArea.x() + frameGeo.width() > childAreaGeo.width() ) ||
 	     ( topLeftMdiChildArea.y() + frameGeo.height() > childAreaGeo.height() ) )
@@ -643,7 +643,7 @@ void KMdiMainFrm::attachWindow( KMdiChildView *pWnd, bool bShow, bool bAutomatic
 	m_pMdi->manageChild( lpC, false, bCascade );
 	if ( m_pMdi->topChild() && m_pMdi->topChild() ->isMaximized() )
 	{
-		TQRect r = lpC->geometry();
+		TQRect r = lpC->tqgeometry();
 		lpC->setGeometry( -lpC->m_pClient->x(), -lpC->m_pClient->y(),
 		                  m_pMdi->width() + KMDI_CHILDFRM_DOUBLE_BORDER,
 		                  m_pMdi->height() + lpC->captionHeight() + KMDI_CHILDFRM_SEPARATOR + KMDI_CHILDFRM_DOUBLE_BORDER );
@@ -702,20 +702,20 @@ void KMdiMainFrm::detachWindow( KMdiChildView *pWnd, bool bShow )
 				pWnd->setGeometry( TQRect( m_pMdi->getCascadePoint( m_pDocumentViews->count() - 1 ), defaultChildFrmSize() ) );
 			}
 		}
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 		if ( mdiMode() == KMdi::ToplevelMode )
 		{
-			XSetTransientForHint( qt_xdisplay(), pWnd->winId(), topLevelWidget() ->winId() );
+			XSetTransientForHint( qt_xdisplay(), pWnd->winId(), tqtopLevelWidget() ->winId() );
 		}
 #endif
 
 		return ;
 	}
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 	if ( mdiMode() == KMdi::ToplevelMode )
 	{
-		XSetTransientForHint( qt_xdisplay(), pWnd->winId(), topLevelWidget() ->winId() );
+		XSetTransientForHint( qt_xdisplay(), pWnd->winId(), tqtopLevelWidget() ->winId() );
 	}
 #endif
 
@@ -1212,12 +1212,12 @@ bool KMdiMainFrm::eventFilter( TQObject * /*obj*/, TQEvent *e )
 
 				/** these are quite some assumptions:
 				 *   The key combination uses exactly one modifier key
-				 *   The WIN button in KDE is the meta button in Qt
+				 *   The WIN button in KDE is the meta button in TQt
 				 **/
 				if ( state != ( ( TQKeyEvent * ) e ) ->stateAfter() &&
-				        ( ( modFlags & KKey::CTRL ) > 0 ) == ( ( state & Qt::ControlButton ) > 0 ) &&
-				        ( ( modFlags & KKey::ALT ) > 0 ) == ( ( state & Qt::AltButton ) > 0 ) &&
-				        ( ( modFlags & KKey::WIN ) > 0 ) == ( ( state & Qt::MetaButton ) > 0 ) )
+				        ( ( modFlags & KKey::CTRL ) > 0 ) == ( ( state & TQt::ControlButton ) > 0 ) &&
+				        ( ( modFlags & KKey::ALT ) > 0 ) == ( ( state & TQt::AltButton ) > 0 ) &&
+				        ( ( modFlags & KKey::WIN ) > 0 ) == ( ( state & TQt::MetaButton ) > 0 ) )
 				{
 					activeWindow() ->updateTimeStamp();
 					setSwitching( false );
@@ -1238,14 +1238,14 @@ bool KMdiMainFrm::eventFilter( TQObject * /*obj*/, TQEvent *e )
  */
 void KMdiMainFrm::closeAllViews()
 {
-	//save the children first to a list, as removing invalidates our iterator
-	TQValueList<KMdiChildView*> children;
+	//save the tqchildren first to a list, as removing invalidates our iterator
+	TQValueList<KMdiChildView*> tqchildren;
 	for ( KMdiChildView * w = m_pDocumentViews->first();w;w = m_pDocumentViews->next() )
 	{
-		children.append( w );
+		tqchildren.append( w );
 	}
 	TQValueListIterator<KMdiChildView *> childIt;
-	for ( childIt = children.begin(); childIt != children.end(); ++childIt )
+	for ( childIt = tqchildren.begin(); childIt != tqchildren.end(); ++childIt )
 	{
 		( *childIt )->close();
 	}
@@ -1273,7 +1273,7 @@ void KMdiMainFrm::closeActiveView()
 		m_pCurrentWindow->close();
 }
 
-/** find the root dockwidgets and store their geometry */
+/** find the root dockwidgets and store their tqgeometry */
 void KMdiMainFrm::findRootDockWidgets( TQPtrList<KDockWidget>* rootDockWidgetList, TQValueList<TQRect>* positionList )
 {
 	//nothing is valid
@@ -1289,18 +1289,18 @@ void KMdiMainFrm::findRootDockWidgets( TQPtrList<KDockWidget>* rootDockWidgetLis
 		pObjList = queryList( "KDockWidget_Compat::KDockWidget" );
 
 	TQObjectListIt it( *pObjList );
-	// for all dockwidgets (which are children of this mainwindow)
+	// for all dockwidgets (which are tqchildren of this mainwindow)
 	while ( ( *it ) )
 	{
 		KDockWidget* dockWindow = 0L; /* pDockW */
 		KDockWidget* rootDockWindow = 0L; /* pRootDockWindow */
 		KDockWidget* undockCandidate = 0L; /* pUndockCandidate */
-		TQWidget* pW = static_cast<TQWidget*>( ( *it ) );
+		TQWidget* pW = TQT_TQWIDGET( ( *it ) );
 		
 		// find the oldest ancestor of the current dockwidget that can be undocked
 		while ( !pW->isTopLevel() )
 		{
-			if ( ::qt_cast<KDockWidget*>( pW ) ||  pW->inherits( "KDockWidget_Compat::KDockWidget" ) )
+			if ( ::tqqt_cast<KDockWidget*>( pW ) ||  pW->inherits( "KDockWidget_Compat::KDockWidget" ) )
 			{
 				undockCandidate = static_cast<KDockWidget*>( pW );
 				if ( undockCandidate->enableDocking() != KDockWidget::DockNone )
@@ -1357,7 +1357,7 @@ void KMdiMainFrm::switchToToplevelMode()
 	const int frameBorderWidth = 7;  // @todo: Can we / do we need to ask the window manager?
 	setUndockPositioningOffset( TQPoint( 0, ( m_pTaskBar ? m_pTaskBar->height() : 0 ) + frameBorderWidth ) );
 
-	// 1.) select the dockwidgets to be undocked and store their geometry
+	// 1.) select the dockwidgets to be undocked and store their tqgeometry
 	TQPtrList<KDockWidget> rootDockWidgetList;
 	TQValueList<TQRect> positionList;
 
@@ -1403,7 +1403,7 @@ void KMdiMainFrm::switchToToplevelMode()
 	{
 		//if we don't have a parent widget ( which i expect we wouldn't )
 		//make sure we take into account the size of the docks provided by
-		//QMainWindow
+		//TQMainWindow
 		int topDockHeight = topDock() ? topDock()->height() : 0;
 		int bottomDockHeight = bottomDock() ? bottomDock()->height() : 0;
 		int menuBarHeight = hasMenuBar() ? menuBar()->height() : 0;
@@ -1425,7 +1425,7 @@ void KMdiMainFrm::switchToToplevelMode()
 	TQPtrListIterator<KMdiChildView> kmdicvit( *m_pDocumentViews );
 	for ( kmdicvit.toFirst(); ( *kmdicvit ); ++kmdicvit )
 	{
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 		XSetTransientForHint( qt_xdisplay(), ( *kmdicvit )->winId(), winId() );
 #endif
 		( *kmdicvit )->show();
@@ -1470,7 +1470,7 @@ void KMdiMainFrm::switchToChildframeMode()
 	if ( m_mdiMode == KMdi::TabPageMode )
 	{
 		kdDebug(760) << k_funcinfo << "finishing tab page mode" << endl;
-		// select the dockwidgets to be undocked and store their geometry
+		// select the dockwidgets to be undocked and store their tqgeometry
 		findRootDockWidgets( &rootDockWidgetList, &positionList );
 		kdDebug(760) << k_funcinfo << "Found " << rootDockWidgetList.count() << " widgets to undock" << endl;
 		
@@ -1490,7 +1490,7 @@ void KMdiMainFrm::switchToChildframeMode()
 		kdDebug(760) << k_funcinfo << "finishing ideal mode" << endl;
 		finishIDEAlMode( false );
 
-		// select the dockwidgets to be undocked and store their geometry
+		// select the dockwidgets to be undocked and store their tqgeometry
 		findRootDockWidgets( &rootDockWidgetList, &positionList );
 		kdDebug(760) << k_funcinfo << "Found " << rootDockWidgetList.count() << " widgets to undock" << endl;
 		
@@ -1663,8 +1663,8 @@ void KMdiMainFrm::finishTabPageMode()
 			if ( pView->isToolView() )
 				continue;
 			kdDebug(760) << "KMdiMainFrm::finishTabPageMode: in loop" << endl;
-			TQSize mins = pView->minimumSize();
-			TQSize maxs = pView->maximumSize();
+			TQSize mins = pView->tqminimumSize();
+			TQSize maxs = pView->tqmaximumSize();
 			TQSize sz = pView->size();
 			TQWidget* pParent = pView->parentWidget();
 			TQPoint p( pParent->mapToGlobal( pParent->pos() ) - pParent->pos() + m_undockPositioningOffset );
@@ -1787,7 +1787,7 @@ void KMdiMainFrm::setToolviewStyle( int flag )
 			switch ( flag )
 			{
 			case KMdi::IconOnly:
-				dockWidget->setTabPageLabel( TQString::null );
+				dockWidget->setTabPageLabel( TQString() );
 				dockWidget->setPixmap( *( it.data()->wrappedWidget()->icon() ) );
 				break;
 			case KMdi::TextOnly:
@@ -1903,7 +1903,7 @@ void KMdiMainFrm::findToolViewsDockedToMain( TQPtrList<KDockWidget>* list, KDock
 	KDockWidget* widget = mainDock->findNearestDockWidget( dprtmw );
 	if ( widget && widget->parentDockTabGroup() )
 	{
-		widget = static_cast<KDockWidget*>( widget->parentDockTabGroup() ->parent() );
+		widget = static_cast<KDockWidget*>( TQT_TQWIDGET(widget->parentDockTabGroup() ->parent()) );
 
 		if ( widget )
 		{
@@ -1935,7 +1935,7 @@ void KMdiMainFrm::setupToolViewsForIDEALMode()
 	KDockWidget *mainDock = getMainDockWidget();
 	KDockWidget *w = mainDock;
 	if ( mainDock->parentDockTabGroup() )
-		w = static_cast<KDockWidget*>( mainDock->parentDockTabGroup()->parent() );
+		w = static_cast<KDockWidget*>( TQT_TQWIDGET(mainDock->parentDockTabGroup()->parent()) );
 
 	TQPtrList<KDockWidget> leftReparentWidgets;
 	TQPtrList<KDockWidget> rightReparentWidgets;
@@ -1943,7 +1943,7 @@ void KMdiMainFrm::setupToolViewsForIDEALMode()
 	TQPtrList<KDockWidget> topReparentWidgets;
 
 	if ( mainDock->parentDockTabGroup() )
-		mainDock = static_cast<KDockWidget*>( mainDock->parentDockTabGroup() ->parent() );
+		mainDock = static_cast<KDockWidget*>( TQT_TQWIDGET(mainDock->parentDockTabGroup() ->parent()) );
 
 	findToolViewsDockedToMain( &leftReparentWidgets, KDockWidget::DockLeft );
 	findToolViewsDockedToMain( &rightReparentWidgets, KDockWidget::DockRight );
@@ -2079,8 +2079,8 @@ void KMdiMainFrm::finishIDEAlMode( bool full )
 			KMdiChildView* pView = it.current();
 			if ( pView->isToolView() )
 				continue;
-			TQSize mins = pView->minimumSize();
-			TQSize maxs = pView->maximumSize();
+			TQSize mins = pView->tqminimumSize();
+			TQSize maxs = pView->tqmaximumSize();
 			TQSize sz = pView->size();
 			TQWidget* pParent = pView->parentWidget();
 			TQPoint p( pParent->mapToGlobal( pParent->pos() ) - pParent->pos() + m_undockPositioningOffset );
@@ -2141,7 +2141,7 @@ void KMdiMainFrm::idealToolViewsToStandardTabs( TQStringList widgetNames, KDockW
 	KDockWidget * mainDock = getMainDockWidget();
 	if ( mainDock->parentDockTabGroup() )
 	{
-		mainDock = static_cast<KDockWidget*>( mainDock->parentDockTabGroup() ->parent() );
+		mainDock = static_cast<KDockWidget*>( TQT_TQWIDGET(mainDock->parentDockTabGroup() ->parent()) );
 	}
 
 	if ( widgetNames.count() > 0 )
