@@ -125,7 +125,7 @@ TQString nodeTypeToString( int type )
 	return "Custom";
     }
 
-    return TQString::null;
+    return TQString();
 }
 
 
@@ -136,7 +136,7 @@ AST::AST()
       m_endLine( 0 ), m_endColumn( 0 )
 {
 #ifndef CPPPARSER_NO_CHILDREN
-    m_children.setAutoDelete( false );
+    m_tqchildren.setAutoDelete( false );
 #endif
 }
 
@@ -196,12 +196,12 @@ void AST::setParent( AST* parent )
 #ifndef CPPPARSER_NO_CHILDREN
 void AST::appendChild( AST* child )
 {
-    m_children.append( child );
+    m_tqchildren.append( child );
 }
 
 void AST::removeChild( AST* child )
 {
-    m_children.remove( child );
+    m_tqchildren.remove( child );
 }
 #endif
 
@@ -235,7 +235,7 @@ void NameAST::addClassOrNamespaceName( ClassOrNamespaceNameAST::Node& classOrNam
 TQString NameAST::text() const
 {
     if( !m_unqualifiedName.get() )
-        return TQString::null;
+        return TQString();
 
     TQString str;
 
@@ -470,11 +470,11 @@ void ClassOrNamespaceNameAST::setTemplateArgumentList( TemplateArgumentListAST::
 TQString ClassOrNamespaceNameAST::text() const
 {
     if( !m_name.get() )
-        return TQString::null;
+        return TQString();
 
     TQString str = m_name->text();
     if( m_templateArgumentList.get() )
-        str += TQString::fromLatin1("< ") + m_templateArgumentList->text() + TQString::fromLatin1(" >");
+        str += TQString::tqfromLatin1("< ") + m_templateArgumentList->text() + TQString::tqfromLatin1(" >");
 
     return str;
 }
