@@ -26,7 +26,7 @@
 #include <tqstringlist.h>
 #include <ksharedptr.h>
 
-#if defined( Q_OS_WIN32 ) || defined( Q_CC_SUN )
+#if defined( Q_OS_WIN32 ) || defined( TQ_CC_SUN )
 
 #ifndef _THROW0
 #  define _THROW0()
@@ -183,9 +183,9 @@ enum NodeType
 TQString nodeTypeToString( int type );
 
 
-#if defined(CPPPARSER_QUICK_ALLOCATOR)
+#if defined(CPPPARSER_TQUICK_ALLOCATOR)
 
-#include <quick_allocator.h>
+#include <tquick_allocator.h>
 
 #define DECLARE_ALLOC(tp) \
     void * operator new(std::size_t) \
@@ -263,7 +263,7 @@ public:
     void getEndPosition( int* line, int* col ) const;
 
 #ifndef CPPPARSER_NO_CHILDREN
-    TQPtrList<AST> children() { return m_children; }
+    TQPtrList<AST> tqchildren() { return m_tqchildren; }
     void appendChild( AST* child );
     void removeChild( AST* child );
 #endif
@@ -292,7 +292,7 @@ private:
     int m_endLine, m_endColumn;
     Slice m_slice;
 #ifndef CPPPARSER_NO_CHILDREN
-    TQPtrList<AST> m_children;
+    TQPtrList<AST> m_tqchildren;
 #endif
 
 private:
