@@ -383,7 +383,7 @@ void Driver::addDependence( const TQString & fileName, const Dependence & dep )
   m_currentParsedFile->addIncludeFile( file, 0, dep.second == Dep_Local );
   
   if ( !TQFile::exists( file ) ) {
-    Problem p( i18n( "Could not find include file %1" ).arg( dep.first ),
+    Problem p( i18n( "Could not find include file %1" ).tqarg( dep.first ),
                lexer ? lexer->currentLine() : -1,
                lexer ? lexer->currentColumn() : -1, Problem::Level_Warning );
     addProblem( fileName, p );
@@ -520,7 +520,7 @@ void Driver::parseFile( const TQString& fileName, bool onlyPreProcess, bool forc
     if( macrosGlobal ) {
         for( MacroMap::iterator it = m_macros.begin(); it != m_macros.end(); ++it) {
             if( (*it).second.fileName() == fileName ) {
-                (*it).second.setFileName( TQString::null );
+                (*it).second.setFileName( TQString() );
             }
         }
     }
@@ -598,31 +598,32 @@ void Driver::setupLexer( Lexer * lexer ) {
 
   // qt
   lexer->addSkipWord( "Q_OBJECT" );
-  lexer->addSkipWord( "Q_OVERRIDE", SkipWordAndArguments );
+  lexer->addSkipWord( "TQ_OBJECT" );
+  lexer->addSkipWord( "TQ_OVERRIDE", SkipWordAndArguments );
   lexer->addSkipWord( "Q_ENUMS", SkipWordAndArguments );
-  lexer->addSkipWord( "Q_PROPERTY", SkipWordAndArguments );
-  lexer->addSkipWord( "Q_CLASSINFO", SkipWordAndArguments );
-  lexer->addSkipWord( "Q_SETS", SkipWordAndArguments );
+  lexer->addSkipWord( "TQ_PROPERTY", SkipWordAndArguments );
+  lexer->addSkipWord( "TQ_CLASSINFO", SkipWordAndArguments );
+  lexer->addSkipWord( "TQ_SETS", SkipWordAndArguments );
   lexer->addSkipWord( "Q_UNUSED", SkipWordAndArguments );
-  lexer->addSkipWord( "Q_CREATE_INSTANCE", SkipWordAndArguments );
-  lexer->addSkipWord( "Q_DUMMY_COMPARISON_OPERATOR", SkipWordAndArguments );
+  lexer->addSkipWord( "TQ_CREATE_INSTANCE", SkipWordAndArguments );
+  lexer->addSkipWord( "TQ_DUMMY_COMPARISON_OPERATOR", SkipWordAndArguments );
   lexer->addSkipWord( "ACTIVATE_SIGNAL_WITH_PARAM", SkipWordAndArguments );
-  lexer->addSkipWord( "Q_INLINE_TEMPLATES" );
-  lexer->addSkipWord( "Q_TEMPLATE_EXTERN" );
-  lexer->addSkipWord( "Q_TYPENAME" );
-  lexer->addSkipWord( "Q_REFCOUNT" );
-  lexer->addSkipWord( "Q_EXPLICIT" );
+  lexer->addSkipWord( "TQ_INLINE_TEMPLATES" );
+  lexer->addSkipWord( "TQ_TEMPLATE_EXTERN" );
+  lexer->addSkipWord( "TQ_TYPENAME" );
+  lexer->addSkipWord( "TQ_REFCOUNT" );
+  lexer->addSkipWord( "TQ_EXPLICIT" );
   lexer->addSkipWord( "QMAC_PASCAL" );
   lexer->addSkipWord( "QT_STATIC_CONST" );
   lexer->addSkipWord( "QT_STATIC_CONST_IMPL" );
-  lexer->addSkipWord( "QT_WIN_PAINTER_MEMBERS" );
-  lexer->addSkipWord( "QT_NC_MSGBOX" );
-  lexer->addSkipWord( "Q_VARIANT_AS", SkipWordAndArguments );
+  lexer->addSkipWord( "TQT_WIN_PAINTER_MEMBERS" );
+  lexer->addSkipWord( "TQT_NC_MSGBOX" );
+  lexer->addSkipWord( "TQ_VARIANT_AS", SkipWordAndArguments );
   lexer->addSkipWord( "CALLBACK_CALL_TYPE" );
 
   // qt4 [erbsland]
-  lexer->addSkipWord( "Q_DECLARE_FLAGS", SkipWordAndArguments );
-  lexer->addSkipWord( "Q_DECLARE_OPERATORS_FOR_FLAGS", SkipWordAndArguments );
+  lexer->addSkipWord( "TQ_DECLARE_FLAGS", SkipWordAndArguments );
+  lexer->addSkipWord( "TQ_DECLARE_OPERATORS_FOR_FLAGS", SkipWordAndArguments );
 
   // flex
   lexer->addSkipWord( "yyconst" );
@@ -688,7 +689,7 @@ TQString Driver::findIncludeFile( const Dependence& dep, const TQString& fromFil
       return fileInfo.absFilePath();
   }
 
-  return TQString::null;
+  return TQString();
 }
 
 TQString Driver::findIncludeFile( const Dependence& dep ) const {
@@ -707,7 +708,7 @@ TQString Driver::findIncludeFile( const Dependence& dep ) const {
       return fileInfo.absFilePath();
   }
 
-  return TQString::null;
+  return TQString();
 }
 
 void Driver::setResolveDependencesEnabled( bool enabled ) {
