@@ -30,7 +30,7 @@
 #if defined( KDEVELOP_BGPARSER )
 #include <tqthread.h>
 
-class KDevTread: public QThread
+class KDevTread: public TQThread
 {
 public:
     static void yield()
@@ -100,7 +100,7 @@ struct LexerData
                 return scope[ name ];
         }
 
-        return TQString::null;
+        return TQString();
     }
 
 };
@@ -152,7 +152,7 @@ void Lexer::reset()
     m_index = 0;
     m_size = 0;
     m_tokens.clear();
-    m_source = TQString::null;
+    m_source = TQString();
     m_ptr = 0;
     m_endPtr = 0;
     m_startLine = false;
@@ -184,7 +184,7 @@ int Lexer::toInt( const Token& token )
 	int i = s[0] == 'L' ? 2 : 1; // wide char ?
 	if( s[i] == '\\' ){
 	    // escaped char
-	    int c = s[i+1].unicode();
+	    int c = s[i+1].tqunicode();
 	    switch( c ) {
 	    case '0':
 		return 0;
@@ -195,7 +195,7 @@ int Lexer::toInt( const Token& token )
 		return c;
 	    }
 	} else {
-	    return s[i].unicode();
+	    return s[i].tqunicode();
 	}
     } else {
 	return 0;
@@ -386,21 +386,21 @@ void Lexer::nextToken( Token& tk, bool stopOnNewline )
                 TQString tokText = tok.text();
                 HashedString str = (tok == Token_identifier && d->hasBind(tokText)) ? d->apply( tokText ) : tokText;
                 if( str == ide ){
-			//Problem p( i18n("unsafe use of macro '%1', macro is ignored").arg(ide.str()), m_currentLine, m_currentColumn, Problem::Level_Warning );
+			//Problem p( i18n("unsafe use of macro '%1', macro is ignored").tqarg(ide.str()), m_currentLine, m_currentColumn, Problem::Level_Warning );
                     //m_driver->addProblem( m_driver->currentFileName(), p );
                     m_driver->removeMacro( ide );
-                    // str = TQString::null;
+                    // str = TQString();
                 }
 
                 if( stringify ) {
-                    textToInsert.append( TQString::fromLatin1("\"") + str.str() + TQString::fromLatin1("\" ") );
+                    textToInsert.append( TQString::tqfromLatin1("\"") + str.str() + TQString::tqfromLatin1("\" ") );
                 } else if( merge ){
                     textToInsert.truncate( textToInsert.length() - 1 );
-                    textToInsert.append( str.str()  + TQString::fromLatin1(" ") );
+                    textToInsert.append( str.str()  + TQString::tqfromLatin1(" ") );
                 } else if( tok == Token_ellipsis && d->hasBind("...") ){
                     textToInsert.append( ellipsisArg );
                 } else {
-                    textToInsert.append( str.str() + TQString::fromLatin1(" ") );
+                    textToInsert.append( str.str() + TQString::tqfromLatin1(" ") );
                 }
             }
         
@@ -419,7 +419,7 @@ void Lexer::nextToken( Token& tk, bool stopOnNewline )
 	    tk.setStartPosition( startLine, startColumn );
 	    tk.setEndPosition( m_currentLine, m_currentColumn );
 	} else if( m_skipWordsEnabled ){
-	    __gnu_cxx::hash_map< HashedString, QPair<SkipType, TQString> >::iterator pos = m_words.find( ide );
+	    __gnu_cxx::hash_map< HashedString, TQPair<SkipType, TQString> >::iterator pos = m_words.find( ide );
 	    if( pos != m_words.end() ){
 		if( (*pos).second.first == SkipWordAndArguments ){
 		    readWhiteSpaces();
@@ -434,9 +434,9 @@ void Lexer::nextToken( Token& tk, bool stopOnNewline )
 		}
 	    } else if( /*qt_rx.exactMatch(ide) ||*/
 		ide.str().endsWith("EXPORT") ||
-		(ide.str().startsWith("Q_EXPORT") && ide.str() != "Q_EXPORT_INTERFACE") ||
-		ide.str().startsWith("QM_EXPORT") ||
-		ide.str().startsWith("QM_TEMPLATE")){
+		(ide.str().startsWith("TQ_EXPORT") && ide.str() != "TQ_EXPORT_INTERFACE") ||
+		ide.str().startsWith("TQM_EXPORT") ||
+		ide.str().startsWith("TQM_TEMPLATE")){
 
 		readWhiteSpaces();
 		if( currentChar() == '(' )
@@ -514,7 +514,7 @@ void Lexer::resetSkipWords()
 
 void Lexer::addSkipWord( const TQString& word, SkipType skipType, const TQString& str )
 {
-    m_words[ word ] = qMakePair( skipType, str );
+    m_words[ word ] = tqMakePair( skipType, str );
 }
 
 void Lexer::skip( int l, int r )
@@ -1026,7 +1026,7 @@ int Lexer::macroExpression()
 }
 
 // *IMPORTANT*
-// please, don't include lexer.moc here, because Lexer isn't a TQObject class!!
+// please, don't include lexer.tqmoc here, because Lexer isn't a TQObject class!!
 // if you have problem while recompiling try to remove cppsupport/.deps,
 // cppsupport/Makefile.in and rerun automake/autoconf
 
