@@ -30,7 +30,7 @@
 #include <hashedstring.h>
 #include <ext/hash_map>
 
-#define CHARTYPE QChar
+#define CHARTYPE TQChar
 
 enum Type {
     Token_eof = 0,
@@ -61,6 +61,7 @@ enum Type {
     Token_k_dcop_signals,
 
     Token_Q_OBJECT,
+    Token_TQ_OBJECT,
     Token_signals,
     Token_slots,
     Token_emit,
@@ -217,7 +218,7 @@ public:
     void setPreprocessorEnabled( bool enabled );
 
     void resetSkipWords();
-    void addSkipWord( const TQString& word, SkipType skipType=SkipWord, const TQString& str = TQString::null );
+    void addSkipWord( const TQString& word, SkipType skipType=SkipWord, const TQString& str = TQString() );
 
     TQString source() const;
     void setSource( const TQString& source );
@@ -243,11 +244,11 @@ public:
     int currentColumn() const { return m_currentColumn; }
 
     inline const CHARTYPE* offset( int offset ) const {
-        return m_source.unicode() + offset;
+        return m_source.tqunicode() + offset;
     }
 
     inline int getOffset( const TQChar* p ) const {
-        return int(p - (m_source.unicode()));
+        return int(p - (m_source.tqunicode()));
     }
     
 private:
@@ -322,7 +323,7 @@ private:
     bool m_recordComments;
     bool m_recordWhiteSpaces;
     bool m_startLine;
-    __gnu_cxx::hash_map< HashedString, QPair<SkipType, TQString> > m_words;
+    __gnu_cxx::hash_map< HashedString, TQPair<SkipType, TQString> > m_words;
 
     
     int m_skippedLines;
@@ -513,12 +514,12 @@ inline const Token& Lexer::nextToken()
 
 inline const Token& Lexer::tokenAt( int n ) const
 {
-    return *m_tokens[ QMIN(n, m_size-1) ];
+    return *m_tokens[ TQMIN(n, m_size-1) ];
 }
 
 inline const Token& Lexer::lookAhead( int n ) const
 {
-    return *m_tokens[ QMIN(m_index + n, m_size-1) ];
+    return *m_tokens[ TQMIN(m_index + n, m_size-1) ];
 }
 
 inline int Lexer::tokenPosition( const Token& token ) const
