@@ -161,7 +161,7 @@ typedef KSharedPtr<EnumeratorModel> EnumeratorDom;
 @class ItemList
 The list of code model items.
 This is a type definition: @code typedef TQValueList<ItemDom> ItemList; @endcode
-@sa QValueList
+@sa TQValueList
 */
 typedef TQValueList<ItemDom> ItemList;
 
@@ -169,7 +169,7 @@ typedef TQValueList<ItemDom> ItemList;
 @class FileList
 The list of code model files.
 This is a type definition: @code typedef TQValueList<FileDom> FileList; @endcode
-@sa QValueList
+@sa TQValueList
 */
 typedef TQValueList<FileDom> FileList;
 
@@ -177,7 +177,7 @@ typedef TQValueList<FileDom> FileList;
 @class NamespaceList
 The list of code model namespaces.
 This is a type definition: @code typedef TQValueList<NamespaceDom> NamespaceList; @endcode
-@sa QValueList
+@sa TQValueList
 */
 typedef TQValueList<NamespaceDom> NamespaceList;
 
@@ -185,7 +185,7 @@ typedef TQValueList<NamespaceDom> NamespaceList;
 @class ClassList
 The list of code model classes.
 This is a type definition: @code typedef TQValueList<ClassDom> ClassList; @endcode
-@sa QValueList
+@sa TQValueList
 */
 typedef TQValueList<ClassDom> ClassList;
 
@@ -193,7 +193,7 @@ typedef TQValueList<ClassDom> ClassList;
 @class FunctionList
 The list of code model functions.
 This is a type definition: @code typedef TQValueList<FunctionDom> FunctionList; @endcode
-@sa QValueList
+@sa TQValueList
 */
 typedef TQValueList<FunctionDom> FunctionList;
 
@@ -201,7 +201,7 @@ typedef TQValueList<FunctionDom> FunctionList;
 @class FunctionDefinitionList
 The list of code model function definitions.
 This is a type definition: @code typedef TQValueList<FunctionDefinitionDom> FunctionDefinitionList; @endcode
-@sa QValueList
+@sa TQValueList
 */
 
 typedef TQValueList<FunctionDefinitionDom> FunctionDefinitionList;
@@ -209,7 +209,7 @@ typedef TQValueList<FunctionDefinitionDom> FunctionDefinitionList;
 @class VariableList
 The list of code model variables.
 This is a type definition: @code typedef TQValueList<VariableDom> VariableList; @endcode
-@sa QValueList
+@sa TQValueList
 */
 typedef TQValueList<VariableDom> VariableList;
 
@@ -217,7 +217,7 @@ typedef TQValueList<VariableDom> VariableList;
 @class ArgumentList
 The list of code model arguments.
 This is a type definition: @code typedef TQValueList<ArgumentDom> ArgumentList; @endcode
-@sa QValueList
+@sa TQValueList
 */
 typedef TQValueList<ArgumentDom> ArgumentList;
 
@@ -225,7 +225,7 @@ typedef TQValueList<ArgumentDom> ArgumentList;
 @class EnumList
 The list of code model enums.
 This is a type definition: @code typedef TQValueList<EnumDom> EnumList; @endcode
-@sa QValueList
+@sa TQValueList
 */
 typedef TQValueList<EnumDom> EnumList;
 
@@ -233,7 +233,7 @@ typedef TQValueList<EnumDom> EnumList;
 @class TypeAliasList
 The list of code model type aliases.
 This is a type definition: @code typedef TQValueList<TypeAliasDom> TypeAliasList; @endcode
-@sa QValueList
+@sa TQValueList
 */
 typedef TQValueList<TypeAliasDom> TypeAliasList;
 
@@ -241,7 +241,7 @@ typedef TQValueList<TypeAliasDom> TypeAliasList;
 @class EnumeratorList
 The list of code model enumerators.
 This is a type definition: @code typedef TQValueList<EnumeratorDom> EnumeratorList; @endcode
-@sa QValueList
+@sa TQValueList
 */
 typedef TQValueList<EnumeratorDom> EnumeratorList;
 
@@ -619,7 +619,7 @@ private:
 
 class TemplateModelItem {
     public:
-        typedef QPair< TQString, TQString > ParamPair;
+        typedef TQPair< TQString, TQString > ParamPair;
         typedef TQValueVector< ParamPair > ParamMap; ///The first is the name, and the second the default-parameter, or "" if there is none.
         
         virtual const ParamMap& getTemplateParams() {
@@ -1044,7 +1044,7 @@ protected:
     NamespaceModel( CodeModel* model );
 
 public:
-  typedef std::set<NamespaceAliasModel> NamespaceAliasModelList; ///I'm using std-sets here, because Qt-3 has no appropriate replacement
+  typedef std::set<NamespaceAliasModel> NamespaceAliasModelList; ///I'm using std-sets here, because TQt-3 has no appropriate replacement
   typedef std::set<NamespaceImportModel> NamespaceImportModelList;
   
     /**A definition of safe pointer to the namespace model.*/
