@@ -35,8 +35,8 @@
 
 #include "flagboxes.h"
 
-// partial copy of Qt-3.1 for back-compatibility to KDE-3.0
-TQString QRegExp_escape( const TQString& str )
+// partial copy of TQt-3.1 for back-compatibility to KDE-3.0
+TQString TQRegExp_escape( const TQString& str )
 {
     static const char meta[] = "$()*+.?[\\]^{|}";
     TQString quoted = str;
@@ -51,7 +51,7 @@ TQString QRegExp_escape( const TQString& str )
 }
 
 
-class FlagListToolTip : public QToolTip
+class FlagListToolTip : public TQToolTip
 {
 public:
     FlagListToolTip(TQWidget *parent);
@@ -72,7 +72,7 @@ void FlagListToolTip::maybeTip(const TQPoint &pos)
     FlagListItem *flitem = static_cast<FlagListItem*>(item);
 
     if (item)
-        tip(listbox->itemRect(item), flitem->desc);
+        tip(listbox->tqitemRect(item), flitem->desc);
 }
 
 
@@ -270,7 +270,7 @@ void FlagPathEditController::readFlags( TQStringList * list )
             if ((*sli).startsWith(peitem->flag))
             {
 //                kdDebug() << "Processing.." << endl;
-                peitem->setText((*sli).replace(TQRegExp(QRegExp_escape(peitem->flag)),""));
+                peitem->setText((*sli).replace(TQRegExp(TQRegExp_escape(peitem->flag)),""));
                 sli = list->remove(sli);
                 continue;
             }
@@ -306,22 +306,22 @@ FlagPathEdit::FlagPathEdit( TQWidget * parent, TQString pathDelimiter,
 {
     TQBoxLayout *topLayout = new TQVBoxLayout(this, 0, 1);
     topLayout->addWidget(new TQLabel(description, this));
-    TQBoxLayout *layout = new TQHBoxLayout(topLayout, KDialog::spacingHint());
+    TQBoxLayout *tqlayout = new TQHBoxLayout(topLayout, KDialog::spacingHint());
 
     if (delimiter.isEmpty())
     {
         url = new KURLRequester(this);
         url->setMode(mode);
-        layout->addWidget(url);
+        tqlayout->addWidget(url);
     }
     else
     {
         edit = new KLineEdit(this);
-        layout->addWidget(edit);
+        tqlayout->addWidget(edit);
         details = new TQPushButton("...", this);
         details->setMaximumWidth(30);
         connect(details, TQT_SIGNAL(clicked()), this, TQT_SLOT(showPathDetails()));
-        layout->addWidget(details);
+        tqlayout->addWidget(details);
     }
 
     TQApplication::sendPostedEvents(this, TQEvent::ChildInserted);
@@ -471,7 +471,7 @@ void FlagEditController::readFlags( TQStringList * list )
         {
             if ((*sli).startsWith(peitem->flag))
             {
-                peitem->appendText((*sli).replace(TQRegExp(QRegExp_escape(peitem->flag)),""));
+                peitem->appendText((*sli).replace(TQRegExp(TQRegExp_escape(peitem->flag)),""));
                 sli = list->remove(sli);
                 continue;
             }
@@ -489,7 +489,7 @@ void FlagEditController::readFlags( TQStringList * list )
         {
             if ((*sli).startsWith(sitem->flag))
             {
-                sitem->setText((*sli).replace(TQRegExp(QRegExp_escape(sitem->flag)),""));
+                sitem->setText((*sli).replace(TQRegExp(TQRegExp_escape(sitem->flag)),""));
                 sli = list->remove(sli);
                 continue;
             }
@@ -532,16 +532,16 @@ FlagListEdit::FlagListEdit( TQWidget * parent, TQString listDelimiter, FlagEditC
 {
     TQBoxLayout *topLayout = new TQVBoxLayout(this, 0, 1);
     topLayout->addWidget(new TQLabel(description, this));
-    TQBoxLayout *layout = new TQHBoxLayout(topLayout, KDialog::spacingHint());
+    TQBoxLayout *tqlayout = new TQHBoxLayout(topLayout, KDialog::spacingHint());
 
     edit = new KLineEdit(this);
-    layout->addWidget(edit);
+    tqlayout->addWidget(edit);
     if (! listDelimiter.isEmpty())
     {
         details = new TQPushButton("...", this);
         details->setMaximumWidth(30);
         connect(details, TQT_SIGNAL(clicked()), this, TQT_SLOT(showListDetails()));
-        layout->addWidget(details);
+        tqlayout->addWidget(details);
     }
 
     TQApplication::sendPostedEvents(this, TQEvent::ChildInserted);
@@ -624,7 +624,7 @@ void FlagSpinEdit::setText( const TQString text )
 
 TQString FlagSpinEdit::text( )
 {
-    return TQString("%1").arg(spb->value());
+    return TQString("%1").tqarg(spb->value());
 }
 
 TQString FlagSpinEdit::flags( )
