@@ -57,7 +57,7 @@ static bool checkGetNameAndEmail(const TQString& input, const TQString& expName,
 {
   TQString name, email;
   bool retVal = KPIM::getNameAndMail(input, name, email);
-  check( "getNameAndMail " + input + " retVal", retVal?TQString::fromLatin1( "true" ):TQString::fromLatin1( "false" ), expRetVal?TQString::fromLatin1( "true" ):TQString::fromLatin1( "false" ) );
+  check( "getNameAndMail " + input + " retVal", retVal?TQString::tqfromLatin1( "true" ):TQString::tqfromLatin1( "false" ), expRetVal?TQString::tqfromLatin1( "true" ):TQString::tqfromLatin1( "false" ) );
   check( "getNameAndMail " + input + " name", name, expName );
   check( "getNameAndMail " + input + " email", email, expEmail );
   return true;
@@ -166,10 +166,10 @@ int main(int argc, char *argv[])
   KApplication app( false, false );
 
   // Empty input
-  checkGetNameAndEmail( TQString::null, TQString::null, TQString::null, false );
+  checkGetNameAndEmail( TQString(), TQString(), TQString(), false );
 
   // Email only
-  checkGetNameAndEmail( "faure@kde.org", TQString::null, "faure@kde.org", false );
+  checkGetNameAndEmail( "faure@kde.org", TQString(), "faure@kde.org", false );
 
   // Normal case
   checkGetNameAndEmail( "David Faure <faure@kde.org>", "David Faure", "faure@kde.org", true );
@@ -203,8 +203,8 @@ int main(int argc, char *argv[])
   //checkGetNameAndEmail( "\"a@b\" <faure@kde.org>", "a@b", "faure@kde.org", true );
 
   // While typing, when there's no '@' yet
-  checkGetNameAndEmail( "foo", "foo", TQString::null, false );
-  checkGetNameAndEmail( "foo <", "foo", TQString::null, false );
+  checkGetNameAndEmail( "foo", "foo", TQString(), false );
+  checkGetNameAndEmail( "foo <", "foo", TQString(), false );
   checkGetNameAndEmail( "foo <b", "foo", "b", true );
 
   // If multiple emails are there, only return the first one
@@ -226,7 +226,7 @@ int main(int argc, char *argv[])
   checkIsValidEmailAddress( "mattfruitsalad.org", "TooFewAts" );
 
   // An empty string
-  checkIsValidEmailAddress( TQString::null , "AddressEmpty" );
+  checkIsValidEmailAddress( TQString() , "AddressEmpty" );
 
   // email address starting with a @
   checkIsValidEmailAddress( "@mattfruitsalad.org", "MissingLocalPart" );
@@ -433,7 +433,7 @@ int main(int argc, char *argv[])
   checkIsValidSimpleEmailAddress( "matt@123.123.123.123]", "false" );
   checkIsValidSimpleEmailAddress( "\"matt@fruitsalad.org", "false" );
   checkIsValidSimpleEmailAddress( "matt\"@fruitsalad.org", "false" );
-  checkIsValidSimpleEmailAddress( TQString::null, "false" );
+  checkIsValidSimpleEmailAddress( TQString(), "false" );
 
   // and here some insane but still valid cases
   checkIsValidSimpleEmailAddress( "\"m@tt\"@fruitsalad.org", "true" );
