@@ -66,6 +66,7 @@ class LIBKCAL_EXPORT CalendarResources :
       public KRES::ManagerObserver<ResourceCalendar>
 {
   Q_OBJECT
+  TQ_OBJECT
   public:
     /**
        @class DestinationPolicy
@@ -161,7 +162,7 @@ class LIBKCAL_EXPORT CalendarResources :
     */
     CalendarResources(
       const TQString &timeZoneId,
-      const TQString &family = TQString::fromLatin1( "calendar" ) );
+      const TQString &family = TQString::tqfromLatin1( "calendar" ) );
 
     /**
        Destructor
