@@ -33,7 +33,7 @@ using namespace KCal;
 
 Incidence::Incidence() :
   IncidenceBase(),
-  mRelatedTo(0), mStatus(StatusNone), mSecrecy(SecrecyPublic),
+  mRelatedTo(0), mtqStatus(StatusNone), mSecrecy(SecrecyPublic),
   mPriority(0), mRecurrence(0),
   mHasRecurrenceID( false ), mChildRecurrenceEvents()
 {
@@ -57,7 +57,7 @@ Incidence::Incidence( const Incidence &i ) : IncidenceBase( i ),Recurrence::Obse
 //  Incidence::List mRelations;    Incidence::List mRelations;
   mResources = i.mResources;
   mStatusString = i.mStatusString;
-  mStatus = i.mStatus;
+  mtqStatus = i.mtqStatus;
   mSecrecy = i.mSecrecy;
   mPriority = i.mPriority;
   mLocation = i.mLocation;
@@ -125,7 +125,7 @@ Incidence& Incidence::operator=( const Incidence &i )
   mRelations.clear();
   mResources = i.mResources;
   mStatusString = i.mStatusString;
-  mStatus = i.mStatus;
+  mtqStatus = i.mtqStatus;
   mSecrecy = i.mSecrecy;
   mPriority = i.mPriority;
   mLocation = i.mLocation;
@@ -196,8 +196,8 @@ bool Incidence::operator==( const Incidence& i2 ) const
         relations() == i2.relations() &&
         attachments() == i2.attachments() &&
         resources() == i2.resources() &&
-        mStatus == i2.mStatus &&
-        ( mStatus == StatusNone || stringCompare( mStatusString, i2.mStatusString ) ) &&
+        mtqStatus == i2.mtqStatus &&
+        ( mtqStatus == StatusNone || stringCompare( mStatusString, i2.mStatusString ) ) &&
         secrecy() == i2.secrecy() &&
         priority() == i2.priority() &&
         stringCompare( location(), i2.location() ) &&
@@ -207,16 +207,16 @@ bool Incidence::operator==( const Incidence& i2 ) const
 
 void Incidence::recreate()
 {
-  setCreated(TQDateTime::currentDateTime());
+  setCreated(TQDateTime::tqcurrentDateTime());
 
   setUid(CalFormat::createUniqueId());
-  setSchedulingID( TQString::null );
+  setSchedulingID( TQString() );
 
   setRevision(0);
 
-  setLastModified(TQDateTime::currentDateTime());
+  setLastModified(TQDateTime::tqcurrentDateTime());
   setPilotId( 0 );
-  setSyncStatus( SYNCNONE );
+  setSynctqStatus( SYNCNONE );
 }
 
 void Incidence::setReadOnly( bool readOnly )
@@ -353,7 +353,7 @@ void Incidence::setRelatedTo(Incidence *relatedTo)
     if ( mRelatedTo->uid() != mRelatedToUid )
       setRelatedToUid( mRelatedTo->uid() );
   } else {
-    setRelatedToUid( TQString::null );
+    setRelatedToUid( TQString() );
   }
 }
 
@@ -445,9 +445,9 @@ bool Incidence::recursOn(const TQDate &qd, Calendar *cal) const
     IncidenceList il = childIncidences();
     IncidenceListIterator it;
     for ( it = il.begin(); it != il.end(); ++it ) {
-      QDateTime modifiedDt = cal->incidence(*it)->recurrenceID();
-      modifiedDt.setTime(QTime());
-      if (QDateTime(qd) == modifiedDt) {
+      TQDateTime modifiedDt = cal->incidence(*it)->recurrenceID();
+      modifiedDt.setTime(TQTime());
+      if (TQDateTime(qd) == modifiedDt) {
         doesRecur = false;
       }
     }
@@ -738,35 +738,35 @@ int Incidence::priority() const
   return mPriority;
 }
 
-void Incidence::setStatus(Incidence::Status status)
+void Incidence::setqStatus(Incidence::tqStatus status)
 {
   if (mReadOnly || status == StatusX) return;
-  mStatus = status;
-  mStatusString = TQString::null;
+  mtqStatus = status;
+  mStatusString = TQString();
   updated();
 }
 
-void Incidence::setCustomStatus(const TQString &status)
+void Incidence::setCustomtqStatus(const TQString &status)
 {
   if (mReadOnly) return;
-  mStatus = status.isEmpty() ? StatusNone : StatusX;
+  mtqStatus = status.isEmpty() ? StatusNone : StatusX;
   mStatusString = status;
   updated();
 }
 
-Incidence::Status Incidence::status() const
+Incidence::tqStatus Incidence::status() const
 {
-  return mStatus;
+  return mtqStatus;
 }
 
 TQString Incidence::statusStr() const
 {
-  if (mStatus == StatusX)
+  if (mtqStatus == StatusX)
     return mStatusString;
-  return statusName(mStatus);
+  return statusName(mtqStatus);
 }
 
-TQString Incidence::statusName(Incidence::Status status)
+TQString Incidence::statusName(Incidence::tqStatus status)
 {
   switch (status) {
     case StatusTentative:    return i18n("incidence status", "Tentative");
@@ -779,7 +779,7 @@ TQString Incidence::statusName(Incidence::Status status)
     case StatusFinal:        return i18n("Final");
     case StatusX:
     case StatusNone:
-    default:                 return TQString::null;
+    default:                 return TQString();
   }
 }
 
