@@ -35,10 +35,10 @@ using namespace KCal;
 // Maximum number of intervals to process
 const int LOOP_LIMIT = 10000;
 
-// FIXME: If Qt is ever changed so that TQDateTime:::addSecs takes into account
+// FIXME: If TQt is ever changed so that TQDateTime:::addSecs takes into account
 //        DST shifts, we need to use our own addSecs method, too, since we
 //        need to caalculate things in UTC!
-/** Workaround for broken TQDateTime::secsTo (at least in Qt 3.3). While
+/** Workaround for broken TQDateTime::secsTo (at least in TQt 3.3). While
    TQDateTime::secsTo does take time zones into account, TQDateTime::addSecs
    does not, so we have a problem:
       TQDateTime d1(TQDate(2005, 10, 30), TQTime(1, 30, 0) );
@@ -418,7 +418,7 @@ DateTimeList RecurrenceRule::Constraint::dateTimes( RecurrenceRule::PeriodType t
 
 bool RecurrenceRule::Constraint::increase( RecurrenceRule::PeriodType type, int freq )
 {
-  // convert the first day of the interval to QDateTime
+  // convert the first day of the interval to TQDateTime
   // Sub-daily types need to be converted to UTC to correctly handle DST shifts
   TQDateTime dt( intervalDateTime( type ) );
 
@@ -1299,7 +1299,7 @@ DateTimeList RecurrenceRule::timesInInterval( const TQDateTime &dtStart,
     if ( dt < enddt ) {
       n = static_cast<int>( ( dt.secsTo( enddt ) - 1 ) / mTimedRepetition ) + 1;
       // limit n by a sane value else we can "explode".
-      n = QMIN( n, LOOP_LIMIT );
+      n = TQMIN( n, LOOP_LIMIT );
       for ( int i = 0;  i < n;  dt = dt.addSecs( mTimedRepetition ), ++i ) {
         result += dt;
       }
@@ -1453,7 +1453,7 @@ RecurrenceRule::Constraint RecurrenceRule::getNextValidDateInterval( const TQDat
     case rMinutely: modifier *= 60;
     case rSecondly:
         periods = ownSecsTo( start, toDate ) / modifier;
-        periods = QMAX( 0, periods);
+        periods = TQMAX( 0, periods);
         if ( periods > 0 )
           periods += ( frequency() - 1 - ( (periods - 1) % frequency() ) );
         nextValid = start.addSecs( modifier * periods );
@@ -1466,7 +1466,7 @@ RecurrenceRule::Constraint RecurrenceRule::getNextValidDateInterval( const TQDat
         modifier *= 7;
     case rDaily:
         periods = start.daysTo( toDate ) / modifier;
-        periods = QMAX( 0, periods);
+        periods = TQMAX( 0, periods);
         if ( periods > 0 )
           periods += (frequency() - 1 - ( (periods - 1) % frequency() ) );
         nextValid = start.addDays( modifier * periods );
@@ -1475,7 +1475,7 @@ RecurrenceRule::Constraint RecurrenceRule::getNextValidDateInterval( const TQDat
     case rMonthly: {
         periods = 12*( toDate.date().year() - start.date().year() ) +
              ( toDate.date().month() - start.date().month() );
-        periods = QMAX( 0, periods);
+        periods = TQMAX( 0, periods);
         if ( periods > 0 )
           periods += (frequency() - 1 - ( (periods - 1) % frequency() ) );
         // set the day to the first day of the month, so we don't have problems
@@ -1485,7 +1485,7 @@ RecurrenceRule::Constraint RecurrenceRule::getNextValidDateInterval( const TQDat
         break; }
     case rYearly:
         periods = ( toDate.date().year() - start.date().year() );
-        periods = QMAX( 0, periods);
+        periods = TQMAX( 0, periods);
         if ( periods > 0 )
           periods += ( frequency() - 1 - ( (periods - 1) % frequency() ) );
         nextValid.setDate( start.date().addYears( periods ) );
