@@ -39,14 +39,14 @@
 
 using namespace KCal;
 
-ScheduleMessage::ScheduleMessage(IncidenceBase *incidence,int method,ScheduleMessage::Status status)
+ScheduleMessage::ScheduleMessage(IncidenceBase *incidence,int method,ScheduleMessage::tqStatus status)
 {
   mIncidence = incidence;
   mMethod = method;
-  mStatus = status;
+  mtqStatus = status;
 }
 
-TQString ScheduleMessage::statusName(ScheduleMessage::Status status)
+TQString ScheduleMessage::statusName(ScheduleMessage::tqStatus status)
 {
   switch (status) {
     case PublishUpdate:
@@ -60,7 +60,7 @@ TQString ScheduleMessage::statusName(ScheduleMessage::Status status)
     case RequestUpdate:
       return i18n("Updated Request");
     default:
-      return i18n("Unknown Status: %1").arg(TQString::number(status));
+      return i18n("Unknown Status: %1").tqarg(TQString::number(status));
   }
 }
 
@@ -99,7 +99,7 @@ FreeBusyCache *Scheduler::freeBusyCache() const
 
 bool Scheduler::acceptTransaction( IncidenceBase *incidence,
                                    Method method,
-                                   ScheduleMessage::Status status,
+                                   ScheduleMessage::tqStatus status,
                                    const TQString &attendee )
 {
   kdDebug(5800) << "Scheduler::acceptTransaction, method="
@@ -133,23 +133,23 @@ TQString Scheduler::methodName(Method method)
 {
   switch (method) {
     case Publish:
-      return TQString::fromLatin1("Publish");
+      return TQString::tqfromLatin1("Publish");
     case Request:
-      return TQString::fromLatin1("Request");
+      return TQString::tqfromLatin1("Request");
     case Refresh:
-      return TQString::fromLatin1("Refresh");
+      return TQString::tqfromLatin1("Refresh");
     case Cancel:
-      return TQString::fromLatin1("Cancel");
+      return TQString::tqfromLatin1("Cancel");
     case Add:
-      return TQString::fromLatin1("Add");
+      return TQString::tqfromLatin1("Add");
     case Reply:
-      return TQString::fromLatin1("Reply");
+      return TQString::tqfromLatin1("Reply");
     case Counter:
-      return TQString::fromLatin1("Counter");
+      return TQString::tqfromLatin1("Counter");
     case Declinecounter:
-      return TQString::fromLatin1("Decline Counter");
+      return TQString::tqfromLatin1("Decline Counter");
     default:
-      return TQString::fromLatin1("Unknown");
+      return TQString::tqfromLatin1("Unknown");
   }
 }
 
@@ -183,7 +183,7 @@ bool Scheduler::deleteTransaction(IncidenceBase *)
 }
 
 bool Scheduler::acceptPublish( IncidenceBase *newIncBase,
-                               ScheduleMessage::Status status, Method method )
+                               ScheduleMessage::tqStatus status, Method method )
 {
   if( newIncBase->type() == "FreeBusy" ) {
     return acceptFreeBusy( newIncBase, method );
@@ -225,7 +225,7 @@ bool Scheduler::acceptPublish( IncidenceBase *newIncBase,
 }
 
 bool Scheduler::acceptRequest( IncidenceBase *incidence,
-                               ScheduleMessage::Status status,
+                               ScheduleMessage::tqStatus status,
                                const TQString &attendee )
 {
   Incidence *inc = static_cast<Incidence *>(incidence);
@@ -389,14 +389,14 @@ TryAgain:
   return true;
 }
 
-bool Scheduler::acceptAdd(IncidenceBase *incidence,ScheduleMessage::Status /* status */)
+bool Scheduler::acceptAdd(IncidenceBase *incidence,ScheduleMessage::tqStatus /* status */)
 {
   deleteTransaction(incidence);
   return false;
 }
 
 bool Scheduler::acceptCancel( IncidenceBase *incidence,
-                              ScheduleMessage::Status status,
+                              ScheduleMessage::tqStatus status,
                               const TQString &attendee )
 {
   Incidence *inc = static_cast<Incidence *>( incidence );
@@ -492,7 +492,7 @@ bool Scheduler::acceptCancel( IncidenceBase *incidence,
   return ret;
 }
 
-bool Scheduler::acceptCancel(IncidenceBase *incidence,ScheduleMessage::Status /* status */)
+bool Scheduler::acceptCancel(IncidenceBase *incidence,ScheduleMessage::tqStatus /* status */)
 {
   const IncidenceBase *toDelete = mCalendar->incidenceFromSchedulingID( incidence->uid() );
 
@@ -525,19 +525,19 @@ bool Scheduler::acceptCancel(IncidenceBase *incidence,ScheduleMessage::Status /*
   return ret;
 }
 
-bool Scheduler::acceptDeclineCounter(IncidenceBase *incidence,ScheduleMessage::Status /* status */)
+bool Scheduler::acceptDeclineCounter(IncidenceBase *incidence,ScheduleMessage::tqStatus /* status */)
 {
   deleteTransaction(incidence);
   return false;
 }
 
-//bool Scheduler::acceptFreeBusy(Incidence *incidence,ScheduleMessage::Status status)
+//bool Scheduler::acceptFreeBusy(Incidence *incidence,ScheduleMessage::tqStatus status)
 //{
 //  deleteTransaction(incidence);
 //  return false;
 //}
 
-bool Scheduler::acceptReply(IncidenceBase *incidence,ScheduleMessage::Status /* status */, Method method)
+bool Scheduler::acceptReply(IncidenceBase *incidence,ScheduleMessage::tqStatus /* status */, Method method)
 {
   if(incidence->type()=="FreeBusy") {
     return acceptFreeBusy(incidence, method);
@@ -576,7 +576,7 @@ bool Scheduler::acceptReply(IncidenceBase *incidence,ScheduleMessage::Status /*
         if (attIn->email().lower()==attEv->email().lower()) {
           //update attendee-info
           kdDebug(5800) << "Scheduler::acceptTransaction update attendee" << endl;
-          attEv->setStatus(attIn->status());
+          attEv->setqStatus(attIn->status());
           attEv->setDelegate(attIn->delegate());
           attEv->setDelegator(attIn->delegator());
           ret = true;
@@ -590,12 +590,12 @@ bool Scheduler::acceptReply(IncidenceBase *incidence,ScheduleMessage::Status /*
     bool attendeeAdded = false;
     for ( Attendee::List::ConstIterator it = attendeesNew.constBegin(); it != attendeesNew.constEnd(); ++it ) {
       Attendee* attNew = *it;
-      TQString msg = i18n("%1 wants to attend %2 but was not invited.").arg( attNew->fullName() )
-          .arg( ev ? ev->summary() : to->summary() );
+      TQString msg = i18n("%1 wants to attend %2 but was not invited.").tqarg( attNew->fullName() )
+          .tqarg( ev ? ev->summary() : to->summary() );
       if ( !attNew->delegator().isEmpty() )
-        msg = i18n("%1 wants to attend %2 on behalf of %3.").arg( attNew->fullName() )
-            .arg( ev ? ev->summary() : to->summary() )
-            .arg( attNew->delegator() );
+        msg = i18n("%1 wants to attend %2 on behalf of %3.").tqarg( attNew->fullName() )
+            .tqarg( ev ? ev->summary() : to->summary() )
+            .tqarg( attNew->delegator() );
       if ( KMessageBox::questionYesNo( 0, msg, i18n("Uninvited attendee"),
            KGuiItem(i18n("Accept Attendance")), KGuiItem(i18n("Reject Attendance")) )
            != KMessageBox::Yes )
@@ -668,14 +668,14 @@ bool Scheduler::acceptReply(IncidenceBase *incidence,ScheduleMessage::Status /*
   return ret;
 }
 
-bool Scheduler::acceptRefresh(IncidenceBase *incidence,ScheduleMessage::Status /* status */)
+bool Scheduler::acceptRefresh(IncidenceBase *incidence,ScheduleMessage::tqStatus /* status */)
 {
   // handled in korganizer's IncomingDialog
   deleteTransaction(incidence);
   return false;
 }
 
-bool Scheduler::acceptCounter(IncidenceBase *incidence,ScheduleMessage::Status /* status */)
+bool Scheduler::acceptCounter(IncidenceBase *incidence,ScheduleMessage::tqStatus /* status */)
 {
   deleteTransaction(incidence);
   return false;
