@@ -26,9 +26,10 @@ namespace KCal {
 
   class ResourceCalendar;
 
-class TestResource : public QObject
+class TestResource : public TQObject
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     TestResource( const TQString& type, KConfig *config );
