@@ -6,9 +6,10 @@
 
 using namespace KCDDB;
 
-class AsyncSMTPSubmitTest : public QObject
+class AsyncSMTPSubmitTest : public TQObject
 {
   Q_OBJECT
+  TQ_OBJECT
 
   public:
     AsyncSMTPSubmitTest();
