@@ -92,7 +92,7 @@ void ScoresList::addLineItem(const ItemArray &items,
         if (line) line->setText(k, itemText(container, index));
         else {
             addColumn( container.item()->label() );
-            setColumnAlignment(k, container.item()->alignment());
+            setColumnAlignment(k, container.item()->tqalignment());
         }
         k++;
     }
@@ -210,7 +210,7 @@ HighscoresDialog::HighscoresDialog(int rank, TQWidget *parent)
         for (uint i=0; i<internal->nbGameTypes(); i++) {
             TQString title = internal->manager.gameTypeLabel(i, Manager::I18N);
             TQString icon = internal->manager.gameTypeLabel(i, Manager::Icon);
-            TQWidget *w = addVBoxPage(title, TQString::null,
+            TQWidget *w = addVBoxPage(title, TQString(),
                                      BarIcon(icon, KIcon::SizeLarge));
             if ( i==internal->gameType() ) createPage(w);
         }
@@ -251,7 +251,7 @@ void HighscoresDialog::slotUser1()
 
 void HighscoresDialog::slotUser2()
 {
-    KURL url = KFileDialog::getSaveURL(TQString::null, TQString::null, this);
+    KURL url = KFileDialog::getSaveURL(TQString(), TQString(), this);
     if ( url.isEmpty() ) return;
     if ( KIO::NetAccess::exists(url, true, this) ) {
         KGuiItem gi = KStdGuiItem::save();
@@ -289,7 +289,7 @@ void LastMultipleScoresList::addLineItem(const ItemArray &si,
         if (line) line->setText(i, itemText(*container, index));
         else {
             addColumn(  container->item()->label() );
-            setColumnAlignment(i, container->item()->alignment());
+            setColumnAlignment(i, container->item()->tqalignment());
         }
     }
 }
@@ -299,7 +299,7 @@ TQString LastMultipleScoresList::itemText(const ItemContainer &item,
 {
     TQString name = item.name();
     if ( name=="rank" )
-        return (_scores[row].type()==Won ? i18n("Winner") : TQString::null);
+        return (_scores[row].type()==Won ? i18n("Winner") : TQString());
     TQVariant v = _scores[row].data(name);
     if ( name=="name" ) return v.toString();
     return item.item()->pretty(row, v);
@@ -333,7 +333,7 @@ void TotalMultipleScoresList::addLineItem(const ItemArray &si,
             TQString label =
                 (i==2 ? i18n("Won Games") : container->item()->label());
             addColumn(label);
-            setColumnAlignment(i, container->item()->alignment());
+            setColumnAlignment(i, container->item()->tqalignment());
         }
     }
 }
@@ -456,7 +456,7 @@ void ConfigDialog::removeSlot()
                                i18n("This will permanently remove your "
                                "registration key. You will not be able to use "
                                "the currently registered nickname anymore."),
-                               TQString::null, gi);
+                               TQString(), gi);
     if ( res==KMessageBox::Continue ) {
         internal->playerInfos().removeKey();
         _registeredName->clear();
@@ -471,7 +471,7 @@ void ConfigDialog::load()
 {
     internal->hsConfig().readCurrentConfig();
     const PlayerInfos &infos = internal->playerInfos();
-    _nickname->setText(infos.isAnonymous() ? TQString::null : infos.name());
+    _nickname->setText(infos.isAnonymous() ? TQString() : infos.name());
     _comment->setText(infos.comment());
     if (_WWHEnabled) {
         _WWHEnabled->setChecked(infos.isWWEnabled());
