@@ -51,7 +51,7 @@ public:
 		IdName=5,
 
 		//KGame
-		IdGameStatus=6,
+		IdGametqStatus=6,
 		IdMaxPlayer=7,
 		IdMinPlayer=8,
 
@@ -66,7 +66,7 @@ public:
 	};
 
 	/**
-	 * Commands for advanced properties (Q_INT8)
+	 * Commands for advanced properties (TQ_INT8)
 	 **/
 	enum PropertyCommandIds 
 	{
@@ -117,7 +117,7 @@ public:
 
 	/**
 	 * Constructs a KGamePropertyBase object and calls registerData.
-	 * @param id The id of this property. MUST be UNIQUE! Used to send and
+	 * @param id The id of this property. MUST be UNITQUE! Used to send and
 	 * receive changes in the property of the playere automatically via
 	 * network. 
 	 * @param owner The owner of the object. Must be a KGamePropertyHandler which manages
@@ -359,7 +359,7 @@ protected:
 		struct {
 			// unsigned char dosave : 1;   // do save this property
 			// unsigned char delaytransmit : 1;   // do not send immediately on
-                                             // change but a KPlayer:QTimer
+                                             // change but a KPlayer:TQTimer
                                              // sends it later on - fast
                                              // changing variables
 			unsigned char emitsignal : 1; // KPlayer notifies on variable change (true)
@@ -546,16 +546,16 @@ private:
  * };
  * TQDataStream& operator<<(TQDataStream& stream, Card& card)
  * {
- * Q_INT16 type = card.type;
- * Q_INT16 suite = card.suite;
+ * TQ_INT16 type = card.type;
+ * TQ_INT16 suite = card.suite;
  * s << type;
  * s << suite;
  * return s;
  * }
  * TQDataStream& operator>>(TQDataStream& stream, Card& card)
  * {
- * Q_INT16 type;
- * Q_INT16 suite;
+ * TQ_INT16 type;
+ * TQ_INT16 suite;
  * s >> type;
  * s >> suite;
  * card.type = (int)type;
@@ -585,7 +585,7 @@ public:
 	 * Constructs a KGameProperty object. A KGameProperty object will transmit
 	 * any changes to the KMessageServer and then to all clients in the
 	 * game (including the one that has sent the new value)
-	 * @param id The id of this property. <em>MUST be UNIQUE</em>! Used to send and
+	 * @param id The id of this property. <em>MUST be UNITQUE</em>! Used to send and
 	 * receive changes in the property of the playere automatically via
 	 * network. 
 	 * @param owner The parent of the object. Must be a KGame which manages
@@ -842,7 +842,7 @@ private:
 
 typedef KGameProperty<int>   KGamePropertyInt;
 typedef KGameProperty<unsigned int>   KGamePropertyUInt;
-typedef KGameProperty<TQString>   KGamePropertyQString;
-typedef KGameProperty<Q_INT8>   KGamePropertyBool;
+typedef KGameProperty<TQString>   KGamePropertyTQString;
+typedef KGameProperty<TQ_INT8>   KGamePropertyBool;
 
 #endif
