@@ -111,7 +111,7 @@ static bool itemIsHeader( const TQListBoxItem* item )
 
 AddresseeLineEdit::AddresseeLineEdit( TQWidget* parent, bool useCompletion,
                                       const char *name )
-  : ClickLineEdit( parent, TQString::null, name ), DCOPObject( newLineEditDCOPObjectName() ),
+  : ClickLineEdit( parent, TQString(), name ), DCOPObject( newLineEditDCOPObjectName() ),
     m_useSemiColonAsSeparator( false ), m_allowDistLists( true )
 {
   m_useCompletion = useCompletion;
@@ -310,7 +310,7 @@ void AddresseeLineEdit::insert( const TQString &t )
     eot--;
   }
   if ( eot == 0 ) {
-    contents = TQString::null;
+    contents = TQString();
   } else if ( pos >= eot ) {
     if ( contents[ eot - 1 ] == ',' ) {
       eot--;
@@ -344,9 +344,9 @@ void AddresseeLineEdit::mouseReleaseEvent( TQMouseEvent *e )
 {
   // reimplemented from TQLineEdit::mouseReleaseEvent()
   if ( m_useCompletion
-       && TQApplication::clipboard()->supportsSelection()
+       && TQApplication::tqclipboard()->supportsSelection()
        && !isReadOnly()
-       && e->button() == MidButton ) {
+       && e->button() == Qt::MidButton ) {
     m_smartPaste = true;
   }
 
@@ -365,7 +365,7 @@ void AddresseeLineEdit::dropEvent( TQDropEvent *e )
       while ( ( eot > 0 ) && contents[ eot - 1 ].isSpace() )
         eot--;
       if ( eot == 0 )
-        contents = TQString::null;
+        contents = TQString();
       else if ( contents[ eot - 1 ] == ',' ) {
         eot--;
         contents.truncate( eot );
@@ -389,7 +389,7 @@ void AddresseeLineEdit::dropEvent( TQDropEvent *e )
       }
     } else {
       // Let's see if this drop contains a comma separated list of emails
-      TQString dropData = TQString::fromUtf8( e->encodedData( "text/plain" ) );
+      TQString dropData = TQString::fromUtf8( e->tqencodedData( "text/plain" ) );
       TQStringList addrs = splitEmailAddrList( dropData );
       if ( addrs.count() > 0 ) {
         setText( normalizeAddressesAndDecodeIDNs( dropData ) );
@@ -482,7 +482,7 @@ void AddresseeLineEdit::doCompletion( bool ctrlT )
         //if only our \" is left, remove it since user has not typed it either
         if ( m_searchExtended && m_searchString == "\"" ){
           m_searchExtended = false;
-          m_searchString = TQString::null;
+          m_searchString = TQString();
           setText( m_previousAddresses );
           break;
         }
@@ -757,13 +757,13 @@ void AddresseeLineEdit::addContact( const KABC::Addressee& addr, int weight, int
 void AddresseeLineEdit::addCompletionItem( const TQString& string, int weight, int completionItemSource, const TQStringList * keyWords )
 {
   // Check if there is an exact match for item already, and use the max weight if so.
-  // Since there's no way to get the information from KCompletion, we have to keep our own QMap
+  // Since there's no way to get the information from KCompletion, we have to keep our own TQMap
   CompletionItemsMap::iterator it = s_completionItemMap->find( string );
   if ( it != s_completionItemMap->end() ) {
-    weight = QMAX( ( *it ).first, weight );
+    weight = TQMAX( ( *it ).first, weight );
     ( *it ).first = weight;
   } else {
-    s_completionItemMap->insert( string, qMakePair( weight, completionItemSource ) );
+    s_completionItemMap->insert( string, tqMakePair( weight, completionItemSource ) );
   }
   if ( keyWords == 0 )
     s_completion->addItem( string, weight );
@@ -852,7 +852,7 @@ void AddresseeLineEdit::setCompletedItems( const TQStringList& items, bool autoS
         TQPoint oldPosOfItemUnderMouse;
         if ( itemUnderMouse ) {
             oldTextUnderMouse = itemUnderMouse->text();
-            oldPosOfItemUnderMouse = completionBox->itemRect( itemUnderMouse ).topLeft();
+            oldPosOfItemUnderMouse = completionBox->tqitemRect( itemUnderMouse ).topLeft();
         }
 
         completionBox->setItems( items );
@@ -865,7 +865,7 @@ void AddresseeLineEdit::setCompletedItems( const TQStringList& items, bool autoS
           // calls show(), and that's where KCompletionBox installs its filter.
           // We want to be first, though, so do it now.
           if ( s_completion->order() == KCompletion::Weighted )
-            qApp->installEventFilter( this );
+            tqApp->installEventFilter( this );
         }
 
         // Try to re-select what was selected before, otherrwise use the first
@@ -882,7 +882,7 @@ void AddresseeLineEdit::setCompletedItems( const TQStringList& items, bool autoS
               // if the mouse was over an item, before, but now that's elsewhere,
               // move the cursor, so folks don't accidently click the wrong item
               if ( newItemUnderMouse ) {
-                  TQRect r = completionBox->itemRect( newItemUnderMouse );
+                  TQRect r = completionBox->tqitemRect( newItemUnderMouse );
                   TQPoint target = r.topLeft();
                   if ( oldPosOfItemUnderMouse != target ) {
                       target.setX( target.x() + r.width()/2 );
@@ -991,7 +991,7 @@ void AddresseeLineEdit::updateSearchString()
     m_previousAddresses = m_searchString.left( n );
     m_searchString = m_searchString.mid( n ).stripWhiteSpace();
   } else {
-    m_previousAddresses = TQString::null;
+    m_previousAddresses = TQString();
   }
 }
 
@@ -1037,12 +1037,12 @@ int KPIM::AddresseeLineEdit::addCompletionSource( const TQString &source, int we
 
 bool KPIM::AddresseeLineEdit::eventFilter(TQObject *obj, TQEvent *e)
 {
-  if ( obj == completionBox() ) {
+  if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(completionBox()) ) {
     if ( e->type() == TQEvent::MouseButtonPress ||
          e->type() == TQEvent::MouseMove ||
          e->type() == TQEvent::MouseButtonRelease ||
          e->type() == TQEvent::MouseButtonDblClick ) {
-      TQMouseEvent* me = static_cast<TQMouseEvent*>( e );
+      TQMouseEvent* me = TQT_TQMOUSEEVENT( e );
       // find list box item at the event position
       TQListBoxItem *item = completionBox()->itemAt( me->pos() );
       if ( !item ) {
@@ -1054,14 +1054,14 @@ bool KPIM::AddresseeLineEdit::eventFilter(TQObject *obj, TQEvent *e)
       // avoid selection of headers on button press, or move or release while
       // a button is pressed
       if ( e->type() == TQEvent::MouseButtonPress
-          || me->state() & LeftButton || me->state() & MidButton
-          || me->state() & RightButton ) {
+          || me->state() & Qt::LeftButton || me->state() & Qt::MidButton
+          || me->state() & Qt::RightButton ) {
         if ( itemIsHeader(item) ) {
           return true; // eat the event, we don't want anything to happen
         } else {
           // if we are not on one of the group heading, make sure the item
           // below or above is selected, not the heading, inadvertedly, due
-          // to fuzzy auto-selection from QListBox
+          // to fuzzy auto-selection from TQListBox
           completionBox()->setCurrentItem( item );
           completionBox()->setSelected( completionBox()->index( item ), true );
           if ( e->type() == TQEvent::MouseMove )
@@ -1070,18 +1070,18 @@ bool KPIM::AddresseeLineEdit::eventFilter(TQObject *obj, TQEvent *e)
       }
     }
   }
-  if ( ( obj == this ) &&
+  if ( ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(this) ) &&
      ( e->type() == TQEvent::AccelOverride ) ) {
-    TQKeyEvent *ke = static_cast<TQKeyEvent*>( e );
+    TQKeyEvent *ke = TQT_TQKEYEVENT( e );
     if ( ke->key() == Key_Up || ke->key() == Key_Down || ke->key() == Key_Tab ) {
       ke->accept();
       return true;
     }
   }
-  if ( ( obj == this ) &&
+  if ( ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(this) ) &&
        ( e->type() == TQEvent::KeyPress || e->type() == TQEvent::KeyRelease ) &&
        completionBox()->isVisible() ) {
-    TQKeyEvent *ke = static_cast<TQKeyEvent*>( e );
+    TQKeyEvent *ke = TQT_TQKEYEVENT( e );
     int currentIndex = completionBox()->currentItem();
     if ( currentIndex < 0 ) {
       return true;
@@ -1145,7 +1145,7 @@ bool KPIM::AddresseeLineEdit::eventFilter(TQObject *obj, TQEvent *e)
       /// first, find the header of the current section
       TQListBoxItem *myHeader = 0;
       const int iterationstep = ke->key() == Key_Tab ?  1 : -1;
-      int i = QMIN( QMAX( currentIndex - iterationstep, 0 ), completionBox()->count() - 1 );
+      int i = TQMIN( TQMAX( currentIndex - iterationstep, 0 ), completionBox()->count() - 1 );
       while ( i>=0 ) {
         if ( itemIsHeader( completionBox()->item(i) ) ) {
           myHeader = completionBox()->item( i );
