@@ -162,13 +162,13 @@ AddresseeViewItem::category() const
   return d->category;
 }
 
-QString
+TQString
 AddresseeViewItem::name() const
 {
   return text(0);
 }
 
-QString
+TQString
 AddresseeViewItem::email() const
 {
   return text(1);
@@ -353,7 +353,7 @@ AddressesDialog::setShowBCC( bool b )
   d->ui->mBCCButton->setShown( b );
 }
 
-QStringList
+TQStringList
 AddressesDialog::to() const
 {
   TQStringList emails = allDistributionLists( d->toItem );
@@ -363,7 +363,7 @@ AddressesDialog::to() const
   return emails;
 }
 
-QStringList
+TQStringList
 AddressesDialog::cc() const
 {
   TQStringList emails = allDistributionLists( d->ccItem );
@@ -373,7 +373,7 @@ AddressesDialog::cc() const
   return emails;
 }
 
-QStringList
+TQStringList
 AddressesDialog::bcc() const
 {
   TQStringList emails = allDistributionLists( d->bccItem );
@@ -437,19 +437,19 @@ AddressesDialog::bccAddresses()  const
 }
 
 
-QStringList
+TQStringList
 AddressesDialog::toDistributionLists() const
 {
   return allDistributionLists( d->toItem );
 }
 
-QStringList
+TQStringList
 AddressesDialog::ccDistributionLists() const
 {
   return allDistributionLists( d->ccItem );
 }
 
-QStringList
+TQStringList
 AddressesDialog::bccDistributionLists() const
 {
   return allDistributionLists( d->bccItem );
@@ -708,7 +708,7 @@ AddressesDialog::addAddresseesToSelected( AddresseeViewItem *parent,
   parent->setOpen( true );
 }
 
-QStringList
+TQStringList
 AddressesDialog::entryToString( const KABC::Addressee::List& l ) const
 {
   TQStringList entries;
@@ -894,7 +894,7 @@ AddressesDialog::saveAs()
   bool ok = false;
   TQString name = KInputDialog::getText( i18n("New Distribution List"),
                                         i18n("Please enter name:"),
-                                        TQString::null, &ok,
+                                        TQString(), &ok,
                                         this );
   if ( !ok || name.isEmpty() )
     return;
@@ -912,7 +912,7 @@ AddressesDialog::saveAs()
     KMessageBox::information( 0,
                               i18n( "<qt>Distribution list with the given name <b>%1</b> "
                                     "already exists. Please select a different name.</qt>" )
-                              .arg( name ) );
+                              .tqarg( name ) );
     return;
   }
 
@@ -1111,7 +1111,7 @@ AddressesDialog::allAddressee( AddresseeViewItem* parent ) const
   return lst;
 }
 
-QStringList
+TQStringList
 AddressesDialog::allDistributionLists( AddresseeViewItem* parent ) const
 {
   TQStringList lists;
