@@ -19,11 +19,11 @@
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
+    the TQt library by Trolltech AS, Norway (or with modified versions
+    of TQt that use the same license as TQt), and distribute linked
     combinations including the two.  You must obey the GNU General
     Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
+    TQt.  If you modify this file, you may extend this exception to
     your version of the file, but you are not obligated to do so.  If
     you do not wish to do so, delete this exception statement from
     your version.
@@ -73,17 +73,17 @@ namespace KPIM {
     mMetrics( pdm )
   {
     // initialize with defaults - should match the corresponding application defaults
-    mForegroundColor = TQApplication::palette().active().text();
+    mForegroundColor = TQApplication::tqpalette().active().text();
     mLinkColor = KGlobalSettings::linkColor();
     mVisitedLinkColor = KGlobalSettings::visitedLinkColor();
-    mBackgroundColor = TQApplication::palette().active().base();
+    mBackgroundColor = TQApplication::tqpalette().active().base();
     cHtmlWarning = TQColor( 0xFF, 0x40, 0x40 ); // warning frame color: light red
 
     cPgpEncrH = TQColor( 0x00, 0x80, 0xFF ); // light blue
     cPgpOk1H  = TQColor( 0x40, 0xFF, 0x40 ); // light green
     cPgpOk0H  = TQColor( 0xFF, 0xFF, 0x40 ); // light yellow
     cPgpWarnH = TQColor( 0xFF, 0xFF, 0x40 ); // light yellow
-    cPgpErrH  = Qt::red;
+    cPgpErrH  = TQt::red;
 
     for ( int i = 0 ; i < 3 ; ++i )
       mQuoteColor[i] = TQColor( 0x00, 0x80 - i * 0x10, 0x00 ); // shades of green
@@ -184,9 +184,9 @@ namespace KPIM {
       ? level % numQuoteLevels + 1
       : kMin( level + 1, numQuoteLevels ) ;
     if ( level >= numQuoteLevels )
-      return TQString( "<div class=\"deepquotelevel%1\">" ).arg( effectiveLevel );
+      return TQString( "<div class=\"deepquotelevel%1\">" ).tqarg( effectiveLevel );
     else
-      return TQString( "<div class=\"quotelevel%1\">" ).arg( effectiveLevel );
+      return TQString( "<div class=\"quotelevel%1\">" ).tqarg( effectiveLevel );
   }
 
   TQString CSSHelper::nonQuotedFontTag() const {
@@ -214,9 +214,9 @@ namespace KPIM {
   TQString CSSHelper::printCssDefinitions( bool fixed ) const {
     const TQString headerFont = TQString( "  font-family: \"%1\" ! important;\n"
                                         "  font-size: %2pt ! important;\n" )
-                           .arg( mPrintFont.family() )
-                           .arg( mPrintFont.pointSize() );
-    const TQColorGroup & cg = TQApplication::palette().active();
+                           .tqarg( mPrintFont.family() )
+                           .tqarg( mPrintFont.pointSize() );
+    const TQColorGroup & cg = TQApplication::tqpalette().active();
 
     const TQFont printFont = bodyFont( fixed, true /* print */ );
     TQString quoteCSS;
@@ -234,7 +234,7 @@ namespace KPIM {
                "  color: #000000 ! important;\n"
                "  background-color: #ffffff ! important\n"
                "}\n\n" )
-      .arg( printFont.family(),
+      .tqarg( printFont.family(),
             TQString::number( printFont.pointSize() ) )
       +
       TQString( "tr.textAtmH,\n"
@@ -288,7 +288,7 @@ namespace KPIM {
                "  display:none ! important;\n"
                "}\n\n"
             )
-      .arg( headerFont,
+      .tqarg( headerFont,
             cg.background().name(),
             cg.foreground().name() )
       + quoteCSS;
@@ -300,15 +300,15 @@ namespace KPIM {
     const TQString linkColor = mLinkColor.name();
     const TQString headerFont = TQString("  font-family: \"%1\" ! important;\n"
                                        "  font-size: %2px ! important;\n")
-      .arg( mBodyFont.family() )
-      .arg( pointsToPixel( helper->mMetrics, mBodyFont.pointSize() ) );
+      .tqarg( mBodyFont.family() )
+      .tqarg( pointsToPixel( helper->mMetrics, mBodyFont.pointSize() ) );
     const TQString background = ( mBackingPixmapOn
                          ? TQString( "  background-image:url(file://%1) ! important;\n" )
-                           .arg( mBackingPixmapStr )
+                           .tqarg( mBackingPixmapStr )
                          : TQString( "  background-color: %1 ! important;\n" )
-                           .arg( bgColor ) );
+                           .tqarg( bgColor ) );
     const TQString bodyFontSize = TQString::number( pointsToPixel( helper->mMetrics, fontSize( fixed ) ) ) + "px" ;
-    const TQColorGroup & cg = TQApplication::palette().active();
+    const TQColorGroup & cg = TQApplication::tqpalette().active();
 
     TQString quoteCSS;
     if ( bodyFont( fixed ).italic() )
@@ -322,13 +322,13 @@ namespace KPIM {
     for ( int i = 0 ; i < 3 ; ++i ) {
       quoteCSS += TQString( "div.quotelevel%1 {\n"
                            "  color: %2 ! important;\n" )
-        .arg( TQString::number(i+1), mQuoteColor[i].name() );
+        .tqarg( TQString::number(i+1), mQuoteColor[i].name() );
       if ( mQuoteFont[i].italic() )
         quoteCSS += "  font-style: italic ! important;\n";
       if ( mQuoteFont[i].bold() )
         quoteCSS += "  font-weight: bold ! important;\n";
       if ( mShrinkQuotes )
-        quoteCSS += "  font-size: " + TQString::fromLatin1( quoteFontSizes[i] )
+        quoteCSS += "  font-size: " + TQString::tqfromLatin1( quoteFontSizes[i] )
           + "% ! important;\n";
       quoteCSS += "}\n\n";
     }
@@ -337,7 +337,7 @@ namespace KPIM {
     for ( int i = 0 ; i < 3 ; ++i ) {
       quoteCSS += TQString( "div.deepquotelevel%1 {\n"
                            "  color: %2 ! important;\n" )
-        .arg( TQString::number(i+1), mQuoteColor[i].name() );
+        .tqarg( TQString::number(i+1), mQuoteColor[i].name() );
       if ( mQuoteFont[i].italic() )
         quoteCSS += "  font-style: italic ! important;\n";
       if ( mQuoteFont[i].bold() )
@@ -354,7 +354,7 @@ namespace KPIM {
                "  color: %3 ! important;\n"
                "%4"
                "}\n\n" )
-      .arg( bodyFont( fixed ).family(),
+      .tqarg( bodyFont( fixed ).family(),
             bodyFontSize,
             fgColor,
             background )
@@ -392,7 +392,7 @@ namespace KPIM {
                "tr.rfc822H {\n"
                "%4"
                "}\n\n" )
-      .arg( linkColor, fgColor, bgColor, headerFont )
+      .tqarg( linkColor, fgColor, bgColor, headerFont )
       +
       TQString( "table.encr {\n"
                "  background-color: %1 ! important;\n"
@@ -404,7 +404,7 @@ namespace KPIM {
                "}\n\n"
 
                "tr.encrB { background-color: %4 ! important; }\n\n" )
-      .arg( cPgpEncrF.name(),
+      .tqarg( cPgpEncrF.name(),
             cPgpEncrH.name(),
             headerFont,
             cPgpEncrB.name() )
@@ -419,7 +419,7 @@ namespace KPIM {
                "}\n\n"
 
                "tr.signOkKeyOkB { background-color: %4 ! important; }\n\n" )
-      .arg( cPgpOk1F.name(),
+      .tqarg( cPgpOk1F.name(),
             cPgpOk1H.name(),
             headerFont,
             cPgpOk1B.name() )
@@ -434,7 +434,7 @@ namespace KPIM {
                "}\n\n"
 
                "tr.signOkKeyBadB { background-color: %4 ! important; }\n\n" )
-      .arg( cPgpOk0F.name(),
+      .tqarg( cPgpOk0F.name(),
             cPgpOk0H.name(),
             headerFont,
             cPgpOk0B.name() )
@@ -449,7 +449,7 @@ namespace KPIM {
                "}\n\n"
 
                "tr.signWarnB { background-color: %4 ! important; }\n\n" )
-      .arg( cPgpWarnF.name(),
+      .tqarg( cPgpWarnF.name(),
             cPgpWarnH.name(),
             headerFont,
             cPgpWarnB.name() )
@@ -464,7 +464,7 @@ namespace KPIM {
                "}\n\n"
 
                "tr.signErrB { background-color: %4 ! important; }\n\n" )
-      .arg( cPgpErrF.name(),
+      .tqarg( cPgpErrF.name(),
             cPgpErrH.name(),
             headerFont,
             cPgpErrB.name() )
@@ -472,7 +472,7 @@ namespace KPIM {
       TQString( "div.htmlWarn {\n"
                "  border: 2px solid %1 ! important;\n"
                "}\n\n" )
-      .arg( cHtmlWarning.name() )
+      .tqarg( cHtmlWarning.name() )
       +
       TQString( "div.header {\n"
                "%1"
@@ -519,12 +519,12 @@ namespace KPIM {
                "}\n\n"
                )
 
-      .arg( headerFont )
-      .arg( cg.highlight().name(),
+      .tqarg( headerFont )
+      .tqarg( cg.highlight().name(),
             cg.highlightedText().name(),
             cg.foreground().name(),
             cg.background().name() )
-      .arg( cg.mid().name() )
+      .tqarg( cg.mid().name() )
       + quoteCSS;
   }
 
