@@ -34,7 +34,7 @@ void TestManager::slotAllPluginsLoaded()
 {
   kdDebug()<<"Done"<<endl;
   m_manager->shutdown();
-  qApp->exit();
+  tqApp->exit();
 }
 
 void TestManager::slotPluginLoaded( Plugin *plugin )
