@@ -15,10 +15,10 @@
     Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 #ifdef KDE_USE_FINAL
-#undef QT_NO_ASCII_CAST
+#undef TQT_NO_ASCII_CAST
 #endif
 
-#undef QT_NO_COMPAT
+#undef TQT_NO_COMPAT
 
 #include <iostream>
 
@@ -39,7 +39,7 @@
 
 
 //----------------------------------------------------------------------------
-// a small function to encode attribute values, code stolen from QDom
+// a small function to encode attribute values, code stolen from TQDom
 static TQString toXml(const TQString& str)
 {
   TQString tmp(str);
@@ -409,7 +409,7 @@ KScoringExpression::KScoringExpression(const TQString& h, const TQString& t, con
     expr.setCaseSensitive( true );
   }
   else if (t == "CONTAINS" ) cond = CONTAINS;
-  else if (t == "EQUALS" ) cond = EQUALS;
+  else if (t == "ETQUALS" ) cond = ETQUALS;
   else if (t == "GREATER") {
     cond = GREATER;
     expr_int = expr_str.toInt();
@@ -435,7 +435,7 @@ int KScoringExpression::getConditionForName(const TQString& s)
   if (s == getNameForCondition(CONTAINS)) return CONTAINS;
   else if (s == getNameForCondition(MATCH)) return MATCH;
   else if (s == getNameForCondition(MATCHCS)) return MATCHCS;
-  else if (s == getNameForCondition(EQUALS)) return EQUALS;
+  else if (s == getNameForCondition(ETQUALS)) return ETQUALS;
   else if (s == getNameForCondition(SMALLER)) return SMALLER;
   else if (s == getNameForCondition(GREATER)) return GREATER;
   else {
@@ -452,7 +452,7 @@ TQString KScoringExpression::getNameForCondition(int cond)
   case CONTAINS: return i18n("Contains Substring");
   case MATCH: return i18n("Matches Regular Expression");
   case MATCHCS: return i18n("Matches Regular Expression (Case Sensitive)");
-  case EQUALS: return i18n("Is Exactly the Same As");
+  case ETQUALS: return i18n("Is Exactly the Same As");
   case SMALLER: return i18n("Less Than");
   case GREATER: return i18n("Greater Than");
   default:
@@ -469,7 +469,7 @@ TQStringList KScoringExpression::conditionNames()
   l << getNameForCondition(CONTAINS);
   l << getNameForCondition(MATCH);
   l << getNameForCondition(MATCHCS);
-  l << getNameForCondition(EQUALS);
+  l << getNameForCondition(ETQUALS);
   l << getNameForCondition(SMALLER);
   l << getNameForCondition(GREATER);
   return l;
@@ -510,7 +510,7 @@ bool KScoringExpression::match(ScorableArticle& a) const
 
   if (!head.isEmpty()) {
     switch (cond) {
-    case EQUALS:
+    case ETQUALS:
       res = (head.lower() == expr_str.lower());
       break;
     case CONTAINS:
@@ -569,7 +569,7 @@ TQString KScoringExpression::getTypeString(int cond)
   case CONTAINS: return "CONTAINS";
   case MATCH: return "MATCH";
   case MATCHCS: return "MATCHCS";
-  case EQUALS: return "EQUALS";
+  case ETQUALS: return "ETQUALS";
   case SMALLER: return "SMALLER";
   case GREATER: return "GREATER";
   default:
@@ -773,7 +773,7 @@ TQString KScoringRule::getExpireDateString() const
 
 bool KScoringRule::isExpired() const
 {
-  return (expires.isValid() && (expires < TQDate::currentDate()));
+  return (expires.isValid() && (expires < TQDate::tqcurrentDate()));
 }
 
 
@@ -925,7 +925,7 @@ KScoringRule* KScoringManager::addRule(const ScorableArticle& a, TQString group,
     new KScoringExpression("From","CONTAINS",
                             a.from(),"0"));
   if (score) rule->addAction(new ActionSetScore(score));
-  rule->setExpireDate(TQDate::currentDate().addDays(30));
+  rule->setExpireDate(TQDate::tqcurrentDate().addDays(30));
   addRule(rule);
   KScoringEditor *edit = KScoringEditor::createEditor(this);
   edit->setRule(rule);
@@ -1137,7 +1137,7 @@ TQString KScoringManager::findUniqueName() const
 
   while (nr < 99999999) {
     nr++;
-    ret = i18n("rule %1").arg(nr);
+    ret = i18n("rule %1").tqarg(nr);
 
     duplicated=false;
     TQPtrListIterator<KScoringRule> it(allRules);
