@@ -15,7 +15,7 @@
     Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 
-#undef QT_NO_COMPAT
+#undef TQT_NO_COMPAT
 
 #include "kscoring.h"
 #include "kscoringeditor.h"
@@ -91,7 +91,7 @@ SingleConditionWidget::SingleConditionWidget(KScoringManager *m,TQWidget *p, con
   connect( regExpButton, TQT_SIGNAL( clicked() ), TQT_SLOT( showRegExpDialog() ) );
 
   // occupy at much width as possible
-  setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding,TQSizePolicy::Fixed));
+  tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding,TQSizePolicy::Fixed));
   setFrameStyle(Box | Sunken);
   setLineWidth(1);
 }
@@ -226,7 +226,7 @@ SingleActionWidget::SingleActionWidget(KScoringManager *m,TQWidget *p, const cha
 
   // init widget stack and the types combo box
   int index = 1;
-  types->insertItem(TQString::null);
+  types->insertItem(TQString());
   TQStringList l = ActionBase::userNames();
   for ( TQStringList::Iterator it = l.begin(); it != l.end(); ++it ) {
     TQString name = *it;
@@ -301,7 +301,7 @@ ActionBase* SingleActionWidget::createAction() const
     case ActionBase::NOTIFY:
       return new ActionNotify(notifyEditor->text());
     case ActionBase::COLOR:
-      return new ActionColor(colorEditor->color().name());
+      return new ActionColor(TQString(colorEditor->color().name()));
     case ActionBase::MARKASREAD:
       return new ActionMarkAsRead();
     default:
@@ -390,7 +390,7 @@ void ActionEditWidget::clearWidget(TQWidget *w)
 //
 //============================================================================
 RuleEditWidget::RuleEditWidget(KScoringManager *m,TQWidget *p, const char *n)
-  : TQWidget(p,n), dirty(false), manager(m), oldRuleName(TQString::null)
+  : TQWidget(p,n), dirty(false), manager(m), oldRuleName(TQString())
 {
   kdDebug(5100) << "RuleEditWidget::RuleEditWidget()" << endl;
   if ( !n ) setName( "RuleEditWidget" );
@@ -421,7 +421,7 @@ RuleEditWidget::RuleEditWidget(KScoringManager *m,TQWidget *p, const char *n)
   groupsBox = new KComboBox( false, groupB, "groupsBox" );
   groupsBox->setDuplicatesEnabled(false);
   groupsBox->insertStringList(manager->getGroups());
-  groupsBox->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed));
+  groupsBox->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed));
   groupL->addWidget( groupsBox, 3, 1 );
 
   // expires
@@ -508,7 +508,7 @@ void RuleEditWidget::slotEditRule(const TQString& ruleName)
   expireEdit->setEnabled(b);
   expireLabel->setEnabled(b);
   if (b)
-    expireEdit->setValue(TQDate::currentDate().daysTo(rule->getExpireDate()));
+    expireEdit->setValue(TQDate::tqcurrentDate().daysTo(rule->getExpireDate()));
   else
     expireEdit->setValue(30);
   if (rule->getLinkMode() == KScoringRule::AND) {
@@ -533,12 +533,12 @@ void RuleEditWidget::clearContents()
   expireEdit->setEnabled(false);
   condEditor->slotEditRule(0);
   actionEditor->slotEditRule(0);
-  oldRuleName = TQString::null;
+  oldRuleName = TQString();
 }
 
 void RuleEditWidget::updateRule(KScoringRule *rule)
 {
-  oldRuleName = TQString::null;
+  oldRuleName = TQString();
   TQString groups = groupsEdit->text();
   if (groups.isEmpty())
     rule->setGroups(TQStringList(".*"));
@@ -546,7 +546,7 @@ void RuleEditWidget::updateRule(KScoringRule *rule)
     rule->setGroups(TQStringList::split(";",groups));
   bool b = expireCheck->isChecked();
   if (b)
-    rule->setExpireDate(TQDate::currentDate().addDays(expireEdit->value()));
+    rule->setExpireDate(TQDate::tqcurrentDate().addDays(expireEdit->value()));
   else
     rule->setExpireDate(TQDate());
   actionEditor->updateRule(rule);
@@ -655,7 +655,7 @@ RuleListWidget::RuleListWidget(KScoringManager *m, bool standalone, TQWidget *p,
   TQStringList l = m->getGroups();
   filterBox->insertItem(i18n("<all groups>"));
   filterBox->insertStringList(l);
-  filterBox->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed));
+  filterBox->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed));
   connect(filterBox,TQT_SIGNAL(activated(const TQString&)),
           this,TQT_SLOT(slotGroupFilter(const TQString&)));
   slotGroupFilter(i18n("<all groups>"));
@@ -746,7 +746,7 @@ void RuleListWidget::slotEditRule()
     emit ruleEdited(ruleList->currentText());
   }
   else if (ruleList->count() == 0)
-    emit ruleEdited(TQString::null);
+    emit ruleEdited(TQString());
 }
 
 void RuleListWidget::slotEditRule(TQListBoxItem* item)
@@ -881,7 +881,7 @@ KScoringEditor::KScoringEditor(KScoringManager* m,
   connect(ruleEditor, TQT_SIGNAL(shrink()), TQT_SLOT(slotShrink()));
   connect(this,TQT_SIGNAL(finished()),TQT_SLOT(slotFinished()));
   ruleLister->slotRuleSelected(0);
-  resize(550, sizeHint().height());
+  resize(550, tqsizeHint().height());
 }
 
 void KScoringEditor::setDirty()
@@ -918,7 +918,7 @@ void KScoringEditor::slotDoShrink()
 {
   updateGeometry();
   TQApplication::sendPostedEvents();
-  resize(width(),sizeHint().height());
+  resize(width(),tqsizeHint().height());
 }
 
 void KScoringEditor::slotApply()
@@ -996,7 +996,7 @@ void KScoringEditorWidgetDialog::slotDoShrink()
 {
   updateGeometry();
   TQApplication::sendPostedEvents();
-  resize(width(),sizeHint().height());
+  resize(width(),tqsizeHint().height());
 }
 
 //============================================================================
