@@ -49,7 +49,7 @@ static KStaticDeleter<KConfig> configDeleter;
 
 TQString LdapObject::toString() const
 {
-  TQString result = TQString::fromLatin1( "\ndn: %1\n" ).arg( dn );
+  TQString result = TQString::tqfromLatin1( "\ndn: %1\n" ).tqarg( dn );
   for ( LdapAttrMap::ConstIterator it = attrs.begin(); it != attrs.end(); ++it ) {
     TQString attr = it.key();
     for ( LdapAttrValue::ConstIterator it2 = (*it).begin(); it2 != (*it).end(); ++it2 ) {
@@ -62,8 +62,8 @@ TQString LdapObject::toString() const
 
 void LdapObject::clear()
 {
-  dn = TQString::null;
-  objectClass = TQString::null;
+  dn = TQString();
+  objectClass = TQString();
   attrs.clear();
 }
 
@@ -278,53 +278,53 @@ void LdapSearch::readConfig( LdapServer &server, KConfig *config, int j, bool ac
 {
   TQString prefix;
   if ( active ) prefix = "Selected";
-  TQString host =  config->readEntry( prefix + TQString( "Host%1" ).arg( j ), "" ).stripWhiteSpace();
+  TQString host =  config->readEntry( prefix + TQString( "Host%1" ).tqarg( j ), "" ).stripWhiteSpace();
   if ( !host.isEmpty() )
     server.setHost( host );
 
-  int port = config->readNumEntry( prefix + TQString( "Port%1" ).arg( j ), 389 );
+  int port = config->readNumEntry( prefix + TQString( "Port%1" ).tqarg( j ), 389 );
   server.setPort( port );
 
-  TQString base = config->readEntry( prefix + TQString( "Base%1" ).arg( j ), "" ).stripWhiteSpace();
+  TQString base = config->readEntry( prefix + TQString( "Base%1" ).tqarg( j ), "" ).stripWhiteSpace();
   if ( !base.isEmpty() )
     server.setBaseDN( base );
 
-  TQString user = config->readEntry( prefix + TQString( "User%1" ).arg( j ) ).stripWhiteSpace();
+  TQString user = config->readEntry( prefix + TQString( "User%1" ).tqarg( j ) ).stripWhiteSpace();
   if ( !user.isEmpty() )
     server.setUser( user );
 
-  TQString bindDN = config->readEntry( prefix + TQString( "Bind%1" ).arg( j ) ).stripWhiteSpace();
+  TQString bindDN = config->readEntry( prefix + TQString( "Bind%1" ).tqarg( j ) ).stripWhiteSpace();
   if ( !bindDN.isEmpty() )
     server.setBindDN( bindDN );
 
-  TQString pwdBindDN = config->readEntry( prefix + TQString( "PwdBind%1" ).arg( j ) );
+  TQString pwdBindDN = config->readEntry( prefix + TQString( "PwdBind%1" ).tqarg( j ) );
   if ( !pwdBindDN.isEmpty() )
     server.setPwdBindDN( pwdBindDN );
 
-  server.setTimeLimit( config->readNumEntry( prefix + TQString( "TimeLimit%1" ).arg( j ) ) );
-  server.setSizeLimit( config->readNumEntry( prefix + TQString( "SizeLimit%1" ).arg( j ) ) );
-  server.setVersion( config->readNumEntry( prefix + TQString( "Version%1" ).arg( j ), 3 ) );
-  server.setSecurity( config->readNumEntry( prefix + TQString( "Security%1" ).arg( j ) ) );
-  server.setAuth( config->readNumEntry( prefix + TQString( "Auth%1" ).arg( j ) ) );
-  server.setMech( config->readEntry( prefix + TQString( "Mech%1" ).arg( j ) ) );
+  server.setTimeLimit( config->readNumEntry( prefix + TQString( "TimeLimit%1" ).tqarg( j ) ) );
+  server.setSizeLimit( config->readNumEntry( prefix + TQString( "SizeLimit%1" ).tqarg( j ) ) );
+  server.setVersion( config->readNumEntry( prefix + TQString( "Version%1" ).tqarg( j ), 3 ) );
+  server.setSecurity( config->readNumEntry( prefix + TQString( "Security%1" ).tqarg( j ) ) );
+  server.setAuth( config->readNumEntry( prefix + TQString( "Auth%1" ).tqarg( j ) ) );
+  server.setMech( config->readEntry( prefix + TQString( "Mech%1" ).tqarg( j ) ) );
 }
 
 void LdapSearch::writeConfig( const LdapServer &server, KConfig *config, int j, bool active )
 {
   TQString prefix;
   if ( active ) prefix = "Selected";
-  config->writeEntry( prefix + TQString( "Host%1" ).arg( j ), server.host() );
-  config->writeEntry( prefix + TQString( "Port%1" ).arg( j ), server.port() );
-  config->writeEntry( prefix + TQString( "Base%1" ).arg( j ), server.baseDN() );
-  config->writeEntry( prefix + TQString( "User%1" ).arg( j ), server.user() );
-  config->writeEntry( prefix + TQString( "Bind%1" ).arg( j ), server.bindDN() );
-  config->writeEntry( prefix + TQString( "PwdBind%1" ).arg( j ), server.pwdBindDN() );
-  config->writeEntry( prefix + TQString( "TimeLimit%1" ).arg( j ), server.timeLimit() );
-  config->writeEntry( prefix + TQString( "SizeLimit%1" ).arg( j ), server.sizeLimit() );
-  config->writeEntry( prefix + TQString( "Version%1" ).arg( j ), server.version() );
-  config->writeEntry( prefix + TQString( "Security%1" ).arg( j ), server.security() );
-  config->writeEntry( prefix + TQString( "Auth%1" ).arg( j ), server.auth() );
-  config->writeEntry( prefix + TQString( "Mech%1" ).arg( j ), server.mech() );
+  config->writeEntry( prefix + TQString( "Host%1" ).tqarg( j ), server.host() );
+  config->writeEntry( prefix + TQString( "Port%1" ).tqarg( j ), server.port() );
+  config->writeEntry( prefix + TQString( "Base%1" ).tqarg( j ), server.baseDN() );
+  config->writeEntry( prefix + TQString( "User%1" ).tqarg( j ), server.user() );
+  config->writeEntry( prefix + TQString( "Bind%1" ).tqarg( j ), server.bindDN() );
+  config->writeEntry( prefix + TQString( "PwdBind%1" ).tqarg( j ), server.pwdBindDN() );
+  config->writeEntry( prefix + TQString( "TimeLimit%1" ).tqarg( j ), server.timeLimit() );
+  config->writeEntry( prefix + TQString( "SizeLimit%1" ).tqarg( j ), server.sizeLimit() );
+  config->writeEntry( prefix + TQString( "Version%1" ).tqarg( j ), server.version() );
+  config->writeEntry( prefix + TQString( "Security%1" ).tqarg( j ), server.security() );
+  config->writeEntry( prefix + TQString( "Auth%1" ).tqarg( j ), server.auth() );
+  config->writeEntry( prefix + TQString( "Mech%1" ).tqarg( j ), server.mech() );
 }
 
 KConfig* LdapSearch::config()
@@ -351,7 +351,7 @@ LdapSearch::LdapSearch()
 
 void LdapSearch::readWeighForClient( LdapClient *client, KConfig *config, int clientNumber )
 {
-  const int completionWeight = config->readNumEntry( TQString( "SelectedCompletionWeight%1" ).arg( clientNumber ), -1 );
+  const int completionWeight = config->readNumEntry( TQString( "SelectedCompletionWeight%1" ).tqarg( clientNumber ), -1 );
   if ( completionWeight != -1 )
     client->setCompletionWeight( completionWeight );
 }
@@ -442,7 +442,7 @@ void LdapSearch::startSearch( const TQString& txt )
    * person entries without an email address to show up, while still not showing things
    * like structural entries in the ldap tree. */
   TQString filter = TQString( "&(|(objectclass=person)(objectclass=groupOfNames)(mail=*))(|(cn=%1*)(mail=%2*)(mail=*@%3*)(givenName=%4*)(sn=%5*))" )
-      .arg( mSearchText ).arg( mSearchText ).arg( mSearchText ).arg( mSearchText ).arg( mSearchText );
+      .tqarg( mSearchText ).tqarg( mSearchText ).tqarg( mSearchText ).tqarg( mSearchText ).tqarg( mSearchText );
 
   TQValueList< LdapClient* >::Iterator it;
   for ( it = mClients.begin(); it != mClients.end(); ++it ) {
@@ -590,7 +590,7 @@ void LdapSearch::makeSearchData( TQStringList& ret, LdapResultList& resList )
       ret.append( mail );
     } else {
       //kdDebug(5300) << "LdapSearch::makeSearchData() name: \"" << name << "\"  mail: \"" << mail << "\"" << endl;
-      ret.append( TQString( "%1 <%2>" ).arg( name ).arg( mail ) );
+      ret.append( TQString( "%1 <%2>" ).tqarg( name ).tqarg( mail ) );
     }
 
     LdapResult sr;
