@@ -9,8 +9,8 @@ main()
 
   // test for http://bugs.kde.org/show_bug.cgi?id=54886
   KRegExp3 reg("^");
-  TQString res = reg.replace(TQString::fromLatin1("Fun stuff"),
-			    TQString::fromLatin1("[fun] "));
+  TQString res = reg.replace(TQString::tqfromLatin1("Fun stuff"),
+			    TQString::tqfromLatin1("[fun] "));
   kdDebug() << res << endl;
 
 }
