@@ -24,9 +24,10 @@
 
 #include <tqwidget.h>
 
-class DateEdit : public QWidget
+class DateEdit : public TQWidget
 {
   Q_OBJECT
+  TQ_OBJECT
 
   public:
     DateEdit( TQWidget *parent = 0, const char *name = 0 );
