@@ -21,9 +21,10 @@
 
 #include <tqobject.h>
 
-class TestDistrList : public QObject
+class TestDistrList : public TQObject
 {
     Q_OBJECT
+  TQ_OBJECT
 
 public:
     TestDistrList() {}
