@@ -6,7 +6,7 @@
 
 int main( int argc, char * argv[] ) {
   if ( argc == 1 ) {
-    (void)new QUtf7Codec;
+    (void)new TQUtf7Codec;
 
     TQTextCodec * codec = TQTextCodec::codecForName("utf-7");
     assert(codec);
