@@ -8,7 +8,7 @@
          http://www.kde.org
          http://www.hackerbuero.org $
    $ License: LGPL with the following explicit clarification:
-         This code may be linked against any version of the Qt toolkit
+         This code may be linked against any version of the TQt toolkit
          from Troll Tech, Norway. $
 
 */
@@ -26,6 +26,7 @@ namespace ThreadWeaver {
     class WeaverThreadLogger : public WeaverExtension
     {
         Q_OBJECT
+  TQ_OBJECT
     public:
         WeaverThreadLogger( TQObject *parent = 0, const char *name = 0);
         ~WeaverThreadLogger();
