@@ -20,11 +20,11 @@
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
+    the TQt library by Trolltech AS, Norway (or with modified versions
+    of TQt that use the same license as TQt), and distribute linked
     combinations including the two.  You must obey the GNU General
     Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
+    TQt.  If you modify this file, you may extend this exception to
     your version of the file, but you are not obligated to do so.  If
     you do not wish to do so, delete this exception statement from
     your version.
@@ -192,7 +192,7 @@ namespace KSieve {
 
   Lexer::Token Lexer::Impl::nextToken( TQString & result ) {
     assert( !atEnd() );
-    result = TQString::null;
+    result = TQString();
     //clearErrors();
 
     const int oldLine = line();
@@ -476,9 +476,9 @@ namespace KSieve {
 
     const int identifierLength = mState.cursor - identifierStart;
 
-    // Can use the fast fromLatin1 here, since identifiers are always
+    // Can use the fast tqfromLatin1 here, since identifiers are always
     // in the us-ascii subset:
-    result += TQString::fromLatin1( identifierStart, identifierLength );
+    result += TQString::tqfromLatin1( identifierStart, identifierLength );
 
     if ( atEnd() || isDelim( *mState.cursor ) )
       return true;
@@ -499,8 +499,8 @@ namespace KSieve {
   }
 
   bool Lexer::Impl::parseNumber( TQString & result ) {
-    // number     := 1*DIGIT [QUANTIFIER]
-    // QUANTIFIER := "K" / "M" / "G"
+    // number     := 1*DIGIT [TQUANTIFIER]
+    // TQUANTIFIER := "K" / "M" / "G"
 
     assert( isdigit( *mState.cursor ) );
 
@@ -592,7 +592,7 @@ namespace KSieve {
 	if ( line == "." )
 	  break;
       } else {
-	lines.push_back( TQString::null );
+	lines.push_back( TQString() );
       }
     }
 
@@ -608,7 +608,7 @@ namespace KSieve {
   }
 
   bool Lexer::Impl::parseQuotedString( TQString & result ) {
-    // quoted-string := DQUOTE *CHAR DQUOTE
+    // quoted-string := DTQUOTE *CHAR DTQUOTE
 
     // check that caller plays by the rules:
     assert( *(mState.cursor-1) == '"' );
