@@ -8,9 +8,10 @@ class TQGridLayout;
 
 
 //-----------------------------------------------------------------------------
-class BaseAppearanceConfig : public QWidget
+class BaseAppearanceConfig : public TQWidget
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     BaseAppearanceConfig();
 
@@ -20,9 +21,10 @@ protected:
 };
 
 //-----------------------------------------------------------------------------
-class ColorConfig : public QWidget
+class ColorConfig : public TQWidget
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     ColorConfig();
 
