@@ -10,14 +10,16 @@
 class LIBKSIRTET_EXPORT AppearanceConfig : public BaseAppearanceConfig
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     AppearanceConfig();
 };
 
 //-----------------------------------------------------------------------------
-class LIBKSIRTET_EXPORT GameConfig : public QWidget
+class LIBKSIRTET_EXPORT GameConfig : public TQWidget
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
     GameConfig();
 
