@@ -6,7 +6,7 @@ void errorBox(const TQString &msg1, const TQString &msg2, TQWidget *parent)
 {
     TQString str;
     if ( msg2.isNull() ) str = msg1;
-    else str = i18n("%1:\n%2").arg(msg1).arg(msg2);
+    else str = i18n("%1:\n%2").tqarg(msg1).tqarg(msg2);
     KMessageBox::error(parent, str);
 }
 
