@@ -7,9 +7,10 @@
 #include "mp_interface.h"
 
 
-class KeyData : public QObject
+class KeyData : public TQObject
 {
  Q_OBJECT
+  TQ_OBJECT
  public:
     KeyData(uint maxNb, uint nbActions, const ActionData *,
             TQObject *parent);
@@ -36,7 +37,7 @@ class KeyData : public QObject
     TQMap<KAction *, SpecialData>           _specActions;
 
     TQString group() const
-        { return TQString("Keys (%1 humans)").arg(_cols.size()); }
+        { return TQString("Keys (%1 humans)").tqarg(_cols.size()); }
 };
 
 #endif // KEYS_H
