@@ -10,12 +10,12 @@ using namespace RSS;
 void Tester::test()
 {
 	Loader *loader = Loader::create();
-	connect( loader, TQT_SIGNAL( loadingComplete( Loader *, Document, Status ) ),
-	         this, TQT_SLOT( slotLoadingComplete( Loader *, Document, Status ) ) );
+	connect( loader, TQT_SIGNAL( loadingComplete( Loader *, Document, tqStatus ) ),
+	         this, TQT_SLOT( slotLoadingComplete( Loader *, Document, tqStatus ) ) );
 	loader->loadFrom( "http://sourceforge.net/export/rss2_projnews.php?group_id=29057&rss_fulltext=1", new FileRetriever );
 }
 
-void Tester::slotLoadingComplete( Loader *loader, Document doc, Status status )
+void Tester::slotLoadingComplete( Loader *loader, Document doc, tqStatus status )
 {
 	if ( status == Success )
 		kdDebug() << "Successfully retrieverd '" << doc.title() << "'" << endl;
