@@ -9,16 +9,17 @@
 
 using RSS::Loader;
 using RSS::Document;
-using RSS::Status;
+using RSS::tqStatus;
 
-class Tester : public QObject
+class Tester : public TQObject
 {
 	Q_OBJECT
+  TQ_OBJECT
 	public:
 		void test();
 
 	private slots:
-		void slotLoadingComplete( Loader *loader, Document doc, Status status );
+		void slotLoadingComplete( Loader *loader, Document doc, tqStatus status );
 };
 
 #endif
