@@ -14,9 +14,10 @@
 #include "KEMessage.h"
 
 
-class KChildConnect: public QObject
+class KChildConnect: public TQObject
 {
   Q_OBJECT
+  TQ_OBJECT
 
   protected:
   TQStrList inputcache;
@@ -33,7 +34,7 @@ class KChildConnect: public QObject
 
   virtual bool SendMsg(KEMessage *msg);
   virtual bool Send(TQString str);
-  virtual KR_STATUS QueryStatus();
+  virtual KR_STATUS QuerytqStatus();
 
   public slots:
 
