@@ -1,5 +1,5 @@
-#ifndef EQUALIZERVIEW_H
-#define EQUALIZERVIEW_H
+#ifndef ETQUALIZERVIEW_H
+#define ETQUALIZERVIEW_H
 
 #include <tqwidget.h>
 #include <kdialogbase.h>
@@ -14,9 +14,10 @@ class TQHBoxLayout;
 class EqualizerWidget;
 
 
-class EqualizerLevel : public QWidget
+class EqualizerLevel : public TQWidget
 {
 Q_OBJECT
+  TQ_OBJECT
 public:
 	EqualizerLevel(TQWidget *parent, VBand band);
 
@@ -36,6 +37,7 @@ private:
 class PresetList : public KListView
 {
 Q_OBJECT
+  TQ_OBJECT
 public:
 	PresetList(TQWidget *parent, const char *name=0);
 
@@ -47,6 +49,7 @@ public:
 class EqualizerView : public KDialogBase
 {
 Q_OBJECT
+  TQ_OBJECT
 	TQPtrList<EqualizerLevel> mBands;
 
 public:
