@@ -118,7 +118,7 @@ void KaimanStyleElement::loadPixmaps(TQString &val_s_filename)
                     int w = (x==0) ? firstWidth : width;
 
                     TQPixmap *part = new TQPixmap(w,h,pixmap.depth());
-                    part->fill(Qt::black);
+                    part->fill(TQt::black);
                     bitBlt(part,0,0,&pixmap,sourcex,sourcey,w,h);
                     pixmaps.insert(i,part);
 
@@ -142,7 +142,7 @@ void KaimanStyleElement::loadPixmaps(TQString &val_s_filename)
         for ( int i=0; i<pixmapNum; i++ )
         {
             TQPixmap *pm = new TQPixmap(10, 10);
-            pm->fill(Qt::black);
+            pm->fill(TQt::black);
             pixmaps.insert( i, pm );
         }
     }
@@ -160,7 +160,7 @@ void KaimanStyleElement::setPixmap( int num )
         if ( num<0 ) num = 0;
 
         _currentPixmap = num;
-        repaint( FALSE );
+        tqrepaint( FALSE );
     }
 }
 
@@ -321,7 +321,7 @@ void KaimanStyleButton::updateButtonState() {
     }
 
     setPixmap( *I_pmIndex[i_i_currentState] );
-    repaint();
+    tqrepaint();
 }
 
 
@@ -349,7 +349,7 @@ void KaimanStyleSlider::setValue( int value )
     if (value>_max) value=_max;
     if (value<_min) value=_min;
     _value = value;
-    repaint();
+    tqrepaint();
 }
 
 
@@ -359,7 +359,7 @@ void KaimanStyleSlider::setValue( int value, int min, int max )
         _min = min;
         _max = max;
         setValue( value );
-        repaint();
+        tqrepaint();
     }
 }
 
@@ -413,7 +413,7 @@ void KaimanStyleSlider::mouseReleaseEvent(TQMouseEvent *qme)
     {
         _down = false;
         releaseMouse();
-        repaint();
+        tqrepaint();
 
         setValue( pos2value(qme->x(), qme->y()) );
         emit newValue( value() );
@@ -465,7 +465,7 @@ void KaimanStyleSlider::enterEvent ( TQEvent * e )
     if ( !_lit && optionPrelight )
     {
         _lit = true;
-        repaint();
+        tqrepaint();
     }
 
     KaimanStyleMasked::enterEvent( e );
@@ -476,7 +476,7 @@ void KaimanStyleSlider::leaveEvent ( TQEvent * e )
     if ( _lit )
     {
         _lit = false;
-        repaint();
+        tqrepaint();
     }
 
     KaimanStyleMasked::leaveEvent( e );
@@ -522,7 +522,7 @@ void KaimanStyleBackground::mouseMoveEvent(TQMouseEvent *qme)
 
 void KaimanStyleBackground::mousePressEvent(TQMouseEvent *qme)
 {
-    // On the background we move the shaped toplevel around
+    // On the background we move the tqshaped toplevel around
     if (!i_b_move) {
         i_point_dragStart = qme->pos();
         i_point_lastPos = qme->globalPos();
@@ -599,7 +599,7 @@ void KaimanStyleNumber::setValue( int value )
     if ( _value!=value )
     {
         _value = value;
-        repaint();
+        tqrepaint();
     }
 }
 
@@ -667,7 +667,7 @@ void KaimanStyleText::setValue( TQString value )
         _pos = 0;
         _direction = 1;
         _value = value;
-        repaint();
+        tqrepaint();
     }
 }
 
@@ -698,7 +698,7 @@ void KaimanStyleText::timeout()
         // check new position
         if ( _pos+_direction>=0 && (int)_value.length()-(_pos+_direction)>=digits ) {
             _pos += _direction;
-            repaint();
+            tqrepaint();
         }
 
         _timer->start( _delay, TRUE );
@@ -1098,7 +1098,7 @@ void  KaimanStyle::interpretTokens(TQStringList& ref_s_tokens)
     l_kse_elem->element = l_s_elem;
 
     if (  l_s_tokenTypes.left(1) == "V" ) {
-        // Vertical flag
+        //Qt::Vertical flag
         l_vertPixmaps = true;
         l_s_tokenTypes = l_s_tokenTypes.mid(1);
     }
@@ -1400,13 +1400,13 @@ bool KaimanStyle::eventFilter( TQObject *o, TQEvent *e )
             TQMouseEvent *m = (TQMouseEvent*)e;
 
             // handle noatun context menu
-            if (m->button()==RightButton) {
+            if (m->button()==Qt::RightButton) {
                 NoatunStdAction::ContextMenu::showContextMenu();
                 return true;
             }
 
-            TQPoint mousePos( m->x()+static_cast<TQWidget *>(o)->x(),
-                             m->y()+static_cast<TQWidget *>(o)->y() );
+            TQPoint mousePos( m->x()+TQT_TQWIDGET(o)->x(),
+                             m->y()+TQT_TQWIDGET(o)->y() );
             TQWidget *slider = 0;
 
             /* find slider that is under the mouse position */
@@ -1456,7 +1456,7 @@ bool KaimanStyle::loadPixmaps()
 
     if ( (l_pixmap_Background != 0) && (l_pixmap_Mask != 0) ) {
 
-        // OK, background and mask are defined. So now I can calculate the shape
+        // OK, background and mask are defined. So now I can calculate the tqshape
         int l_i_width_Mask  = l_pixmap_Mask->width();
         int l_i_height_Mask = l_pixmap_Mask->height();
 
@@ -1468,11 +1468,11 @@ bool KaimanStyle::loadPixmaps()
         l_image_Mask.fill( 0xff );
 
         uchar *l_c_pixel;
-        uint l_qcol_white = qRgb(255,255,255);
+        uint l_qcol_white = tqRgb(255,255,255);
 
         for (int l_i_x=0; l_i_x<l_i_width_Mask; l_i_x++) {
             for (int l_i_y=0; l_i_y < l_i_height_Mask; l_i_y++) {
-                if ( ((*((QRgb*)  l_image_MaskOrig.scanLine(l_i_y)+l_i_x) & 0x00ffffff)) != (l_qcol_white & 0x00ffffff) ) {
+                if ( ((*((TQRgb*)  l_image_MaskOrig.scanLine(l_i_y)+l_i_x) & 0x00ffffff)) != (l_qcol_white & 0x00ffffff) ) {
                     l_c_pixel = (uchar *)l_image_Mask.scanLine(l_i_y);
                     *(l_c_pixel + (l_i_x>>3)   )  &= ~(1 << (l_i_x & 7));
                 }
