@@ -1,5 +1,5 @@
-#ifndef KJEQUALIZER_H
-#define KJEQUALIZER_H
+#ifndef KJETQUALIZER_H
+#define KJETQUALIZER_H
 
 #include "kjwidget.h"
 //#include "kjloader.h"
@@ -11,6 +11,7 @@ class VInterpolation;
 class KJEqualizer : public TQObject, public KJWidget
 {
 Q_OBJECT
+  TQ_OBJECT
 public:
 	KJEqualizer(const TQStringList &, KJLoader *parent);
 	~KJEqualizer(void);
@@ -31,7 +32,7 @@ private:
 	int mBandWidth;
 	int mBandHalfHeight;
 	TQPixmap mBars; // holds all slider images
-	TQPixmap *mBack; // holds background of EQ for easy repaint
+	TQPixmap *mBack; // holds background of EQ for easy tqrepaint
 	TQPixmap *mView; // holds prepared img of all sliders
 	VInterpolation *mInterpEq;
 };
