@@ -49,7 +49,7 @@ SafeListViewItem::SafeListViewItem(TQListView *parent, TQListViewItem *after, co
 	addRef();
 	setUrl(text);
 
-	static_cast<KListView*>(parent)->moveItem(this, 0, after);
+	static_cast<KListView*>(TQT_TQWIDGET(parent))->moveItem(this, 0, after);
 	setOn(true);
 
 	// is this really needed, it makes the listview too wide for me :(
@@ -91,7 +91,7 @@ SafeListViewItem::SafeListViewItem(TQListView *parent, TQListViewItem *after, co
 		}
 	}
 
-	static_cast<KListView*>(parent)->moveItem(this, 0, after);
+	static_cast<KListView*>(TQT_TQWIDGET(parent))->moveItem(this, 0, after);
 	modified();
 
 	if (!streamable() && enqueue(url()))
@@ -355,10 +355,10 @@ List::List(View *parent)
 	setDragEnabled(true);
 	setItemsMovable(true);
 	setSelectionMode(TQListView::Extended);
-	connect(this, TQT_SIGNAL(dropped(TQDropEvent*, TQListViewItem*)), TQT_SLOT(dropEvent(TQDropEvent*, TQListViewItem*)));
-	connect(this, TQT_SIGNAL(moved()), TQT_SLOT(move()));
-	connect(this, TQT_SIGNAL(aboutToMove()), parent, TQT_SLOT(setNoSorting()));
-	connect(this, TQT_SIGNAL(deleteCurrentItem()), parent, TQT_SLOT(deleteSelected()));
+	connect(TQT_TQOBJECT(this), TQT_SIGNAL(dropped(TQDropEvent*, TQListViewItem*)), TQT_SLOT(dropEvent(TQDropEvent*, TQListViewItem*)));
+	connect(TQT_TQOBJECT(this), TQT_SIGNAL(moved()), TQT_SLOT(move()));
+	connect(TQT_TQOBJECT(this), TQT_SIGNAL(aboutToMove()), parent, TQT_SLOT(setNoSorting()));
+	connect(TQT_TQOBJECT(this), TQT_SIGNAL(deleteCurrentItem()), parent, TQT_SLOT(deleteSelected()));
 }
 
 List::~List()
@@ -377,7 +377,7 @@ bool List::acceptDrag(TQDropEvent *event) const
 
 void List::dropEvent(TQDropEvent *event, TQListViewItem *after)
 {
-	static_cast<View*>(parent())->setNoSorting();
+	static_cast<View*>(TQT_TQWIDGET(parent()))->setNoSorting();
 	KURL::List textlist;
 	if (!KURLDrag::decode(event, textlist)) return;
 	event->acceptAction();
@@ -467,7 +467,7 @@ bool View::saveToURL(const KURL &url)
 	}
 	else
 	{
-		KMessageBox::error( this, i18n("Could not write to %1.").arg(url.prettyURL()) );
+		KMessageBox::error( this, i18n("Could not write to %1.").tqarg(url.prettyURL()) );
 		return false;
 	}
 }
@@ -638,25 +638,25 @@ View::View(SplitPlaylist *)
 {
 	list=new List(this);
 	setCentralWidget(list);
-	connect(list, TQT_SIGNAL(modified(void)), this, TQT_SLOT(setModified(void)) );
+	connect(list, TQT_SIGNAL(modified(void)), TQT_TQOBJECT(this), TQT_SLOT(setModified(void)) );
 	// connect the click on the header with sorting
 	connect(list->header(),TQT_SIGNAL(clicked(int)),this,TQT_SLOT(headerClicked(int)) );
 
-	mOpen=new KAction(i18n("Add &Files..."), "queue", 0, this, TQT_SLOT(addFiles()), actionCollection(), "add_files");
-	(void) new KAction(i18n("Add Fol&ders..."), "folder", 0, this, TQT_SLOT(addDirectory()),  actionCollection(), "add_dir");
-	mDelete=new KAction(i18n("Delete"), "editdelete", Key_Delete, this, TQT_SLOT(deleteSelected()),  actionCollection(), "delete");
+	mOpen=new KAction(i18n("Add &Files..."), "queue", 0, TQT_TQOBJECT(this), TQT_SLOT(addFiles()), actionCollection(), "add_files");
+	(void) new KAction(i18n("Add Fol&ders..."), "folder", 0, TQT_TQOBJECT(this), TQT_SLOT(addDirectory()),  actionCollection(), "add_dir");
+	mDelete=new KAction(i18n("Delete"), "editdelete", Key_Delete, TQT_TQOBJECT(this), TQT_SLOT(deleteSelected()),  actionCollection(), "delete");
 
-	mClose=KStdAction::close(this, TQT_SLOT(close()), actionCollection());
-	mFind=KStdAction::find(this, TQT_SLOT(find()), actionCollection());
+	mClose=KStdAction::close(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection());
+	mFind=KStdAction::find(TQT_TQOBJECT(this), TQT_SLOT(find()), actionCollection());
 
-	(void) KStdAction::configureToolbars(this, TQT_SLOT(configureToolBars()), actionCollection());
-	mOpenNew=KStdAction::openNew(this, TQT_SLOT(openNew()), actionCollection());
-	mOpenpl=KStdAction::open(this, TQT_SLOT(open()), actionCollection());
-	mSave=KStdAction::save(this, TQT_SLOT(save()), actionCollection());
-	mSaveAs=KStdAction::saveAs(this, TQT_SLOT(saveAs()), actionCollection());
+	(void) KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT(configureToolBars()), actionCollection());
+	mOpenNew=KStdAction::openNew(TQT_TQOBJECT(this), TQT_SLOT(openNew()), actionCollection());
+	mOpenpl=KStdAction::open(TQT_TQOBJECT(this), TQT_SLOT(open()), actionCollection());
+	mSave=KStdAction::save(TQT_TQOBJECT(this), TQT_SLOT(save()), actionCollection());
+	mSaveAs=KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(saveAs()), actionCollection());
 
-	(void) new KAction(i18n("Shuffle"), "misc", 0, SPL, TQT_SLOT( randomize() ), actionCollection(), "shuffle");
-	(void) new KAction(i18n("Clear"), "editclear", 0, list, TQT_SLOT( clear() ), actionCollection(), "clear");
+	(void) new KAction(i18n("Shuffle"), "misc", 0, TQT_TQOBJECT(SPL), TQT_SLOT( randomize() ), actionCollection(), "shuffle");
+	(void) new KAction(i18n("Clear"), "editclear", 0, TQT_TQOBJECT(list), TQT_SLOT( clear() ), actionCollection(), "clear");
 
 	createGUI("splui.rc");
 
@@ -679,11 +679,11 @@ static bool testWord(TQListViewItem *i, const TQString &finder)
 		return true;
 	if (item->file().find(finder, 0, false) >=0)
 		return true;
-	if (item->url().path().find(finder.local8Bit(), 0, false) >=0)
+	if (item->url().path().find(finder.local8Bit().data(), 0, false) >=0)
 		return true;
 	if (item->lengthString().find(finder, 0, false) >=0)
 		return true;
-	if (item->mimetype().find(finder.local8Bit(), 0, false) >=0)
+	if (item->mimetype().find(finder.local8Bit().data(), 0, false) >=0)
 		return true;
 	return false;
 }
@@ -746,12 +746,12 @@ void View::findIt(Finder *f)
 		{
 			if (f->isForward())
 			{
-				if (KMessageBox::questionYesNo(this, i18n("End of playlist reached. Continue searching from beginning?"),TQString::null,KStdGuiItem::cont(),KStdGuiItem::cancel()) == KMessageBox::Yes)
+				if (KMessageBox::questionYesNo(this, i18n("End of playlist reached. Continue searching from beginning?"),TQString(),KStdGuiItem::cont(),KStdGuiItem::cancel()) == KMessageBox::Yes)
 					search=list->firstChild();
 			}
 			else
 			{
-				if (KMessageBox::questionYesNo(this, i18n("Beginning of playlist reached. Continue searching from end?"),TQString::null,KStdGuiItem::cont(),KStdGuiItem::cancel()) == KMessageBox::Yes)
+				if (KMessageBox::questionYesNo(this, i18n("Beginning of playlist reached. Continue searching from end?"),TQString(),KStdGuiItem::cont(),KStdGuiItem::cancel()) == KMessageBox::Yes)
 					search=list->lastChild();
 			}
 		}
