@@ -72,8 +72,8 @@ WaSkin::WaSkin() : TQWidget(0, "NoatunWinampSkin"), UserInterface()
 
     createHighLevelElements();
     createButtons();
-    setMinimumSize(sizeHint());
-    setMaximumSize(sizeHint());
+    setMinimumSize(tqsizeHint());
+    setMaximumSize(tqsizeHint());
 
     KWin::setType(this->winId(), NET::Override);
     setBackgroundMode(NoBackground);
@@ -126,7 +126,7 @@ WaSkin::WaSkin() : TQWidget(0, "NoatunWinampSkin"), UserInterface()
     newSong();
 
     // HACK: We won't get focus events otherwise
-    setFocusPolicy(TQWidget::ClickFocus);
+    setFocusPolicy(TQ_ClickFocus);
 
     show();
 }
@@ -142,7 +142,7 @@ void WaSkin::loadSkin(TQString newSkinDir)
 {
     waSkinManager->loadSkin(newSkinDir);
 
-    setMinimumSize(sizeHint());
+    setMinimumSize(tqsizeHint());
 
     if (title_shaded) {
         // waSkinModel::load() resets our skin model :(
@@ -154,7 +154,7 @@ void WaSkin::loadSkin(TQString newSkinDir)
     }
 }
 
-TQSize WaSkin::sizeHint() const
+TQSize WaSkin::tqsizeHint() const
 {
     TQRect temp_rect;
 
@@ -254,8 +254,8 @@ void WaSkin::createButtons()
     repeat->setPixmapDownSelected(_WA_SKIN_SHUFREP_REPEAT_SET_PRES);
 
 
-    eq->setPixmapUp(_WA_SKIN_SHUFREP_EQ_NOT_SET_NORM);
-    eq->setPixmapDown(_WA_SKIN_SHUFREP_EQ_NOT_SET_PRES);
+    eq->setPixmapUp(_WA_SKIN_SHUFREP_ETQ_NOT_SET_NORM);
+    eq->setPixmapDown(_WA_SKIN_SHUFREP_ETQ_NOT_SET_PRES);
 
     playlist->setPixmapUp(_WA_SKIN_SHUFREP_PLAYLIST_NOT_SET_NORM);
     playlist->setPixmapDown( _WA_SKIN_SHUFREP_PLAYLIST_NOT_SET_PRES);
@@ -305,7 +305,7 @@ void WaSkin::createHighLevelElements()
 
     waInfo = new WaInfo();
 
-    waStatus = new WaStatus();
+    watqStatus = new WatqStatus();
 
     waStereo = new WaIndicator(_WA_MAPPING_MONOSTER_STEREO, _WA_SKIN_MONOSTER_STEREO_TRUE, _WA_SKIN_MONOSTER_STEREO_FALSE);
     waMono = new WaIndicator(_WA_MAPPING_MONOSTER_MONO, _WA_SKIN_MONOSTER_MONO_TRUE, _WA_SKIN_MONOSTER_MONO_FALSE);
@@ -337,7 +337,7 @@ void WaSkin::setChannels(int val)
 void WaSkin::shade() {
     waSkinModel->setSkinModel(WA_MODEL_WINDOWSHADE);
 
-    setMinimumSize(sizeHint());
+    setMinimumSize(tqsizeHint());
     setMask(*windowRegion->mainWindowShadeMask());
 
     title_shaded = true;
@@ -346,7 +346,7 @@ void WaSkin::shade() {
 void WaSkin::unshade() {
     waSkinModel->setSkinModel(WA_MODEL_NORMAL);
 
-    setMinimumSize(sizeHint());
+    setMinimumSize(tqsizeHint());
     setMask(*windowRegion->mainWindowMask());
 
     title_shaded = false;
@@ -558,9 +558,9 @@ void WaSkin::balanceSetValue(int val)
         waInfo->setText(i18n("Balance: Center"));
     }
     else if (val < 0) {
-        waInfo->setText(i18n("Balance: %1% Left").arg(-val));
+        waInfo->setText(i18n("Balance: %1% Left").tqarg(-val));
     } else {
-        waInfo->setText(i18n("Balance: %1% Right").arg(val));
+        waInfo->setText(i18n("Balance: %1% Right").tqarg(val));
    }
 }
 
@@ -672,14 +672,14 @@ void WaSkin::volumeSliderReleased()
 void WaSkin::volumeSetValue(int val)
 {
     if (mVolumePressed)
-        waInfo->setText(i18n("Volume: %1%").arg(val));
+        waInfo->setText(i18n("Volume: %1%").tqarg(val));
 
     napp->player()->setVolume(val);
 }
 
 void WaSkin::slotPlaying()
 {
-    waStatus->setStatus(STATUS_PLAYING);
+    watqStatus->settqStatus(STATUS_PLAYING);
 
     if (!napp->playlist()->current()) {
       return;
@@ -710,7 +710,7 @@ void WaSkin::slotPlaying()
 
 void WaSkin::slotStopped()
 {
-    waStatus->setStatus(STATUS_STOPPED);
+    watqStatus->settqStatus(STATUS_STOPPED);
 
     waDigit->setTime("");
 
@@ -733,7 +733,7 @@ void WaSkin::slotStopped()
 
 void WaSkin::slotPaused()
 {
-    waStatus->setStatus(STATUS_PAUSED);
+    watqStatus->settqStatus(STATUS_PAUSED);
 }
 
 void WaSkin::keyPressEvent(TQKeyEvent *e) {
