@@ -22,14 +22,15 @@
 
 enum status_enum {STATUS_PLAYING, STATUS_STOPPED, STATUS_PAUSED};
 
-class WaStatus : public WaWidget {
+class WatqStatus : public WaWidget {
     Q_OBJECT
+  TQ_OBJECT
 
   public:
-     WaStatus();
-    ~WaStatus();
+     WatqStatus();
+    ~WatqStatus();
 
-    void setStatus(status_enum status) { _status = status; update(); }
+    void settqStatus(status_enum status) { _status = status; update(); }
     status_enum status() const { return _status; }
 
   private:
