@@ -138,7 +138,7 @@ void g_NPN_ForceRedraw(NPP /*instance*/)
 }
 
 
-// invalidate rect
+// tqinvalidate rect
 void g_NPN_InvalidateRect(NPP /*instance*/, NPRect* /*invalidRect*/)
 {
    // http://devedge.netscape.com/library/manuals/2002/plugin/1.0/npn_api7.html#999503
@@ -147,7 +147,7 @@ void g_NPN_InvalidateRect(NPP /*instance*/, NPRect* /*invalidRect*/)
 }
 
 
-// invalidate region
+// tqinvalidate region
 void g_NPN_InvalidateRegion(NPP /*instance*/, NPRegion /*invalidRegion*/)
 {
    // http://devedge.netscape.com/library/manuals/2002/plugin/1.0/npn_api8.html#999528
@@ -252,8 +252,8 @@ NPError g_NPN_GetURL(NPP instance, const char *url, const char *target)
 
    NSPluginInstance *inst = static_cast<NSPluginInstance*>(instance->ndata);
    if (inst) {
-      inst->requestURL( TQString::fromLatin1(url), TQString::null,
-                        TQString::fromLatin1(target), 0 );
+      inst->requestURL( TQString::tqfromLatin1(url), TQString::null,
+                        TQString::tqfromLatin1(target), 0 );
    }
 
    return NPERR_NO_ERROR;
@@ -267,8 +267,8 @@ NPError g_NPN_GetURLNotify(NPP instance, const char *url, const char *target,
    NSPluginInstance *inst = static_cast<NSPluginInstance*>(instance->ndata);
    if (inst) {
       kdDebug(1431) << "g_NPN_GetURLNotify: ndata=" << (void*)inst << endl;
-      inst->requestURL( TQString::fromLatin1(url), TQString::null,
-                        TQString::fromLatin1(target), notifyData, true );
+      inst->requestURL( TQString::tqfromLatin1(url), TQString::null,
+                        TQString::tqfromLatin1(target), notifyData, true );
    }
 
    return NPERR_NO_ERROR;
@@ -318,7 +318,7 @@ NPError g_NPN_PostURLNotify(NPP instance, const char* url, const char* target,
                break;
             }
 
-            TQString thisLine = TQString::fromLatin1(previousStart, &buf[l-1] - previousStart).stripWhiteSpace();
+            TQString thisLine = TQString::tqfromLatin1(previousStart, &buf[l-1] - previousStart).stripWhiteSpace();
 
             previousStart = &buf[l];
             previousCR = true;
@@ -360,9 +360,9 @@ NPError g_NPN_PostURLNotify(NPP instance, const char* url, const char* target,
    }
 
    NSPluginInstance *inst = static_cast<NSPluginInstance*>(instance->ndata);
-   if (inst && !inst->normalizedURL(TQString::fromLatin1(url)).isNull()) {
-      inst->postURL( TQString::fromLatin1(url), postdata, args.contentType(),
-                     TQString::fromLatin1(target), notifyData, args, true );
+   if (inst && !inst->normalizedURL(TQString::tqfromLatin1(url)).isNull()) {
+      inst->postURL( TQString::tqfromLatin1(url), postdata, args.contentType(),
+                     TQString::tqfromLatin1(target), notifyData, args, true );
    } else {
       // Unsupported / insecure
       return NPERR_INVALID_URL;
@@ -415,7 +415,7 @@ NPError g_NPN_PostURL(NPP instance, const char* url, const char* target,
                break;
             }
 
-            TQString thisLine = TQString::fromLatin1(previousStart, &buf[l-1] - previousStart).stripWhiteSpace();
+            TQString thisLine = TQString::tqfromLatin1(previousStart, &buf[l-1] - previousStart).stripWhiteSpace();
 
             previousStart = &buf[l];
             previousCR = true;
@@ -457,9 +457,9 @@ NPError g_NPN_PostURL(NPP instance, const char* url, const char* target,
    }
 
    NSPluginInstance *inst = static_cast<NSPluginInstance*>(instance->ndata);
-   if (inst && !inst->normalizedURL(TQString::fromLatin1(url)).isNull()) {
-      inst->postURL( TQString::fromLatin1(url), postdata, args.contentType(),
-                     TQString::fromLatin1(target), 0L, args, false );
+   if (inst && !inst->normalizedURL(TQString::tqfromLatin1(url)).isNull()) {
+      inst->postURL( TQString::tqfromLatin1(url), postdata, args.contentType(),
+                     TQString::tqfromLatin1(target), 0L, args, false );
    } else {
       // Unsupported / insecure
       return NPERR_INVALID_URL;
@@ -820,7 +820,7 @@ void NSPluginInstance::timer()
                     s->post( url, req.data, req.mime, req.notify, req.args );
                 } else if (url.lower().startsWith("javascript:")){
                     if (_callback) {
-                        static Q_INT32 _jsrequestid = 0;
+                        static TQ_INT32 _jsrequestid = 0;
 			_jsrequests.insert(_jsrequestid, new Request(req));
                         _callback->evalJavaScript(_jsrequestid++, url.mid(11));
                     } else {
@@ -916,7 +916,7 @@ void NSPluginInstance::streamFinished( NSPluginStreamBase* strm )
    _timer->start( 100, true );
 }
 
-int NSPluginInstance::setWindow(Q_INT8 remove)
+int NSPluginInstance::setWindow(TQ_INT8 remove)
 {
    if (remove)
    {
@@ -980,7 +980,7 @@ static void resizeWidgets(Window w, int width, int height) {
 }
 
 
-void NSPluginInstance::resizePlugin(Q_INT32 w, Q_INT32 h)
+void NSPluginInstance::resizePlugin(TQ_INT32 w, TQ_INT32 h)
 {
    if (w == _width && h == _height)
       return;
@@ -1021,7 +1021,7 @@ void NSPluginInstance::resizePlugin(Q_INT32 w, Q_INT32 h)
 }
 
 
-void NSPluginInstance::javascriptResult(Q_INT32 id, TQString result) {
+void NSPluginInstance::javascriptResult(TQ_INT32 id, TQString result) {
     TQMap<int, Request*>::iterator i = _jsrequests.find( id );
     if (i != _jsrequests.end()) {
         Request *req = i.data();
@@ -1295,7 +1295,7 @@ void NSPluginViewer::shutdown()
 #if QT_VERSION < 0x030100
    quitXt();
 #else
-   qApp->quit();
+   tqApp->quit();
 #endif
 }
 
@@ -1330,6 +1330,9 @@ DCOPRef NSPluginViewer::newClass( TQString plugin )
 
 /****************************************************************************/
 
+bool NSPluginClass::s_initedGTK = false;
+
+typedef void gtkInitFunc(int *argc, char ***argv);
 
 NSPluginClass::NSPluginClass( const TQString &library,
                               TQObject *parent, const char *name )
@@ -1377,6 +1380,23 @@ NSPluginClass::NSPluginClass( const TQString &library,
 
     // initialize plugin
     kdDebug(1431) << "Plugin library " << library << " loaded!" << endl;
+
+    // see if it uses gtk
+    if (!s_initedGTK) {
+        gtkInitFunc* gtkInit = (gtkInitFunc*)_handle->symbol("gtk_init");
+        if (gtkInit) {
+            kdDebug(1431) << "Calling gtk_init for the plugin" << endl;
+            // Prevent gtk_init() from replacing the X error handlers, since the Gtk
+            // handlers abort when they receive an X error, thus killing the viewer.
+            int (*old_error_handler)(Display*,XErrorEvent*) = XSetErrorHandler(0);
+            int (*old_io_error_handler)(Display*) = XSetIOErrorHandler(0);
+            gtkInit(0, 0);
+            XSetErrorHandler(old_error_handler);
+            XSetIOErrorHandler(old_io_error_handler);
+            s_initedGTK = true;
+        }
+    }
+
     _constructed = true;
     _error = initialize()!=NPERR_NO_ERROR;
 }
@@ -1458,10 +1478,10 @@ void NSPluginClass::shutdown()
 }
 
 
-DCOPRef NSPluginClass::newInstance( TQString url, TQString mimeType, Q_INT8 embed,
+DCOPRef NSPluginClass::newInstance( TQString url, TQString mimeType, TQ_INT8 embed,
                                     TQStringList argn, TQStringList argv,
                                     TQString appId, TQString callbackId,
-                                    Q_INT8 reload, Q_INT8 doPost, TQByteArray postData, Q_UINT32 xembed )
+                                    TQ_INT8 reload, TQ_INT8 doPost, TQByteArray postData, TQ_UINT32 xembed )
 {
    kdDebug(1431) << "-> NSPluginClass::NewInstance" << endl;
 
@@ -1654,6 +1674,7 @@ bool NSPluginStreamBase::create( const TQString& url, const TQString& mimeType,
     _stream->pdata = 0;
     _stream->lastmodified = 0;
     _stream->notifyData = _notifyData;
+    _stream->headers = 0;
 
     _mimeType = mimeType;
 
@@ -1670,7 +1691,7 @@ void NSPluginStreamBase::updateURL( const KURL& newURL )
 int NSPluginStreamBase::process( const TQByteArray &data, int start )
 {
    int32 max, sent, to_sent, len;
-   char *d = data.data() + start;
+   char *d = const_cast<TQByteArray&>(data).data() + start;
 
    to_sent = data.size() - start;
    while (to_sent > 0)
@@ -1878,6 +1899,7 @@ bool NSPluginStream::get( const TQString& url, const TQString& mimeType,
         _job = KIO::get(KURL( url ), false, false);
         _job->addMetaData("errorPage", "false");
         _job->addMetaData("AllowCompressedPage", "false");
+        _job->addMetaData("PropagateHttpHeader", "true");
         if (reload) {
             _job->addMetaData("cache", "reload");
         }
@@ -1905,6 +1927,7 @@ bool NSPluginStream::post( const TQString& url, const TQByteArray& data,
         _job = KIO::http_post(KURL( url ), data, false);
         _job->addMetaData("content-type", args.contentType());
         _job->addMetaData("errorPage", "false");
+        _job->addMetaData("PropagateHttpHeader", "true");
         _job->addMetaData("AllowCompressedPage", "false");
         connect(_job, TQT_SIGNAL(data(KIO::Job *, const TQByteArray &)),
                 TQT_SLOT(data(KIO::Job *, const TQByteArray &)));
@@ -1944,13 +1967,13 @@ void NSPluginStream::totalSize(KIO::Job * job, KIO::filesize_t size)
 
 void NSPluginStream::mimetype(KIO::Job * job, const TQString &mimeType)
 {
-    kdDebug(1431) << "NSPluginStream::TQByteArray - job=" << (void*)job << " mimeType=" << mimeType << endl;
+    kdDebug(1431) << "NSPluginStream::mimetype - job=" << (void*)job << " mimeType=" << mimeType << endl;
     _mimeType = mimeType;
+    TQString tmp_headers = job->metaData()["HTTP-Headers"];
+    _headers.duplicate(tmp_headers.latin1(), tmp_headers.length());
+    _stream->headers = _headers.data();
 }
 
-
-
-
 void NSPluginStream::resume()
 {
    if ( error() || tries()>8 ) {
