@@ -125,7 +125,7 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, TQWidget *parent, const ch
     TQString defaultProjectsDir = config->readPathEntry("DefaultProjectsDir", TQDir::homeDirPath()+"/");
 
     KStandardDirs *dirs = AppWizardFactory::instance()->dirs();
-    TQStringList m_templateNames = dirs->findAllResources("apptemplates", TQString::null, false, true);
+    TQStringList m_templateNames = dirs->findAllResources("apptemplates", TQString(), false, true);
 
     kdDebug(9010) << "Templates: " << endl;
     TQStringList categories;
@@ -304,7 +304,7 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, TQWidget *parent, const ch
     // How about names like "__" or "123" for project name? Are they legal?
     TQRegExpValidator *appname_edit_validator;
     appname_edit_validator = new TQRegExpValidator (appname_regexp,
-                                                   appname_edit,
+                                                   TQT_TQOBJECT(appname_edit),
                                                    "AppNameValidator");
     appname_edit->setValidator(appname_edit_validator);
 
@@ -415,7 +415,7 @@ void AppWizardDialog::licenseChanged()
 		for (it = m_fileTemplates.begin(); it != m_fileTemplates.end(); ++it)
 		{
 			TQMultiLineEdit *edit = (*it).edit;
-			edit->setText( TQString::null );
+			edit->setText( TQString() );
 		}
 	} else {
 		KDevLicense* lic = licenses()[ license_combo->currentText() ];
@@ -486,7 +486,7 @@ void AppWizardDialog::accept()
 	}
 	else
 	{
-		KMessageBox::sorry(this, i18n("The template %1 cannot be opened.").arg( source + "/" + m_pCurrentAppInfo->sourceArchive ) );
+		KMessageBox::sorry(this, i18n("The template %1 cannot be opened.").tqarg( source + "/" + m_pCurrentAppInfo->sourceArchive ) );
 		templateArchive.close();
 		return;
 	}
@@ -509,7 +509,7 @@ void AppWizardDialog::accept()
 	m_pCurrentAppInfo->subMap.insert("EMAIL", email_edit->text() );
 	m_pCurrentAppInfo->subMap.insert("VERSION", version_edit->text());
 	m_pCurrentAppInfo->subMap.insert( "I18N", "i18n" );
-	m_pCurrentAppInfo->subMap.insert("YEAR", TQString::number( TQDate::currentDate().year() ) );
+	m_pCurrentAppInfo->subMap.insert("YEAR", TQString::number( TQDate::tqcurrentDate().year() ) );
 
 	// This isn't too pretty, but we have several templates that use KAboutData::License_${LICENSE}
 	// and unsurprisingly, KAboutData doesn't cover every imaginable case.
@@ -517,7 +517,7 @@ void AppWizardDialog::accept()
 	TQString license = license_combo->currentText();
 	if ( license == "GPL" || license == "GPL_V2" || license == "LGPL" || license == "LGPL_V2"||
 		license == "BSD" || license == "NCSA" || license == "MIT" || license == "Artistic" || 
-		license == "QPL" || license == "QPL_V1_0" )
+		license == "QPL" || license == "TQPL_V1_0" )
 	{
 		m_pCurrentAppInfo->subMap.insert("LICENSE", license );
 	}
@@ -543,7 +543,7 @@ void AppWizardDialog::accept()
 
 	// This is too silly for words, but it's either this or reimplementing FileTemplate
 	TQString tempProjectDomSource = "<!DOCTYPE kdevelop><kdevelop><general><author>%1</author><email>%2</email><version>%3</version></general></kdevelop>";
-	tempProjectDomSource = tempProjectDomSource.arg( author_edit->text() ).arg( email_edit->text() ).arg( version_edit->text() );
+	tempProjectDomSource = tempProjectDomSource.tqarg( author_edit->text() ).tqarg( email_edit->text() ).tqarg( version_edit->text() );
 	TQDomDocument tempProjectDom;
 	tempProjectDom.setContent( tempProjectDomSource );
 
@@ -559,13 +559,13 @@ void AppWizardDialog::accept()
 		temps.setEncoding(TQTextStream::UnicodeUTF8);
 		temps << templateText;
 		f.flush();
-		TQString templateName( TQString( "%1_TEMPLATE" ).arg( (*it).suffix ).upper() );
+		TQString templateName( TQString( "%1_TEMPLATE" ).tqarg( (*it).suffix ).upper() );
 		cleanUpSubstMap << templateName;
 		m_pCurrentAppInfo->subMap.insert( templateName, KMacroExpander::expandMacros(templateText , m_pCurrentAppInfo->subMap)  );
 
 		installFile file;
 		file.source = tempFile->name();
-		file.dest = TQString( "%{dest}/templates/%1" ).arg( (*it).suffix );
+		file.dest = TQString( "%{dest}/templates/%1" ).tqarg( (*it).suffix );
 		file.process = true;
 		file.isXML = false;
 		m_pCurrentAppInfo->fileList.append( file );
@@ -585,8 +585,8 @@ void AppWizardDialog::accept()
 			for( ; it != files.end(); ++it )
 			{
 				installFile file;
-				file.source = TQString( "%{kdevelop}/template-common/%1" ).arg( *it );
-				file.dest = TQString("%{dest}/%1").arg( *it );
+				file.source = TQString( "%{kdevelop}/template-common/%1" ).tqarg( *it );
+				file.dest = TQString("%{dest}/%1").tqarg( *it );
 				file.process = true;
 				file.isXML = false;
 				m_pCurrentAppInfo->fileList.append( file );
@@ -645,7 +645,7 @@ void AppWizardDialog::accept()
 		{
 			if( ! KIO::NetAccess::mkdir( (*dirIt).dir, this ) )
 			{
-				KMessageBox::sorry(this, i18n("The directory %1 cannot be created.").arg( (*dirIt).dir ) );
+				KMessageBox::sorry(this, i18n("The directory %1 cannot be created.").tqarg( (*dirIt).dir ) );
 				return;
 			}
 		}
@@ -664,7 +664,7 @@ void AppWizardDialog::accept()
 			}
 			else
 			{
-				KMessageBox::sorry(this, i18n("The archive %1 cannot be opened.").arg( (*archIt).source ) );
+				KMessageBox::sorry(this, i18n("The archive %1 cannot be opened.").tqarg( (*archIt).source ) );
 				archive.close();
 				return;
 			}
@@ -682,7 +682,7 @@ void AppWizardDialog::accept()
 		{
 			if( !copyFile( *fileIt ) )
 			{
-				KMessageBox::sorry(this, i18n("The file %1 cannot be created.").arg( (*fileIt).dest) );
+				KMessageBox::sorry(this, i18n("The file %1 cannot be created.").tqarg( (*fileIt).dest) );
 				return;
 			}
 			setPermissions(*fileIt);
@@ -824,7 +824,7 @@ void AppWizardDialog::unpackArchive( const KArchiveDirectory *dir, const TQStrin
 				// ( where should we currently get that info from? )
 				if ( !copyFile( TQDir::cleanDirPath(tdir.name()+"/"+file->name()), dest + "/" + file->name(), false, process ) )
 				{
-					KMessageBox::sorry(this, i18n("The file %1 cannot be created.").arg( dest) );
+					KMessageBox::sorry(this, i18n("The file %1 cannot be created.").tqarg( dest) );
 					return;
 				}
 				setPermissions(file, dest + "/" + file->name());
@@ -893,7 +893,7 @@ void AppWizardDialog::templatesTreeViewClicked(TQListViewItem *item)
             if (it == l.end())
                 m_lastPage = edit;
             fileTemplate.edit = edit;
-            addPage(edit, i18n("Template for .%1 Files").arg(fileTemplate.suffix));
+            addPage(edit, i18n("Template for .%1 Files").tqarg(fileTemplate.suffix));
             m_fileTemplates.append(fileTemplate);
         }
         licenseChanged();	// to populate the template views
@@ -919,7 +919,7 @@ void AppWizardDialog::destButtonClicked(const TQString& dir)
         TQDir newDir (dir);
         kdDebug(9010) << "DevPrjDir == newdir?: " << defPrjDir.absPath() << " == " << newDir.absPath() << endl;
         if (defPrjDir != newDir) {
-            if (KMessageBox::questionYesNo(this, i18n("Set default project location to: %1?").arg( newDir.absPath() ),
+            if (KMessageBox::questionYesNo(this, i18n("Set default project location to: %1?").tqarg( newDir.absPath() ),
                                            i18n("New Project"), i18n("Set"), i18n("Do Not Set")) == KMessageBox::Yes)
             {
                 config->writePathEntry("DefaultProjectsDir", newDir.absPath() + "/");
@@ -1015,7 +1015,7 @@ void AppWizardDialog::openAfterGeneration()
 	{
 		KMessageBox::sorry( 0, i18n("This is not a valid project file.\n"
 				"XML error in line %1, column %2:\n%3")
-				.arg(errorLine).arg(errorCol).arg(errorMsg));
+				.tqarg(errorLine).tqarg(errorCol).tqarg(errorMsg));
 		return;
 	}
 
@@ -1023,7 +1023,7 @@ void AppWizardDialog::openAfterGeneration()
 	DomUtil::writeMapEntry( projectDOM, "substmap", m_pCurrentAppInfo->subMap );
 
 	//save the selected vcs
-	KTrader::OfferList offers = KTrader::self()->query("KDevelop/VCSIntegrator", TQString("[X-KDevelop-VCS]=='%1'").arg(m_vcsForm->combo->currentText()));
+	KTrader::OfferList offers = KTrader::self()->query("KDevelop/VCSIntegrator", TQString("[X-KDevelop-VCS]=='%1'").tqarg(m_vcsForm->combo->currentText()));
 	if (offers.count() == 1)
 	{
 		KService::Ptr service = offers.first();
@@ -1283,7 +1283,7 @@ void AppWizardDialog::loadLicenses()
 	// kdDebug(9010) << "======================== Entering loadLicenses" << endl;
 	KStandardDirs* dirs = KGlobal::dirs();
 	dirs->addResourceType( "licenses", KStandardDirs::kde_default( "data" ) + "kdevelop/licenses/" );
-	TQStringList licNames = dirs->findAllResources( "licenses", TQString::null, false, true );
+	TQStringList licNames = dirs->findAllResources( "licenses", TQString(), false, true );
 
 	TQStringList::Iterator it;
 	for (it = licNames.begin(); it != licNames.end(); ++it)
@@ -1318,7 +1318,7 @@ void AppWizardDialog::showTemplates(bool all)
 		TQDictIterator<TQListViewItem> dit(m_categoryMap);
 		for (; dit.current(); ++dit)
 		{
-			//checking whether all children are not visible
+			//checking whether all tqchildren are not visible
 			kdDebug(9010) << "check: " << dit.current()->text(0) << endl;
 			bool visible = false;
 			TQListViewItemIterator it(dit.current());
