@@ -62,7 +62,7 @@ ImportDialog::ImportDialog(AppWizardPart *part, TQWidget *parent, const char *na
     urlinput_edit->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);
 
     KStandardDirs *dirs = AppWizardFactory::instance()->dirs();
-    importNames = dirs->findAllResources("appimports", TQString::null, false, true);
+    importNames = dirs->findAllResources("appimports", TQString(), false, true);
     importNames.sort();
 
     TQStringList::ConstIterator it;
@@ -151,7 +151,7 @@ void ImportDialog::accept()
     {
         KMessageBox::sorry( 0, i18n("This is not a valid project file.\n"
                 "XML error in line %1, column %2:\n%3")
-                .arg(errorLine).arg(errorCol).arg(errorMsg));
+                .tqarg(errorLine).tqarg(errorCol).tqarg(errorMsg));
         return;
     }
 
@@ -295,7 +295,7 @@ void ImportDialog::dirChanged()
     // Set the project name
     name_edit->setText(projectName);
 
-    // QMake based?
+    // TQMake based?
     files = dir.entryList("*.pro");
     if (!files.isEmpty()) {
         setProjectType("qtqmake");
@@ -417,7 +417,7 @@ void ImportDialog::scanAutomakeProject(const TQString &dirName)
     TQFile configIn(dirName+"/configure.in");
     TQFile configAc(dirName+"/configure.ac");
     if (configInIn.open(IO_ReadOnly)){
-        cstream.setDevice(&configInIn);
+        cstream.setDevice(TQT_TQIODEVICE(&configInIn));
         while (!cstream.atEnd()) {
             TQString line = cstream.readLine();
             if ( ac_init.search(line) >= 0){
@@ -437,11 +437,11 @@ void ImportDialog::scanAutomakeProject(const TQString &dirName)
     }
 
     if (configIn.open(IO_ReadOnly)){
-        cstream.setDevice(&configIn);
+        cstream.setDevice(TQT_TQIODEVICE(&configIn));
     }
     else{
         if (configAc.open(IO_ReadOnly)){
-            cstream.setDevice(&configAc);
+            cstream.setDevice(TQT_TQIODEVICE(&configAc));
         }
         else{
             return;
@@ -564,7 +564,7 @@ void ImportDialog::createProjectInfrastructure( )
     TQDir dir (urlinput_edit->url());
     TQStringList files = dir.entryList(cmd.existingPattern);
     if (!files.isEmpty()) {
-        if (KMessageBox::questionYesNo(this, i18n("Project infrastrucure already exists in target directory.\nGenerate new project infrastructure and overwrite old?"), TQString::null, i18n("Generate"), i18n("Do Not Generate")) == KMessageBox::No)
+        if (KMessageBox::questionYesNo(this, i18n("Project infrastrucure already exists in target directory.\nGenerate new project infrastructure and overwrite old?"), TQString(), i18n("Generate"), i18n("Do Not Generate")) == KMessageBox::No)
             return;
     }
 
