@@ -95,7 +95,7 @@ TQString ClassTreeItem::scopedText() const
     if (m_item)
         return m_item->path();
 
-    return TQString::null;
+    return TQString();
 }
 
 
@@ -121,7 +121,7 @@ TQString ClassTreeItem::text( int ) const
 {
     if (m_item)
         return m_item->asString();
-    return TQString::null;
+    return TQString();
 }
 
 
@@ -149,7 +149,7 @@ void ClassTreeScopeItem::init()
 TQString ClassTreeScopeItem::text( int col ) const
 {
     if (!m_item)
-        return TQString::null;
+        return TQString();
     if (m_item->name().isEmpty())
         return i18n("Global");
     return ClassTreeItem::text( col );
@@ -310,7 +310,7 @@ TQString ClassTreeMethodItem::text( int ) const
     TQString str;
 
     if ( !m_item )
-        return TQString::null;
+        return TQString();
  
     ParsedMethod* method = static_cast<ParsedMethod*>(m_item);
 
@@ -363,7 +363,7 @@ ClassTreeAttrItem::ClassTreeAttrItem(ClassTreeItem *parent, ClassTreeItem *lastS
 TQString ClassTreeAttrItem::text( int ) const
 {
     if ( !m_item )
-        return TQString::null;
+        return TQString();
     return m_item->name();
 }
 
@@ -387,7 +387,7 @@ ClassTreeScriptItem::ClassTreeScriptItem(ClassTreeItem *parent, ClassTreeItem *l
 TQString ClassTreeScriptItem::text( int ) const
 {
     if ( !m_item )
-        return TQString::null;
+        return TQString();
     return m_item->name();
 }
 
@@ -419,7 +419,7 @@ void ClassTreeScriptItem::setOpen(bool o)
 }
 
 
-class ClassToolTip : public QToolTip
+class ClassToolTip : public TQToolTip
 {
 public:
     ClassToolTip( TQWidget *parent )
@@ -436,7 +436,7 @@ void ClassToolTip::maybeTip(const TQPoint &p)
     ClassTreeBase *ctw = static_cast<ClassTreeBase*>(parentWidget());
 
     TQListViewItem *item = ctw->itemAt(p);
-    TQRect r = ctw->itemRect(item);
+    TQRect r = ctw->tqitemRect(item);
 
     if (item && r.isValid()) {
         ClassTreeItem *ctitem = static_cast<ClassTreeItem*>(item);
@@ -455,7 +455,7 @@ ClassTreeBase::ClassTreeBase(ClassViewPart *part, TQWidget *parent, const char *
     setResizeMode(TQListView::LastColumn);
     setSorting(-1);
     header()->hide();
-    addColumn(TQString::null);
+    addColumn(TQString());
 
     (void) new ClassToolTip(this);
     
