@@ -71,28 +71,28 @@ ClassViewWidget::ClassViewWidget( ClassViewPart * part )
     m_actionViewMode->setItems( lst );
     m_actionViewMode->setWhatsThis(i18n("<b>View mode</b><p>Class browser items can be grouped by directories, listed in a plain or java like view."));
 
-    m_actionNewClass = new KAction( i18n("New Class..."), KShortcut(), this, TQT_SLOT(slotNewClass()),
+    m_actionNewClass = new KAction( i18n("New Class..."), KShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotNewClass()),
 				    m_part->actionCollection(), "classview_new_class" );
     m_actionNewClass->setWhatsThis(i18n("<b>New class</b><p>Calls the <b>New Class</b> wizard."));
 	
-	m_actionCreateAccessMethods = new KAction( i18n("Create get/set Methods"), KShortcut(), this, TQT_SLOT(slotCreateAccessMethods()), m_part->actionCollection(), "classview_create_access_methods" );
+	m_actionCreateAccessMethods = new KAction( i18n("Create get/set Methods"), KShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotCreateAccessMethods()), m_part->actionCollection(), "classview_create_access_methods" );
 	
 	
-    m_actionAddMethod = new KAction( i18n("Add Method..."), KShortcut(), this, TQT_SLOT(slotAddMethod()),
+    m_actionAddMethod = new KAction( i18n("Add Method..."), KShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotAddMethod()),
 				    m_part->actionCollection(), "classview_add_method" );
     m_actionAddMethod->setWhatsThis(i18n("<b>Add method</b><p>Calls the <b>New Method</b> wizard."));
-    m_actionAddAttribute = new KAction( i18n("Add Attribute..."), KShortcut(), this, TQT_SLOT(slotAddAttribute()),
+    m_actionAddAttribute = new KAction( i18n("Add Attribute..."), KShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotAddAttribute()),
 				    m_part->actionCollection(), "classview_add_attribute" );
     m_actionAddAttribute->setWhatsThis(i18n("<b>Add attribute</b><p>Calls the <b>New Attribute</b> wizard."));
 
-    m_actionOpenDeclaration = new KAction( i18n("Open Declaration"), KShortcut(), this, TQT_SLOT(slotOpenDeclaration()),
+    m_actionOpenDeclaration = new KAction( i18n("Open Declaration"), KShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotOpenDeclaration()),
 				    m_part->actionCollection(), "classview_open_declaration" );
     m_actionOpenDeclaration->setWhatsThis(i18n("<b>Open declaration</b><p>Opens a file where the selected item is declared and jumps to the declaration line."));
-    m_actionOpenImplementation = new KAction( i18n("Open Implementation"), KShortcut(), this, TQT_SLOT(slotOpenImplementation()),
+    m_actionOpenImplementation = new KAction( i18n("Open Implementation"), KShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotOpenImplementation()),
 				    m_part->actionCollection(), "classview_open_implementation" );
     m_actionOpenImplementation->setWhatsThis(i18n("<b>Open implementation</b><p>Opens a file where the selected item is defined (implemented) and jumps to the definition line."));
 
-	m_actionFollowEditor = new KToggleAction( i18n("Follow Editor"), KShortcut(), this, TQT_SLOT(slotFollowEditor()), m_part->actionCollection(), "classview_follow_editor" );
+	m_actionFollowEditor = new KToggleAction( i18n("Follow Editor"), KShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotFollowEditor()), m_part->actionCollection(), "classview_follow_editor" );
 
     KConfig* config = m_part->instance()->config();
     config->setGroup( "General" );
@@ -1212,13 +1212,13 @@ void ClassViewWidget::maybeTip( TQPoint const & p )
 				++it;
 			}
 			
-			TQString strstatic = fitem->dom()->isStatic() ? TQString( "[static] " ) : TQString::null;
-			TQString strsignal = fitem->dom()->isSignal() ? TQString( "[signal] " ) : TQString::null;
-			TQString strslot = fitem->dom()->isSlot() ? TQString( "[slot] " ) : TQString::null;
-			TQString strresult = !fitem->dom()->resultType().isEmpty() ? fitem->dom()->resultType() + " " : TQString::null;
+			TQString strstatic = fitem->dom()->isStatic() ? TQString( "[static] " ) : TQString();
+			TQString strsignal = fitem->dom()->isSignal() ? TQString( "[signal] " ) : TQString();
+			TQString strslot = fitem->dom()->isSlot() ? TQString( "[slot] " ) : TQString();
+			TQString strresult = !fitem->dom()->resultType().isEmpty() ? fitem->dom()->resultType() + " " : TQString();
 			
-			TQString strconstant = fitem->dom()->isConstant() ? TQString( " [const]" ) : TQString::null;
-			TQString strabstract = fitem->dom()->isAbstract() ? TQString( " [abstract]" ) : TQString::null;
+			TQString strconstant = fitem->dom()->isConstant() ? TQString( " [const]" ) : TQString();
+			TQString strabstract = fitem->dom()->isAbstract() ? TQString( " [abstract]" ) : TQString();
 			
 			tooltip = access + strstatic + strsignal + strslot + strresult
 				+ fitem->dom()->scope().join("::") + "::" + fitem->dom()->name() 
@@ -1238,7 +1238,7 @@ void ClassViewWidget::maybeTip( TQPoint const & p )
 			else if ( vitem->dom()->access() == CodeModelItem::Public )
 				access = "[public] ";
 
-			TQString strstatic = vitem->dom()->isStatic() ? TQString( "[static] " ) : TQString::null;
+			TQString strstatic = vitem->dom()->isStatic() ? TQString( "[static] " ) : TQString();
 			tooltip = access + strstatic + vitem->dom()->type() + " " + vitem->dom()->name();
 		}	
 	}
@@ -1259,7 +1259,7 @@ void ClassViewWidget::maybeTip( TQPoint const & p )
         
 	kdDebug(0) << tooltip << endl;
 	
-	TQRect r = itemRect( item );
+	TQRect r = tqitemRect( item );
 
 	if ( item && r.isValid() && !tooltip.isEmpty() )
 	{
