@@ -83,7 +83,7 @@ DistpartDialog::DistpartDialog(DistpartPart *part, TQWidget *parent)
             this, TQT_SLOT(slotuploadAddFileToolButtonPressed()));
     connect( uploadRemoveToolButton, TQT_SIGNAL(clicked()),
             this, TQT_SLOT(slotuploadRemoveToolButtonPressed()));
-	connect ( srcDistFileListBox, TQT_SIGNAL(clicked(TQListBoxItem *item)), this, TQT_SLOT(slotRemoveFile(TQListBoxItem *item)));
+	connect ( srcDistFileListBox, TQT_SIGNAL(clicked(TQListBoxItem*)), this, TQT_SLOT(slotRemoveFile(TQListBoxItem*)));
 //	connect(  buildAllPushButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotbuildAllPushButtonPressed() ));
 //	connect(  exportSPECPushButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotexportSPECPushButtonPressed( ) ) );
 //	connect(  srcPackagePushButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotsrcPackagePushButtonPressed() ) );
@@ -142,14 +142,14 @@ void DistpartDialog::slotcreateSrcArchPushButtonPressed() {
 		}
 		else
 		{
-			prog->setLabel(i18n("Adding file: %1").arg( file) );
+			prog->setLabel(i18n("Adding file: %1").tqarg( file) );
 			prog->progressBar()->setValue( (idx*100)/srcDistFileListBox->numRows() );
 		}
 	}
     	tar.close( );
 	prog->hide();
 	delete prog;
-	KMessageBox::information( this, i18n("Archive made at: %1").arg( filename ), i18n("Archive Done") );
+	KMessageBox::information( this, i18n("Archive made at: %1").tqarg( filename ), i18n("Archive Done") );
 
     }
     else
@@ -457,7 +457,7 @@ TQString DistpartDialog::getSourceName() {
     name += (getcustomProjectCheckBoxState() && getbzipCheckBoxState()) ? ".tar.bz2" : ".tar.gz";
     return name.replace(TQRegExp("%n"),getappNameFormatLineEditText())
 	.replace(TQRegExp("%v"),getversionLineEditText())
-	.replace(TQRegExp("%d"),TQDate::currentDate().toString("yyyyMMdd"));
+	.replace(TQRegExp("%d"),TQDate::tqcurrentDate().toString("yyyyMMdd"));
 }
 
 void DistpartDialog::loadSettings() {
@@ -592,7 +592,7 @@ void DistpartDialog::slotAddFileButtonPressed(){
 }
 
 void DistpartDialog::slotRemoveFile(TQListBoxItem *item){
-	if ( KMessageBox::Yes == KMessageBox::warningYesNo( this, i18n("Remove %1").arg( item->text() ), i18n("Remove File") )){
+	if ( KMessageBox::Yes == KMessageBox::warningYesNo( this, i18n("Remove %1").tqarg( item->text() ), i18n("Remove File") )){
 	for(uint count =0; count< srcDistFileListBox->numRows(); count++){
 		if ( item == srcDistFileListBox->item(count)){
 			srcDistFileListBox->removeItem(count);
