@@ -98,7 +98,7 @@ DocumentationPart::DocumentationPart(TQObject *parent, const char *name, const T
 
     TQWhatsThis::add(m_widget, i18n("<b>Documentation browser</b><p>"
         "The documentation browser gives access to various "
-        "documentation sources (Qt DCF, Doxygen, KDoc, KDevelopTOC and DevHelp "
+        "documentation sources (TQt DCF, Doxygen, KDoc, KDevelopTOC and DevHelp "
         "documentation) and the KDevelop manuals. It also provides documentation index "
         "and full text search capabilities."));
 
@@ -125,8 +125,8 @@ DocumentationPart::~DocumentationPart()
 void DocumentationPart::loadDocumentationPlugins()
 {
     KTrader::OfferList docPluginOffers =
-        KTrader::self()->query(TQString::fromLatin1("KDevelop/DocumentationPlugins"),
-            TQString("[X-KDevelop-Version] == %1").arg(KDEVELOP_PLUGIN_VERSION));
+        KTrader::self()->query(TQString::tqfromLatin1("KDevelop/DocumentationPlugins"),
+            TQString("[X-KDevelop-Version] == %1").tqarg(KDEVELOP_PLUGIN_VERSION));
 
     KTrader::OfferList::ConstIterator serviceIt = docPluginOffers.begin();
     for ( ; serviceIt != docPluginOffers.end(); ++serviceIt )
@@ -156,7 +156,7 @@ void DocumentationPart::emitIndexSelected(IndexBox *indexBox)
 {
     if (!m_hasIndex)
     {
-        TQApplication::setOverrideCursor(TQCursor(Qt::WaitCursor));
+        TQApplication::setOverrideCursor(TQCursor(TQt::WaitCursor));
         emit indexSelected(indexBox);
         indexBox->fill();
         m_hasIndex = true;
@@ -347,13 +347,13 @@ void DocumentationPart::infoPage()
 
 void DocumentationPart::manPage(const TQString &term)
 {
-    TQString url = TQString::fromLatin1("man:/%1").arg(term);
+    TQString url = TQString::tqfromLatin1("man:/%1").tqarg(term);
     partController()->showDocument(KURL(url));
 }
 
 void DocumentationPart::infoPage(const TQString &term)
 {
-    TQString url = TQString::fromLatin1("info:/%1").arg(term);
+    TQString url = TQString::tqfromLatin1("info:/%1").tqarg(term);
     partController()->showDocument(KURL(url));
 }
 
@@ -465,40 +465,40 @@ void DocumentationPart::contextMenu(TQPopupMenu *popup, const Context *context)
             TQString squeezed = KStringHandler::csqueeze(m_contextStr, 30);
             int id = -1;
             if (hasContextFeature(Finder)) {
-                id = popup->insertItem(i18n("Find Documentation: %1").arg(squeezed),
+                id = popup->insertItem(i18n("Find Documentation: %1").tqarg(squeezed),
                                     this, TQT_SLOT(contextFindDocumentation()));
-                popup->setWhatsThis(id, i18n("<b>Find documentation</b><p>"
+                popup->tqsetWhatsThis(id, i18n("<b>Find documentation</b><p>"
                                     "Opens the documentation finder tab and searches "
                                     "all possible sources of documentation like "
                                     "table of contents, index, man and info databases, "
                                     "Google, etc."));
             }
             if (hasContextFeature(IndexLookup)) {
-                id = popup->insertItem(i18n("Look in Documentation Index: %1").arg(squeezed),
+                id = popup->insertItem(i18n("Look in Documentation Index: %1").tqarg(squeezed),
                                 this, TQT_SLOT(contextLookInDocumentationIndex()));
-                popup->setWhatsThis(id, i18n("<b>Look in documentation index</b><p>"
+                popup->tqsetWhatsThis(id, i18n("<b>Look in documentation index</b><p>"
                                 "Opens the documentation index tab. It allows "
                                 "a term to be entered which will be looked for in "
                                 "the documentation index."));
             }
             if (hasContextFeature(FullTextSearch)) {
-                id = popup->insertItem(i18n("Search in Documentation: %1").arg(squeezed),
+                id = popup->insertItem(i18n("Search in Documentation: %1").tqarg(squeezed),
                                 this, TQT_SLOT(contextSearchInDocumentation()));
-                popup->setWhatsThis(id, i18n("<b>Search in documentation</b><p>Searches "
+                popup->tqsetWhatsThis(id, i18n("<b>Search in documentation</b><p>Searches "
                                 "for a term under the cursor in "
                                 "the documentation. For this to work, "
                                 "a full text index must be created first, which can be done in the "
                                 "configuration dialog of the documentation plugin."));
             }
             if (hasContextFeature(GotoMan)) {
-                id = popup->insertItem(i18n("Goto Manpage: %1").arg(squeezed),
+                id = popup->insertItem(i18n("Goto Manpage: %1").tqarg(squeezed),
                                 this, TQT_SLOT(contextManPage()));
-                popup->setWhatsThis(id, i18n("<b>Goto manpage</b><p>Tries to open a man page for the term under the cursor."));
+                popup->tqsetWhatsThis(id, i18n("<b>Goto manpage</b><p>Tries to open a man page for the term under the cursor."));
             }
             if (hasContextFeature(GotoInfo)) {
-                id = popup->insertItem( i18n("Goto Infopage: %1").arg(squeezed),
+                id = popup->insertItem( i18n("Goto Infopage: %1").tqarg(squeezed),
                                 this, TQT_SLOT(contextInfoPage()) );
-                popup->setWhatsThis(id, i18n("<b>Goto infopage</b><p>Tries to open an info page for the term under the cursor."));
+                popup->tqsetWhatsThis(id, i18n("<b>Goto infopage</b><p>Tries to open an info page for the term under the cursor."));
             }
             if (id != -1)
                 popup->insertSeparator();
