@@ -172,7 +172,7 @@ IndexItem::List IndexItem::urls() const
     TQValueList<IndexItemProto*> itemProtos = m_listbox->items[text()];
     for (TQValueList<IndexItemProto*>::const_iterator it = itemProtos.begin();
         it != itemProtos.end(); ++it)
-        urlList.append(qMakePair((*it)->description(), (*it)->url()));
+        urlList.append(tqMakePair((*it)->description(), (*it)->url()));
     return urlList;
 }
 
@@ -209,7 +209,7 @@ void ConfigurationItem::paintCell(TQPainter *p, const TQColorGroup &cg, int colu
         p->fillRect(0, 0, width, height(), cg.brush(crole));
 
         TQFontMetrics fm(lv->fontMetrics());
-        int boxsize = lv->style().pixelMetric(TQStyle::PM_CheckListButtonSize, lv);
+        int boxsize = lv->tqstyle().tqpixelMetric(TQStyle::PM_CheckListButtonSize, lv);
         int marg = lv->itemMargin();
         int styleflags = TQStyle::Style_Default;
                 
@@ -229,7 +229,7 @@ void ConfigurationItem::paintCell(TQPainter *p, const TQColorGroup &cg, int colu
             y = (fm.height() + 2 + marg - boxsize) / 2;
 
         TQStyleOption opt(this);
-        lv->style().drawPrimitive(TQStyle::PE_CheckListIndicator, p,
+        lv->tqstyle().tqdrawPrimitive(TQStyle::PE_CheckListIndicator, p,
             TQRect(x, y, boxsize, fm.height() + 2 + marg), cg, styleflags, opt);
                
         return;
@@ -240,7 +240,7 @@ void ConfigurationItem::paintCell(TQPainter *p, const TQColorGroup &cg, int colu
 int ConfigurationItem::width(const TQFontMetrics &fm, const TQListView *lv, int c) const
 {
     if ((c == 0) || (c == 1) || (c == 2))
-        return lv->style().pixelMetric(TQStyle::PM_CheckListButtonSize, lv) + 4;
+        return lv->tqstyle().tqpixelMetric(TQStyle::PM_CheckListButtonSize, lv) + 4;
     return TQListViewItem::width(fm, lv, c);
 }
 
@@ -630,7 +630,7 @@ void IndexBox::removeIndexItem(IndexItemProto *item)
     if (items[text].count() == 0)
     {
         items.remove(text);
-        TQListBoxItem *item = findItem(text, Qt::CaseSensitive | Qt::ExactMatch);
+        TQListBoxItem *item = findItem(text, TQt::CaseSensitive | TQt::ExactMatch);
         if (item)
             delete item;
     }
