@@ -75,22 +75,22 @@ DocDoxygenPlugin::~DocDoxygenPlugin()
 {
 }
 
-QPair<KFile::Mode, TQString> DocDoxygenPlugin::catalogLocatorProps()
+TQPair<KFile::Mode, TQString> DocDoxygenPlugin::catalogLocatorProps()
 {
-    return QPair<KFile::Mode, TQString>(KFile::File, "index.html *.tag");
+    return TQPair<KFile::Mode, TQString>(KFile::File, "index.html *.tag");
 }
 
 TQString DocDoxygenPlugin::catalogTitle(const TQString& url)
 {
     TQFileInfo fi(url);
     if (!fi.exists())
-        return TQString::null;
+        return TQString();
     
     if (fi.extension(false) == "html")
     {
         TQFile f(url);
         if (!f.open(IO_ReadOnly))
-            return TQString::null;
+            return TQString();
         
         TQTextStream ts(&f);
         TQString contents = ts.read();
@@ -118,7 +118,7 @@ TQString DocDoxygenPlugin::catalogTitle(const TQString& url)
             return re.cap(1);   
         }
     }
-    return TQString::null;
+    return TQString();
 }
 
 TQString DocDoxygenPlugin::pluginName() const
@@ -256,7 +256,7 @@ void DocDoxygenPlugin::createIndex(IndexBox* index, DocumentationCatalogItem* it
         if (!d.exists())
             continue;
 
-        const QFileInfoList *dirEntries = d.entryInfoList();
+        const TQFileInfoList *dirEntries = d.entryInfoList();
         if (!dirEntries) continue;
         TQPtrListIterator<TQFileInfo> it(*dirEntries);
         for (; it.current(); ++it)
@@ -306,7 +306,7 @@ void DocDoxygenPlugin::createTOC(DocumentationCatalogItem* item)
         if (!d.exists())
             continue;
 
-        const QFileInfoList *dirEntries = d.entryInfoList();
+        const TQFileInfoList *dirEntries = d.entryInfoList();
         if (!dirEntries) continue;
         TQPtrListIterator<TQFileInfo> it(*dirEntries);
         for (; it.current(); ++it)
@@ -450,7 +450,7 @@ void DocDoxygenPlugin::createIndexFromTag(TQDomDocument &dom, IndexBox *index,
             TQString filename = childEl.namedItem("filename").firstChild().toText().data();
 
             IndexItemProto *indexItem = new IndexItemProto(this, item, index, classname, 
-            i18n("%1 Class Reference").arg(classname));
+            i18n("%1 Class Reference").tqarg(classname));
             indexItem->addURL(KURL(prefix + filename));
             
             createIndexFromTag(dom, index, item, childEl, prefix + filename);
@@ -467,7 +467,7 @@ void DocDoxygenPlugin::createIndexFromTag(TQDomDocument &dom, IndexBox *index,
             
             if (classname != membername)
             {
-                IndexItemProto *indexItem = new IndexItemProto(this, item, index, membername,i18n("%1::%2%3 Member Reference").arg(classname).arg(membername).arg(arglist));
+                IndexItemProto *indexItem = new IndexItemProto(this, item, index, membername,i18n("%1::%2%3 Member Reference").tqarg(classname).tqarg(membername).tqarg(arglist));
                 indexItem->addURL(KURL(prefix + "#" + anchor));
             }
         }
