@@ -172,7 +172,7 @@ void DoxygenPart::adjustDoxyfile()
     patterns->addValue("*.tlh");
     patterns->addValue("*.diff");
     patterns->addValue("*.patch");
-    patterns->addValue("*.moc");
+    patterns->addValue("*.tqmoc");
     patterns->addValue("*.xpm");
     patterns->addValue("*.dox");
   }
@@ -448,7 +448,7 @@ void DoxygenPart::slotRunPreview( )
         if (poDir != 0)
             *poDir->valueRef() = dirVal;
 
-        KMessageBox::error(mainWindow()->main(), i18n("Cannot create temporary file '%1'").arg(file.name()));
+        KMessageBox::error(mainWindow()->main(), i18n("Cannot create temporary file '%1'").tqarg(file.name()));
         return;
     }
 
@@ -485,7 +485,7 @@ void DoxygenPart::slotActivePartChanged( KParts::Part * part )
 	if (doc != 0)
 		m_file = doc->url().path();
 	else
-		m_file = TQString::null;
+		m_file = TQString();
 	// <-
     m_activeEditor = dynamic_cast<KTextEditor::EditInterface*>(part);
     m_cursor = part ? dynamic_cast<KTextEditor::ViewCursorInterface*>(part->widget()) : 0;
