@@ -147,9 +147,9 @@ void FCConfigWidget::loadProjectTemplates(TQListView *view)
 {
     TQDir templDir( m_part->project()->projectDirectory() + "/templates/" );
     templDir.setFilter( TQDir::Files );
-    const QFileInfoList * list = templDir.entryInfoList();
+    const TQFileInfoList * list = templDir.entryInfoList();
     if( list ){
-      QFileInfoListIterator it( *list );
+      TQFileInfoListIterator it( *list );
       TQFileInfo *fi;
       while ( (fi = it.current()) != 0 ) {
         FileType * filetype;
@@ -259,7 +259,7 @@ void FCConfigWidget::saveProjectConfig()
             TQString dest;
             dest = m_part->project()->projectDirectory() + "/templates/";
             if (it2.current()->text(1) == "create")
-                copyTemplate(TQString::null, dest, it2.current()->text(0));
+                copyTemplate(TQString(), dest, it2.current()->text(0));
             else
                 copyTemplate(it2.current()->text(1), dest, it2.current()->text(0));
         }
@@ -295,7 +295,7 @@ void FCConfigWidget::saveConfiguration(TQDomDocument &dom, TQDomElement &element
                 else
                     dest = m_part->project()->projectDirectory() + "/templates/";
                 if (it.current()->text(4) == "create")
-                    copyTemplate(TQString::null, dest, it.current()->text(0));
+                    copyTemplate(TQString(), dest, it.current()->text(0));
                 else
                     copyTemplate(it.current()->text(4), dest, it.current()->text(0));
             }
@@ -322,7 +322,7 @@ void FCConfigWidget::saveConfiguration(TQDomDocument &dom, TQDomElement &element
                     else
                         dest = m_part->project()->projectDirectory() + "/templates/";
                     if (lastChild->text(4) == "create")
-                        copyTemplate(TQString::null, dest, it.current()->text(0) + "-" + lastChild->text(0));
+                        copyTemplate(TQString(), dest, it.current()->text(0) + "-" + lastChild->text(0));
                     else
                         copyTemplate(lastChild->text(4), dest, it.current()->text(0) + "-" + lastChild->text(0));
                 }
@@ -649,7 +649,7 @@ void FCConfigWidget::edit_template_content_button_clicked( )
             m_part->partController()->editDocument(content);
         else
         {
-            KMessageBox::information(this, i18n("Requested template does not exist yet.\nIt will be opened immediately after accepting the configuration dialog."), TQString::null, "Edit template content warning");
+            KMessageBox::information(this, i18n("Requested template does not exist yet.\nIt will be opened immediately after accepting the configuration dialog."), TQString(), "Edit template content warning");
             fctemplates_view->currentItem()->setPixmap(0, SmallIcon("edit"));
             urlsToEdit.append(content);
         }
@@ -674,9 +674,9 @@ void FCConfigWidget::edit_type_content_button_clicked( )
         else
         {
             if (it->text(4) == "create")
-                KMessageBox::information(this, i18n("Template for the selected file type does not exist yet.\nIt will be opened immediately after accepting the configuration dialog."), TQString::null, "Edit type template content warning");
+                KMessageBox::information(this, i18n("Template for the selected file type does not exist yet.\nIt will be opened immediately after accepting the configuration dialog."), TQString(), "Edit type template content warning");
             else
-                KMessageBox::information(this, i18n("Template for the selected file type has been changed.\nIt will be opened immediately after accepting the configuration dialog."), TQString::null, "Edit type template content warning");
+                KMessageBox::information(this, i18n("Template for the selected file type has been changed.\nIt will be opened immediately after accepting the configuration dialog."), TQString(), "Edit type template content warning");
             fc_view->currentItem()->setPixmap(0, SmallIcon("edit"));
             urlsToEdit.append(content);
         }
@@ -697,9 +697,9 @@ void FCConfigWidget::edit_type_content_button_clicked( )
         else
         {
             if (it->text(4) == "create")
-                KMessageBox::information(this, i18n("Template for the selected file type does not exist yet.\nIt will be opened immediately after accepting the configuration dialog."), TQString::null, "Edit global type template content warning");
+                KMessageBox::information(this, i18n("Template for the selected file type does not exist yet.\nIt will be opened immediately after accepting the configuration dialog."), TQString(), "Edit global type template content warning");
             else
-                KMessageBox::information(this, i18n("Template for the selected file type has been changed.\nIt will be opened immediately after accepting the configuration dialog."), TQString::null, "Edit global type template content warning");
+                KMessageBox::information(this, i18n("Template for the selected file type has been changed.\nIt will be opened immediately after accepting the configuration dialog."), TQString(), "Edit global type template content warning");
             fc_view->currentItem()->setPixmap(0, SmallIcon("edit"));
             urlsToEdit.append(content);
         }
