@@ -78,7 +78,7 @@ FileCreatePart::FileCreatePart(TQObject *parent, const char *name, const TQStrin
 		this, TQT_SLOT(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int )) );
 
 
-  KToolBarPopupAction * newAction = new KToolBarPopupAction( i18n("&New"), "filenew", CTRL+Qt::Key_N, this, TQT_SLOT(slotNewFile()), actionCollection(), "file_new");
+  KToolBarPopupAction * newAction = new KToolBarPopupAction( i18n("&New"), "filenew", CTRL+TQt::Key_N, this, TQT_SLOT(slotNewFile()), actionCollection(), "file_new");
   newAction->setWhatsThis( i18n("<b>New file</b><p>Creates a new file. Also adds it the project if the <b>Add to project</b> checkbox is turned on.") );
   newAction->setToolTip( i18n("Create a new file") );
   m_newPopupMenu = newAction->popupMenu();
@@ -210,8 +210,8 @@ void FileCreatePart::slotProjectClosed() {
 void FileCreatePart::slotFiletypeSelected(const FileType * filetype) {
 
   KDevCreateFile::CreatedFile createdFile = createNewFile(filetype->ext(),
-                                                          TQString::null,
-                                                          TQString::null,
+                                                          TQString(),
+                                                          TQString(),
                                                           filetype->subtypeRef());
 
   openCreatedFile(createdFile);
@@ -383,7 +383,7 @@ KDevCreateFile::CreatedFile FileCreatePart::createNewFile(TQString ext, TQString
   selectedURL = dialog.url();
   const FileType *selectedFileType = dialog.selectedType();
 
-  if (dialog.addToProject() && !projectURL.isParentOf(selectedURL) && !(project()->options() & KDevProject::UsesQMakeBuildSystem) ) {
+  if (dialog.addToProject() && !projectURL.isParentOf(selectedURL) && !(project()->options() & KDevProject::UsesTQMakeBuildSystem) ) {
     result.status = KDevCreateFile::CreatedFile::STATUS_NOTWITHINPROJECT;
     return result;
   }
@@ -425,7 +425,7 @@ KDevCreateFile::CreatedFile FileCreatePart::createNewFile(TQString ext, TQString
     // work out the path relative to the project directory
 //    TQString relToProj = URLUtil::relativePath(projectURL, selectedURL, URLUtil::SLASH_PREFIX );
 	  TQString relToProj;
-	  if( project()->options() & KDevProject::UsesQMakeBuildSystem )
+	  if( project()->options() & KDevProject::UsesTQMakeBuildSystem )
 	  {
 		relToProj = URLUtil::relativePathToFile( project()->projectDirectory(), fullPath );
 		  project()->addFile(relToProj);
@@ -451,7 +451,7 @@ KDevCreateFile::CreatedFile FileCreatePart::createNewFile(TQString ext, TQString
 }
 
 void FileCreatePart::slotNoteFiletype(const FileType * filetype) {
-  kdDebug(9034) << "Noting file type: " << (filetype ? filetype->ext() : TQString::fromLatin1("Null") ) << endl;
+  kdDebug(9034) << "Noting file type: " << (filetype ? filetype->ext() : TQString::tqfromLatin1("Null") ) << endl;
   m_filedialogFiletype = filetype;
 }
 
@@ -501,9 +501,9 @@ void FileCreatePart::slotInitialize( )
     TQDir templDir( project()->projectDirectory() + "/templates/" );
     if (templDir.exists()) {
       templDir.setFilter( TQDir::Files );
-      const QFileInfoList * list = templDir.entryInfoList();
+      const TQFileInfoList * list = templDir.entryInfoList();
       if( list ){
-        QFileInfoListIterator it( *list );
+        TQFileInfoListIterator it( *list );
         TQFileInfo *fi;
         while ( (fi = it.current()) != 0 ) {
           addFileType(fi->fileName());
