@@ -107,7 +107,7 @@ ProjectviewPart::~ProjectviewPart()
   delete m_guibuilder;
   if ( m_widget ) {
     mainWindow()->removeView( m_widget );
-    delete m_widget;  // deletes the children as well
+    delete m_widget;  // deletes the tqchildren as well
   }
 }
 
@@ -491,7 +491,7 @@ void ProjectviewPart::slotSaveAsProjectView(bool askForName)
         }
         newProjectView = newProjectView.remove("="); // we use this string in config files and = would confuse it
         if (m_projectViews.contains(newProjectView) > 0 &&
-            KMessageBox::warningContinueCancel(mainWindow()->main(), i18n("<qt>A view session named <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>").arg(newProjectView), TQString::null, i18n("Overwrite")) != KMessageBox::Continue)
+            KMessageBox::warningContinueCancel(mainWindow()->main(), i18n("<qt>A view session named <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>").tqarg(newProjectView), TQString(), i18n("Overwrite")) != KMessageBox::Continue)
         {
             return;
         }
