@@ -72,7 +72,7 @@
 
 
 // from kfiledialog.cpp - avoid qt warning in STDERR (~/.xsessionerrors)
-static void silenceQToolBar(QtMsgType, const char *)
+static void silenceTQToolBar(TQtMsgType, const char *)
 {}
 
 
@@ -105,7 +105,7 @@ void KDevFileSelectorToolBarParent::resizeEvent ( TQResizeEvent * )
 {
     if (m_tb)
     {
-        setMinimumHeight(m_tb->sizeHint().height());
+        setMinimumHeight(m_tb->tqsizeHint().height());
         m_tb->resize(width(),height());
     }
 }
@@ -125,7 +125,7 @@ KDevFileSelector::KDevFileSelector( FileSelectorPart *part, KDevMainWindow *main
 
     TQVBoxLayout* lo = new TQVBoxLayout(this);
 
-    QtMsgHandler oldHandler = qInstallMsgHandler( silenceQToolBar );
+    TQtMsgHandler oldHandler = tqInstallMsgHandler( silenceTQToolBar );
 
     KDevFileSelectorToolBarParent *tbp=new KDevFileSelectorToolBarParent(this);
     toolbar = new KDevFileSelectorToolBar(tbp);
@@ -133,10 +133,10 @@ KDevFileSelector::KDevFileSelector( FileSelectorPart *part, KDevMainWindow *main
     lo->addWidget(tbp);
     toolbar->setMovingEnabled(false);
     toolbar->setFlat(true);
-    qInstallMsgHandler( oldHandler );
+    tqInstallMsgHandler( oldHandler );
 
     cmbPath = new KURLComboBox( KURLComboBox::Directories, true, this, "path combo" );
-    cmbPath->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
+    cmbPath->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
     KURLCompletion* cmpl = new KURLCompletion(KURLCompletion::DirCompletion);
     cmbPath->setCompletionObject( cmpl );
     lo->addWidget(cmbPath);
@@ -171,7 +171,7 @@ KDevFileSelector::KDevFileSelector( FileSelectorPart *part, KDevMainWindow *main
     btnFilter->setIconSet( SmallIconSet("filter" ) );
     btnFilter->setToggleButton( true );
     filter = new KHistoryCombo( true, filterBox, "filter");
-    filter->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
+    filter->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
     filterBox->setStretchFactor(filter, 2);
     connect( btnFilter, TQT_SIGNAL( clicked() ), this, TQT_SLOT( btnFilterClick() ) );
     lo->addWidget(filterBox);
@@ -186,7 +186,7 @@ KDevFileSelector::KDevFileSelector( FileSelectorPart *part, KDevMainWindow *main
 
     // kaction for the dir sync method
     acSyncDir = new KAction( i18n("Current Document Directory"), "dirsynch", 0,
-                             this, TQT_SLOT( setActiveDocumentDir() ), mActionCollection, "sync_dir" );
+                             TQT_TQOBJECT(this), TQT_SLOT( setActiveDocumentDir() ), mActionCollection, "sync_dir" );
     toolbar->setIconText( KToolBar::IconOnly );
     toolbar->setIconSize( 16 );
     toolbar->setEnableContextMenu( false );
@@ -209,7 +209,7 @@ KDevFileSelector::KDevFileSelector( FileSelectorPart *part, KDevMainWindow *main
     connect( bookmarkHandler, TQT_SIGNAL( openURL( const TQString& )),
              this, TQT_SLOT( setDir( const TQString& ) ) );
 
-    waitingUrl = TQString::null;
+    waitingUrl = TQString();
 
     // whatsthis help
     TQWhatsThis::add
@@ -349,10 +349,10 @@ void KDevFileSelector::slotFilterChange( const TQString & nf )
     if ( empty )
     {
         dir->clearFilter();
-        filter->lineEdit()->setText( TQString::null );
+        filter->lineEdit()->setText( TQString() );
         TQToolTip::add
             ( btnFilter,
-                    TQString( i18n("Apply last filter (\"%1\")") ).arg( lastFilter ) );
+                    TQString( i18n("Apply last filter (\"%1\")") ).tqarg( lastFilter ) );
     }
     else
     {
@@ -415,7 +415,7 @@ void KDevFileSelector::btnFilterClick()
 {
     if ( !btnFilter->isOn() )
     {
-        slotFilterChange( TQString::null );
+        slotFilterChange( TQString() );
     }
     else
     {
@@ -432,7 +432,7 @@ void KDevFileSelector::autoSync()
     if ( isVisible() )
     {
         setActiveDocumentDir();
-        waitingUrl = TQString::null;
+        waitingUrl = TQString();
     }
     // else set waiting url
     else
@@ -454,13 +454,13 @@ void KDevFileSelector::autoSync( KParts::Part *part )
     KURL u ( doc->url() );
     if ( u.isEmpty() )
     {
-        waitingUrl = TQString::null;
+        waitingUrl = TQString();
         return;
     }
     if ( isVisible() )
     {
         setDir( u.directory() );
-        waitingUrl = TQString::null;
+        waitingUrl = TQString();
     }
     else
     {
@@ -499,13 +499,13 @@ void KDevFileSelector::showEvent( TQShowEvent * )
     {
         kdDebug()<<"syncing fs on show"<<endl;
         setActiveDocumentDir();
-        waitingUrl = TQString::null;
+        waitingUrl = TQString();
     }
     // else, if we have a waiting URL set it
     else if ( ! waitingUrl.isEmpty() )
     {
         setDir( waitingUrl );
-        waitingUrl = TQString::null;
+        waitingUrl = TQString();
     }
 }
 
@@ -519,11 +519,11 @@ bool KDevFileSelector::eventFilter( TQObject* o, TQEvent *e )
         And the popup is rather useless, if the paths are only partly visible.
     */
     TQListBox *lb = cmbPath->listBox();
-    if ( o == lb && e->type() == TQEvent::Show )
+    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(lb) && e->type() == TQEvent::Show )
     {
         int add
             = lb->height() < lb->contentsHeight() ? lb->verticalScrollBar()->width() : 0;
-        int w = QMIN( mainwin->main()->width(), lb->contentsWidth() + add );
+        int w = TQMIN( mainwin->main()->width(), lb->contentsWidth() + add );
         lb->resize( w, lb->height() );
         /// @todo - move the listbox to a suitable place if nessecary
         /// @todo - decide if it is worth caching the size while untill the contents
@@ -537,16 +537,16 @@ bool KDevFileSelector::eventFilter( TQObject* o, TQEvent *e )
 
 //BEGIN ACtionLBItem
 /*
-   QListboxItem that can store and return a string,
+   TQListboxItem that can store and return a string,
    used for the toolbar action selector.
 */
-class ActionLBItem : public QListBoxPixmap
+class ActionLBItem : public TQListBoxPixmap
 {
 public:
     ActionLBItem( TQListBox *lb=0,
                   const TQPixmap &pm = TQPixmap(),
-                  const TQString &text=TQString::null,
-                  const TQString &str=TQString::null ) :
+                  const TQString &text=TQString(),
+                  const TQString &str=TQString() ) :
             TQListBoxPixmap( lb, pm, text ),
             _str(str)
     {}
