@@ -18,8 +18,8 @@
  *
  */
 
-#ifndef QUICKOPENFUNCTIONCHOOSEFORM_H
-#define QUICKOPENFUNCTIONCHOOSEFORM_H
+#ifndef TQUICKOPENFUNCTIONCHOOSEFORM_H
+#define TQUICKOPENFUNCTIONCHOOSEFORM_H
 
 #include "quickopenfunctionchooseformbase.h"
 
@@ -28,6 +28,7 @@
 class QuickOpenFunctionChooseForm : public QuickOpenFunctionChooseFormBase
 {
   Q_OBJECT
+  TQ_OBJECT
 
 public:
   QuickOpenFunctionChooseForm(TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
