@@ -50,7 +50,7 @@ SnippetWidget::SnippetWidget(SnippetPart *part)
 		: KListView(0, "snippet widget"), TQToolTip( viewport() ),
 		m_part( part )
 {
-    // init the QPtrList
+    // init the TQPtrList
     _list.setAutoDelete(TRUE);
 
     // init the KListView
@@ -165,7 +165,7 @@ void SnippetWidget::slotRemove()
 
   if (group) {
     if (group->childCount() > 0 &&
-        KMessageBox::warningContinueCancel(this, i18n("Do you really want to remove this group and all its snippets?"),TQString::null,KStdGuiItem::del())
+        KMessageBox::warningContinueCancel(this, i18n("Do you really want to remove this group and all its snippets?"),TQString(),KStdGuiItem::del())
         == KMessageBox::Cancel)
       return;
 
@@ -327,9 +327,9 @@ void SnippetWidget::writeConfig()
     SnippetGroup * group = dynamic_cast<SnippetGroup*>(item);
     if (group) {
       kdDebug(9035) << "-->GROUP " << item->getName() << group->getId() << " " << iGroupCount<< endl;
-      strKeyName=TQString("snippetGroupName_%1").arg(iGroupCount);
-      strKeyId=TQString("snippetGroupId_%1").arg(iGroupCount);
-      strKeyText=TQString("snippetGroupLang_%1").arg(iGroupCount);
+      strKeyName=TQString("snippetGroupName_%1").tqarg(iGroupCount);
+      strKeyId=TQString("snippetGroupId_%1").tqarg(iGroupCount);
+      strKeyText=TQString("snippetGroupLang_%1").tqarg(iGroupCount);
 
       _cfg->writeEntry(strKeyName, group->getName());
       _cfg->writeEntry(strKeyId, group->getId());
@@ -337,9 +337,9 @@ void SnippetWidget::writeConfig()
       iGroupCount++;
     } else if (dynamic_cast<SnippetItem*>(item)) {
       kdDebug(9035) << "-->ITEM " << item->getName() << item->getParent() << " " << iSnipCount << endl;
-      strKeyName=TQString("snippetName_%1").arg(iSnipCount);
-      strKeyText=TQString("snippetText_%1").arg(iSnipCount);
-      strKeyId=TQString("snippetParent_%1").arg(iSnipCount);
+      strKeyName=TQString("snippetName_%1").tqarg(iSnipCount);
+      strKeyText=TQString("snippetText_%1").tqarg(iSnipCount);
+      strKeyId=TQString("snippetParent_%1").tqarg(iSnipCount);
 
       _cfg->writeEntry(strKeyName, item->getName());
       _cfg->writeEntry(strKeyText, item->getText());
@@ -357,8 +357,8 @@ void SnippetWidget::writeConfig()
   for ( it = _mapSaved.begin(); it != _mapSaved.end(); ++it ) {  //write the saved variable values
     if (it.data().length()<=0) continue;  //is the saved value has no length -> no need to save it
 
-    strKeyName=TQString("snippetSavedName_%1").arg(iCount);
-    strKeyText=TQString("snippetSavedVal_%1").arg(iCount);
+    strKeyName=TQString("snippetSavedName_%1").tqarg(iCount);
+    strKeyText=TQString("snippetSavedVal_%1").tqarg(iCount);
 
     _cfg->writeEntry(strKeyName, it.key());
     _cfg->writeEntry(strKeyText, it.data());
@@ -394,8 +394,8 @@ void SnippetWidget::initConfigOldVersion(KConfig *cfg)
   TQString strKeyName="";
   TQString strKeyText="";
   for ( int i=0; i<iCount; i++) {  //read the snippet-list
-    strKeyName=TQString("snippetName_%1").arg(i);
-    strKeyText=TQString("snippetText_%1").arg(i);
+    strKeyName=TQString("snippetName_%1").tqarg(i);
+    strKeyText=TQString("snippetText_%1").tqarg(i);
 
     TQString strNameVal="";
     TQString strTextVal="";
@@ -434,9 +434,9 @@ void SnippetWidget::initConfig()
   int iCount = _cfg->readNumEntry("snippetGroupCount", -1);
 
   for ( int i=0; i<iCount; i++) {  //read the group-list
-    strKeyName=TQString("snippetGroupName_%1").arg(i);
-    strKeyId=TQString("snippetGroupId_%1").arg(i);
-    strKeyText=TQString("snippetGroupLang_%1").arg(i);
+    strKeyName=TQString("snippetGroupName_%1").tqarg(i);
+    strKeyId=TQString("snippetGroupId_%1").tqarg(i);
+    strKeyText=TQString("snippetGroupLang_%1").tqarg(i);
 
     TQString strNameVal="";
     int iIdVal=-1;
@@ -465,9 +465,9 @@ void SnippetWidget::initConfig()
   if (iCount != -1) {
     iCount = _cfg->readNumEntry("snippetCount", 0);
     for ( int i=0; i<iCount; i++) {  //read the snippet-list
-        strKeyName=TQString("snippetName_%1").arg(i);
-        strKeyText=TQString("snippetText_%1").arg(i);
-        strKeyId=TQString("snippetParent_%1").arg(i);
+        strKeyName=TQString("snippetName_%1").tqarg(i);
+        strKeyText=TQString("snippetText_%1").tqarg(i);
+        strKeyId=TQString("snippetParent_%1").tqarg(i);
 
         TQString strNameVal="";
         TQString strTextVal="";
@@ -491,9 +491,9 @@ void SnippetWidget::initConfig()
 
   iCount = _cfg->readNumEntry("snippetSavedCount", 0);
 
-  for ( int i=1; i<=iCount; i++) {  //read the saved-values and store in QMap
-    strKeyName=TQString("snippetSavedName_%1").arg(i);
-    strKeyText=TQString("snippetSavedVal_%1").arg(i);
+  for ( int i=1; i<=iCount; i++) {  //read the saved-values and store in TQMap
+    strKeyName=TQString("snippetSavedName_%1").tqarg(i);
+    strKeyText=TQString("snippetSavedVal_%1").tqarg(i);
 
     TQString strNameVal="";
     TQString strTextVal="";
@@ -526,7 +526,7 @@ void SnippetWidget::maybeTip( const TQPoint & p )
 	if (!item)
 	  return;
 
-	TQRect r = itemRect( item );
+	TQRect r = tqitemRect( item );
 
 	if (r.isValid() &&
         _SnippetConfig.useToolTips() )
@@ -589,7 +589,7 @@ TQString SnippetWidget::parseText(TQString text, TQString del)
   TQRect rMulti = _SnippetConfig.getMultiRect();
 
   do {
-    iFound = text.find(TQRegExp("\\"+del+"[A-Za-z-_0-9\\s]*\\"+del), iEnd+1);  //find the next variable by this QRegExp
+    iFound = text.find(TQRegExp("\\"+del+"[A-Za-z-_0-9\\s]*\\"+del), iEnd+1);  //find the next variable by this TQRegExp
     if (iFound >= 0) {
       iEnd = text.find(del, iFound+1)+1;
       strName = text.mid(iFound, iEnd-iFound);
@@ -597,7 +597,7 @@ TQString SnippetWidget::parseText(TQString text, TQString del)
       if ( strName != del+del  ) {  //if not doubel-delimiter 
         if (iInMeth == 0) { //if input-method "single" is selected
           if ( mapVar[strName].length() <= 0 ) {  // and not already in map
-            strMsg=i18n("Please enter the value for <b>%1</b>:").arg(strName);
+            strMsg=i18n("Please enter the value for <b>%1</b>:").tqarg(strName);
             strNew = showSingleVarDialog( strName, &_mapSaved, rSingle );
             if (strNew=="")
               return ""; //user clicked Cancle
@@ -633,7 +633,7 @@ TQString SnippetWidget::parseText(TQString text, TQString del)
       return "";
     }
 
-    rMulti.setWidth(w);   //this is a hack to save the dialog's dimensions in only one QRect
+    rMulti.setWidth(w);   //this is a hack to save the dialog's dimensions in only one TQRect
     rMulti.setHeight(bh);
     rMulti.setTop(oh);
     rMulti.setLeft(0);
@@ -671,7 +671,7 @@ bool SnippetWidget::showMultiVarDialog(TQMap<TQString, TQString> * map, TQMap<TQ
   TQDialog dlg(this);
   dlg.setCaption(i18n("Enter Values for Variables"));
 
-  TQGridLayout * layout = new TQGridLayout( &dlg, 1, 1, 11, 6, "layout");
+  TQGridLayout * tqlayout = new TQGridLayout( &dlg, 1, 1, 11, 6, "tqlayout");
   TQGridLayout * layoutTop = new TQGridLayout( 0, 1, 1, 0, 6, "layoutTop");
   TQGridLayout * layoutVar = new TQGridLayout( 0, 1, 1, 0, 6, "layoutVar");
   TQGridLayout * layoutBtn = new TQGridLayout( 0, 1, 1, 0, 6, "layoutBtn");
@@ -681,25 +681,25 @@ bool SnippetWidget::showMultiVarDialog(TQMap<TQString, TQString> * map, TQMap<TQ
   TQCheckBox * cb = NULL;
 
   labTop = new TQLabel( &dlg, "label" );
-  labTop->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)1, (TQSizePolicy::SizeType)0, 0, 0,
+  labTop->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)1, (TQSizePolicy::SizeType)0, 0, 0,
                          labTop->sizePolicy().hasHeightForWidth() ) );
   labTop->setText(i18n("Enter the replacement values for these variables:"));
   layoutTop->addWidget(labTop, 0, 0);
-  layout->addMultiCellLayout( layoutTop, 0, 0, 0, 1 );
+  tqlayout->addMultiCellLayout( layoutTop, 0, 0, 0, 1 );
 
 
   int i = 0;                                           //walk through the variable map and add
-  for ( it = map->begin(); it != map->end(); ++it ) {  //a checkbox, a lable and a lineedit to the main layout
+  for ( it = map->begin(); it != map->end(); ++it ) {  //a checkbox, a lable and a lineedit to the main tqlayout
     if (it.key() == _SnippetConfig.getDelimiter() + _SnippetConfig.getDelimiter())
       continue;
 
     cb = new TQCheckBox( &dlg, "cbVar" );
     cb->setChecked( FALSE );
     cb->setText(it.key());
-    layoutVar->addWidget( cb, i ,0, Qt::AlignTop );
+    layoutVar->addWidget( cb, i ,0, TQt::AlignTop );
 
     te = new KTextEdit( &dlg, "teVar" );
-    layoutVar->addWidget( te, i, 1, Qt::AlignTop );
+    layoutVar->addWidget( te, i, 1, TQt::AlignTop );
 
     if ((*mapSave)[it.key()].length() > 0) {
       cb->setChecked( TRUE );
@@ -716,22 +716,22 @@ bool SnippetWidget::showMultiVarDialog(TQMap<TQString, TQString> * map, TQMap<TQ
 
     i++;
   }
-  layout->addMultiCellLayout( layoutVar, 1, 1, 0, 1 );
+  tqlayout->addMultiCellLayout( layoutVar, 1, 1, 0, 1 );
 
   KPushButton * btn1 = new KPushButton( &dlg, "pushButton1" );
   btn1->setText(i18n("&Cancel"));
-  btn1->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)1, (TQSizePolicy::SizeType)0, 0, 0,
+  btn1->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)1, (TQSizePolicy::SizeType)0, 0, 0,
                          btn1->sizePolicy().hasHeightForWidth() ) );
   layoutBtn->addWidget( btn1, 0, 0 );
 
   KPushButton * btn2 = new KPushButton( &dlg, "pushButton2" );
   btn2->setText(i18n("&Apply"));
   btn2->setDefault( TRUE );
-  btn2->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)1, (TQSizePolicy::SizeType)0, 0, 0,
+  btn2->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)1, (TQSizePolicy::SizeType)0, 0, 0,
                          btn2->sizePolicy().hasHeightForWidth() ) );
   layoutBtn->addWidget( btn2, 0, 1 );
 
-  layout->addMultiCellLayout( layoutBtn, 2, 2, 0, 1 );
+  tqlayout->addMultiCellLayout( layoutBtn, 2, 2, 0, 1 );
   // --END-- building a dynamic dialog
 
   //connect the buttons to the TQDialog default slots
@@ -742,7 +742,7 @@ bool SnippetWidget::showMultiVarDialog(TQMap<TQString, TQString> * map, TQMap<TQ
   bool bReturn = false;
   //resize the textedits
   if (iWidth > 1) {
-    TQRect r = dlg.geometry();
+    TQRect r = dlg.tqgeometry();
     r.setHeight(iBasicHeight + iOneHeight*mapVar2Te.count());
     r.setWidth(iWidth);
     dlg.setGeometry(r);
@@ -763,9 +763,9 @@ bool SnippetWidget::showMultiVarDialog(TQMap<TQString, TQString> * map, TQMap<TQ
     }
     bReturn = true;
 
-    iBasicHeight = dlg.geometry().height() - layoutVar->geometry().height();
-    iOneHeight = layoutVar->geometry().height() / mapVar2Te.count();
-    iWidth = dlg.geometry().width();
+    iBasicHeight = dlg.tqgeometry().height() - layoutVar->tqgeometry().height();
+    iOneHeight = layoutVar->tqgeometry().height() / mapVar2Te.count();
+    iWidth = dlg.tqgeometry().width();
   }
 
   //do some cleanup
@@ -780,7 +780,7 @@ bool SnippetWidget::showMultiVarDialog(TQMap<TQString, TQString> * map, TQMap<TQ
   delete layoutTop;
   delete layoutVar;
   delete layoutBtn;
-  delete layout;
+  delete tqlayout;
 
   if (i==0) //if nothing happened this means, that there are no variables to translate
     return true; //.. so just return OK
@@ -800,7 +800,7 @@ TQString SnippetWidget::showSingleVarDialog(TQString var, TQMap<TQString, TQStri
   TQDialog dlg(this);
   dlg.setCaption(i18n("Enter Values for Variables"));
 
-  TQGridLayout * layout = new TQGridLayout( &dlg, 1, 1, 11, 6, "layout");
+  TQGridLayout * tqlayout = new TQGridLayout( &dlg, 1, 1, 11, 6, "tqlayout");
   TQGridLayout * layoutTop = new TQGridLayout( 0, 1, 1, 0, 6, "layoutTop");
   TQGridLayout * layoutVar = new TQGridLayout( 0, 1, 1, 0, 6, "layoutVar");
   TQGridLayout * layoutBtn = new TQGridLayout( 0, 2, 1, 0, 6, "layoutBtn");
@@ -811,8 +811,8 @@ TQString SnippetWidget::showSingleVarDialog(TQString var, TQMap<TQString, TQStri
 
   labTop = new TQLabel( &dlg, "label" );
   layoutTop->addWidget(labTop, 0, 0);
-  labTop->setText(i18n("Enter the replacement values for %1:").arg( var ));
-  layout->addMultiCellLayout( layoutTop, 0, 0, 0, 1 );
+  labTop->setText(i18n("Enter the replacement values for %1:").tqarg( var ));
+  tqlayout->addMultiCellLayout( layoutTop, 0, 0, 0, 1 );
 
 
   cb = new TQCheckBox( &dlg, "cbVar" );
@@ -820,8 +820,8 @@ TQString SnippetWidget::showSingleVarDialog(TQString var, TQMap<TQString, TQStri
   cb->setText(i18n( "Make value &default" ));
 
   te = new KTextEdit( &dlg, "teVar" );
-  layoutVar->addWidget( te, 0, 1, Qt::AlignTop);
-  layoutVar->addWidget( cb, 1, 1, Qt::AlignTop);
+  layoutVar->addWidget( te, 0, 1, TQt::AlignTop);
+  layoutVar->addWidget( cb, 1, 1, TQt::AlignTop);
   if ((*mapSave)[var].length() > 0) {
     cb->setChecked( TRUE );
     te->setText((*mapSave)[var]);
@@ -832,7 +832,7 @@ TQString SnippetWidget::showSingleVarDialog(TQString var, TQMap<TQString, TQStri
                             "If you use the same variable later, even in another snippet, the value entered to the right "
                             "will be the default value for that variable.") );
 
-  layout->addMultiCellLayout( layoutVar, 1, 1, 0, 1 );
+  tqlayout->addMultiCellLayout( layoutVar, 1, 1, 0, 1 );
 
   KPushButton * btn1 = new KPushButton( &dlg, "pushButton1" );
   btn1->setText(i18n("&Cancel"));
@@ -843,7 +843,7 @@ TQString SnippetWidget::showSingleVarDialog(TQString var, TQMap<TQString, TQStri
   btn2->setDefault( TRUE );
   layoutBtn->addWidget( btn2, 0, 1 );
 
-  layout->addMultiCellLayout( layoutBtn, 2, 2, 0, 1 );
+  tqlayout->addMultiCellLayout( layoutBtn, 2, 2, 0, 1 );
   te->setFocus();
   // --END-- building a dynamic dialog
 
@@ -863,7 +863,7 @@ TQString SnippetWidget::showSingleVarDialog(TQString var, TQMap<TQString, TQStri
 
     strReturn = te->text();    //copy the entered values back the the given map
 
-    dlgSize = dlg.geometry();
+    dlgSize = dlg.tqgeometry();
   }
 
   //do some cleanup
@@ -875,7 +875,7 @@ TQString SnippetWidget::showSingleVarDialog(TQString var, TQMap<TQString, TQStri
   delete layoutTop;
   delete layoutVar;
   delete layoutBtn;
-  delete layout;
+  delete tqlayout;
 
   return strReturn;
 }
@@ -920,7 +920,7 @@ void SnippetWidget::slotDropped(TQDropEvent *e, TQListViewItem *)
     group = dynamic_cast<SnippetGroup *>(item2->parent());
 
   TQCString dropped;
-  TQByteArray data = e->encodedData("text/plain");
+  TQByteArray data = e->tqencodedData("text/plain");
   if ( e->provides("text/plain") && data.size()>0 ) {
     //get the data from the event...
     TQString encData(data.data());
