@@ -20,11 +20,11 @@
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
+    the TQt library by Trolltech AS, Norway (or with modified versions
+    of TQt that use the same license as TQt), and distribute linked
     combinations including the two.  You must obey the GNU General
     Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
+    TQt.  If you modify this file, you may extend this exception to
     your version of the file, but you are not obligated to do so.  If
     you do not wish to do so, delete this exception statement from
     your version.
@@ -116,7 +116,7 @@ CalendarManager::CalendarManager()
   for ( CalendarResourceManager::ActiveIterator it = mgr->activeBegin(); it != mgr->activeEnd(); ++it ) {
     if ( (*it)->type() == "imap" || (*it)->type() == "kolab" ) {
       const TQStringList subResources = (*it)->subresources();
-      TQMap<TQString, int> prefixSet; // KDE4: QSet
+      TQMap<TQString, int> prefixSet; // KDE4: TQSet
       for ( TQStringList::ConstIterator subIt = subResources.begin(); subIt != subResources.end(); ++subIt ) {
         if ( !(*subIt).contains( "/.INBOX.directory/" ) )
           // we don't care about shared folders
@@ -190,7 +190,7 @@ class Formatter : public KMail::Interface::BodyPartFormatter
     }
 };
 
-static TQString directoryForStatus( Attendee::PartStat status )
+static TQString directoryFortqStatus( Attendee::PartStat status )
 {
   TQString dir;
   switch ( status ) {
@@ -295,7 +295,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
 
     }
 
-    Attendee* setStatusOnMyself( Incidence* incidence, Attendee* myself,
+    Attendee* seStatusOnMyself( Incidence* incidence, Attendee* myself,
                             Attendee::PartStat status, const TQString &receiver ) const
     {
       Attendee* newMyself = 0;
@@ -310,7 +310,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
                                 true, // RSVP, otherwise we would not be here
                                 status,
                                 myself ? myself->role() : heuristicalRole( incidence ),
-                                myself ? myself->uid() : TQString::null );
+                                myself ? myself->uid() : TQString() );
       if ( myself ) {
         newMyself->setDelegate( myself->delegate() );
         newMyself->setDelegator( myself->delegator() );
@@ -333,7 +333,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
     bool mail( Incidence* incidence, KMail::Callback& callback,
                Attendee::PartStat status,
                Scheduler::Method method = Scheduler::Reply,
-               const TQString &to = TQString::null, MailType type = Answer ) const
+               const TQString &to = TQString(), MailType type = Answer ) const
     {
       ICalFormat format;
       format.setTimeZone( KPimPrefs::timezone(), false );
@@ -344,16 +344,16 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
       TQString subject;
       switch ( type ) {
         case Answer:
-          subject = i18n( "Answer: %1" ).arg( summary );
+          subject = i18n( "Answer: %1" ).tqarg( summary );
           break;
         case Delegation:
-          subject = i18n( "Delegated: %1" ).arg( summary );
+          subject = i18n( "Delegated: %1" ).tqarg( summary );
           break;
         case Forward:
-          subject = i18n( "Forwarded: %1" ).arg( summary );
+          subject = i18n( "Forwarded: %1" ).tqarg( summary );
           break;
         case DeclineCounter:
-          subject = i18n( "Declined Counter Proposal: %1" ).arg( summary );
+          subject = i18n( "Declined Counter Proposal: %1" ).tqarg( summary );
           break;
       }
 
@@ -367,7 +367,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
       TQString recv = to;
       if ( recv.isEmpty() )
         recv = incidence->organizer().fullName();
-      TQString statusString = directoryForStatus( status );  //it happens to return the right strings
+      TQString statusString = directoryFortqStatus( status );  //it happens to return the right strings
       return callback.mailICal( recv, msg, subject, statusString, type != Forward );
     }
 
@@ -375,7 +375,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
     {
       TQString error;
       TQCString dcopService;
-      int result = KDCOPServiceStarter::self()->findServiceFor( "DCOP/Organizer", TQString::null, TQString::null, &error, &dcopService );
+      int result = KDCOPServiceStarter::self()->findServiceFor( "DCOP/Organizer", TQString(), TQString(), &error, &dcopService );
       if ( result == 0 ) {
         // OK, so korganizer (or kontact) is running. Now ensure the object we want is available
         // [that's not the case when kontact was already running, but korganizer not loaded into it...]
@@ -426,7 +426,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
     bool cancelPastInvites( Incidence *incidence, const TQString &path ) const
     {
       TQString warnStr;
-      TQDateTime now = TQDateTime::currentDateTime();
+      TQDateTime now = TQDateTime::tqcurrentDateTime();
       TQDate today = now.date();
       Event * const event = dynamic_cast<Event *>( incidence );
       Todo * const todo = dynamic_cast<Todo *>( incidence );
@@ -434,13 +434,13 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
         Q_ASSERT( event );
         if ( !event->doesFloat() ) {
           if ( event->dtEnd() < now ) {
-            warnStr = i18n( "\"%1\" occurred already." ).arg( event->summary() );
+            warnStr = i18n( "\"%1\" occurred already." ).tqarg( event->summary() );
           } else if ( event->dtStart() <= now && now <= event->dtEnd() ) {
-            warnStr = i18n( "\"%1\" is currently in-progress." ).arg( event->summary() );
+            warnStr = i18n( "\"%1\" is currently in-progress." ).tqarg( event->summary() );
           }
         } else {
           if ( event->dtEnd().date() < today ) {
-            warnStr = i18n( "\"%1\" occurred already." ).arg( event->summary() );
+            warnStr = i18n( "\"%1\" occurred already." ).tqarg( event->summary() );
           } else if ( event->dtStart().date() <= today && today <= event->dtEnd().date() ) {
             warnStr = i18n( "\"%1\", happening all day today, is currently in-progress." ).
                       arg( event->summary() );
@@ -451,19 +451,19 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
         if ( !todo->doesFloat() ) {
           if ( todo->hasDueDate() ) {
             if ( todo->dtDue() < now ) {
-              warnStr = i18n( "\"%1\" is past due." ).arg( todo->summary() );
+              warnStr = i18n( "\"%1\" is past due." ).tqarg( todo->summary() );
             } else if ( todo->hasStartDate() && todo->dtStart() <= now && now <= todo->dtDue() ) {
-              warnStr = i18n( "\"%1\" is currently in-progress." ).arg( todo->summary() );
+              warnStr = i18n( "\"%1\" is currently in-progress." ).tqarg( todo->summary() );
             }
           } else if ( todo->hasStartDate() ) {
             if ( todo->dtStart() < now ) {
-              warnStr = i18n( "\"%1\" has already started." ).arg( todo->summary() );
+              warnStr = i18n( "\"%1\" has already started." ).tqarg( todo->summary() );
             }
           }
         } else {
           if ( todo->hasDueDate() ) {
             if ( todo->dtDue().date() < today) {
-              warnStr = i18n( "\"%1\" is past due." ).arg( todo->summary() );
+              warnStr = i18n( "\"%1\" is past due." ).tqarg( todo->summary() );
             } else if ( todo->hasStartDate() &&
                         todo->dtStart().date() <= today && today <= todo->dtDue().date() ) {
               warnStr = i18n( "\"%1\", happening all-day today, is currently in-progress." ).
@@ -526,12 +526,12 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
         } else if ( path.startsWith( "ATTACH:" ) ) {
           return false;
         } else {
-          queryStr = i18n( "%1?" ).arg( path );
+          queryStr = i18n( "%1?" ).tqarg( path );
         }
 
         if ( KMessageBox::warningYesNo(
                0,
-               i18n( "%1\n%2" ).arg( warnStr ).arg( queryStr ) ) == KMessageBox::No ) {
+               i18n( "%1\n%2" ).tqarg( warnStr ).tqarg( queryStr ) ) == KMessageBox::No ) {
           return true;
         }
       }
@@ -567,7 +567,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
       }
 
       // First, save it for KOrganizer to handle
-      TQString dir = directoryForStatus( status );
+      TQString dir = directoryFortqStatus( status );
       if ( dir.isEmpty() )
         return true; // unknown status
       if ( status != Attendee::Delegated ) // we do that below for delegated incidences
@@ -606,7 +606,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
       }
 
       if ( ( myself && myself->RSVP() ) || heuristicalRSVP( incidence ) ) {
-        Attendee* newMyself = setStatusOnMyself( incidence, myself, status, receiver );
+        Attendee* newMyself = seStatusOnMyself( incidence, myself, status, receiver );
         if ( newMyself && status == Attendee::Delegated ) {
           newMyself->setDelegate( delegateString );
           newMyself->setRSVP( delegatorRSVP );
@@ -632,7 +632,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
                                     true, // RSVP, otherwise we would not be here
                                     status,
                                     heuristicalRole( incidence ),
-                                    TQString::null );
+                                    TQString() );
           incidence->clearAttendees();
           incidence->addAttendee( newMyself );
           ok = mail( incidence, callback, status, Scheduler::Reply );
@@ -649,7 +649,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
       if ( status == Attendee::Delegated ) {
         incidence = icalToString( iCal );
         myself = findMyself( incidence, receiver );
-        myself->setStatus( status );
+        myself->setqStatus( status );
         myself->setDelegate( delegateString );
         TQString name, email;
         KPIM::getNameAndMail( delegateString, name, email );
@@ -820,7 +820,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
         case KMessageBox::No: // means "send email"
           summary = incidence->summary();
           if ( !summary.isEmpty() ) {
-            summary = i18n( "Re: %1" ).arg( summary );
+            summary = i18n( "Re: %1" ).tqarg( summary );
           }
 
           KApplication::kApplication()->invokeMailer( incidence->organizer().email(), summary );
@@ -932,7 +932,7 @@ class UrlHandler : public KMail::Interface::BodyPartURLHandler
         }
       }
 
-      return TQString::null;
+      return TQString();
     }
 };
 
