@@ -357,7 +357,7 @@ void WidgetDatabase::setupDataBase( int id )
 
     r = new WidgetDatabaseRecord;
     r->iconSet = "lcdnumber.xpm";
-    r->name = "TQLCDNumber";
+    r->name = "QLCDNumber";
     r->group = widgetGroup( "Display" );
     r->toolTip = "LCD Number";
 
