@@ -226,7 +226,7 @@ namespace QtCSharp {
 		{
 			if (check)
 				return "\n\n\t\t\tif ((qparent = parent) != null)\n" +
-					   "\t\t\t\tqparent.AddChild (this);\n";
+					   "\t\t\t\parent.AddChild (this);\n";
 			else
 				return "";
 		}
