@@ -182,7 +182,7 @@ namespace QtCSharp {
 			mastermap.Add ("ScaleMode", "TQImage.ScaleMode");
 			mastermap.Add ("PaintDeviceFlags", "TQInternal.PaintDeviceFlags");
 			mastermap.Add ("Rules", "TQJpUnicodeConv.Rules");
-			mastermap.Add ("SegmentStyle", "TQLCDNumber.SegmentStyle");
+			mastermap.Add ("SegmentStyle", "QLCDNumber.SegmentStyle");
 			mastermap.Add ("LayoutMode", "TQListBox.LayoutMode");
 			mastermap.Add ("WidthMode", "TQListView.WidthMode");
 			mastermap.Add ("RenameAction", "TQListView.RenameAction");
@@ -193,11 +193,11 @@ namespace QtCSharp {
 			mastermap.Add ("Access", "QMetaData.Access");
 			mastermap.Add ("Flags", "TQMetaProperty.Flags");
 			mastermap.Add ("Status", "TQMovie.Status");
-			mastermap.Add ("InstanceMode", "TQNPInstance.InstanceMode");
-			mastermap.Add ("StreamMode", "TQNPInstance.StreamMode");
+			mastermap.Add ("InstanceMode", "QNPInstance.InstanceMode");
+			mastermap.Add ("StreamMode", "QNPInstance.StreamMode");
 			mastermap.Add ("Operation", "TQNetworkProtocol.Operation");
 			mastermap.Add ("ConnectionState", "TQNetworkProtocol.ConnectionState");
-			mastermap.Add ("DisposalMethod", "TQPNGImageWriter.DisposalMethod");
+			mastermap.Add ("DisposalMethod", "QPNGImageWriter.DisposalMethod");
 			mastermap.Add ("PDevCmd", "TQPaintDevice.PDevCmd");
 			mastermap.Add ("CoordinateMode", "TQPainter.CoordinateMode");
 			mastermap.Add ("TextDirection", "TQPainter.TextDirection");
@@ -287,7 +287,7 @@ namespace QtCSharp {
 			mastermap.Add ("TQMimeSource", "IQMimeSource");
 			mastermap.Add ("TQLayoutItem", "IQLayoutItem");
 			mastermap.Add ("TQUrl", "IQUrl");
-			mastermap.Add ("TQIODevice", "IQIODevice");
+			mastermap.Add ("QIODevice", "IQIODevice");
 			mastermap.Add ("TQXmlContentHandler", "IQXmlContentHandler");
 			mastermap.Add ("TQXmlErrorHandler", "IQXmlErrorHandler");
 			mastermap.Add ("TQXmlDTDHandler", "IQXmlDTDHandler");
@@ -305,10 +305,10 @@ namespace QtCSharp {
 			//mastermap.Add ("Direction", "TQChar.Direction");
 			//mastermap.Add ("Reason", "TQContextMenuEvent.Reason");
 			//mastermap.Add ("Reason", "TQFocusEvent.Reason");
-			//mastermap.Add ("Reason", "TQNPInstance.Reason");
+			//mastermap.Add ("Reason", "QNPInstance.Reason");
 			//mastermap.Add ("Mode", "TQFileDialog.Mode");
 			//mastermap.Add ("Mode", "TQIconSet.Mode");
-			//mastermap.Add ("Mode", "TQLCDNumber.Mode");
+			//mastermap.Add ("Mode", "QLCDNumber.Mode");
 			//mastermap.Add ("Mode", "TQSqlCursor.Mode");
 			//mastermap.Add ("Shape", "TQFrame.Shape");
 			//mastermap.Add ("Shape", "TQTabBar.Shape");
@@ -375,7 +375,7 @@ namespace QtCSharp {
 			interfaces.Add ("TQMimeSource", "IQMimeSource");
 			interfaces.Add ("TQLayoutItem", "IQLayoutItem");
 			interfaces.Add ("TQUrl", "IQUrl");
-			interfaces.Add ("TQIODevice", "IQIODevice");
+			interfaces.Add ("QIODevice", "IQIODevice");
 			interfaces.Add ("TQXmlContentHandler", "IQXmlContentHandler");
 			interfaces.Add ("TQXmlErrorHandler", "IQXmlErrorHandler");
 			interfaces.Add ("TQXmlDTDHandler", "IQXmlDTDHandler");
