@@ -57,7 +57,7 @@ QuantaDebuggerDBGp::QuantaDebuggerDBGp (TQObject *parent, const char*, const TQS
   m_supportsasync = false;
   m_defaultExecutionState = Starting;
   setExecutionState(m_defaultExecutionState);
-  emit updateStatus(DebuggerUI::NoSession);
+  emit updatetqStatus(DebuggerUI::NoSession);
   
   connect(&m_network, TQT_SIGNAL(command(const TQString&)), this, TQT_SLOT(processCommand(const TQString&)));
   connect(&m_network, TQT_SIGNAL(active(bool)), this, TQT_SLOT(slotNetworkActive(bool)));
@@ -88,9 +88,9 @@ void QuantaDebuggerDBGp::slotNetworkActive(bool active)
   setExecutionState(m_defaultExecutionState);
   
   if(active)
-    emit updateStatus(DebuggerUI::AwaitingConnection);
+    emit updatetqStatus(DebuggerUI::AwaitingConnection);
   else
-    emit updateStatus(DebuggerUI::NoSession);
+    emit updatetqStatus(DebuggerUI::NoSession);
 
 }
 
@@ -113,11 +113,11 @@ void QuantaDebuggerDBGp::slotNetworkConnected(bool connected)
 
   debuggerInterface()->setActiveLine("", 0);
   if(connected)
-    emit updateStatus(DebuggerUI::Connected);
+    emit updatetqStatus(DebuggerUI::Connected);
   else
   {
     setExecutionState(m_defaultExecutionState);
-    emit updateStatus(DebuggerUI::AwaitingConnection);
+    emit updatetqStatus(DebuggerUI::AwaitingConnection);
 
     profilerOpen(false);
   }
@@ -126,7 +126,7 @@ void QuantaDebuggerDBGp::slotNetworkConnected(bool connected)
 
 void QuantaDebuggerDBGp::slotNetworkError(const TQString &errormsg, bool log)
 {
-  debuggerInterface()->showStatus(errormsg, log);
+  debuggerInterface()->showtqStatus(errormsg, log);
 }
 
 
@@ -194,29 +194,29 @@ void QuantaDebuggerDBGp::setExecutionState(const TQString &state)
   if(state == "starting")
   {
     setExecutionState(Starting);
-    emit updateStatus(DebuggerUI::Paused);
+    emit updatetqStatus(DebuggerUI::Paused);
   }
   else if(state == "stopping")
   {
     setExecutionState(Stopping);
-    emit updateStatus(DebuggerUI::Paused);
+    emit updatetqStatus(DebuggerUI::Paused);
     m_network.slotSocketDestroyed(); //XDebug disconnects when stopped and destroys our socket
   }
   else if(state == "stopped")
   {
     setExecutionState(Stopped);
-    emit updateStatus(DebuggerUI::Paused);
+    emit updatetqStatus(DebuggerUI::Paused);
     m_network.slotSocketDestroyed(); //XDebug disconnects when stopped and destroys our socket
   }
   else if(state == "running")
   {
     setExecutionState(Running);
-    emit updateStatus(DebuggerUI::Running);
+    emit updatetqStatus(DebuggerUI::Running);
   }
   else if(state == "break")
   {
     setExecutionState(Break);
-    emit updateStatus(DebuggerUI::Paused);
+    emit updatetqStatus(DebuggerUI::Paused);
   }
 
 }
@@ -263,7 +263,7 @@ void QuantaDebuggerDBGp::processCommand(const TQString& datas)
     TQDomNode response = data.elementsByTagName("response").item(0);
     TQString command = attribute(response, "command");
 
-    // Status command
+    // tqStatus command
     if(command == "status")
       setExecutionState(attribute(response, "status"));
       
@@ -327,7 +327,7 @@ void QuantaDebuggerDBGp::processCommand(const TQString& datas)
   }
   else
   {
-    debuggerInterface()->showStatus(i18n("Unrecognized package: '%1%2'").arg(datas.left(50)).arg(datas.length() > 50 ? "..." : ""), true);
+    debuggerInterface()->showtqStatus(i18n("Unrecognized package: '%1%2'").tqarg(datas.left(50)).tqarg(datas.length() > 50 ? "..." : ""), true);
 
     kdDebug(24002) << datas << endl;
   }
@@ -338,10 +338,10 @@ void QuantaDebuggerDBGp::initiateSession(const TQDomNode& initpacket)
 {
   if(attribute(initpacket, "protocol_version") != protocolversion)
   {
-    debuggerInterface()->showStatus(
+    debuggerInterface()->showtqStatus(
       i18n("The debugger for %1 uses an unsupported protocol version (%2)")
-            .arg(attribute(initpacket, "language"))
-            .arg(attribute(initpacket, "protocol_version"))
+            .tqarg(attribute(initpacket, "language"))
+            .tqarg(attribute(initpacket, "protocol_version"))
           , true);
 
     endSession();
@@ -540,7 +540,7 @@ void QuantaDebuggerDBGp::addBreakpoint (DebuggerBreakpoint* breakpoint)
                         " -n " + TQString::number(breakpoint->line() + 1)
                         , breakpoint->condition());
 
-  breakpoint->setKey(TQString("id %1").arg(id));
+  breakpoint->setKey(TQString("id %1").tqarg(id));
 }
 
 void QuantaDebuggerDBGp::setBreakpointKey( const TQDomNode & response )
@@ -550,7 +550,7 @@ void QuantaDebuggerDBGp::setBreakpointKey( const TQDomNode & response )
   id = attribute(response, "transaction_id").toLong();
   if(id > 0)
   {
-    TQString oldkey = TQString("id %1").arg(id);
+    TQString oldkey = TQString("id %1").tqarg(id);
     DebuggerBreakpoint *bp = debuggerInterface()->findDebuggerBreakpoint(oldkey);
     if(bp)
       debuggerInterface()->updateBreakpointKey(*bp, attribute(response, "id"));
@@ -867,9 +867,9 @@ void QuantaDebuggerDBGp::profilerOpen(bool forceopen)
     else
     {
       if(forceopen)
-        KMessageBox::sorry(NULL, i18n("Unable to open profiler output (%1)").arg(profileroutput), i18n("Profiler File Error"));
+        KMessageBox::sorry(NULL, i18n("Unable to open profiler output (%1)").tqarg(profileroutput), i18n("Profiler File Error"));
       else
-        debuggerInterface()->showStatus(i18n("Unable to open profiler output (%1)").arg(profileroutput), false);
+        debuggerInterface()->showtqStatus(i18n("Unable to open profiler output (%1)").tqarg(profileroutput), false);
     }
   }
   else
@@ -923,7 +923,7 @@ void QuantaDebuggerDBGp::propertySetResponse( const TQDomNode & setnode)
 {
   if(attribute(setnode, "success") == "0")
   {
-    debuggerInterface()->showStatus(i18n("Unable to set value of variable."), true);
+    debuggerInterface()->showtqStatus(i18n("Unable to set value of variable."), true);
   }
 }
 
@@ -932,11 +932,11 @@ DebuggerVariable* QuantaDebuggerDBGp::buildVariable( const TQDomNode & variablen
 {
   /*
     Sample:
-    <property name="$arrayVar" fullname="$arrayVar" address="-1073754976" type="hash" children="1" numchildren="4">
+    <property name="$arrayVar" fullname="$arrayVar" address="-1073754976" type="hash" tqchildren="1" numtqchildren="4">
       <property name="birthyear" fullname="$arrayVar['birthyear']" address="135522364" type="int">
         <![CDATA[1949]]>
       </property>
-      <property name="songs" fullname="$arrayVar['songs']" address="135522236" type="hash" children="1" numchildren="3">
+      <property name="songs" fullname="$arrayVar['songs']" address="135522236" type="hash" tqchildren="1" numtqchildren="3">
         <property name="0" fullname="$arrayVar['songs'][0]" address="135522332" type="string" encoding="base64">
           <![CDATA[SW5ub2NlbnQgV2hlbiBZb3UgRHJlYW0=]]>
         </property>
@@ -956,7 +956,7 @@ DebuggerVariable* QuantaDebuggerDBGp::buildVariable( const TQDomNode & variablen
   }
   else if (type == "string")
   {
-    TQCString value = TQCString(variablenode.firstChild().nodeValue());
+    TQCString value = TQCString(variablenode.firstChild().nodeValue().ascii());
     value = KCodecs::base64Decode(value);
     return debuggerInterface()->newDebuggerVariable( name, value, DebuggerVariableTypes::String);
   }
@@ -1021,16 +1021,16 @@ void QuantaDebuggerDBGp::handleError(const TQDomNode & statusnode )
           }
           else
           {
-            emit updateStatus(DebuggerUI::HaltedOnError);
-            debuggerInterface()->showStatus(errornode.firstChild().nodeValue(), true);
+            emit updatetqStatus(DebuggerUI::HaltedOnError);
+            debuggerInterface()->showtqStatus(errornode.firstChild().nodeValue(), true);
           }
           break; 
         }
         else
         {
           // Fatal error
-          emit updateStatus(DebuggerUI::HaltedOnError);
-          debuggerInterface()->showStatus(errornode.firstChild().nodeValue(), true);
+          emit updatetqStatus(DebuggerUI::HaltedOnError);
+          debuggerInterface()->showtqStatus(errornode.firstChild().nodeValue(), true);
         }
       }
       errornode = errornode.nextSibling();
