@@ -67,7 +67,7 @@ void DebuggerManager::slotNewProjectLoaded(const TQString &projectname, const KU
   if(m_client)
   {
     
-    disconnect(m_client, TQT_SIGNAL(updateStatus(DebuggerUI::DebuggerStatus)), m_debuggerui, TQT_SLOT(slotStatus(DebuggerUI::DebuggerStatus)));
+    disconnect(m_client, TQT_SIGNAL(updatetqStatus(DebuggerUI::DebuggertqStatus)), m_debuggerui, TQT_SLOT(slottqStatus(DebuggerUI::DebuggertqStatus)));
 
     delete m_client;
     m_client = NULL;
@@ -108,7 +108,7 @@ void DebuggerManager::slotNewProjectLoaded(const TQString &projectname, const KU
         if(!m_client)
         {
           emit hideSplash();
-          KMessageBox::error(NULL, i18n("<qt>Unable to load the debugger plugin, error code %1 was returned: <b>%2</b>.</qt>").arg(errCode).arg(KLibLoader::self()->lastErrorMessage()), i18n("Debugger Error"));
+          KMessageBox::error(NULL, i18n("<qt>Unable to load the debugger plugin, error code %1 was returned: <b>%2</b>.</qt>").tqarg(errCode).tqarg(KLibLoader::self()->lastErrorMessage()), i18n("Debugger Error"));
         }
         break;
       }
@@ -143,7 +143,7 @@ void DebuggerManager::slotNewProjectLoaded(const TQString &projectname, const KU
 
     // recreate UI
     m_debuggerui = new DebuggerUI(this, "debuggerui");
-    connect(m_client, TQT_SIGNAL(updateStatus(DebuggerUI::DebuggerStatus)), m_debuggerui, TQT_SLOT(slotStatus(DebuggerUI::DebuggerStatus)));
+    connect(m_client, TQT_SIGNAL(updatetqStatus(DebuggerUI::DebuggertqStatus)), m_debuggerui, TQT_SLOT(slottqStatus(DebuggerUI::DebuggertqStatus)));
     
     // Load saved breakpoints
     if(Project::ref()->debuggerPersistentBreakpoints())
@@ -212,7 +212,7 @@ void DebuggerManager::initActions()
     return;
 
   //Debugger, breakpoint
-  newaction = new KAction(i18n("Toggle &Breakpoint"), SmallIcon("debug_breakpoint"), Qt::CTRL+Qt::SHIFT+Qt::Key_B, this, TQT_SLOT(toggleBreakpoint()), ac, "debug_breakpoints_toggle");
+  newaction = new KAction(i18n("Toggle &Breakpoint"), SmallIcon("debug_breakpoint"), TQt::CTRL+TQt::SHIFT+TQt::Key_B, this, TQT_SLOT(toggleBreakpoint()), ac, "debug_breakpoints_toggle");
   newaction->setToolTip(i18n("Toggles a breakpoint at the current cursor location"));
   
   newaction = new KAction(i18n("&Clear Breakpoints"), 0, this, TQT_SLOT(clearBreakpoints()), ac, "debug_breakpoints_clear");
@@ -299,7 +299,7 @@ DebuggerManager::~DebuggerManager()
   if(m_client)
   {
         
-    disconnect(m_client, TQT_SIGNAL(updateStatus(DebuggerUI::DebuggerStatus)), m_debuggerui, TQT_SLOT(slotStatus(DebuggerUI::DebuggerStatus)));
+    disconnect(m_client, TQT_SIGNAL(updatetqStatus(DebuggerUI::DebuggertqStatus)), m_debuggerui, TQT_SLOT(slottqStatus(DebuggerUI::DebuggertqStatus)));
 
     delete m_client;
     m_client = 0L;
@@ -341,8 +341,8 @@ void DebuggerManager::enableAction(const TQString& action, bool enable)
   {
     // The action may or may not exist, depending on capabilities of the debugger plugin
     KActionCollection *ac = quantaApp->actionCollection();
-    if(ac && ac->action(action))
-      ac->action(action)->setEnabled(enable);
+    if(ac && ac->action(action.ascii()))
+      ac->action(action.ascii())->setEnabled(enable);
   }
 }
 
@@ -605,7 +605,7 @@ bool DebuggerManager::setActiveLine (const TQString& file, int line )
     quantaApp->gotoFileAndLine(filename, line, 0);
   else
   {
-    showStatus(i18n("Unable to open file %1, check your basedirs and mappings.").arg(filename), true);
+    showtqStatus(i18n("Unable to open file %1, check your basedirs and mappings.").tqarg(filename), true);
   }
 
   // Add new active line mark
@@ -659,7 +659,7 @@ void DebuggerManager::disconnectBreakpointSignals(Document* qdoc)
 }
 
 // Show a status message and optionally put it on the log
-bool DebuggerManager::showStatus(const TQString& a_message, bool log)
+bool DebuggerManager::showtqStatus(const TQString& a_message, bool log)
 {
   TQString message = a_message;
   quantaApp->slotStatusMsg(m_client->getName() + ": " + message);
