@@ -57,7 +57,7 @@ QuantaDebuggerGubed::QuantaDebuggerGubed (TQObject *parent, const char* name, co
   m_defaultExecutionState = Pause;
   setExecutionState(m_defaultExecutionState);
 
-  emit updateStatus(DebuggerUI::NoSession);
+  emit updatetqStatus(DebuggerUI::NoSession);
   m_datalen = -1;
 }
 
@@ -80,7 +80,7 @@ QuantaDebuggerGubed::~QuantaDebuggerGubed ()
     delete m_server;
     m_server = NULL;
   }
-  emit updateStatus(DebuggerUI::NoSession);
+  emit updatetqStatus(DebuggerUI::NoSession);
 }
 
 // Try to make a connection to the gubed server
@@ -109,7 +109,7 @@ void QuantaDebuggerGubed::startSession()
       debuggerInterface()->enableAction("debug_request", false);
       kdDebug(24002) << k_funcinfo << ", proxy:" << m_serverHost << ", " << m_serverPort.toUInt() << endl;
 
-      emit updateStatus(DebuggerUI::AwaitingConnection);
+      emit updatetqStatus(DebuggerUI::AwaitingConnection);
     }
   }
   else
@@ -123,14 +123,14 @@ void QuantaDebuggerGubed::startSession()
 
       if(m_server->listen())
       {
-        emit updateStatus(DebuggerUI::AwaitingConnection);
+        emit updatetqStatus(DebuggerUI::AwaitingConnection);
         debuggerInterface()->enableAction("debug_connect", false);
         debuggerInterface()->enableAction("debug_disconnect", true);
         debuggerInterface()->enableAction("debug_request", true);
       }
       else
       {
-        emit updateStatus(DebuggerUI::NoSession);
+        emit updatetqStatus(DebuggerUI::NoSession);
         delete m_server;
         m_server = NULL;
         debuggerInterface()->enableAction("debug_connect", true);
@@ -174,7 +174,7 @@ void QuantaDebuggerGubed::endSession()
   debuggerInterface()->enableAction("debug_leap", false);
   debuggerInterface()->enableAction("debug_pause", false);
 
-  emit updateStatus(DebuggerUI::NoSession);
+  emit updatetqStatus(DebuggerUI::NoSession);
 }
 
 // Change executionstate of the script
@@ -185,7 +185,7 @@ void QuantaDebuggerGubed::setExecutionState(State newstate)
     sendCommand("pause", (char*)0L);
     sendCommand("sendactiveline", (char*)0L);
     if(isActive())
-      emit updateStatus(DebuggerUI::Paused);
+      emit updatetqStatus(DebuggerUI::Paused);
   }
   else if(newstate == Run)
   {
@@ -194,7 +194,7 @@ void QuantaDebuggerGubed::setExecutionState(State newstate)
 
     sendCommand("run", (char*)0L);
     if(isActive())
-      emit updateStatus(DebuggerUI::Running);
+      emit updatetqStatus(DebuggerUI::Running);
   }
   else if(newstate == Trace)
   {
@@ -203,7 +203,7 @@ void QuantaDebuggerGubed::setExecutionState(State newstate)
 
     sendCommand("trace", (char*)0L);
     if(isActive())
-      emit updateStatus(DebuggerUI::Tracing);
+      emit updatetqStatus(DebuggerUI::Tracing);
   }
 
   m_executionState = newstate;
@@ -258,15 +258,15 @@ void QuantaDebuggerGubed::slotError(int)
 
     if(m_socket->error())
     {
-      kdDebug(24002) << k_funcinfo << ", " << m_socket->errorString() << endl;
-      debuggerInterface()->showStatus(m_socket->errorString(), false);
+      kdDebug(24002) << k_funcinfo << ", " << m_socket->KSocketBase::errorString() << endl;
+      debuggerInterface()->showtqStatus(m_socket->KSocketBase::errorString(), false);
     }
   }
 
   if(m_server && m_server->error())
   {
     kdDebug(24002) << k_funcinfo << ", " << m_server->errorString() << endl;
-    debuggerInterface()->showStatus(m_server->errorString(), false);
+    debuggerInterface()->showtqStatus(m_server->errorString(), false);
   }
 
 }
@@ -294,7 +294,7 @@ void QuantaDebuggerGubed::slotReadyAccept()
       connect(m_socket, TQT_SIGNAL(readyRead()), this, TQT_SLOT(slotReadyRead()));
       connected();
 
-      emit updateStatus(DebuggerUI::Connected);
+      emit updatetqStatus(DebuggerUI::Connected);
     }
     else
     {
@@ -307,7 +307,7 @@ void QuantaDebuggerGubed::slotReadyAccept()
 // Connection established
 void QuantaDebuggerGubed::slotConnected(const KNetwork::KResolverEntry &)
 {
-  emit updateStatus(DebuggerUI::Connected);
+  emit updatetqStatus(DebuggerUI::Connected);
   connected();
 }
 
@@ -353,7 +353,7 @@ void QuantaDebuggerGubed::slotConnectionClosed()
 
   debuggerInterface()->setActiveLine("", 0);
 
-  emit updateStatus(DebuggerUI::AwaitingConnection);
+  emit updatetqStatus(DebuggerUI::AwaitingConnection);
   m_active = false;
 }
 
@@ -443,11 +443,11 @@ void QuantaDebuggerGubed::processCommand(const TQString& datas)
   else if(m_command == "status")
   {
     long argcnt = args["args"].toLong();
-    TQString msg = i18n(args["message"]);  // How will we get these messages throught to the translators?
+    TQString msg = i18n(args["message"].ascii());  // How will we get these messages throught to the translators?
     for(int cnt = 1; cnt <= argcnt; cnt++)
-      msg.replace("%" + TQString("%1").arg(cnt) + "%", args[TQString("arg%1").arg(cnt)]);
+      msg.replace("%" + TQString("%1").tqarg(cnt) + "%", args[TQString("arg%1").tqarg(cnt)]);
 
-    debuggerInterface()->showStatus(msg, false);
+    debuggerInterface()->showtqStatus(msg, false);
   }
   // New current line
   else if(m_command == "setactiveline")
@@ -462,7 +462,7 @@ void QuantaDebuggerGubed::processCommand(const TQString& datas)
   // Parsing failed
   else if(m_command == "parsefailed")
   {
-    debuggerInterface()->showStatus(i18n("Syntax or parse error in %1)").arg(args["filenme"]), true);
+    debuggerInterface()->showtqStatus(i18n("Syntax or parse error in %1)").tqarg(args["filenme"]), true);
     return;
   }
   // A debugging session is running
@@ -479,7 +479,7 @@ void QuantaDebuggerGubed::processCommand(const TQString& datas)
   else if(m_command == "error")
   {
     // Put the line number first so double clicking will jump to the corrrect line
-    debuggerInterface()->showStatus(i18n("Error occurred: Line %1, Code %2 (%3) in  %4").arg(args["line"]).arg(args["errnum"]).arg(args["errmsg"]).arg(args["filename"]), true);
+    debuggerInterface()->showtqStatus(i18n("Error occurred: Line %1, Code %2 (%3) in  %4").tqarg(args["line"]).tqarg(args["errnum"]).tqarg(args["errmsg"]).tqarg(args["filename"]), true);
 
     // Filter to get error code only and match it with out mask
     long error = args["errnum"].toLong();
@@ -492,21 +492,21 @@ void QuantaDebuggerGubed::processCommand(const TQString& datas)
     else
       setExecutionState(Pause);
 
-    emit updateStatus(DebuggerUI::HaltedOnError);
+    emit updatetqStatus(DebuggerUI::HaltedOnError);
   }
   // We came across  a hard coded breakpoint
   else if(m_command == "forcebreak")
   {
     setExecutionState(Pause);
-    emit updateStatus(DebuggerUI::HaltedOnBreakpoint);
-    debuggerInterface()->showStatus(i18n("Breakpoint reached"), true);
+    emit updatetqStatus(DebuggerUI::HaltedOnBreakpoint);
+    debuggerInterface()->showtqStatus(i18n("Breakpoint reached"), true);
   }
   // A conditional breakpoint was fulfilled
   else if(m_command == "conditionalbreak")
   {
     setExecutionState(Pause);
-    emit updateStatus(DebuggerUI::HaltedOnBreakpoint);
-    debuggerInterface()->showStatus(i18n("Conditional breakpoint fulfilled"), true);
+    emit updatetqStatus(DebuggerUI::HaltedOnBreakpoint);
+    debuggerInterface()->showtqStatus(i18n("Conditional breakpoint fulfilled"), true);
   }
   // There is a breakpoint set in this file/line
   else if(m_command == "removebreakpoint")
@@ -516,7 +516,7 @@ void QuantaDebuggerGubed::processCommand(const TQString& datas)
   // We're about to debug a file..
   else if(m_command == "initialize")
   {
-    debuggerInterface()->showStatus(i18n("Established connection to %1").arg(args["filename"]), false);
+    debuggerInterface()->showtqStatus(i18n("Established connection to %1").tqarg(args["filename"]), false);
     sendCommand("sendprotocolversion", (char*)0L);
 
     debuggerInterface()->setActiveLine(mapServerPathToLocal(args["filename"]), 0);
@@ -549,7 +549,7 @@ void QuantaDebuggerGubed::processCommand(const TQString& datas)
   // Reached en of an include
   else if(m_command == "end")
   {
-    //debuggerInterface()->showStatus(i18n("At end of include %1").arg(data), true);
+    //debuggerInterface()->showtqStatus(i18n("At end of include %1").tqarg(data), true);
     return;
   }
   // Check protocol version
@@ -557,7 +557,7 @@ void QuantaDebuggerGubed::processCommand(const TQString& datas)
   {
     if(args["version"] != protocolversion)
     {
-      debuggerInterface()->showStatus(i18n("The script being debugged does not communicate with the correct protocol version"), true);
+      debuggerInterface()->showtqStatus(i18n("The script being debugged does not communicate with the correct protocol version"), true);
       sendCommand("die", (char*)0L);
     }
     return;
@@ -603,16 +603,16 @@ bool QuantaDebuggerGubed::sendCommand(const TQString& command, StringMap args)
 
   TQString buffer = phpSerialize(args);
 
-  buffer = TQString(command + ":%1;" + buffer).arg(buffer.length());
-  m_socket->writeBlock(buffer, buffer.length());
+  buffer = TQString(command + ":%1;" + buffer).tqarg(buffer.length());
+  m_socket->writeBlock(buffer.ascii(), buffer.length());
   return true;
 }
 
 // Send a command to gubed
-bool QuantaDebuggerGubed::sendCommand(const TQString& command, char * firstarg, ...)
+bool QuantaDebuggerGubed::sendCommand(const TQString& command, const char * firstarg, ...)
 {
   StringMap ca;
-  char *next;
+  const char *next;
 
   va_list l_Arg;
   va_start(l_Arg, firstarg);
@@ -995,7 +995,7 @@ TQString QuantaDebuggerGubed::phpSerialize(StringMap args)
 {
   StringMap::Iterator it;
   // a:2:{s:4:"name";s:7:"Jessica";s:3:"age";s:2:"26";s:4:"test";i:1;}
-  TQString ret = TQString("a:%1:{").arg(args.size());
+  TQString ret = TQString("a:%1:{").tqarg(args.size());
   for( it = args.begin(); it != args.end(); ++it )
   {
     bool isNumber;
@@ -1003,15 +1003,15 @@ TQString QuantaDebuggerGubed::phpSerialize(StringMap args)
     it.data().toInt(&isNumber);
     if(isNumber && !it.data().isEmpty())
       ret += TQString("s:%1:\"%2\";i:%3;")
-                    .arg(it.key().length())
-                    .arg(it.key())
-                    .arg(it.data());
+                    .tqarg(it.key().length())
+                    .tqarg(it.key())
+                    .tqarg(it.data());
     else
       ret += TQString("s:%1:\"%2\";s:%3:\"%4\";")
-                    .arg(it.key().length())
-                    .arg(it.key())
-                    .arg(it.data().length())
-                    .arg(it.data());
+                    .tqarg(it.key().length())
+                    .tqarg(it.key())
+                    .tqarg(it.data().length())
+                    .tqarg(it.data());
 
   }
 
