@@ -103,7 +103,7 @@ ActionConfigDialog::ActionConfigDialog(const TQDict<ToolbarEntry> &toolbarList,
       {
         if (node.nodeName() == "Action")
         {
-          action = ac->action(node.toElement().attribute("name"));
+          action = ac->action(node.toElement().attribute("name").ascii());
           if (action)
           {
             oldActionItem = new KListViewItem(item, oldActionItem, action->text().replace(r,""), action->shortcut().toString(), action->name());
@@ -190,7 +190,7 @@ void ActionConfigDialog::slotRemoveToolbar()
   }
   if (s != i18n("All"))
   {
-      if ( KMessageBox::warningContinueCancel(this, i18n("Do you really want to remove the \"%1\" toolbar?").arg(s),TQString::null,KStdGuiItem::del()) == KMessageBox::Continue )
+      if ( KMessageBox::warningContinueCancel(this, i18n("Do you really want to remove the \"%1\" toolbar?").tqarg(s),TQString(),KStdGuiItem::del()) == KMessageBox::Continue )
     {
       m_toolbarItem = item;
       connect(m_mainWindow, TQT_SIGNAL(toolbarRemoved(const TQString&)), TQT_SLOT(slotToolbarRemoved(const TQString&)));
@@ -240,7 +240,7 @@ void ActionConfigDialog::slotEditToolbar()
         {
           if (node.nodeName() == "Action")
           {
-            action = ac->action(node.toElement().attribute("name"));
+            action = ac->action(node.toElement().attribute("name").ascii());
             if (action)
             {
               oldItem = new KListViewItem(item, oldItem, action->text().replace(TQRegExp("\\&(?!\\&)"),""), action->shortcut().toString(), action->name());
@@ -266,7 +266,7 @@ void ActionConfigDialog::slotSelectionChanged(TQListViewItem *item)
   if (currentAction && currentAction->inherits("TagAction"))
   {
     if ( buttonApply->isEnabled() &&
-         KMessageBox::questionYesNo(this, i18n("Do you want to save the changes made to this action?"), TQString::null, KStdGuiItem::save(), KStdGuiItem::discard()) == KMessageBox::Yes )
+         KMessageBox::questionYesNo(this, i18n("Do you want to save the changes made to this action?"), TQString(), KStdGuiItem::save(), KStdGuiItem::discard()) == KMessageBox::Yes )
     {
       saveCurrentAction();
     }
@@ -618,7 +618,7 @@ void ActionConfigDialog::saveCurrentAction()
     if (p_toolbar)
     {
       TQDomNode node = p_toolbar->guiClient->domDocument().firstChild().firstChild().firstChild();
-      bool placeOnToolbar = toolbarListBox->findItem(toolbarName, Qt::ExactMatch);
+      bool placeOnToolbar = toolbarListBox->findItem(toolbarName, TQt::ExactMatch);
       while (!node.isNull())
       {
         if (node.nodeName() == "Action" &&
@@ -682,7 +682,7 @@ void ActionConfigDialog::saveCurrentAction()
         p_toolbar->guiClient->xmlFile(), p_toolbar->guiClient->instance());
     }
     TQWidget *toolBar = tb->page(i);
-    if (toolBar->minimumSizeHint().height() > 20)
+    if (toolBar->tqminimumSizeHint().height() > 20)
     {
       toolBar->adjustSize();
       toolBar->setGeometry(0,0, tb->width(), toolBar->height());
@@ -765,7 +765,7 @@ void ActionConfigDialog::slotShortcutCaptured(const KShortcut &shortcut)
     TQString s =  i18n("The '%1' key combination has already been allocated "
                 "to the \"%2\" action.\n"
                 "Please choose a unique key combination.").
-                arg(shortcutText).arg(global);
+                tqarg(shortcutText).tqarg(global);
     KMessageBox::sorry( this, s, i18n("Conflicting Shortcuts"));
   }
 }
@@ -779,7 +779,7 @@ void ActionConfigDialog::accept()
 
 void ActionConfigDialog::reject()
 {
-  if (buttonApply->isEnabled() && KMessageBox::questionYesNo(this, i18n("Do you want to save the changes made to this action?"), TQString::null, KStdGuiItem::save(), KStdGuiItem::discard()) == KMessageBox::Yes  )
+  if (buttonApply->isEnabled() && KMessageBox::questionYesNo(this, i18n("Do you want to save the changes made to this action?"), TQString(), KStdGuiItem::save(), KStdGuiItem::discard()) == KMessageBox::Yes  )
       saveCurrentAction();
   ActionConfigDialogS::reject();
 }
@@ -805,7 +805,7 @@ void ActionConfigDialog::slotNewAction()
   static_cast<TagAction*>(currentAction)->setModified(true);
   TQListViewItem *currentItem = actionTreeView->currentItem();
   TQListViewItem *item = new KListViewItem(allActionsItem);
-  TQString actionText = TQString("Action_%1").arg(m_mainWindow->actionCollection()->count());
+  TQString actionText = TQString("Action_%1").tqarg(m_mainWindow->actionCollection()->count());
   currentAction->setText(actionText);
   item->setText(2, currentAction->name());
   item->setText(0, actionText);
@@ -838,7 +838,7 @@ void ActionConfigDialog::slotNewAction()
 
 void ActionConfigDialog::slotDeleteAction()
 {
-    if ( KMessageBox::warningContinueCancel(this, i18n("<qt>Removing the action removes all the references to it.\nAre you sure you want to remove the <b>%1</b> action?</qt>").arg(currentAction->text()),TQString::null,KStdGuiItem::del()) == KMessageBox::Continue )
+    if ( KMessageBox::warningContinueCancel(this, i18n("<qt>Removing the action removes all the references to it.\nAre you sure you want to remove the <b>%1</b> action?</qt>").tqarg(currentAction->text()),TQString(),KStdGuiItem::del()) == KMessageBox::Continue )
   {
     TQString actionName = currentAction->name();
     emit deleteUserAction(currentAction);
@@ -876,7 +876,7 @@ void ActionConfigDialog::slotAddContainerToolbar()
   TQStringList lst;
   for (i = 0; i < tb->count(); i++)
   {
-    if (!toolbarListBox->findItem(tb->label(i), Qt::ExactMatch))
+    if (!toolbarListBox->findItem(tb->label(i), TQt::ExactMatch))
         lst << tb->label(i);
   }
 
