@@ -113,9 +113,9 @@ void DTEPEditDlg::readGeneral()
 void DTEPEditDlg::readPages()
 {
   int i = 1;
-  while (m_config->hasGroup(TQString("Page%1").arg(i)) && i < 6)
+  while (m_config->hasGroup(TQString("Page%1").tqarg(i)) && i < 6)
   {
-    m_config->setGroup(TQString("Page%1").arg(i));
+    m_config->setGroup(TQString("Page%1").tqarg(i));
     TQString title = m_config->readEntry("Title");
     TQString groups = m_config->readEntry("Groups");
     if (i == 1)
@@ -203,7 +203,7 @@ void DTEPEditDlg::saveResult()
   {
     if (f.exists())
     {
-      if (KMessageBox::questionYesNo(this, i18n("<qt>The file <b>%1</b> is not writable.<br>Do you want to save the configuration to a different file?</qt>").arg(f.filePath()),i18n("Save As"),i18n("Save to Different File"), i18n("Do Not Save")) == KMessageBox::Yes)
+      if (KMessageBox::questionYesNo(this, i18n("<qt>The file <b>%1</b> is not writable.<br>Do you want to save the configuration to a different file?</qt>").tqarg(f.filePath()),i18n("Save As"),i18n("Save to Different File"), i18n("Do Not Save")) == KMessageBox::Yes)
       {
         targetFile = KFileDialog::getSaveFileName(locateLocal("data", resourceDir + "dtep/description.rc"), i18n("*.rc|DTEP Description"), this, i18n("Save Description As"));
       } else
@@ -255,35 +255,35 @@ void DTEPEditDlg::writePages(KConfig *config)
     if (enablePage1->isChecked())
     {
       num++;
-      config->setGroup(TQString("Page%1").arg(num));
+      config->setGroup(TQString("Page%1").tqarg(num));
       writeEntry(config, "Title", pageTitleEdit1->text());
       writeEntry(config, "Groups", groupsEdit1->text());
     }
     if (enablePage2->isChecked())
     {
       num++;
-      config->setGroup(TQString("Page%1").arg(num));
+      config->setGroup(TQString("Page%1").tqarg(num));
       writeEntry(config, "Title", pageTitleEdit2->text());
       writeEntry(config, "Groups", groupsEdit2->text());
     }
     if (enablePage3->isChecked())
     {
       num++;
-      config->setGroup(TQString("Page%1").arg(num));
+      config->setGroup(TQString("Page%1").tqarg(num));
       writeEntry(config, "Title", pageTitleEdit3->text());
       writeEntry(config, "Groups", groupsEdit3->text());
     }
     if (enablePage4->isChecked())
     {
       num++;
-      config->setGroup(TQString("Page%1").arg(num));
+      config->setGroup(TQString("Page%1").tqarg(num));
       writeEntry(config, "Title", pageTitleEdit4->text());
       writeEntry(config, "Groups", groupsEdit4->text());
     }
     if (enablePage5->isChecked())
     {
       num++;
-      config->setGroup(TQString("Page%1").arg(num));
+      config->setGroup(TQString("Page%1").tqarg(num));
       writeEntry(config, "Title", pageTitleEdit5->text());
       writeEntry(config, "Groups", groupsEdit5->text());
     }
@@ -343,10 +343,10 @@ void DTEPEditDlg::readStructures()
   int objectGroupId = m_config->readNumEntry("ObjectGroupIndex", -1);
 
   int i = 1;
-  while (m_config->hasGroup(TQString("StructGroup_%1").arg(i)))
+  while (m_config->hasGroup(TQString("StructGroup_%1").tqarg(i)))
   {
     StructGroup group;
-    m_config->setGroup(TQString("StructGroup_%1").arg(i));
+    m_config->setGroup(TQString("StructGroup_%1").tqarg(i));
     group.name = m_config->readEntry("Name");
     group.noName = m_config->readEntry("No_Name");
     group.icon = m_config->readEntry("Icon");
@@ -387,7 +387,7 @@ void DTEPEditDlg::writeStructures(KConfig *config)
   for (TQValueList<StructGroup>::ConstIterator it = m_structGroups.constBegin(); it != m_structGroups.constEnd(); ++it)
   {
     StructGroup group = *it;
-    config->setGroup(TQString("StructGroup_%1").arg(i));
+    config->setGroup(TQString("StructGroup_%1").tqarg(i));
     writeEntry(config, "Name", group.name);
     writeEntry(config, "No_Name", group.noName);
     writeEntry(config, "Icon", group.icon);
@@ -536,7 +536,7 @@ void DTEPEditDlg::slotDeleteStructGroup()
   int currentItem = structuresList->currentItem();
   if (currentItem != -1)
   {
-      if (KMessageBox::warningContinueCancel(this, i18n("<qt>Do you really want to delete the <b>%1</b> group?</qt>").arg(structuresList->currentText()), i18n("Delete Group"),KStdGuiItem::del()) == KMessageBox::Continue)
+      if (KMessageBox::warningContinueCancel(this, i18n("<qt>Do you really want to delete the <b>%1</b> group?</qt>").tqarg(structuresList->currentText()), i18n("Delete Group"),KStdGuiItem::del()) == KMessageBox::Continue)
     {
       m_structGroups.remove(m_structGroups.at(currentItem));
       structuresList->removeItem(currentItem);
