@@ -121,7 +121,7 @@ Node *Parser::parseArea(int startLine, int startCol, int endLine, int endCol, No
       currentNode->tag->single))
       parentNode = currentNode->parent;
   Tag *tag = 0L;
-  QTag *qTag = 0L;
+  TQTag *qTag = 0L;
   textLine.append(write->text(startLine, startCol, startLine, write->editIf->lineLength(startLine)));
   if (line == endLine)
   {
@@ -860,7 +860,7 @@ void Parser::deleteNodes(Node *firstNode, Node *lastNode, NodeModifsSet *modifs)
     j = 0;
     if (!closesPrevious)
     {
-      //move the children up one level
+      //move the tqchildren up one level
       Node *n = child;
       Node *m = child;
       while (n)
@@ -900,7 +900,7 @@ void Parser::deleteNodes(Node *firstNode, Node *lastNode, NodeModifsSet *modifs)
       }
     } else
     {
-      //change the parent of children, so the prev will be the new parent
+      //change the parent of tqchildren, so the prev will be the new parent
       if (child)
       {
         Node *n = child;
@@ -928,7 +928,7 @@ void Parser::deleteNodes(Node *firstNode, Node *lastNode, NodeModifsSet *modifs)
           prev->child = child;
         }
       }
-      //move down the nodes starting with next one level and append to the list of children of prev
+      //move down the nodes starting with next one level and append to the list of tqchildren of prev
       if (next)
       {
         if (prev->child) //if the previous node has a child, append the next node after the last child
@@ -1020,7 +1020,7 @@ Node *Parser::rebuild(Document *w)
        return n;
    }
 
-   kdDebug(24000) << TQString("Invalid area: %1,%2,%3,%4").arg(area.bLine).arg(area.bCol).arg(area.eLine).arg(area.eCol) << "\n";
+   kdDebug(24000) << TQString("Invalid area: %1,%2,%3,%4").tqarg(area.bLine).tqarg(area.bCol).tqarg(area.eLine).tqarg(area.eCol) << "\n";
 
 //    kdDebug(24000) << "lastNode1: " << lastNode << " " << lastNode->tag << endl;
    deleteNodes(firstNode->nextSibling(), lastNode, modifs);
@@ -1127,7 +1127,7 @@ Node *Parser::rebuild(Document *w)
     node = lastInserted;
 
 //     kdDebug(24000) << "lastNode5: " << lastNode << " " << lastNode->tag << endl;
-    QTag *qTag = 0L;
+    TQTag *qTag = 0L;
     while (node && lastNode)
     {
 //       kdDebug(24000) << "lastNode6: " << lastNode << " " << lastNode->tag << endl;
@@ -1422,7 +1422,7 @@ void Parser::parseIncludedFile(const TQString& fileName, const DTDStruct *dtd)
       encoding = encodingIf->encoding();
     if (encoding.isEmpty())
       encoding = "utf8";  //final fallback
-    str.setCodec(TQTextCodec::codecForName(encoding));
+    str.setCodec(TQTextCodec::codecForName(encoding.ascii()));
     content = str.read();
     file.close();
     if (dtd->specialAreas.count())
@@ -1585,7 +1585,7 @@ void Parser::parseIncludedFile(const TQString& fileName, const DTDStruct *dtd)
                     
                     if (group.appendToTags)
                     {
-                      QTag *qTag = new QTag();
+                      TQTag *qTag = new TQTag();
                       qTag->setName(s.left(s.find('(')));
                       qTag->className = "";
                       if (groupElement->parentNode)
