@@ -69,7 +69,7 @@ htmlDocumentProperties::htmlDocumentProperties( TQWidget* parent, bool forceInse
 	ok->setAutoDefault(true);
 
 	//set the taborder and disable focus for some widgets.
-	currentDTD->setFocusPolicy(TQWidget::NoFocus);
+	currentDTD->setFocusPolicy(TQ_NoFocus);
 	TQWidget::setTabOrder(title, metaItems);
 	TQWidget::setTabOrder(metaItems, metaItemsAdd);
 	TQWidget::setTabOrder(metaItemsAdd, metaItemsDelete);
@@ -98,7 +98,7 @@ htmlDocumentProperties::htmlDocumentProperties( TQWidget* parent, bool forceInse
 	cssRules->addColumn(i18n("Rule"));
 	cssRules->setFrameStyle( TQFrame::Panel | TQFrame::Sunken );
 	cssRules->setLineWidth( 2 );
-	//cssRules->setFocusPolicy(TQWidget::ClickFocus);
+	//cssRules->setFocusPolicy(TQ_ClickFocus);
 	cssRules->setSorting(-1);
 
 	//search for the head, html, title Node
@@ -594,7 +594,7 @@ void htmlDocumentProperties::addBasicNodes(NodeModifsSet *modifs)
 	Node *allTheNodes, *lastHeadChild, *lastBodyChild, *lastHtmlChild;
 	Node *n, *nextNode;
 	bool htmlNodeCreated = false, bodyNodeCreated = false;
-	QTag *qHead, *qBody;
+	TQTag *qHead, *qBody;
 	TQString tagName;
 
 	if(headNode)
