@@ -51,7 +51,7 @@ NodeModif::NodeModif()
   m_type = -1;
   m_node = 0L;
   m_tag = 0L;
-  m_childrenMovedUp = 0;
+  m_tqchildrenMovedUp = 0;
   m_neighboursMovedDown = 0;
 }
 
@@ -1477,7 +1477,7 @@ void undoRedo::debugOutput()
         " - contents: " << (*it2)->tag()->tagStr() << endl;
       if(((*it2)->type() == NodeModif::NodeRemoved && !afterEditorIt) ||
           ((*it2)->type() == NodeModif::NodeAdded && afterEditorIt))
-        kdDebug(24000)<< "==== ChildsNumber1 : " << (*it2)->childrenMovedUp() <<
+        kdDebug(24000)<< "==== ChildsNumber1 : " << (*it2)->tqchildrenMovedUp() <<
         " - ChildsNumber2 : " << (*it2)->neighboursMovedDown() << endl;
     }
     kdDebug(24000)<< "== End Node Modifications set #" << i << endl;
