@@ -428,7 +428,7 @@ kNodeAttrs* KafkaDocument::connectDomNodeToQuantaNode(DOM::Node domNode, Node *n
 	else
 	{
 		kdDebug(25001)<< "KafkaDocument::connectDomNodeToQuantaNode () - " <<
-			"No QTag found! Setting default parameters..." << endl;
+			"No TQTag found! Setting default parameters..." << endl;
 		props->setCHCursorFocus(kNodeAttrs::no);
 		props->setCCEnter(false);
 		props->setCBModified(false);
@@ -527,7 +527,7 @@ bool KafkaDocument::buildKafkaNodeFromNode(Node *node, bool insertNode)
             canInsertEmptyNode = kafkaCommon::hasParent(node, "body");
 
         Node* parent_node = node->parent;
-        QTag* parent_node_description_tag = QuantaCommon::tagFromDTD(parent_node);
+        TQTag* parent_node_description_tag = QuantaCommon::tagFromDTD(parent_node);
         if(parent_node_description_tag && !parent_node_description_tag->isChild(node, false, true))
             canInsertEmptyNode = false;
     }
@@ -734,7 +734,7 @@ bool KafkaDocument::buildKafkaNodeFromNode(Node *node, bool insertNode)
 			node->setLeafNode(ptDomNode);
 			mainEnhancer->enhanceNode(node, parentNode, nextNode);
 
-            QTag* qTag = QuantaCommon::tagFromDTD(getCurrentDoc()->defaultDTD(),
+            TQTag* qTag = QuantaCommon::tagFromDTD(getCurrentDoc()->defaultDTD(),
                     parentNode.nodeName().string());
 
             if(qTag && qTag->isChild(node, false))
@@ -1932,7 +1932,7 @@ void KafkaDocument::slotDomNodeModified(DOM::Node domNode, NodeModifsSet* modifs
 	kNodeAttrs *props, *newProps;
 	DOM::Node newDomNode, parentDomNode, nextSiblingDomNode;
 	DOM::Node *ptDomNode;
-	QTag *qTag;
+	TQTag *qTag;
 
 #ifdef LIGHT_DEBUG
 	TQTime t;
@@ -2328,7 +2328,7 @@ void KafkaDocument::slotCut(Node* startNode, int startOffset, Node* endNode, int
         drag_object->addDragObject(node_drag);
         drag_object->addDragObject(text_drag);
 
-        TQApplication::clipboard()->setData(drag_object);
+        TQApplication::tqclipboard()->setData(drag_object);
 #ifdef LIGHT_DEBUG
         kafkaCommon::coutTree(subtree_root, 3);
 #endif
@@ -2365,7 +2365,7 @@ void KafkaDocument::slotCopy(Node* startNode, int startOffset, Node* endNode, in
         drag_object->addDragObject(node_drag);
         drag_object->addDragObject(text_drag);
 
-        TQApplication::clipboard()->setData(drag_object);
+        TQApplication::tqclipboard()->setData(drag_object);
         // FIXME delete the subtree
 #ifdef LIGHT_DEBUG
         kafkaCommon::coutTree(subtree_root, 3);
@@ -2375,7 +2375,7 @@ void KafkaDocument::slotCopy(Node* startNode, int startOffset, Node* endNode, in
 
 void KafkaDocument::slotPaste()
 {
-    QClipboard *cb = TQApplication::clipboard();
+    TQClipboard *cb = TQApplication::tqclipboard();
     TQMimeSource* e = cb->data();
     Node* node = new Node(0);
 
