@@ -109,7 +109,7 @@ KURL::List Project::files()
   return list;
 }
 
-void Project::insertFile(const KURL& nameURL, bool repaint )
+void Project::insertFile(const KURL& nameURL, bool tqrepaint )
 {
   if (d->excludeRx.exactMatch(nameURL.path()))
       return;
@@ -118,7 +118,7 @@ void Project::insertFile(const KURL& nameURL, bool repaint )
   if ( !d->baseURL.isParentOf(url) )
   {
     KURLRequesterDlg *urlRequesterDlg = new KURLRequesterDlg( d->baseURL.prettyURL(), d->m_mainWindow, "");
-    urlRequesterDlg->setCaption(i18n("%1: Copy to Project").arg(nameURL.prettyURL(0, KURL::StripFileProtocol)));
+    urlRequesterDlg->setCaption(i18n("%1: Copy to Project").tqarg(nameURL.prettyURL(0, KURL::StripFileProtocol)));
     urlRequesterDlg->urlRequester()->setMode( KFile::Directory | KFile::ExistingOnly);
     urlRequesterDlg->exec();
     KURL destination = urlRequesterDlg->selectedURL();
@@ -150,19 +150,19 @@ void Project::insertFile(const KURL& nameURL, bool repaint )
       d->dom.firstChild().firstChild().appendChild( el );
       KURL u = url.upURL();
       ProjectURL *parentURL = d->m_projectFiles.find(u);
-      int uploadStatus = 1;
+      int uploadtqStatus = 1;
       if (parentURL)
-        uploadStatus = parentURL->uploadStatus;
-      d->m_projectFiles.insert( new ProjectURL(url, "", uploadStatus, false, el) );
+        uploadtqStatus = parentURL->uploadtqStatus;
+      d->m_projectFiles.insert( new ProjectURL(url, "", uploadtqStatus, false, el) );
     }
     url.setPath(url.directory(false));
   }
-  emit eventHappened("after_project_add", url.url(), TQString::null);
+  emit eventHappened("after_project_add", url.url(), TQString());
   setModified();
-  if ( repaint )
+  if ( tqrepaint )
   {
     emit reloadTree( &(d->m_projectFiles), false, TQStringList());
-    emit newStatus();
+    emit newtqStatus();
   }
 }
 
@@ -213,7 +213,7 @@ void Project::loadLastProject(bool reload)
     {
       KURL tempURL = KURL().fromPathOrURL(tempPath);
       if (KIO::NetAccess::exists(tempURL, false, d->m_mainWindow) &&
-          KMessageBox::questionYesNo(d->m_mainWindow, i18n("<qt>Found a backup for project <b>%1</b>.<br> Do you want to open it?</qt>").arg(url.prettyURL()), i18n("Open Project Backup"), KStdGuiItem::open(), i18n("Do Not Open") )
+          KMessageBox::questionYesNo(d->m_mainWindow, i18n("<qt>Found a backup for project <b>%1</b>.<br> Do you want to open it?</qt>").tqarg(url.prettyURL()), i18n("Open Project Backup"), KStdGuiItem::open(), i18n("Do Not Open") )
           == KMessageBox::Yes)
       {
         d->m_tmpProjectFile = tempPath;
@@ -262,7 +262,7 @@ void Project::slotOpenProject(const KURL &url)
     {
       emit hideSplash();
       if (KMessageBox::questionYesNo(d->m_mainWindow,
-           i18n("<qt>The file <b>%1</b> does not exist.<br> Do you want to remove it from the list?</qt>").arg(url.prettyURL(0, KURL::StripFileProtocol)), TQString::null, KStdGuiItem::del(), i18n("Keep") )
+           i18n("<qt>The file <b>%1</b> does not exist.<br> Do you want to remove it from the list?</qt>").tqarg(url.prettyURL(0, KURL::StripFileProtocol)), TQString(), KStdGuiItem::del(), i18n("Keep") )
            == KMessageBox::Yes)
       {
         d->m_projectRecent->removeURL(url);
@@ -271,7 +271,7 @@ void Project::slotOpenProject(const KURL &url)
     } else
     {
       d->loadProject ( url );
-      emit eventHappened("after_project_open", url.url(), TQString::null);
+      emit eventHappened("after_project_open", url.url(), TQString());
     }
   }
 }
@@ -297,7 +297,7 @@ void Project::slotAddDirectory(const KURL& p_dirURL, bool showDlg)
       if (showDlg)
       {
         KURLRequesterDlg *urlRequesterDlg = new KURLRequesterDlg( d->baseURL.prettyURL(), d->m_mainWindow, "");
-        urlRequesterDlg->setCaption(i18n("%1: Copy to Project").arg(dirURL.prettyURL(0, KURL::StripFileProtocol)));
+        urlRequesterDlg->setCaption(i18n("%1: Copy to Project").tqarg(dirURL.prettyURL(0, KURL::StripFileProtocol)));
         urlRequesterDlg->urlRequester()->setMode( KFile::Directory | KFile::ExistingOnly);
         urlRequesterDlg->exec();
         destination = urlRequesterDlg->selectedURL();
@@ -379,12 +379,12 @@ void Project::slotRenamed(const KURL& oldURL, const KURL& newURL)
   progressBar->setValue(0);
   progressBar->setTextEnabled(false);
 
-  emit statusMsg(TQString::null);
+  emit statusMsg(TQString());
   if (d->m_modified)
     setModified();  // there happens more than setting the flag !
 
   emit reloadTree(&(d->m_projectFiles), false, TQStringList());
-  emit newStatus();
+  emit newtqStatus();
 }
 
 
@@ -406,7 +406,7 @@ void Project::slotRemove(const KURL& urlToRemove)
     {
       d->m_projectFiles.removeFromListAndXML(url);
       d->m_modified = true;
-      emit eventHappened("after_project_remove", url.url(), TQString::null);
+      emit eventHappened("after_project_remove", url.url(), TQString());
       if (!isFolder)
         break;
     }
@@ -417,17 +417,17 @@ void Project::slotRemove(const KURL& urlToRemove)
   progressBar->setValue(0);
   progressBar->setTextEnabled(false);
 
-  emit statusMsg(TQString::null);
+  emit statusMsg(TQString());
 
   if (d->m_modified)
     setModified();  // there happens more than setting the flag !
   emit reloadTree( &(d->m_projectFiles), false, TQStringList() );
-  emit newStatus();
+  emit newtqStatus();
 
   TQString urlPath = QExtFileInfo::toRelative(urlToRemove, d->baseURL).path();
   TQString nice = urlPath;
   nice = KStringHandler::lsqueeze(nice, 60);
-  if (KMessageBox::warningContinueCancel(d->m_mainWindow, i18n("<qt>Do you want to remove <br><b>%1</b><br> from the server(s) as well?</qt>").arg(nice), i18n("Remove From Server"), KStdGuiItem::remove(), "RemoveFromServer") == KMessageBox::Continue )
+  if (KMessageBox::warningContinueCancel(d->m_mainWindow, i18n("<qt>Do you want to remove <br><b>%1</b><br> from the server(s) as well?</qt>").tqarg(nice), i18n("Remove From Server"), KStdGuiItem::remove(), "RemoveFromServer") == KMessageBox::Continue )
   {
     TQDomNode profilesNode = d->m_sessionDom.firstChild().firstChild().namedItem("uploadprofiles");
     TQDomNodeList profileList = profilesNode.toElement().elementsByTagName("profile");
@@ -862,7 +862,7 @@ void Project::slotUpload()
 
   if (!d->m_uploadDialog)
   {
-    d->m_uploadDialog = new ProjectUpload(KURL(), "", false, false, false, i18n("Upload project items..."));
+    d->m_uploadDialog = new ProjectUpload(KURL(), "", false, false, false, i18n("Upload project items...").ascii());
     connect(d->m_uploadDialog, TQT_SIGNAL(eventHappened(const TQString&, const TQString&, const TQString& )), this, TQT_SIGNAL(eventHappened(const TQString&, const TQString&, const TQString& )));
     d->m_uploadDialog->show();
   } else
@@ -877,7 +877,7 @@ void Project::slotUploadURL(const KURL& urlToUpload, const TQString& profileName
   KURL url = QExtFileInfo::toRelative( urlToUpload, d->baseURL);
   if (!d->m_uploadDialog)
   {
-    d->m_uploadDialog = new ProjectUpload(url, profileName, false, quickUpload, markOnly, i18n("Upload project items..."));
+    d->m_uploadDialog = new ProjectUpload(url, profileName, false, quickUpload, markOnly, i18n("Upload project items...").ascii());
     connect(d->m_uploadDialog, TQT_SIGNAL(eventHappened(const TQString&, const TQString&, const TQString& )), this, TQT_SIGNAL(eventHappened(const TQString&, const TQString&, const TQString& )));
     d->m_uploadDialog->show();
   } else
@@ -893,7 +893,7 @@ void Project::slotGetMessages(const TQString& data)
 void Project::slotRescanPrjDir()
 {
   RescanPrj *dlg = new RescanPrj( d->m_projectFiles, d->baseURL, d->excludeRx,
-                                    d->m_mainWindow, i18n("New Files in Project's Folder"));
+                                    d->m_mainWindow, i18n("New Files in Project's Folder").ascii());
   if ( dlg->exec() )
   {
     d->insertFiles(dlg->files());
@@ -952,7 +952,7 @@ void Project::slotUploadStatusChanged(const KURL& url, int status)
   {
     if ( it.currentKey().startsWith(urlStr) || it.currentKey() + "/" == urlStr)
     {
-      it.current()->uploadStatus = status;
+      it.current()->uploadtqStatus = status;
       el = it.current()->domElement;
       el.setAttribute("uploadstatus", status);
     }
@@ -960,7 +960,7 @@ void Project::slotUploadStatusChanged(const KURL& url, int status)
   setModified();
 }
 
-void Project::slotChangeDocumentFolderStatus(const KURL &url, bool status)
+void Project::slotChangeDocumentFoldertqStatus(const KURL &url, bool status)
 {
   ProjectURL *proUrl = d->m_projectFiles.find(url);
   if (! proUrl)
@@ -1257,7 +1257,7 @@ bool Project::queryClose()
   bool canExit = true;
   if (hasProject())
   {
-    emit eventHappened("before_project_close", d->baseURL.url(), TQString::null);
+    emit eventHappened("before_project_close", d->baseURL.url(), TQString());
     d->config->setGroup("Projects");
     KURL url = d->projectURL.url();
     url.setPass("");
@@ -1270,7 +1270,7 @@ bool Project::queryClose()
     }
     if (canExit)
     {
-      emit eventHappened("after_project_close", d->baseURL.url(), TQString::null);
+      emit eventHappened("after_project_close", d->baseURL.url(), TQString());
   // empty dom tree
       d->dom.clear();
       d->m_sessionDom.clear();
@@ -1280,7 +1280,7 @@ bool Project::queryClose()
       reloadTree( &(d->m_projectFiles), true, TQStringList());
       d->adjustActions();
       d->m_projectRecent->setCurrentItem(-1);
-      newStatus();
+      newtqStatus();
 //      kapp->processEvents(TQEventLoop::ExcludeUserInput | TQEventLoop::ExcludeSocketNotifiers);
     }
   }
@@ -1345,7 +1345,7 @@ void Project::saveBookmarks(const KURL &url, KTextEditor::MarkInterface *markIf)
   {
     KTextEditor::Mark *mark = marks.at(i);
     if (mark->type == KTextEditor::MarkInterface::Bookmark)
-          markList << TQString("%1").arg(mark->line);
+          markList << TQString("%1").tqarg(mark->line);
   }
   TQDomNodeList nl = d->dom.elementsByTagName("item");
   TQDomElement el;
