@@ -144,12 +144,12 @@ void ProjectPrivate::initActions(KActionCollection *ac)
 
   saveAsProjectTemplateAction =
             new KAction( i18n( "Save as Project Template..." ), 0,
-                        m_mainWindow, TQT_SLOT( slotFileSaveAsProjectTemplate() ),
+                        TQT_TQOBJECT(m_mainWindow), TQT_SLOT( slotFileSaveAsProjectTemplate() ),
                         ac, "save_project_template" );
 
   saveSelectionAsProjectTemplateAction =
                         new KAction( i18n( "Save Selection to Project Template File..." ), 0,
-                                    m_mainWindow, TQT_SLOT( slotFileSaveSelectionAsProjectTemplate() ),
+                                    TQT_TQOBJECT(m_mainWindow), TQT_SLOT( slotFileSaveSelectionAsProjectTemplate() ),
                                     ac, "save_selection_project_template" );
   adjustActions();
 }
@@ -211,7 +211,7 @@ void ProjectPrivate::init()
 {
   projectURL  = KURL();
   templateURL = KURL();
-  projectName = TQString::null;
+  projectName = TQString();
   m_modified = false;
   m_defaultDTD = qConfig.defaultDocType;
   excludeRx.setPattern(".*~$");
@@ -223,11 +223,11 @@ void ProjectPrivate::init()
   m_debuggerPersistentBreakpoints = false;
   m_debuggerPersistentWatches = false;
   m_excludeCvsignore = false;
-  currentProjectView = TQString::null;
+  currentProjectView = TQString();
   m_projectFiles.clear();
-  m_mailingList = TQString::null;
-  m_teamLeader.name = TQString::null;
-  m_teamLeader.email = TQString::null;
+  m_mailingList = TQString();
+  m_teamLeader.name = TQString();
+  m_teamLeader.email = TQString();
   m_taskLeaders.clear();
   m_subprojectLeaders.clear();
   m_subprojects.clear();
@@ -328,7 +328,7 @@ void ProjectPrivate::insertFiles( KURL::List files )
           el.setAttribute("url", QuantaCommon::qUrl(QExtFileInfo::toRelative(url, baseURL, false)));
           dom.firstChild().firstChild().appendChild(el);
           m_projectFiles.insert( new ProjectURL(url, "", 1, false, el) );
-          emit eventHappened("after_project_add", url.url(), TQString::null);
+          emit eventHappened("after_project_add", url.url(), TQString());
           m_modified = true;
         }
         url.setPath(url.directory(false));
@@ -340,7 +340,7 @@ void ProjectPrivate::insertFiles( KURL::List files )
         el.setAttribute("url", QuantaCommon::qUrl(QExtFileInfo::toRelative(url, baseURL, false)));
         dom.firstChild().firstChild().appendChild(el);
         m_projectFiles.insert( new ProjectURL(url, "", 1, false, el) );
-        emit eventHappened("after_project_add", url.url(), TQString::null);
+        emit eventHappened("after_project_add", url.url(), TQString());
         m_modified = true;
       }
     }
@@ -351,8 +351,8 @@ void ProjectPrivate::insertFiles( KURL::List files )
   progressBar->setTextEnabled(false);
 
   parent->reloadTree(&(m_projectFiles), false, TQStringList());
-  parent->newStatus();
-  parent->statusMsg(TQString::null);
+  parent->newtqStatus();
+  parent->statusMsg(TQString());
 }
 
 
@@ -696,10 +696,10 @@ void ProjectPrivate::loadProjectXML()
   }
 
 
-  parent->statusMsg(TQString::null);
+  parent->statusMsg(TQString());
   parent->newProjectLoaded(projectName, baseURL, templateURL);
   parent->reloadTree(&(m_projectFiles), true, treeStatusFromXML());
-  parent->newStatus();
+  parent->newtqStatus();
   adjustActions();
 }
 
@@ -917,7 +917,7 @@ void ProjectPrivate::slotSaveAsProjectView(bool askForName)
     {
       if (!askForName ||
           KMessageBox::warningContinueCancel(m_mainWindow, i18n("<qt>A project view named <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>")
-                                            .arg(currentProjectView), TQString::null, i18n("Overwrite")) == KMessageBox::Continue)
+                                            .tqarg(currentProjectView), TQString(), i18n("Overwrite")) == KMessageBox::Continue)
       {
         node.parentNode().removeChild(node);
         break;
@@ -1056,7 +1056,7 @@ bool ProjectPrivate::createEmptyDom()
   if (!result)
   {
     parent->hideSplash();
-    KMessageBox::sorry(m_mainWindow, i18n("<qt>Cannot open file <b>%1</b> for writing.</qt>").arg(projectURL.prettyURL(0, KURL::StripFileProtocol)));
+    KMessageBox::sorry(m_mainWindow, i18n("<qt>Cannot open file <b>%1</b> for writing.</qt>").tqarg(projectURL.prettyURL(0, KURL::StripFileProtocol)));
     delete tempFile;
     tempFile = 0L;
     delete sessionTempFile;
@@ -1099,7 +1099,7 @@ void ProjectPrivate::getStatusFromTree()
     i--;
   }
   TQStringList folderList;
-  parent->getTreeStatus( &folderList );
+  parent->getTreetqStatus( &folderList );
   // toplevel folder is always open in a project and QExtFileInfo::toRelative
   // creates strange output -> we remove the toplevel folder
   if (folderList.count() > 0)
@@ -1122,7 +1122,7 @@ void ProjectPrivate::slotNewProject()
 {
   TQWizard *wiz = new TQWizard(m_mainWindow, "new", true);
   wiz->setCaption(i18n("New Project Wizard"));
-  wiz->setSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Minimum);
+  wiz->tqsetSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Minimum);
 
   png = new ProjectNewGeneral(0L);
 
@@ -1197,7 +1197,7 @@ void ProjectPrivate::slotNewProject()
   delete wiz;
 
   adjustActions();
-  parent->newStatus();
+  parent->newtqStatus();
 }
 
 /** close project and edited files */
@@ -1212,33 +1212,33 @@ void ProjectPrivate::slotProceedWithCloseProject(bool success)
 {
   disconnect(ViewManager::ref(), TQT_SIGNAL(filesClosed(bool)), this, TQT_SLOT(slotProceedWithCloseProject(bool)));
   if (!success) return;
-  emit eventHappened("before_project_close", baseURL.url(), TQString::null);
+  emit eventHappened("before_project_close", baseURL.url(), TQString());
   if (!uploadProjectFile())
   {
     if (KMessageBox::warningContinueCancel(m_mainWindow, i18n("Saving of project failed. Do you want to continue with closing (might cause data loss)?"), i18n("Project Saving Error"), KStdGuiItem::close()) == KMessageBox::Cancel)
       return;
   }
-  emit eventHappened("after_project_close", baseURL.url(), TQString::null);
+  emit eventHappened("after_project_close", baseURL.url(), TQString());
   // empty dom tree
   dom.clear();
   m_sessionDom.clear();
   m_events->clear();
   config->setGroup("Projects");
-  config->writePathEntry("Last Project", TQString::null);
+  config->writePathEntry("Last Project", TQString());
   init();
   parent->newProjectLoaded(projectName, baseURL, templateURL);
   parent->reloadTree( &(m_projectFiles), true, TQStringList());
   adjustActions();
   m_projectRecent->setCurrentItem(-1);
-  parent->newStatus();
-  kapp->processEvents(TQEventLoop::ExcludeUserInput | TQEventLoop::ExcludeSocketNotifiers);
+  parent->newtqStatus();
+  kapp->tqprocessEvents(TQEventLoop::ExcludeUserInput | TQEventLoop::ExcludeSocketNotifiers);
 }
 
 
 /** open project file */
 void ProjectPrivate::slotOpenProject()
 {
-  KURL url = KFileDialog::getOpenURL( TQString::null,
+  KURL url = KFileDialog::getOpenURL( TQString(),
                       "*.wpj *.webprj"+i18n("|Project Files\n*|All Files"), m_mainWindow,
                       i18n("Open Project"));
 
@@ -1284,11 +1284,11 @@ bool ProjectPrivate::saveProject()
       f.close();
     }
     m_modified = false;
-    parent->statusMsg(i18n( "Wrote project file %1" ).arg(m_tmpProjectFile));
+    parent->statusMsg(i18n( "Wrote project file %1" ).tqarg(m_tmpProjectFile));
   } else
   {
     parent->hideSplash();
-    KMessageBox::error(m_mainWindow, i18n("<qt>Cannot open the file <b>%1</b> for writing.</qt>").arg(m_tmpProjectFile));
+    KMessageBox::error(m_mainWindow, i18n("<qt>Cannot open the file <b>%1</b> for writing.</qt>").tqarg(m_tmpProjectFile));
     result = false;
   }
   return result;
@@ -1339,7 +1339,7 @@ void ProjectPrivate::loadProjectFromTemp(const KURL &url, const TQString &tempFi
   } else
   {
     parent->hideSplash();
-    KMessageBox::error(m_mainWindow, i18n("<qt>Cannot open the file <b>%1</b> for reading.</qt>").arg(tempFile));
+    KMessageBox::error(m_mainWindow, i18n("<qt>Cannot open the file <b>%1</b> for reading.</qt>").tqarg(tempFile));
   }
 }
 
@@ -1351,13 +1351,13 @@ bool ProjectPrivate::loadProject(const KURL &url)
   if (!url.isValid())
   {
     parent->hideSplash();
-    KMessageBox::sorry(m_mainWindow, i18n("<qt>Malformed URL: <b>%1</b></qt>").arg(url.prettyURL()));
+    KMessageBox::sorry(m_mainWindow, i18n("<qt>Malformed URL: <b>%1</b></qt>").tqarg(url.prettyURL()));
     return false;
   }
   if ( projectAlreadyOpen(url.url()) )
   {
     parent->hideSplash();
-    if (KMessageBox::warningContinueCancel(m_mainWindow, i18n("<qt>The project<br><b>%1</b><br> seems to be used by another Quanta instance.<br>You may end up with data loss if you open the same project in two instances, modify and save them in both.<br><br>Do you want to proceed with open?</qt>").arg(url.prettyURL()), TQString::null, KStdGuiItem::open()) == KMessageBox::Cancel)
+    if (KMessageBox::warningContinueCancel(m_mainWindow, i18n("<qt>The project<br><b>%1</b><br> seems to be used by another Quanta instance.<br>You may end up with data loss if you open the same project in two instances, modify and save them in both.<br><br>Do you want to proceed with open?</qt>").tqarg(url.prettyURL()), TQString(), KStdGuiItem::open()) == KMessageBox::Cancel)
       return false;
   }
   TQString projectTmpFile;
@@ -1416,7 +1416,7 @@ bool ProjectPrivate::loadProject(const KURL &url)
   } else
   {
     parent->hideSplash();
-    KMessageBox::error(m_mainWindow, i18n("<qt>Cannot access the project file <b>%1</b>.</qt>").arg(url.prettyURL(0, KURL::StripFileProtocol)));
+    KMessageBox::error(m_mainWindow, i18n("<qt>Cannot access the project file <b>%1</b>.</qt>").tqarg(url.prettyURL(0, KURL::StripFileProtocol)));
     return false;
   }
   return true;
@@ -1532,7 +1532,7 @@ void ProjectPrivate::slotDebuggerOptions()
       else
       {
         parent->hideSplash();
-        KMessageBox::error(NULL, i18n("<qt>Unable to load the debugger plugin, error code %1 was returned: <b>%2</b>.</qt>").arg(errCode).arg(KLibLoader::self()->lastErrorMessage()), i18n("Debugger Error"));
+        KMessageBox::error(NULL, i18n("<qt>Unable to load the debugger plugin, error code %1 was returned: <b>%2</b>.</qt>").tqarg(errCode).tqarg(KLibLoader::self()->lastErrorMessage()), i18n("Debugger Error"));
       }
     }
   }
@@ -1632,14 +1632,14 @@ bool ProjectPrivate::uploadProjectFile()
     tempFile = 0L;
     delete sessionTempFile;
     sessionTempFile = 0L;
-    m_tmpProjectFile = TQString::null;
+    m_tmpProjectFile = TQString();
     return true;
   }
   if (KIO::NetAccess::upload(m_tmpProjectFile, projectURL, m_mainWindow) && KIO::NetAccess::upload(m_tmpSessionFile, sessionURL, m_mainWindow))
   {
     removeFromConfig(projectURL.url());    // remove the project from the list of open projects
     if (quantaApp)
-      parent->statusMsg(i18n( "Uploaded project file %1" ).arg( projectURL.prettyURL()));
+      parent->statusMsg(i18n( "Uploaded project file %1" ).tqarg( projectURL.prettyURL()));
     // delete all temp files we used
     // first the one from creating a new project
     delete tempFile;
@@ -1659,7 +1659,7 @@ bool ProjectPrivate::uploadProjectFile()
   {
     if (quantaApp)
     {
-      parent->statusMsg(TQString::null );
+      parent->statusMsg(TQString() );
       KMessageBox::error(m_mainWindow, KIO::NetAccess::lastErrorString());
     }
     return false;
