@@ -63,7 +63,7 @@
 #include "resource.h"
 
 ProjectUpload::ProjectUpload(const KURL& url, const TQString& profileName, bool showOnlyProfiles, bool quickUpload, bool markOnly, const char* name)
-  :ProjectUploadS( 0L, name, false, Qt::WDestructiveClose)
+  :ProjectUploadS( 0L, name, false, TQt::WDestructiveClose)
 {
     m_quickUpload = quickUpload;
     m_profilesOnly = showOnlyProfiles;
@@ -73,7 +73,7 @@ ProjectUpload::ProjectUpload(const KURL& url, const TQString& profileName, bool
     startUrl = url;
     if (m_profilesOnly)
     {
-      clearWFlags(Qt::WDestructiveClose);
+      clearWFlags(TQt::WDestructiveClose);
       uploadFrame->hide();
       buttonCancel->hide();
       adjustSize();
@@ -211,15 +211,15 @@ void ProjectUpload::slotBuildTree()
          uploadedTime = m_uploadTimeList[s];
        int modifiedTime = item.time(KIO::UDS_MODIFICATION_TIME);
        el.setAttribute("modified_time", modifiedTime);
-       int uploadStatus = el.attribute("uploadstatus", "1").toInt();
-       if (m_quickUpload || (forceUpload && uploadStatus == 0))
-        uploadStatus = 1;
-       if (m_quickUpload || (uploadedTime != modifiedTime && uploadStatus != 0))
+       int uploadtqStatus = el.attribute("uploadstatus", "1").toInt();
+       if (m_quickUpload || (forceUpload && uploadtqStatus == 0))
+        uploadtqStatus = 1;
+       if (m_quickUpload || (uploadedTime != modifiedTime && uploadtqStatus != 0))
        {
          modified.append( u );
          it->setSelected(true);
        }
-       if (uploadStatus == 2)
+       if (uploadtqStatus == 2)
          it->setConfirmUpload(true);
        totalProgress->setValue(i);
      }
@@ -382,7 +382,7 @@ void ProjectUpload::startUpload()
     } else
     {
       if (KMessageBox::warningContinueCancel(this, i18n("<qt><b>%1</b> seems to be unaccessible.<br>Do you want to proceed with upload?</qt>")
-          .arg(u.prettyURL(0, KURL::StripFileProtocol)),TQString::null,KStdGuiItem::cont()) == KMessageBox::Continue)
+          .tqarg(u.prettyURL(0, KURL::StripFileProtocol)),TQString(),KStdGuiItem::cont()) == KMessageBox::Continue)
       {
         upload();
         return;
@@ -463,7 +463,7 @@ void ProjectUpload::upload()
     connect( job, TQT_SIGNAL( infoMessage( KIO::Job *,const TQString& ) ),
                 this, TQT_SLOT( uploadMessage( KIO::Job *,const TQString& ) ) );
 
-    labelCurFile->setText(i18n("Current: %1").arg(currentURL.fileName()));
+    labelCurFile->setText(i18n("Current: %1").tqarg(currentURL.fileName()));
     currentProgress->setProgress( 0 );
     return;
   } else  //it is a dir, so just go to the next item
@@ -517,7 +517,7 @@ void ProjectUpload::selectModified()
   {
     TQListViewItem *it = list->findItem( (*file).path() );
     it->setSelected(true);
-    it->repaint();
+    it->tqrepaint();
   }
   list->checkboxTree();
 }
@@ -564,7 +564,7 @@ void ProjectUpload::slotUploadNext()
      UploadTreeFile *itf = dynamic_cast<UploadTreeFile*>(it);
      if (itf)
       itf->setWhichPixmap( "check_clear" );
-     it->repaint();
+     it->tqrepaint();
     }
     toUpload.remove( it );
 
@@ -639,7 +639,7 @@ void ProjectUpload::slotRemoveProfile()
    } else
    {
       TQString profileName = comboProfile->currentText();
-      if (KMessageBox::warningContinueCancel(this, i18n("<qt>Do you really want to remove the <b>%1</b> upload profile?</qt>").arg(profileName),
+      if (KMessageBox::warningContinueCancel(this, i18n("<qt>Do you really want to remove the <b>%1</b> upload profile?</qt>").tqarg(profileName),
                                    i18n("Profile Removal"), KStdGuiItem::del()) == KMessageBox::Continue)
        {
           m_profilesNode.removeChild(m_currentProfileElement);
@@ -652,7 +652,7 @@ void ProjectUpload::slotRemoveProfile()
           slotNewProfileSelected(currentProfile);
           if (profileName == defaultProfile())
           {
-              KMessageBox::information(this, i18n("<qt>You have removed your default profile.<br>The new default profile will be <b>%1</b>.</qt>").arg(currentProfile), i18n("Profile Removal"));
+              KMessageBox::information(this, i18n("<qt>You have removed your default profile.<br>The new default profile will be <b>%1</b>.</qt>").tqarg(currentProfile), i18n("Profile Removal"));
               m_profilesNode.toElement().setAttribute("defaultProfile", currentProfile);
           }
           comboProfile->removeItem(idx);
