@@ -142,11 +142,11 @@ Document::Document(KTextEditor::Document *doc,
   //conflicting shortcuts, so change them
   a = m_view->actionCollection()->action("view_border");
   if (a)
-    a->setShortcut(Qt::SHIFT + Qt::Key_F9);
+    a->setShortcut(TQt::SHIFT + TQt::Key_F9);
 
   a = m_view->actionCollection()->action("view_folding_markers");
   if (a)
-    a->setShortcut(Qt::SHIFT + Qt::Key_F11);
+    a->setShortcut(TQt::SHIFT + TQt::Key_F11);
 
   KActionMenu *bookmarkAction = dynamic_cast<KActionMenu*>(m_view->actionCollection()->action( "bookmarks" ));
   if (bookmarkAction)
@@ -164,7 +164,7 @@ Document::Document(KTextEditor::Document *doc,
         m_encoding = encodingIf->encoding();
   if (m_encoding.isEmpty())
       m_encoding = "utf8";  //final fallback
-  m_codec = TQTextCodec::codecForName(m_encoding);
+  m_codec = TQTextCodec::codecForName(m_encoding.ascii());
 
   selectionIf = dynamic_cast<KTextEditor::SelectionInterface *>(m_doc);
   selectionIfExt = dynamic_cast<KTextEditor::SelectionInterfaceExt *>(m_doc);
@@ -190,7 +190,7 @@ Document::Document(KTextEditor::Document *doc,
   }
 
   tempFile = 0;
-  m_tempFileName = TQString::null;
+  m_tempFileName = TQString();
   dtdName = Project::ref()->defaultDTD();
   reparseEnabled = true;
   repaintEnabled = true;
@@ -198,7 +198,7 @@ Document::Document(KTextEditor::Document *doc,
   docUndoRedo = new undoRedo(this);
 
   //path of the backup copy file of the document
-  m_backupPathValue = TQString::null;
+  m_backupPathValue = TQString();
 
   connect( m_doc,  TQT_SIGNAL(charactersInteractivelyInserted (int ,int ,const TQString&)),
            this,  TQT_SLOT(slotCharactersInserted(int ,int ,const TQString&)) );
@@ -409,7 +409,7 @@ void Document::insertFile(const KURL& url)
   {
     if (!KIO::NetAccess::download(url, fileName, this))
     {
-      KMessageBox::error(this, i18n("<qt>Cannot download <b>%1</b>.</qt>").arg( url.prettyURL(0, KURL::StripFileProtocol)));
+      KMessageBox::error(this, i18n("<qt>Cannot download <b>%1</b>.</qt>").tqarg( url.prettyURL(0, KURL::StripFileProtocol)));
       return;
     }
   }
@@ -421,7 +421,7 @@ void Document::insertFile(const KURL& url)
     insertText(stream.read());
     file.close();
   } else
-    KMessageBox::error(this, i18n("<qt>Cannot open <b>%1</b> for reading.</qt>").arg(url.prettyURL(0, KURL::StripFileProtocol)));
+    KMessageBox::error(this, i18n("<qt>Cannot open <b>%1</b> for reading.</qt>").tqarg(url.prettyURL(0, KURL::StripFileProtocol)));
 }
 
 /** Inserts text at the current cursor position */
@@ -552,7 +552,7 @@ void Document::insertText(const TQString &a_text, bool adjustCursor, bool repars
   }
 }
 
-bool Document::insertChildTags(QTag *tag, QTag *lastTag)
+bool Document::insertChildTags(TQTag *tag, TQTag *lastTag)
 {
   bool childInserted = false;
   if (!tag || tag == lastTag) //avoid infinite recursion
@@ -565,7 +565,7 @@ bool Document::insertChildTags(QTag *tag, QTag *lastTag)
     if (it.data())
     {
       childInserted = true;
-      QTag *childTag = QuantaCommon::tagFromDTD(tag->parentDTD, it.key());
+      TQTag *childTag = QuantaCommon::tagFromDTD(tag->parentDTD, it.key());
       TQString tagStr =QuantaCommon::tagCase(it.key());
       if ( tag->parentDTD->singleTagStyle == "xml" &&
            ( childTag->isSingle() ||
@@ -630,7 +630,7 @@ void Document::createTempFile()
         encoding = encodingIf->encoding();
   if (encoding.isEmpty())
       encoding = "utf8";  //final fallback
-  tempFile->textStream()->setCodec(TQTextCodec::codecForName(encoding));
+  tempFile->textStream()->setCodec(TQTextCodec::codecForName(encoding.ascii()));
   * (tempFile->textStream()) << editIf->text();
 
   m_tempFileName = TQFileInfo(*(tempFile->file())).filePath();
@@ -648,7 +648,7 @@ void Document::closeTempFile()
  if (TQFileInfo(m_tempFileName).exists())
      TQFile::remove(m_tempFileName);
 
- m_tempFileName = TQString::null;
+ m_tempFileName = TQString();
 }
 
 TQString Document::tempFileName()
@@ -732,7 +732,7 @@ void Document::slotCompletionDone( KTextEditor::CompletionEntry completion )
     viewCursorIf->setCursorPositionReal(line,col-1);
     if (dtd)
     {
-      QTag *tag = QuantaCommon::tagFromDTD(dtd,completion.userdata);
+      TQTag *tag = QuantaCommon::tagFromDTD(dtd,completion.userdata);
       if (tag)
       {
         m_lastCompletionList = getAttributeValueCompletions(tag->name(), completion.text);
@@ -852,13 +852,13 @@ void Document::slotCharactersInserted(int line, int column, const TQString& stri
       if (encoding != m_encoding)
       {
         m_encoding = encoding;
-        m_codec = TQTextCodec::codecForName(encoding);
+        m_codec = TQTextCodec::codecForName(encoding.ascii());
       }
       if (!m_codec->canEncode(string[0]))
       {
         m_replaceLine = line;
         m_replaceCol = column;
-        m_replaceStr = QuantaCommon::encodedChar(string[0].unicode());
+        m_replaceStr = QuantaCommon::encodedChar(string[0].tqunicode());
         TQTimer::singleShot(0, this, TQT_SLOT(slotReplaceChar()));
         return;
       }
@@ -866,7 +866,7 @@ void Document::slotCharactersInserted(int line, int column, const TQString& stri
   }
   if (qConfig.replaceAccented)
   {
-    uint c = string[0].unicode();
+    uint c = string[0].tqunicode();
     if (c > 191)
     {
       m_replaceLine = line;
@@ -936,7 +936,7 @@ void Document::slotCharactersInserted(int line, int column, const TQString& stri
 */
 bool Document::xmlAutoCompletion(int line, int column, const TQString & string)
 {
-  QTag *tag;
+  TQTag *tag;
   TQString tagName;
   bool handled = false;
   tagName = getTagNameAt(line, column);
@@ -1208,9 +1208,9 @@ TQValueList<KTextEditor::CompletionEntry>* Document::getTagCompletions(int line,
       node = node->parent;
   if (node && node->tag->type != Tag::XmlTag)
       node = 0L;
-  QTag *parentQTag= 0L;
+  TQTag *parentTQTag= 0L;
   if (node && node->parent)
-      parentQTag = QuantaCommon::tagFromDTD(node->parent);
+      parentTQTag = QuantaCommon::tagFromDTD(node->parent);
   TQString textLine = editIf->textLine(line).left(col);
   TQString word = findWordRev(textLine, completionDTD).upper();
   TQString classStr = "";
@@ -1290,20 +1290,20 @@ TQValueList<KTextEditor::CompletionEntry>* Document::getTagCompletions(int line,
   //A TQMap to hold the completion type (function/string/class/etc)
   TQMap<TQString, TQString> type;
   TQString tagName;
-  TQDictIterator<QTag> it(*(completionDTD->tagsList));
+  TQDictIterator<TQTag> it(*(completionDTD->tagsList));
   int i = 0;
   for( ; it.current(); ++it )
   {
-    QTag *tag = it.current();
+    TQTag *tag = it.current();
     if ((tag->type != "entity") && (tag->className == classStr ||
         isDerivatedFrom(classStr, tag->className)))
     {
       tagName = tag->name();
       if (!tagName.isEmpty() && tagName.upper().startsWith(word))
       {
-        if (!parentQTag || (parentQTag && parentQTag->isChild(tagName)))
+        if (!parentTQTag || (parentTQTag && parentTQTag->isChild(tagName)))
         {
-          tagName = tag->name() + TQString("%1").arg(i, 10);
+          tagName = tag->name() + TQString("%1").tqarg(i, 10);
           tagNameList += tagName;
           comments.insert(tagName, tag->comment);
           i++;
@@ -1312,14 +1312,14 @@ TQValueList<KTextEditor::CompletionEntry>* Document::getTagCompletions(int line,
     }
   }
 
-  TQDictIterator<QTag> it2(userTagList);
+  TQDictIterator<TQTag> it2(userTagList);
   for( ; it2.current(); ++it2 )
   {
-    QTag *tag = it2.current();
+    TQTag *tag = it2.current();
     if ((tag->className == classStr ||
          isDerivatedFrom(classStr, tag->className)) && tag->name().upper().startsWith(word))
     {
-      tagName = tag->name() + TQString("%1").arg(i, 10);
+      tagName = tag->name() + TQString("%1").tqarg(i, 10);
       tagNameList += tagName;
       comments.insert(tagName, tag->comment);
       
@@ -1404,7 +1404,7 @@ TQValueList<KTextEditor::CompletionEntry>* Document::getAttributeCompletions(con
 {
   TQValueList<KTextEditor::CompletionEntry> *completions = new TQValueList<KTextEditor::CompletionEntry>();
   KTextEditor::CompletionEntry completion;
-  QTag *tag = QuantaCommon::tagFromDTD(completionDTD, tagName);
+  TQTag *tag = QuantaCommon::tagFromDTD(completionDTD, tagName);
   if (!tag)
   {
     tag = userTagList.find(tagName.lower());
@@ -1588,10 +1588,10 @@ TQValueList<KTextEditor::CompletionEntry>* Document::getCharacterCompletions(con
   KTextEditor::CompletionEntry completion;
   completion.type = "charCompletion";
   //add the entities from the tag files
-  TQDictIterator<QTag> it(*(completionDTD->tagsList));
+  TQDictIterator<TQTag> it(*(completionDTD->tagsList));
   for( ; it.current(); ++it )
   {
-    QTag *tag = it.current();
+    TQTag *tag = it.current();
     if (tag->type == "entity")
     {
       TQString tagName = tag->name(true);
@@ -1794,11 +1794,11 @@ bool Document::scriptAutoCompletion(int line, int column, const TQString& insert
  {
    TQString textLine = s.left(i);
    TQString word = findWordRev(textLine, completionDTD);
-   TQValueList<QTag *> tags;
+   TQValueList<TQTag *> tags;
    if (!word.isEmpty())
    {
       tags.append(userTagList.find(word.lower()));
-      TQDictIterator<QTag> it(*(completionDTD->tagsList));
+      TQDictIterator<TQTag> it(*(completionDTD->tagsList));
       for( ; it.current(); ++it )
       {
         if (it.currentKey() == word)
@@ -1806,9 +1806,9 @@ bool Document::scriptAutoCompletion(int line, int column, const TQString& insert
       }
    }
    TQStringList argList;
-   for (TQValueList<QTag*>::ConstIterator it = tags.constBegin(); it != tags.constEnd(); ++it)
+   for (TQValueList<TQTag*>::ConstIterator it = tags.constBegin(); it != tags.constEnd(); ++it)
    {
-     QTag *tag = *it;
+     TQTag *tag = *it;
      if (!tag)
        continue;
      TQString arguments;
@@ -2212,7 +2212,7 @@ void Document::slotCompletionAborted()
 }
 
 /** Ask for user confirmation if the file was changed outside. */
-void Document::checkDirtyStatus()
+void Document::checkDirtytqStatus()
 {
   TQString fileName;
   if (url().isLocalFile())
@@ -2236,7 +2236,7 @@ void Document::checkDirtyStatus()
           const char* c = "";
           KMD5 context(c);
           context.reset();
-          context.update(f);
+          context.update(*TQT_TQIODEVICE(&f));
           m_md5sum = context.hexDigest();
           f.close();
         }
@@ -2252,7 +2252,7 @@ void Document::checkDirtyStatus()
           const char* c = "";
           KMD5 context(c);
           context.reset();
-          context.update(f);
+          context.update(*TQT_TQIODEVICE(&f));
           md5sum = context.hexDigest();
           kdDebug(24000) << "MD5 sum of current doc: " << m_md5sum << endl;
           kdDebug(24000) << "MD5 sum of doc on disc : " << md5sum << endl;
@@ -2323,7 +2323,7 @@ bool Document::saveAs(const KURL& url)
         const char* c = "";
         KMD5 context(c);
         context.reset();
-        context.update(f);
+        context.update(*TQT_TQIODEVICE(&f));
         m_md5sum = context.hexDigest();
         f.close();
       }
@@ -2576,9 +2576,9 @@ bool Document::hasChanged()
   return b;
 }
 
-void Document::setChanged(bool newStatus)
+void Document::setChanged(bool newtqStatus)
 {
-  changed = newStatus;
+  changed = newtqStatus;
 }
 
 void Document::paste()
@@ -2614,7 +2614,7 @@ TQStringList Document::tagAreas(const TQString& tag, bool includeCoordinates, bo
         TQString s = text(bl, bc, el, ec);
         if (includeCoordinates)
         {
-          s.prepend(TQString("%1,%2,%3,%4\n").arg(bl).arg(bc).arg(el).arg(ec));
+          s.prepend(TQString("%1,%2,%3,%4\n").tqarg(bl).tqarg(bc).tqarg(el).tqarg(ec));
         }
         result += s;
         if (skipFoundContent)
@@ -2708,7 +2708,7 @@ void Document::createBackup(KConfig* config)
     if (file.open(IO_WriteOnly))
     {
       TQTextStream stream(&file);
-      stream.setCodec(TQTextCodec::codecForName(encoding));
+      stream.setCodec(TQTextCodec::codecForName(encoding.ascii()));
       stream << editIf->text();
       file.close();
     }
@@ -2870,12 +2870,12 @@ void Document::open(const KURL &url, const TQString &encoding)
     {
        encodingIf->setEncoding(encoding);
        m_encoding = encoding;
-       m_codec = TQTextCodec::codecForName(m_encoding);
+       m_codec = TQTextCodec::codecForName(m_encoding.ascii());
     }
     connect(m_doc, TQT_SIGNAL(completed()), this, TQT_SLOT(slotOpeningCompleted()));
     connect(m_doc, TQT_SIGNAL(canceled(const TQString&)), this, TQT_SLOT(slotOpeningFailed(const TQString&)));
     if (!openURL(url))
-      slotOpeningFailed(TQString::null);
+      slotOpeningFailed(TQString());
     if (!url.isLocalFile())
     {
       QExtFileInfo internalFileInfo;
@@ -2889,7 +2889,7 @@ void Document::slotOpeningCompleted()
   if (!u.isLocalFile())
   {
     m_modifTime = TQDateTime();
-    qApp->exit_loop();
+    tqApp->exit_loop();
   }
   else
   {
@@ -2910,7 +2910,7 @@ void Document::slotOpeningFailed(const TQString &errorMessage)
   m_md5sum = "";
   Q_UNUSED(errorMessage); //TODO: append the error message to our own error message
   if (!url().isLocalFile())
-    qApp->exit_loop();
+    tqApp->exit_loop();
   disconnect(m_doc, TQT_SIGNAL(completed()), this, TQT_SLOT(slotOpeningCompleted()));
   disconnect(m_doc, TQT_SIGNAL(canceled(const TQString&)), this, TQT_SLOT(slotOpeningFailed(const TQString&)));
   emit openingFailed(url());
@@ -3043,7 +3043,7 @@ void Document::processDTD(const TQString& documentType)
 
   if (!isUntitled())
   {
-    quantaApp->messageOutput()->showMessage(i18n("\"%1\" is used for \"%2\".\n").arg(DTDs::ref()->getDTDNickNameFromName(dtdName)).arg(url().prettyURL(0, KURL::StripFileProtocol)));
+    quantaApp->messageOutput()->showMessage(i18n("\"%1\" is used for \"%2\".\n").tqarg(DTDs::ref()->getDTDNickNameFromName(dtdName)).tqarg(url().prettyURL(0, KURL::StripFileProtocol)));
   }
   quantaApp->slotLoadToolbarForDTD(dtdName);
   StructTreeView::ref()->useOpenLevelSetting = true;
@@ -3056,10 +3056,10 @@ void Document::slotFileDirty(const TQString& fileName)
 {
   if ( url().path() == fileName && !dirty() )
   {
-    setDirtyStatus(true);
+    setDirtytqStatus(true);
     if (this == ViewManager::ref()->activeDocument())
     {
-      checkDirtyStatus();
+      checkDirtytqStatus();
     }
   }
 }
@@ -3099,11 +3099,11 @@ TQStringList Document::groupsForDTEPs()
 
 TQString Document::annotationText(uint line)
 {
-  TQMap<uint, QPair<TQString, TQString> >::Iterator it = m_annotations.find(line);
+  TQMap<uint, TQPair<TQString, TQString> >::Iterator it = m_annotations.find(line);
   if (it != m_annotations.end())
     return it.data().first;
   else
-   return TQString::null;
+   return TQString();
 }
 
 void Document::setAnnotationText(uint line, const TQString& text)
@@ -3115,7 +3115,7 @@ void Document::setAnnotationText(uint line, const TQString& text)
       markIf->removeMark(line, KTextEditor::MarkInterface::markType08);
   } else
   {
-    m_annotations.insert(line, qMakePair(text, TQString("")));
+    m_annotations.insert(line, tqMakePair(text, TQString("")));
     if (markIf)
       markIf->setMark(line, KTextEditor::MarkInterface::markType08);
     uint line, column;
@@ -3147,11 +3147,11 @@ void Document::setAnnotationText(uint line, const TQString& text)
     s.prepend(commentBegin + " ");
     s.append(" " + commentEnd + "\n");
     insertText(s, true, true);
-    emit showAnnotation(line, "", qMakePair(text, TQString("")));
+    emit showAnnotation(line, "", tqMakePair(text, TQString("")));
   }
 }
 
-void Document::addAnnotation(uint line, const QPair<TQString, TQString>& annotation)
+void Document::addAnnotation(uint line, const TQPair<TQString, TQString>& annotation)
 {
   m_annotations.insert(line, annotation);
   if (markIf)
@@ -3181,7 +3181,7 @@ bool Document::openURL(const KURL& url)
       const char* c = "";
       KMD5 context(c);
       context.reset();
-      context.update(f);
+      context.update(*TQT_TQIODEVICE(&f));
       m_md5sum = context.hexDigest();
       f.close();
     }
