@@ -239,7 +239,7 @@ bool DTDs::readTagDir2(DTDStruct *dtd)
 
   if (!TQFile::exists(dtd->fileName)) return false;
 
-  kapp->setOverrideCursor( TQCursor(Qt::WaitCursor) );
+  kapp->setOverrideCursor( TQCursor(TQt::WaitCursor) );
 
   KConfig *dtdConfig = new KConfig(dtd->fileName, true);
 
@@ -264,7 +264,7 @@ bool DTDs::readTagDir2(DTDStruct *dtd)
   dtd->defaultExtension = dtdConfig->readEntry("DefaultExtension");
   dtd->caseSensitive = caseSensitive;
   int numOfTags = 0;
-  QTagList *tagList = new QTagList(119, false); //max 119 tag in a DTD
+  TQTagList *tagList = new TQTagList(119, false); //max 119 tag in a DTD
   tagList->setAutoDelete(true);
   //read all the tag files
   KURL dirURL(dtd->fileName);
@@ -272,10 +272,10 @@ bool DTDs::readTagDir2(DTDStruct *dtd)
   TQString dirName = dirURL.path(1);
   if (TQFile::exists(dirName + "common.tag"))
     readTagFile(dirName + "common.tag", dtd, 0L);
-  //bool idleTimerStatus = quantaApp->slotEnableIdleTimer(false);
+  //bool idleTimertqStatus = quantaApp->slotEnableIdleTimer(false);
   emit enableIdleTimer(false);
   KURL::List files = QExtFileInfo::allFilesRelative(dirURL, "*.tag", 0L);
-  //quantaApp->slotEnableIdleTimer(idleTimerStatus);
+  //quantaApp->slotEnableIdleTimer(idleTimertqStatus);
   emit enableIdleTimer(true);
   TQString tmpStr;
   KURL::List::ConstIterator end_f = files.constEnd();
@@ -313,7 +313,7 @@ bool DTDs::readTagDir2(DTDStruct *dtd)
   TQStrList attrList;
   for (uint i = 0 ; i < extraTagsList.count(); i++)
   {
-    QTag *tag = new QTag();
+    TQTag *tag = new TQTag();
     tag->setName(TQString(extraTagsList.at(i)).stripWhiteSpace());
 
     tmpStr = (dtd->caseSensitive) ? tag->name() : tag->name().upper();
@@ -533,7 +533,7 @@ bool DTDs::readTagDir2(DTDStruct *dtd)
       TQString tagStr;
       for (uint index = 1; index <= structGroupsCount; index++)
       {
-        dtdConfig->setGroup(TQString("StructGroup_%1").arg(index));
+        dtdConfig->setGroup(TQString("StructGroup_%1").tqarg(index));
         //new code
         group.name = dtdConfig->readEntry("Name").stripWhiteSpace();
         group.noName = dtdConfig->readEntry("No_Name").stripWhiteSpace();
@@ -583,7 +583,7 @@ bool DTDs::readTagDir2(DTDStruct *dtd)
       TQString tagName;
       for (uint index = 1; index <= structGroupsCount; index++)
       {
-        dtdConfig->setGroup(TQString("StructGroup_%1").arg(index));
+        dtdConfig->setGroup(TQString("StructGroup_%1").tqarg(index));
         group.name = dtdConfig->readEntry("Name").stripWhiteSpace();
         group.noName = dtdConfig->readEntry("No_Name").stripWhiteSpace();
         group.icon = dtdConfig->readEntry("Icon").stripWhiteSpace();
@@ -621,14 +621,14 @@ void DTDs::resolveInherited (DTDStruct *dtd)
   if (!dtd->inheritsTagsFrom.isEmpty())
   {
     DTDStruct *parent = (DTDStruct *) find(dtd->inheritsTagsFrom);  // this loads the dtd, if not present in memory
-    TQDictIterator<QTag> tag_it(*(parent->tagsList));
+    TQDictIterator<TQTag> tag_it(*(parent->tagsList));
     for ( ; tag_it.current(); ++tag_it)
     {
-      QTag *tag = tag_it.current();
+      TQTag *tag = tag_it.current();
       TQString searchForTag = (dtd->caseSensitive) ? tag->name() : tag->name().upper();
       if (!dtd->tagsList->find(searchForTag))
       {
-        QTag *newTag = new QTag(*tag);
+        TQTag *newTag = new TQTag(*tag);
         dtd->tagsList->insert(searchForTag, newTag);
       }
     }
@@ -667,7 +667,7 @@ void DTDs::resolveInherited (DTDStruct *dtd)
 
 
 /** Reads the tags for the tag files. Returns the number of read tags. */
-uint DTDs::readTagFile(const TQString& fileName, DTDStruct* parentDTD, QTagList *tagList)
+uint DTDs::readTagFile(const TQString& fileName, DTDStruct* parentDTD, TQTagList *tagList)
 {
 //  kdDebug(24000) << "dtds::readTagFile:" << fileName << endl;
  TQFile f(fileName);
@@ -685,7 +685,7 @@ uint DTDs::readTagFile(const TQString& fileName, DTDStruct* parentDTD, QTagList
  if (!m_doc->setContent( &f, &errorMsg, &errorLine, &errorCol ))
  {
    emit hideSplash();
-   KMessageBox::error(0L, i18n("<qt>The DTD tag file %1 is not valid.<br> The error message is: <i>%2 in line %3, column %4.</i></qt>").arg(fileName).arg(errorMsg).arg(errorLine).arg(errorCol),
+   KMessageBox::error(0L, i18n("<qt>The DTD tag file %1 is not valid.<br> The error message is: <i>%2 in line %3, column %4.</i></qt>").tqarg(fileName).tqarg(errorMsg).tqarg(errorLine).tqarg(errorCol),
    i18n("Invalid Tag File"));
    kdWarning() << fileName << ": " << errorMsg << ": " << errorLine << "," << errorCol << endl;
  }
@@ -705,7 +705,7 @@ uint DTDs::readTagFile(const TQString& fileName, DTDStruct* parentDTD, QTagList
         parentDTD->classInheritance[name] = extends;
       continue;
     }
-    QTag *tag = new QTag();
+    TQTag *tag = new TQTag();
     tag->setName(e.attribute("name"));
     tag->setFileName(fileName);
     tag->parentDTD = parentDTD;
@@ -739,7 +739,7 @@ uint DTDs::readTagFile(const TQString& fileName, DTDStruct* parentDTD, QTagList
 /**
  Parse the dom document and retrieve the tag attributes
 */
-void DTDs::setAttributes(TQDomNode *dom, QTag* tag, bool &common)
+void DTDs::setAttributes(TQDomNode *dom, TQTag* tag, bool &common)
 {
  common = false;
  Attribute *attr;
@@ -784,7 +784,7 @@ void DTDs::setAttributes(TQDomNode *dom, QTag* tag, bool &common)
     tag->className = el.attribute("class", "");
     tag->comment = el.attribute("comment", "");
     if (!tag->comment.isEmpty())
-      tag->comment = " [" + i18n(tag->comment) + "] ";
+      tag->comment = " [" + i18n(tag->comment.ascii()) + "] ";
     tag->comment.prepend(el.attribute("version"));
  } else
  {
@@ -794,7 +794,7 @@ void DTDs::setAttributes(TQDomNode *dom, QTag* tag, bool &common)
  for ( TQDomNode n = dom->firstChild(); !n.isNull(); n = n.nextSibling() )
  {
    tmpStr = n.nodeName();
-   if (tmpStr == "children")
+   if (tmpStr == "tqchildren")
    {
      TQDomElement el = n.toElement();
      TQDomElement item = el.firstChild().toElement();
@@ -914,7 +914,7 @@ void DTDs::slotLoadDTD()
       TQString nickName = dtdcfg.readEntry("NickName", dtdName);
       DTDStruct * dtd = m_dict->find(dtdName) ;
       if (dtd &&
-          KMessageBox::warningYesNo(0L, i18n("<qt>Do you want to replace the existing <b>%1</b> DTD?</qt>").arg(nickName), TQString::null, i18n("Replace"), i18n("Do Not Replace")) == KMessageBox::No)
+          KMessageBox::warningYesNo(0L, i18n("<qt>Do you want to replace the existing <b>%1</b> DTD?</qt>").tqarg(nickName), TQString(), i18n("Replace"), i18n("Do Not Replace")) == KMessageBox::No)
       {
         return;
       }
@@ -924,7 +924,7 @@ void DTDs::slotLoadDTD()
           TQString family = dtdcfg.readEntry("Family", "1");
           Document *w = ViewManager::ref()->activeDocument();
           if (family == "1" && w &&
-              KMessageBox::questionYesNo(0L, i18n("<qt>Use the newly loaded <b>%1</b> DTD for the current document?</qt>").arg(nickName), i18n("Change DTD"), i18n("Use"), i18n("Do Not Use")) == KMessageBox::Yes)
+              KMessageBox::questionYesNo(0L, i18n("<qt>Use the newly loaded <b>%1</b> DTD for the current document?</qt>").tqarg(nickName), i18n("Change DTD"), i18n("Use"), i18n("Do Not Use")) == KMessageBox::Yes)
           {
             w->setDTDIdentifier(dtdName);
             emit loadToolbarForDTD(w->getDTDIdentifier());
@@ -946,18 +946,18 @@ void DTDs::slotLoadDTEP(const TQString &_dirName, bool askForAutoload)
   TQString nickName = dtdcfg.readEntry("NickName", dtdName);
   DTDStruct * dtd = m_dict->find(dtdName) ;
   if ( dtd &&
-      KMessageBox::warningYesNo(0L, i18n("<qt>Do you want to replace the existing <b>%1</b> DTD?</qt>").arg(nickName), TQString::null, i18n("Replace"), i18n("Do Not Replace")) == KMessageBox::No)
+      KMessageBox::warningYesNo(0L, i18n("<qt>Do you want to replace the existing <b>%1</b> DTD?</qt>").tqarg(nickName), TQString(), i18n("Replace"), i18n("Do Not Replace")) == KMessageBox::No)
   {
     return;
   }
   removeDTD(dtd);
   if (!readTagDir(dirName))
   {
-    KMessageBox::error(0L, i18n("<qt>Cannot read the DTEP from <b>%1</b>. Check that the folder contains a valid DTEP (<i>description.rc and *.tag files</i>).</qt>").arg(dirName), i18n("Error Loading DTEP"));
+    KMessageBox::error(0L, i18n("<qt>Cannot read the DTEP from <b>%1</b>. Check that the folder contains a valid DTEP (<i>description.rc and *.tag files</i>).</qt>").tqarg(dirName), i18n("Error Loading DTEP"));
   } else
   {
     TQString family = dtdcfg.readEntry("Family", "1");
-    if (askForAutoload && KMessageBox::questionYesNo(0L, i18n("<qt>Autoload the <b>%1</b> DTD in the future?</qt>").arg(nickName), TQString::null, i18n("Load"), i18n("Do Not Load")) == KMessageBox::Yes)
+    if (askForAutoload && KMessageBox::questionYesNo(0L, i18n("<qt>Autoload the <b>%1</b> DTD in the future?</qt>").tqarg(nickName), TQString(), i18n("Load"), i18n("Do Not Load")) == KMessageBox::Yes)
     {
       KURL src;
       src.setPath(dirName);
@@ -968,7 +968,7 @@ void DTDs::slotLoadDTEP(const TQString &_dirName, bool askForAutoload)
     }
     Document *w = ViewManager::ref()->activeDocument();
     if (family == "1" && w &&
-        KMessageBox::questionYesNo(0L, i18n("<qt>Use the newly loaded <b>%1</b> DTD for the current document?</qt>").arg(nickName), i18n("Change DTD"), i18n("Use"), i18n("Do Not Use")) == KMessageBox::Yes)
+        KMessageBox::questionYesNo(0L, i18n("<qt>Use the newly loaded <b>%1</b> DTD for the current document?</qt>").tqarg(nickName), i18n("Change DTD"), i18n("Use"), i18n("Do Not Use")) == KMessageBox::Yes)
     {
       w->setDTDIdentifier(dtdName);
       emit loadToolbarForDTD(w->getDTDIdentifier());
