@@ -19,7 +19,7 @@
 #define QUANTA_H
 
 #define QUANTA_PACKAGE "quanta"
-#define QUANTA_VERSION "3.5.10"
+#define QUANTA_VERSION "3.5.13"
 
 #define IDS_STATUS      1
 #define IDS_INS_OVR     2
@@ -30,7 +30,7 @@
 
 #define IDS_DEFAULT     "Ready."
 
-// include files for Qt
+// include files for TQt
 #include <tqmap.h>
 #include <tqdict.h>
 #include <tqvaluelist.h>
@@ -95,8 +95,6 @@ class DebuggerManager;
 class QuantaInit;
 class KToolBarPopupAction;
 class KTempFile;
-class KParts::Part;
-class KParts::PartManager;
 namespace KTextEditor
 {
   class Mark;
@@ -114,6 +112,7 @@ struct ToolbarEntry;
 class QuantaApp : public KMdiMainFrm, public DCOPWindowManagerIf
 {
   Q_OBJECT
+  TQ_OBJECT
 
 friend class QuantaInit;
 
@@ -195,7 +194,7 @@ public:
    * @param attr The string containing the attrs of the new Node to create.
    * @return Returns a new Node created according to the contents of the TagDialog.
    */
-  Node *showTagDialogAndReturnNode(const TQString &tag, const TQString &attr = TQString::null);
+  Node *showTagDialogAndReturnNode(const TQString &tag, const TQString &attr = TQString());
   /** Returns the baseURL of the document. */
   KURL baseURL();
 
@@ -283,11 +282,11 @@ public slots:
        unexpected things may happen. */
   void slotStatusMsg(const TQString &text);
 
-  void slotNewStatus();
+  void slotNewtqStatus();
   void slotNewLineColumn();
-//  void slotUpdateStatus(TQWidget*);FIXME:
+//  void slotUpdatetqStatus(TQWidget*);FIXME:
 
-  /** repaint preview */
+  /** tqrepaint preview */
   void slotRepaintPreview();
   /** toggles showing the preview */
   void slotToggleShowPreview();
@@ -299,7 +298,7 @@ public slots:
         - hide if the preview was in the editor area
         - update if the preview is in a toolview
    */
-  void slotChangePreviewStatus();
+  void slotChangePreviewtqStatus();
   /** Called when the preview widget got or lost the focus */
   void slotPreviewHasFocus(bool focus);
 
@@ -317,7 +316,7 @@ public slots:
   void slotOptionsConfigureToolbars();
   void slotNewToolbarConfig();
   /** Configure toolbars, show defaultToolbar by default */
-  void slotConfigureToolbars(const TQString& defaultToolbar = TQString::null);
+  void slotConfigureToolbars(const TQString& defaultToolbar = TQString());
   void slotOptionsConfigureActions();
 
   void setCursorPosition(int row, int col );
@@ -525,12 +524,12 @@ protected slots:
 
 protected:
   /** Create a DTEP tarball which can be uploaded or sent in email. Returns
-  *   the name of the created file or TQString::null if creation has failed.
+  *   the name of the created file or TQString() if creation has failed.
   */
   TQString createDTEPTarball();
 
   /** Create a toolbar tarball which can be uploaded or sent in email. Returns
-  *   the name of the created file or TQString::null if creation has failed.
+  *   the name of the created file or TQString() if creation has failed.
   */
   TQString createToolbarTarball();
 
@@ -545,7 +544,7 @@ protected:
   virtual bool queryClose();
   void saveAsTemplate (bool projectTemplate, bool selectionOnly = false);
   /** Saves a toolbar as local or project specific. */
-  bool saveToolbar(bool localToolbar = true, const TQString& toolbarToSave = TQString::null, const KURL& destURL = KURL());
+  bool saveToolbar(bool localToolbar = true, const TQString& toolbarToSave = TQString(), const KURL& destURL = KURL());
   /** Saves the toolbar and the actions. Returns the name of the actions file*/
   KURL saveToolbarToFile(const TQString& toolbarName,const KURL& destFile);
   /** Makes the tabwidget look and behave like we want. If closeButtonsOnly is true,
