@@ -67,7 +67,7 @@
 
 #include <X11/Xlib.h>
 
-class BaseTreeViewToolTip : public QToolTip
+class BaseTreeViewToolTip : public TQToolTip
 {
 public:
     BaseTreeViewToolTip( TQWidget *parent, BaseTreeView *lv );
@@ -106,7 +106,7 @@ void BaseTreeViewToolTip::maybeTip( const TQPoint &pos )
         text.append( "<br>" + item->text(1));
     }
     if ( !text.isEmpty() )
-      tip(m_view->itemRect(item), text);
+      tip(m_view->tqitemRect(item), text);
 }
 
 
@@ -265,7 +265,7 @@ void BaseTreeBranch::updateOpenFolder()
   while (item) {
     if (item->isDir() && item->isOpen()) {
       updateDirectory( item->url() );
-      kapp->processEvents(TQEventLoop::ExcludeUserInput | TQEventLoop::ExcludeSocketNotifiers);
+      kapp->tqprocessEvents(TQEventLoop::ExcludeUserInput | TQEventLoop::ExcludeSocketNotifiers);
       // dive into the tree first
       newItem = dynamic_cast<KFileTreeViewItem *>(item->firstChild());
       if (newItem) {
@@ -295,7 +295,7 @@ BaseTreeView::BaseTreeView(TQWidget *parent, const char *name)
 : KFileTreeView(parent, name), fileInfoDlg(0), m_saveOpenFolder(false), m_openWithMenu(0L), m_openWithMenuId(-1)
 {
   m_parent = parent;
-  TQToolTip::remove(viewport());  // remove the tooltip from QListView
+  TQToolTip::remove(viewport());  // remove the tooltip from TQListView
   m_tooltip = new BaseTreeViewToolTip(viewport(), this);
   setFrameStyle( Panel | Sunken );
   setRootIsDecorated(true);
@@ -303,7 +303,7 @@ BaseTreeView::BaseTreeView(TQWidget *parent, const char *name)
   setLineWidth(2);
   setFullWidth(true);
   setShowSortIndicator(true);
-  setFocusPolicy(TQWidget::ClickFocus);
+  setFocusPolicy(TQ_ClickFocus);
   setShowFolderOpenPixmap(false);
 
   connect(this, TQT_SIGNAL(returnPressed(TQListViewItem *)),
@@ -371,7 +371,7 @@ void BaseTreeView::slotSelectFile(TQListViewItem *item)
     if ( QuantaCommon::checkMimeGroup(urlToOpen,"text") )
     {
       emit openFile(urlToOpen);
-      item->repaint();
+      item->tqrepaint();
     }
     else if ( QuantaCommon::checkMimeGroup(urlToOpen, "image") ) //it may be an image
       {
@@ -385,7 +385,7 @@ void BaseTreeView::slotSelectFile(TQListViewItem *item)
           if (QuantaCommon::denyBinaryInsert(this) == KMessageBox::Yes)
           {
             emit openFile(urlToOpen);
-            item->repaint();
+            item->tqrepaint();
           }
         }
    }
@@ -437,7 +437,7 @@ FileInfoDlg* BaseTreeView::addFileInfoPage(KPropertiesDialog* propDlg)
 
     TQFrame *quantaFilePage = propDlg->addPage(i18n("Quanta File Info"));
     TQVBoxLayout *topLayout = new TQVBoxLayout( quantaFilePage);
-    quantaFileProperties = new FileInfoDlg( quantaFilePage, i18n("Quanta") );
+    quantaFileProperties = new FileInfoDlg( quantaFilePage, i18n("Quanta").ascii() );
 
     int fsize,fimgsize=0;
     int ct=0,imgct=0,position=0;
@@ -478,7 +478,7 @@ FileInfoDlg* BaseTreeView::addFileInfoPage(KPropertiesDialog* propDlg)
             if (position!=-1) imgname=imgname.left(position);
             position=imgname.find("'",0,false);
             if (position!=-1) imgname=imgname.left(position);
-            if (!quantaFileProperties->imageList->findItem(imgname,Qt::ExactMatch))     //check if image was already counted
+            if (!quantaFileProperties->imageList->findItem(imgname,TQt::ExactMatch))     //check if image was already counted
             {
               KURL v(KURL::fromPathOrURL( path ),imgname);
               imgpath=v.path();
@@ -494,15 +494,15 @@ FileInfoDlg* BaseTreeView::addFileInfoPage(KPropertiesDialog* propDlg)
          }
          qfile.close();
 
-         quantaFileProperties->lineNum->setText(i18n("Number of lines: %1").arg(ct));
-         quantaFileProperties->imageNum->setText(i18n("Number of images included: %1").arg(imgct));
-         quantaFileProperties->imageSize->setText(i18n("Size of the included images: %1 bytes").arg(fimgsize));
-         quantaFileProperties->totalSize->setText(i18n("Total size with images: %1 bytes").arg(fsize+fimgsize));
+         quantaFileProperties->lineNum->setText(i18n("Number of lines: %1").tqarg(ct));
+         quantaFileProperties->imageNum->setText(i18n("Number of images included: %1").tqarg(imgct));
+         quantaFileProperties->imageSize->setText(i18n("Size of the included images: %1 bytes").tqarg(fimgsize));
+         quantaFileProperties->totalSize->setText(i18n("Total size with images: %1 bytes").tqarg(fsize+fimgsize));
         }
         else if (mimetype.contains("image"))
         {              // assume it's an image file
           TQImage imagefile=TQImage(nameForInfo);
-          quantaFileProperties->lineNum->setText(i18n("Image size: %1 x %2").arg(imagefile.width()).arg(imagefile.height()));
+          quantaFileProperties->lineNum->setText(i18n("Image size: %1 x %2").tqarg(imagefile.width()).tqarg(imagefile.height()));
           quantaFileProperties->imageNum->hide();
           quantaFileProperties->imageSize->hide();
           quantaFileProperties->totalSize->hide();
@@ -536,7 +536,7 @@ void BaseTreeView::slotOpen()
   if (item)
   {
     emit open(item);
-    item->repaint();
+    item->tqrepaint();
   }
 }
 
@@ -554,7 +554,7 @@ void BaseTreeView::slotOpenWith()
 
 void BaseTreeView::slotOpenWithApplication()
 {
-  KService::Ptr ptr = KService::serviceByDesktopPath(sender()->name());
+  KService::Ptr ptr = KService::serviceByDesktopPath(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name());
   if (ptr)
   {
     KURL::List list;
@@ -648,7 +648,7 @@ void BaseTreeView::slotCopy()
 {
    if (currentItem())
    {
-     QClipboard *cb = TQApplication::clipboard();
+     TQClipboard *cb = TQApplication::tqclipboard();
      cb->setText( currentURL().prettyURL() );
    }
 }
@@ -658,7 +658,7 @@ void BaseTreeView::slotPaste()
 {
   if (currentItem())
   {
-    QClipboard *cb = TQApplication::clipboard();
+    TQClipboard *cb = TQApplication::tqclipboard();
     KURL::List list( TQStringList::split( TQChar('\n'), cb->text() ) );
 
     KURL url = currentURL();
@@ -952,7 +952,7 @@ bool BaseTreeView::isFileOpen(const KURL &url)
 
 bool BaseTreeView::isPathInClipboard()
 {
-  QClipboard *cb = TQApplication::clipboard();
+  TQClipboard *cb = TQApplication::tqclipboard();
   KURL::List list( TQStringList::split( TQChar('\n'), cb->text() ) );
   for ( KURL::List::Iterator it = list.begin(); it != list.end(); ++it )
   {
@@ -972,13 +972,13 @@ void BaseTreeView::slotDocumentClosed(const KURL& url)
     item = (*it)->findTVIByURL(url);
     if (item)
     {
-      item->repaint();
+      item->tqrepaint();
     }
   }
 /*  TQListViewItemIterator iter(this);
   for ( ; iter.current(); ++iter )
   {
-    iter.current()->repaint();
+    iter.current()->tqrepaint();
   }*/
 }
 
@@ -1038,7 +1038,7 @@ void BaseTreeView::doRename(KFileTreeViewItem* kftvi, const TQString & newName)
     bool proceed = true;
     if (QExtFileInfo::exists(newURL, false, this))
     {
-      proceed = KMessageBox::warningContinueCancel(this, i18n("<qt>The file <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>").arg(newURL.prettyURL(0, KURL::StripFileProtocol)),i18n("Overwrite"), i18n("Overwrite")) == KMessageBox::Continue;
+      proceed = KMessageBox::warningContinueCancel(this, i18n("<qt>The file <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>").tqarg(newURL.prettyURL(0, KURL::StripFileProtocol)),i18n("Overwrite"), i18n("Overwrite")) == KMessageBox::Continue;
     }
     if (proceed)
     {
@@ -1184,7 +1184,7 @@ void BaseTreeView::slotCreateSiteTemplate()
      error = true;
 
    if (error)
-     KMessageBox::error(this, i18n("<qt>There was an error while creating the site template tarball.<br>Check that you can read the files from <i>%1</i>, you have write access to <i>%2</i> and that you have enough free space in your temporary folder.</qt>").arg(url.prettyURL(0, KURL::StripFileProtocol)).arg(targetURL.prettyURL(0, KURL::StripFileProtocol)), i18n("Template Creation Error"));
+     KMessageBox::error(this, i18n("<qt>There was an error while creating the site template tarball.<br>Check that you can read the files from <i>%1</i>, you have write access to <i>%2</i> and that you have enough free space in your temporary folder.</qt>").tqarg(url.prettyURL(0, KURL::StripFileProtocol)).tqarg(targetURL.prettyURL(0, KURL::StripFileProtocol)), i18n("Template Creation Error"));
    delete tempFile;
 }
 
@@ -1216,7 +1216,7 @@ void BaseTreeView::slotCreateFile()
       url.setPath(url.directory() + "/" + fileName);
     if (QExtFileInfo::exists(url, false, this))
     {
-      KMessageBox::error(this, i18n("<qt>Cannot create file, because a file named <b>%1</b> already exists.</qt>").arg(fileName), i18n("Error Creating File"));
+      KMessageBox::error(this, i18n("<qt>Cannot create file, because a file named <b>%1</b> already exists.</qt>").tqarg(fileName), i18n("Error Creating File"));
       return;
     }
     KTempFile *tempFile = new KTempFile(tmpDir);
