@@ -154,7 +154,7 @@ ProjectTreeView::ProjectTreeView(TQWidget *parent, const char *name )
   m_folderMenu->insertItem(i18n("&Remove From Project"), this, TQT_SLOT(slotRemoveFromProject(int)));
   m_folderMenu->insertItem(SmallIcon("editdelete"), i18n("&Delete"), this, TQT_SLOT(slotDelete()));
   m_folderMenu->insertSeparator();
-  m_setDocumentRootId = m_folderMenu->insertItem(i18n("Document-&Base Folder"), this, TQT_SLOT(slotChangeDocumentFolderStatus()));
+  m_setDocumentRootId = m_folderMenu->insertItem(i18n("Document-&Base Folder"), this, TQT_SLOT(slotChangeDocumentFoldertqStatus()));
   m_folderMenu->insertItem(i18n("Upload &Status"), m_uploadStatusMenu);
   m_folderMenu->insertItem(SmallIcon("info"), i18n("&Properties"), this, TQT_SLOT(slotProperties()));
 
@@ -188,7 +188,7 @@ ProjectTreeView::~ProjectTreeView(){
 KFileTreeBranch* ProjectTreeView::newBranch(const KURL& url)
 {
   TQString m_projectNameStr = m_projectName+" ";
-  if (m_projectName)
+  if (!m_projectName.isEmpty())
   {
     if (url.protocol() == "file")
     {
@@ -212,7 +212,7 @@ KFileTreeBranch* ProjectTreeView::newBranch(const KURL& url)
           this,           TQT_SLOT(slotPopulateFinished(KFileTreeViewItem*)));
   addBranch(m_projectDir);
   m_projectDir->urlList = m_projectFiles;  // set list for filter
-  if (m_projectName)
+  if (!m_projectName.isEmpty())
     m_projectDir->populate(m_projectDir->rootUrl(), m_projectDir->root());
   else
     m_projectDir->root()->setEnabled(false);
@@ -400,7 +400,7 @@ void ProjectTreeView::slotCreateFile()
       url.setPath(url.directory() + "/" + fileName);
     if (QExtFileInfo::exists(url, false, this))
     {
-      KMessageBox::error(this, i18n("<qt>Cannot create file, because a file named <b>%1</b> already exists.</qt>").arg(fileName), i18n("Error Creating File"));
+      KMessageBox::error(this, i18n("<qt>Cannot create file, because a file named <b>%1</b> already exists.</qt>").tqarg(fileName), i18n("Error Creating File"));
       return;
     }
     KTempFile *tempFile = new KTempFile(tmpDir);
@@ -425,7 +425,7 @@ void ProjectTreeView::slotRemoveFromProject(int askForRemove)
     TQString nice = QExtFileInfo::toRelative(url, m_projectBaseURL).path();
     nice = KStringHandler::lsqueeze(nice, 60);
     if ( !askForRemove ||
-         KMessageBox::warningContinueCancel(this,i18n("<qt>Do you really want to remove <br><b>%1</b><br> from the project?</qt>").arg(nice), i18n("Remove From Project"), KStdGuiItem::remove(), "RemoveFromProject") == KMessageBox::Continue )
+         KMessageBox::warningContinueCancel(this,i18n("<qt>Do you really want to remove <br><b>%1</b><br> from the project?</qt>").tqarg(nice), i18n("Remove From Project"), KStdGuiItem::remove(), "RemoveFromProject") == KMessageBox::Continue )
     {
       if ( currentKFileTreeViewItem()->isDir() ) url.adjustPath(+1);
       emit removeFromProject(url);
@@ -527,7 +527,7 @@ void ProjectTreeView::slotAlwaysUpload()
       url.adjustPath(+1);
     if (m_projectFiles->contains(url) || url == m_projectBaseURL)
     {
-       emit changeUploadStatus(url, ProjectURL::AlwaysUpload);
+       emit changeUploadtqStatus(url, ProjectURL::AlwaysUpload);
     }
 }
 
@@ -541,7 +541,7 @@ void ProjectTreeView::slotNeverUpload()
       url.adjustPath(+1);
     if (m_projectFiles->contains(url) || url == m_projectBaseURL)
     {
-       emit changeUploadStatus(url, ProjectURL::NeverUpload);
+       emit changeUploadtqStatus(url, ProjectURL::NeverUpload);
     }
 }
 
@@ -555,7 +555,7 @@ void ProjectTreeView::slotConfirmUpload()
       url.adjustPath(+1);
     if (m_projectFiles->contains(url) || url == m_projectBaseURL)
     {
-       emit changeUploadStatus(url, ProjectURL::ConfirmUpload);
+       emit changeUploadtqStatus(url, ProjectURL::ConfirmUpload);
     }
 }
 
@@ -573,7 +573,7 @@ void ProjectTreeView::slotUploadMenuAboutToShow()
     ProjectURL *proUrl = m_projectFiles->find( url );
     if (proUrl)
     {
-        switch (proUrl->uploadStatus)
+        switch (proUrl->uploadtqStatus)
         {
             case ProjectURL::NeverUpload:
                {
@@ -595,7 +595,7 @@ void ProjectTreeView::slotUploadMenuAboutToShow()
     }
 }
 
-void ProjectTreeView::slotChangeDocumentFolderStatus()
+void ProjectTreeView::slotChangeDocumentFoldertqStatus()
 {
     KFileTreeViewItem *kftvi = currentKFileTreeViewItem();
     if (! kftvi)
@@ -606,14 +606,14 @@ void ProjectTreeView::slotChangeDocumentFolderStatus()
     if (!m_documentFolderList.contains(currentURL()))
     {
       m_documentFolderList.append(currentURL());
-      emit changeUploadStatus(url, ProjectURL::AlwaysUpload);
-      emit changeDocumentFolderStatus(url, true);
+      emit changeUploadtqStatus(url, ProjectURL::AlwaysUpload);
+      emit changeDocumentFoldertqStatus(url, true);
     } else
     {
       m_documentFolderList.remove(currentURL());
-      emit changeUploadStatus(url, false);
+      emit changeUploadtqStatus(url, false);
     }
-    currentItem()->repaint();
+    currentItem()->tqrepaint();
 }
 
 bool ProjectTreeView::isDocumentFolder(const KURL &url)
