@@ -104,7 +104,7 @@ DualEditableTree::DualEditableTree(TQWidget *parent, const char *name)
 : EditableTree(parent, name)
 {
   curCol = 0;
-  setFocusPolicy(TQWidget::ClickFocus);
+  setFocusPolicy(TQ_ClickFocus);
   this->installEventFilter(this);
   connect(this, TQT_SIGNAL(clicked(TQListViewItem *, const TQPoint &, int )),
     this, TQT_SLOT(itemClicked(TQListViewItem *, const TQPoint &, int )));
@@ -128,7 +128,7 @@ bool DualEditableTree::eventFilter(TQObject *object, TQEvent *event)
 
   if(event->type() == TQEvent::KeyPress && m_editable)
   {
-    TQKeyEvent *keyevent = static_cast<TQKeyEvent *>(event);
+    TQKeyEvent *keyevent = TQT_TQKEYEVENT(event);
     switch(keyevent->key())
     {
       case Key_Left:
@@ -223,7 +223,7 @@ TagAttributeTree::TagAttributeTree(TQWidget *parent, const char *name)
   setSorting(-1);
   setFrameStyle( Panel | Sunken );
   setLineWidth( 2 );
-  setFocusPolicy(TQWidget::ClickFocus);
+  setFocusPolicy(TQ_ClickFocus);
   addColumn(i18n("Attribute Name"));
   addColumn(i18n("Value"));
   setResizeMode(TQListView::LastColumn);
@@ -259,7 +259,7 @@ void TagAttributeTree::setCurrentNode(Node *node)
   AttributeItem *item = 0L;
   TopLevelItem *group = 0L;
   TQString attrName;
-  QTag *qTag = QuantaCommon::tagFromDTD(node);
+  TQTag *qTag = QuantaCommon::tagFromDTD(node);
   Node *n = node->parent;
   while (n)
   {
@@ -458,24 +458,24 @@ EnhancedTagAttributeTree::EnhancedTagAttributeTree(TQWidget *parent, const char
   widgetLayout = new TQGridLayout( this, 1, 1, 11, 6, "MainLayout");
 
   attrTree = new TagAttributeTree(this, "TagAttributeTree");
-  attrTree->setSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::MinimumExpanding);
+  attrTree->tqsetSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::MinimumExpanding);
   widgetLayout->addMultiCellWidget( attrTree, 1, 1, 0, 3 );
 
-  nodeName = new TQLabel(this, i18n( "Node Name" ));
-  nodeName->setSizePolicy( TQSizePolicy( TQSizePolicy::MinimumExpanding, TQSizePolicy::Fixed, 0, 0, nodeName->sizePolicy().hasHeightForWidth() ) );
+  nodeName = new TQLabel(this, i18n( "Node Name" ).ascii());
+  nodeName->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::MinimumExpanding, TQSizePolicy::Fixed, 0, 0, nodeName->sizePolicy().hasHeightForWidth() ) );
 
   widgetLayout->addWidget( nodeName, 0, 0 );
-  deleteTag = new KPushButton(this, i18n( "Delete Tag" ));
+  deleteTag = new KPushButton(this, i18n( "Delete Tag" ).ascii());
   deleteTag->setPixmap(SmallIcon("editdelete"));
   deleteTag->setMaximumHeight(32);
   deleteTag->setMaximumWidth(32);
   TQToolTip::add(deleteTag, i18n("Delete the current tag only."));
 
-  deleteAll = new KPushButton(this, i18n( "Delete All" ));
+  deleteAll = new KPushButton(this, i18n( "Delete All" ).ascii());
   deleteAll->setPixmap(SmallIcon("editdelete"));
   deleteAll->setMaximumHeight(32);
   deleteAll->setMaximumWidth(32);
-  TQToolTip::add(deleteAll, i18n("Delete the current tag and all its children."));
+  TQToolTip::add(deleteAll, i18n("Delete the current tag and all its tqchildren."));
 
   widgetLayout->addWidget( deleteTag, 0, 2 );
   widgetLayout->addWidget( deleteAll, 0, 3 );
@@ -515,7 +515,7 @@ void EnhancedTagAttributeTree::showCaption()
     if(curNode->tag->type == Tag::XmlTag || curNode->tag->type == Tag::XmlTagEnd ||
       curNode->tag->type == Tag::ScriptTag)
     {
-      TQString s = i18n("Current tag: <b>%1</b>").arg(curNode->tag->name);
+      TQString s = i18n("Current tag: <b>%1</b>").tqarg(curNode->tag->name);
       nodeName->setText(KStringHandler::rPixelSqueeze(s, nodeName->fontMetrics(), attrTree->width()- 50));
     }
     else if(curNode->tag->type == Tag::Text)
@@ -586,7 +586,7 @@ void EnhancedTagAttributeTree::deleteNode()
     return;
 
   Node *oldCurNode, *oldCurNodeParent, *child;
-  QTag *oldCurNodeParentQTag;
+  TQTag *oldCurNodeParentTQTag;
   int curLine, curCol;
   long offset;
   DOM::Node domNode;
@@ -624,13 +624,13 @@ void EnhancedTagAttributeTree::deleteNode()
   //Then we see if the new parent - child relationships are valid, and if not, delete the child and restart
   if(oldCurNodeParent)
   {
-    oldCurNodeParentQTag = QuantaCommon::tagFromDTD(oldCurNodeParent);
-    if(oldCurNodeParentQTag)
+    oldCurNodeParentTQTag = QuantaCommon::tagFromDTD(oldCurNodeParent);
+    if(oldCurNodeParentTQTag)
     {
       child = oldCurNodeParent->child;
       while(child)
       {
-        if(!oldCurNodeParentQTag->isChild(child))
+        if(!oldCurNodeParentTQTag->isChild(child))
         {
           kafkaCommon::extractAndDeleteNode(child, modifs, false);
           //too lazy to get the real next node ;-)
