@@ -259,7 +259,7 @@ void TemplatesTreeView::slotMenu(KListView*, TQListViewItem *item, const TQPoint
     return;
   }
   setSelected(item, true);
-  bool hasProject = m_projectName;
+  bool hasProject = !m_projectName.isEmpty();
   m_folderMenu->setItemVisible(m_insertFolderInProject, hasProject);
   m_fileMenu->setItemVisible(m_insertFileInProject, hasProject);
 
@@ -373,7 +373,7 @@ void TemplatesTreeView::slotOpen()
 /** No descriptions */
 void TemplatesTreeView::slotNewDir()
 {
-  NewTemplateDirDlg *createDirDlg = new NewTemplateDirDlg(this,i18n("Create New Template Folder"));
+  NewTemplateDirDlg *createDirDlg = new NewTemplateDirDlg(this,i18n("Create New Template Folder").ascii());
   createDirDlg->typesCombo->insertItem(typeToi18n["text/all"]);
   createDirDlg->typesCombo->insertItem(typeToi18n["file/all"]);
   createDirDlg->typesCombo->insertItem(typeToi18n["template/all"]);
@@ -386,7 +386,7 @@ void TemplatesTreeView::slotNewDir()
     createDirDlg->parentAttr->setText(i18n("&Inherit parent attribute (nothing)"));
    } else
    {
-     createDirDlg->parentAttr->setText(i18n("&Inherit parent attribute (%1)").arg(typeToi18n[m_dirInfo.mimeType]));
+     createDirDlg->parentAttr->setText(i18n("&Inherit parent attribute (%1)").tqarg(typeToi18n[m_dirInfo.mimeType]));
    }
    if (createDirDlg->exec())
    {
@@ -404,7 +404,7 @@ void TemplatesTreeView::slotNewDir()
    if (!dir.mkdir(startDir+"/"+createDirDlg->dirName->text()))
    {
       KMessageBox::error(this,i18n("Error while creating the new folder.\n \
-                   Maybe you do not have permission to write in the %1 folder.").arg(startDir));
+                   Maybe you do not have permission to write in the %1 folder.").tqarg(startDir));
       return;
    }
    if (! createDirDlg->parentAttr->isChecked())
@@ -467,13 +467,13 @@ void TemplatesTreeView::contentsDropEvent(TQDropEvent *e)
         bool proceed = true;
         if (QExtFileInfo::exists(url, false, this))
         {
-          proceed = KMessageBox::warningContinueCancel(this, i18n("<qt>The file <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>").arg(url.prettyURL(0, KURL::StripFileProtocol)),i18n("Overwrite"), i18n("Overwrite")) == KMessageBox::Continue;
+          proceed = KMessageBox::warningContinueCancel(this, i18n("<qt>The file <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>").tqarg(url.prettyURL(0, KURL::StripFileProtocol)),i18n("Overwrite"), i18n("Overwrite")) == KMessageBox::Continue;
         }
         if (proceed)
         {
           if (!QuantaNetAccess::upload(tempFile->name(), url, m_parent, false))
           {
-            KMessageBox::error(this,i18n("<qt>Could not write to file <b>%1</b>.<br>Check if you have rights to write there or that your connection is working.</qt>").arg(url.prettyURL(0, KURL::StripFileProtocol)));
+            KMessageBox::error(this,i18n("<qt>Could not write to file <b>%1</b>.<br>Check if you have rights to write there or that your connection is working.</qt>").tqarg(url.prettyURL(0, KURL::StripFileProtocol)));
           }
         }
         delete tempFile;
@@ -564,7 +564,7 @@ void TemplatesTreeView::slotProperties()
 //Always add the Quanta directory page
   TQFrame *quantaDirPage = propDlg->addPage(i18n("Quanta Template"));
   TQVBoxLayout *topLayout = new TQVBoxLayout( quantaDirPage);
-  m_quantaProperties = new QuantaPropertiesPage( quantaDirPage, i18n("Quanta") );
+  m_quantaProperties = new QuantaPropertiesPage( quantaDirPage, i18n("Quanta").ascii() );
 
   m_quantaProperties->typesCombo->insertItem(typeToi18n["text/all"]);
   m_quantaProperties->typesCombo->insertItem(typeToi18n["file/all"]);
@@ -619,7 +619,7 @@ void TemplatesTreeView::slotProperties()
     m_quantaProperties->parentAttr->setText(i18n("&Inherit parent attribute (nothing)"));
    } else
    {
-    m_quantaProperties->parentAttr->setText(i18n("&Inherit parent attribute (%1)").arg(typeToi18n[m_parentDirInfo.mimeType]));
+    m_quantaProperties->parentAttr->setText(i18n("&Inherit parent attribute (%1)").tqarg(typeToi18n[m_parentDirInfo.mimeType]));
    }
    m_quantaProperties->preTextEdit->setText(m_dirInfo.preText);
    m_quantaProperties->postTextEdit->setText(m_dirInfo.postText);
@@ -846,7 +846,7 @@ void TemplatesTreeView::slotPaste()
 {
   if (currentItem())
   {
-    QClipboard *cb = TQApplication::clipboard();
+    TQClipboard *cb = TQApplication::tqclipboard();
     KURL::List list( TQStringList::split( TQChar('\n'), cb->text() ) );
 
     KURL url;
@@ -873,11 +873,11 @@ void TemplatesTreeView::slotDelete()
     KURL url = currentURL();
     TQString msg;
     if ( currentKFileTreeViewItem()->isDir() )
-      msg = i18n("Do you really want to delete folder \n%1 ?\n").arg(url.path());
+      msg = i18n("Do you really want to delete folder \n%1 ?\n").tqarg(url.path());
     else
-      msg = i18n("Do you really want to delete file \n%1 ?\n").arg(url.path());
+      msg = i18n("Do you really want to delete file \n%1 ?\n").tqarg(url.path());
 
-    if ( KMessageBox::warningContinueCancel(this, msg, TQString::null, KStdGuiItem::del()) == KMessageBox::Continue )
+    if ( KMessageBox::warningContinueCancel(this, msg, TQString(), KStdGuiItem::del()) == KMessageBox::Continue )
     {
       KIO::Job *job = KIO::del(url);
       connect( job, TQT_SIGNAL( result( KIO::Job *) ), this , TQT_SLOT( slotJobFinished( KIO::Job *) ) );
@@ -925,7 +925,7 @@ KURL TemplatesTreeView::filterTemplate()
    filterAction->setInputFileName(url.path());
    filterAction->execute(true);
    filterAction->setOutputFile(0L);
-   filterAction->setInputFileName(TQString::null);
+   filterAction->setInputFileName(TQString());
    tempFile->close();
    tempFileList.append(tempFile);
    url.setPath(tempFile->name());
@@ -982,7 +982,7 @@ void TemplatesTreeView::slotSendInMail()
     TQStringList attachmentFile;
     attachmentFile += createTemplateTarball();
 
-    TagMailDlg *mailDlg = new TagMailDlg( this, i18n("Send template in email"));
+    TagMailDlg *mailDlg = new TagMailDlg( this, i18n("Send template in email").ascii() );
     TQString toStr;
     TQString message = i18n("Hi,\n This is a Quanta Plus [http://quanta.kdewebdev.org] template tarball.\n\nHave fun.\n");
     TQString titleStr;
@@ -1006,7 +1006,7 @@ void TemplatesTreeView::slotSendInMail()
         delete mailDlg;
         return;
       }
-      kapp->invokeMailer(toStr, TQString::null, TQString::null, subjectStr, message, TQString::null, attachmentFile);
+      kapp->invokeMailer(toStr, TQString(), TQString(), subjectStr, message, TQString(), attachmentFile);
     }
     delete mailDlg;
 }
@@ -1064,7 +1064,7 @@ void TemplatesTreeView::slotExtractSiteTemplate()
           KIO::NetAccess::removeTempFile(tempFile);
           if (!m_projectBaseURL.isEmpty() && !QExtFileInfo::toRelative(targetURL, m_projectBaseURL).url().startsWith("."))
           {
-             if (KMessageBox::questionYesNo(this, i18n("You have extracted the site template to a folder which is not under your main project folder.\nDo you want to copy the folder into the main project folder?"), TQString::null, i18n("Copy Folder"), i18n("Do Not Copy")) == KMessageBox::Yes)
+             if (KMessageBox::questionYesNo(this, i18n("You have extracted the site template to a folder which is not under your main project folder.\nDo you want to copy the folder into the main project folder?"), TQString(), i18n("Copy Folder"), i18n("Do Not Copy")) == KMessageBox::Yes)
              {
                  emit insertDirInProject(targetURL);
              }
@@ -1072,7 +1072,7 @@ void TemplatesTreeView::slotExtractSiteTemplate()
       } else
          error = true;
       if (error)
-        KMessageBox::error(this, i18n("<qt>Some error happened while extracting the <i>%1</i> site template file.<br>Check that you have write permission for <i>%2</i> and that there is enough free space in your temporary folder.</qt>").arg(url.prettyURL(0, KURL::StripFileProtocol)).arg(targetURL.prettyURL(0, KURL::StripFileProtocol)));
+        KMessageBox::error(this, i18n("<qt>Some error happened while extracting the <i>%1</i> site template file.<br>Check that you have write permission for <i>%2</i> and that there is enough free space in your temporary folder.</qt>").tqarg(url.prettyURL(0, KURL::StripFileProtocol)).tqarg(targetURL.prettyURL(0, KURL::StripFileProtocol)));
    }
 }
 
