@@ -41,7 +41,7 @@
 #include <ktempdir.h>
 #include <ktempfile.h>
 
-//remove the below ones when KQPasteAction is removed
+//remove the below ones when KTQPasteAction is removed
 #include <dcopclient.h>
 #include <kdebug.h>
 #include <kpopupmenu.h>
@@ -60,7 +60,7 @@
 //#include "resource.h"
 
 
-QConfig qConfig; //holds the main configuration settings
+TQConfig qConfig; //holds the main configuration settings
 TQString tmpDir;
 
 TQRegExp scriptBeginRx;
@@ -148,7 +148,7 @@ bool QuantaCommon::isSingleTag(const TQString& dtdName, const TQString& tag)
   if (dtd && !tag.isEmpty())
   {
     TQString searchForTag = (dtd->caseSensitive) ? tag : tag.upper();
-    QTag* qtag = dtd->tagsList->find(searchForTag);
+    TQTag* qtag = dtd->tagsList->find(searchForTag);
     if (qtag)
         single = qtag->isSingle();
   }
@@ -165,7 +165,7 @@ bool QuantaCommon::isOptionalTag(const TQString& dtdName, const TQString& tag)
   if (dtd && !tag.isEmpty())
   {
     TQString searchForTag = (dtd->caseSensitive) ? tag : tag.upper();
-    QTag* qtag = dtd->tagsList->find(searchForTag);
+    TQTag* qtag = dtd->tagsList->find(searchForTag);
     if (qtag)
         optional = qtag->isOptional();
   }
@@ -196,7 +196,7 @@ AttributeList* QuantaCommon::tagAttributes(const TQString& dtdName, const TQStri
   if (dtd && !tag.isEmpty())
   {
     TQString searchForTag = (dtd->caseSensitive) ? tag : tag.upper();
-    QTag* qtag = dtd->tagsList->find(searchForTag);
+    TQTag* qtag = dtd->tagsList->find(searchForTag);
     if (qtag)
         attrs = qtag->attributes();
   }
@@ -204,17 +204,17 @@ AttributeList* QuantaCommon::tagAttributes(const TQString& dtdName, const TQStri
   return attrs;
 }
 
-/** Returns the QTag object for the tag "tag" from the DTD named "dtdname". */
-QTag* QuantaCommon::tagFromDTD(const TQString& dtdName, const TQString& tag)
+/** Returns the TQTag object for the tag "tag" from the DTD named "dtdname". */
+TQTag* QuantaCommon::tagFromDTD(const TQString& dtdName, const TQString& tag)
 {
   const DTDStruct* dtd = DTDs::ref()->find(dtdName);
   return tagFromDTD(dtd, tag);
 }
 
-/** Returns the QTag object for the tag "tag" from the DTD. */
-QTag* QuantaCommon::tagFromDTD(const DTDStruct *dtd, const TQString& tag)
+/** Returns the TQTag object for the tag "tag" from the DTD. */
+TQTag* QuantaCommon::tagFromDTD(const DTDStruct *dtd, const TQString& tag)
 {
-  QTag *qtag = 0;
+  TQTag *qtag = 0;
   if (dtd && !tag.isEmpty())
   {
     TQString searchForTag = (dtd->caseSensitive) ? tag : tag.upper();
@@ -224,8 +224,8 @@ QTag* QuantaCommon::tagFromDTD(const DTDStruct *dtd, const TQString& tag)
  return qtag;
 }
 
-/** Returns the QTag object for the node "node" from node's DTD. */
-QTag* QuantaCommon::tagFromDTD(Node *node)
+/** Returns the TQTag object for the node "node" from node's DTD. */
+TQTag* QuantaCommon::tagFromDTD(Node *node)
 {
   if(!node || !node->tag)
     return 0L;
@@ -382,8 +382,8 @@ TQString QuantaCommon::qUrl(const KURL &url)
 void QuantaCommon::dirCreationError(TQWidget *widget, const KURL& url)
 {
   KMessageBox::error(widget, i18n("<qt>Cannot create folder<br><b>%1</b>.<br>Check that you have write permission in the parent folder or that the connection to<br><b>%2</b><br> is valid.</qt>")
-                             .arg(url.prettyURL(0, KURL::StripFileProtocol))
-                             .arg(url.protocol()+"://"+url.user()+"@"+url.host()));}
+                             .tqarg(url.prettyURL(0, KURL::StripFileProtocol))
+                             .tqarg(url.protocol()+"://"+url.user()+"@"+url.host()));}
 
 /**
 Adds the backslash before the special chars (like ?, *, . ) so the returned
@@ -596,7 +596,7 @@ DCOPReply QuantaCommon::callDCOPMethod(const TQString& interface, const TQString
   if (!kapp->inherits("KUniqueApplication"))
   {
     pid_t pid = ::getpid();
-    app += TQString("-%1").arg(pid);
+    app += TQString("-%1").tqarg(pid);
   }
   DCOPRef quantaRef(app.utf8(), interface.utf8());
   DCOPReply reply;
@@ -707,7 +707,7 @@ bool QuantaCommon::checkOverwrite(const KURL& url, TQWidget *window)
   if (QExtFileInfo::exists(url, false, window))
   {
     if (KMessageBox::warningContinueCancel(window,
-            i18n( "<qt>The file <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>" ).arg(url.prettyURL(0, KURL::StripFileProtocol)), TQString::null, i18n("Overwrite")) == KMessageBox::Cancel)
+            i18n( "<qt>The file <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>" ).tqarg(url.prettyURL(0, KURL::StripFileProtocol)), TQString(), i18n("Overwrite")) == KMessageBox::Cancel)
             result = false;
   }
 
@@ -746,8 +746,8 @@ TQString QuantaCommon::encodedChar(uint code)
 {
    
   if (replacementMap.contains(code))
-    return TQString("%1;").arg(replacementMap[code]);
+    return TQString("%1;").tqarg(replacementMap[code]);
   else
-    return TQString("&#%1;").arg(code);
+    return TQString("&#%1;").tqarg(code);
 }
 
