@@ -74,7 +74,7 @@ int MyProcess::commSetupDoneC()
 
 TagAction::TagAction( TQDomElement *element, KMainWindow *parentMainWindow, bool toggle)
     : KToggleAction(element->attribute("text").isEmpty() ? TQString("") : i18n(element->attribute("text").utf8()), 
-                    KShortcut(element->attribute("shortcut")), 0, 0, parentMainWindow->actionCollection(), element->attribute("name")),
+                    KShortcut(element->attribute("shortcut")), 0, 0, parentMainWindow->actionCollection(), element->attribute("name").ascii()),
  //disable toggle now m_toggle(toggle)
   m_toggle(false)
 {
@@ -93,8 +93,8 @@ TagAction::TagAction( TQDomElement *element, KMainWindow *parentMainWindow, bool
   m_file = 0L;
   loopStarted = false;
 #if KDE_VERSION >= KDE_MAKE_VERSION(3,4,0)
-  connect(this, TQT_SIGNAL(activated(KAction::ActivationReason, Qt::ButtonState)), 
-          TQT_SLOT(slotActionActivated(KAction::ActivationReason, Qt::ButtonState)));
+  connect(this, TQT_SIGNAL(activated(KAction::ActivationReason, TQt::ButtonState)), 
+          TQT_SLOT(slotActionActivated(KAction::ActivationReason, TQt::ButtonState)));
 #else
   connect(this, TQT_SIGNAL(activated()), TQT_SLOT(slotActionActivated()));
 #endif
@@ -114,7 +114,7 @@ TQString TagAction::type()
 }
 
 #if KDE_VERSION >= KDE_MAKE_VERSION(3,4,0)
-bool TagAction::slotActionActivated(KAction::ActivationReason reason, Qt::ButtonState /*state*/)
+bool TagAction::slotActionActivated(KAction::ActivationReason reason, TQt::ButtonState /*state*/)
 {
     QuantaView *view = ViewManager::ref()->activeView();
     if ( !view || !view->document())
@@ -162,7 +162,7 @@ bool TagAction::slotActionActivated(KAction::ActivationReason reason, Qt::Button
               start_node = end_node = current_node;
               start_offset = end_offset = current_offset;
   
-              QTag* tag_description = QuantaCommon::tagFromDTD(KafkaDocument::ref()->getCurrentDoc()->defaultDTD(), XMLTagName());
+              TQTag* tag_description = QuantaCommon::tagFromDTD(KafkaDocument::ref()->getCurrentDoc()->defaultDTD(), XMLTagName());
               scope = tag_description->scope();
   //             Q_ASSERT(!scope.isNull());
               if(scope.isNull())
@@ -281,7 +281,7 @@ bool TagAction::slotActionActivated(KAction::ActivationReason reason, Qt::Button
                 s1 += " "+QuantaCommon::attrCase(attr);
             if (otag.text().right(1) == ">")
             {
-                QTag *dtdTag = QuantaCommon::tagFromDTD(w->defaultDTD(), name);
+                TQTag *dtdTag = QuantaCommon::tagFromDTD(w->defaultDTD(), name);
                 if ( w->defaultDTD()->singleTagStyle == "xml" && dtdTag &&
                      (dtdTag->isSingle() || (!qConfig.closeOptionalTags && dtdTag->isOptional()))
                    )
@@ -338,10 +338,10 @@ bool TagAction::slotActionActivated(KAction::ActivationReason reason, Qt::Button
             pid_t pid = ::getpid();
             if (kapp->inherits("KUniqueApplication"))
             {
-                command.replace("%pid", TQString("unique %1").arg(pid));
+                command.replace("%pid", TQString("unique %1").tqarg(pid));
             } else
             {
-                command.replace("%pid", TQString("%1").arg(pid));
+                command.replace("%pid", TQString("%1").tqarg(pid));
             }
             TQString buffer;
             TQString inputType = script.attribute("input","none");
@@ -461,7 +461,7 @@ bool TagAction::slotActionActivated(KAction::ActivationReason reason, Qt::Button
                 if (proc->start(KProcess::NotifyOnExit, KProcess::All))
                 {
                     emit clearMessages();
-                    emit showMessage(i18n("The \"%1\" script started.\n").arg(actionText()), false);
+                    emit showMessage(i18n("The \"%1\" script started.\n").tqarg(actionText()), false);
                     if (!m_useInputFile)
                     {
                         if ( inputType == "current" || inputType == "selected" )
@@ -472,11 +472,11 @@ bool TagAction::slotActionActivated(KAction::ActivationReason reason, Qt::Button
                     proc->closeStdin();
                 } else
                 {
-                    KMessageBox::error(m_parentMainWindow, i18n("<qt>There was an error running <b>%1</b>.<br>Check that you have the <i>%2</i> executable installed and it is accessible.</qt>").arg(command + " " + args).arg(command), i18n("Script Not Found"));
+                    KMessageBox::error(m_parentMainWindow, i18n("<qt>There was an error running <b>%1</b>.<br>Check that you have the <i>%2</i> executable installed and it is accessible.</qt>").tqarg(command + " " + args).tqarg(command), i18n("Script Not Found"));
                     ViewManager::ref()->activeView()->setFocus();
                     if (loopStarted)
                     {
-                        qApp->exit_loop();
+                        tqApp->exit_loop();
                         loopStarted = false;
                     }
                     return false;
@@ -486,9 +486,9 @@ bool TagAction::slotActionActivated(KAction::ActivationReason reason, Qt::Button
     return true;
 }
 #else
- // hack to compile. moc doesn't check the "#ifdef" at the declaration and the compiler complains 
+ // hack to compile. tqmoc doesn't check the "#ifdef" at the declaration and the compiler complains 
  // of no matching function.
-bool TagAction::slotActionActivated(KAction::ActivationReason /*reason*/, Qt::ButtonState /*state*/)
+bool TagAction::slotActionActivated(KAction::ActivationReason /*reason*/, TQt::ButtonState /*state*/)
 {return true;}
 #endif
 
@@ -535,7 +535,7 @@ bool TagAction::slotActionActivated()
           s1 += " "+QuantaCommon::attrCase(attr);
        if (otag.text().right(1) == ">")
        {
-         QTag *dtdTag = QuantaCommon::tagFromDTD(w->defaultDTD(), name);
+         TQTag *dtdTag = QuantaCommon::tagFromDTD(w->defaultDTD(), name);
          if ( w->defaultDTD()->singleTagStyle == "xml" && dtdTag &&
               (dtdTag->isSingle() || (!qConfig.closeOptionalTags && dtdTag->isOptional()))
             )
@@ -592,10 +592,10 @@ bool TagAction::slotActionActivated()
     pid_t pid = ::getpid();
     if (kapp->inherits("KUniqueApplication"))
     {
-      command.replace("%pid", TQString("unique %1").arg(pid));
+      command.replace("%pid", TQString("unique %1").tqarg(pid));
     } else
     {
-      command.replace("%pid", TQString("%1").arg(pid));
+      command.replace("%pid", TQString("%1").tqarg(pid));
     }
     TQString buffer;
     TQString inputType = script.attribute("input","none");
@@ -715,7 +715,7 @@ bool TagAction::slotActionActivated()
     if (proc->start(KProcess::NotifyOnExit, KProcess::All))
     {
       emit clearMessages();
-      emit showMessage(i18n("The \"%1\" script started.\n").arg(actionText()), false);
+      emit showMessage(i18n("The \"%1\" script started.\n").tqarg(actionText()), false);
       if (!m_useInputFile)
       {
         if ( inputType == "current" || inputType == "selected" )
@@ -726,11 +726,11 @@ bool TagAction::slotActionActivated()
       proc->closeStdin();
     } else
     {
-      KMessageBox::error(m_parentMainWindow, i18n("<qt>There was an error running <b>%1</b>.<br>Check that you have the <i>%2</i> executable installed and it is accessible.</qt>").arg(command + " " + args).arg(command), i18n("Script Not Found"));
+      KMessageBox::error(m_parentMainWindow, i18n("<qt>There was an error running <b>%1</b>.<br>Check that you have the <i>%2</i> executable installed and it is accessible.</qt>").tqarg(command + " " + args).tqarg(command), i18n("Script Not Found"));
       ViewManager::ref()->activeView()->setFocus();
       if (loopStarted)
       {
-          qApp->exit_loop();
+          tqApp->exit_loop();
           loopStarted = false;
       }
       return false;
@@ -787,7 +787,7 @@ void TagAction::slotGetScriptOutput( KProcess *, char *buffer, int buflen )
     if ( firstOutput )
     {
       emit showMessagesView();
-      emit showMessage(i18n("The \"%1\" script output:\n").arg(actionText()), false);
+      emit showMessage(i18n("The \"%1\" script output:\n").tqarg(actionText()), false);
     }
     emit showMessage(text, true);
   } else
@@ -847,7 +847,7 @@ void TagAction::slotGetScriptError( KProcess *, char *buffer, int buflen )
     if ( firstError )
     {
       emit showMessagesView();
-      emit showMessage(i18n("The \"%1\" script output:\n").arg(actionText()), false);
+      emit showMessage(i18n("The \"%1\" script output:\n").tqarg(actionText()), false);
     }
     emit showMessage(text, true);
   }
@@ -925,7 +925,7 @@ TQString TagAction::openXMLTagString() const
     if (otag.text().right(1) == ">")
     {
         Document* w = ViewManager::ref()->activeView()->document();
-        QTag *dtdTag = QuantaCommon::tagFromDTD(w->defaultDTD(), name);
+        TQTag *dtdTag = QuantaCommon::tagFromDTD(w->defaultDTD(), name);
         if ( w->defaultDTD()->singleTagStyle == "xml" && dtdTag &&
              (dtdTag->isSingle() || (!qConfig.closeOptionalTags && dtdTag->isOptional()))
            )
@@ -967,10 +967,10 @@ void TagAction::slotProcessExited(KProcess *process)
 {
   if (loopStarted)
   {
-    qApp->exit_loop();
+    tqApp->exit_loop();
     loopStarted = false;
   }
-  emit showMessage(i18n("The \"%1\" script has exited.").arg(actionText()), false);
+  emit showMessage(i18n("The \"%1\" script has exited.").tqarg(actionText()), false);
   delete process;
 }
 
@@ -1008,7 +1008,7 @@ void TagAction::execute(bool blocking)
 /** Timeout occurred while waiting for some network function to return. */
 void TagAction::slotTimeout()
 {
-  if ((m_killCount == 0) && (KMessageBox::questionYesNo(m_parentMainWindow, i18n("<qt>The filtering action <b>%1</b> seems to be locked.<br>Do you want to terminate it?</qt>").arg(actionText()), i18n("Action Not Responding"), i18n("Terminate"), i18n("Keep Running")) == KMessageBox::Yes))
+  if ((m_killCount == 0) && (KMessageBox::questionYesNo(m_parentMainWindow, i18n("<qt>The filtering action <b>%1</b> seems to be locked.<br>Do you want to terminate it?</qt>").tqarg(actionText()), i18n("Action Not Responding"), i18n("Terminate"), i18n("Keep Running")) == KMessageBox::Yes))
   {
     if (::kill(-proc->pid(), SIGTERM))
     {
@@ -1021,7 +1021,7 @@ void TagAction::slotTimeout()
     ::kill(-proc->pid(), SIGKILL);
     if (loopStarted)
     {
-        qApp->exit_loop();
+        tqApp->exit_loop();
         loopStarted = false;
     }
     return;
@@ -1062,12 +1062,12 @@ void TagAction::applyTagInSelection(Node* start_node, int start_offset, Node* en
     //user to add this node. In that case, try to insert the Node in the closest parent accepting it.
     //e.g. TR : a normal insertion would require to have the caret in the TABLE Node, but it is
     //impossible
-    QTag* nodeQTag = QuantaCommon::tagFromDTD(w->defaultDTD(), node->tag->name);
-    if (!nodeQTag) return;
+    TQTag* nodeTQTag = QuantaCommon::tagFromDTD(w->defaultDTD(), node->tag->name);
+    if (!nodeTQTag) return;
 
     bool specialTagInsertion = false;
-    TQPtrList<QTag> qTagList = nodeQTag->parents();
-    QTag* qTag = 0;
+    TQPtrList<TQTag> qTagList = nodeTQTag->parents();
+    TQTag* qTag = 0;
     for (qTag = qTagList.first(); qTag; qTag = qTagList.next())
     {
         if (qTag->isChild("#text", false))
@@ -1083,8 +1083,8 @@ void TagAction::applyTagInSelection(Node* start_node, int start_offset, Node* en
         //let's try to insert this node in the closest parent accepting it.
         while (nodeParent)
         {
-            QTag* nodeParentQTag = QuantaCommon::tagFromDTD(w->defaultDTD(), nodeParent->tag->name);
-            if (nodeParentQTag && nodeParentQTag->isChild(node))
+            TQTag* nodeParentTQTag = QuantaCommon::tagFromDTD(w->defaultDTD(), nodeParent->tag->name);
+            if (nodeParentTQTag && nodeParentTQTag->isChild(node))
             {
                 nodeCursor = kafkaCommon::createMandatoryNodeSubtree(node, w);
                 start_offset = 0;
@@ -1095,7 +1095,7 @@ void TagAction::applyTagInSelection(Node* start_node, int start_offset, Node* en
             nodeParent = nodeParent->parent;
         }
     }
-    else if(!nodeQTag->isSingle())
+    else if(!nodeTQTag->isSingle())
     {
         //If some text is selected in kafka, surround the selection with the new Node.
         if(!start_node|| !end_node)
