@@ -30,9 +30,10 @@
 class TQListBox;
 class TQListView;
 
-class PamView : public QWidget
+class PamView : public TQWidget
 {
   Q_OBJECT
+  TQ_OBJECT
 public:
   PamView(TQWidget *parent = 0, const char *name = 0);
   virtual ~PamView();
