@@ -221,7 +221,7 @@ bool ProjectManager::loadProject(const KURL &projectURL)
   if( projectLoaded() && url.path() == projectFile().path() )
   {
     if (KMessageBox::questionYesNo(TopLevel::getInstance()->main(),
-        i18n("Are you sure you want to reopen the current project?"), TQString::null, i18n("Reopen"), i18n("Do Not Reopen")) == KMessageBox::No)
+        i18n("Are you sure you want to reopen the current project?"), TQString(), i18n("Reopen"), i18n("Do Not Reopen")) == KMessageBox::No)
       return false;
   }
 
@@ -355,7 +355,7 @@ bool ProjectManager::loadProjectFile()
   TQString path;
   if (!KIO::NetAccess::download(m_info->m_projectURL, path, 0)) {
     KMessageBox::sorry(TopLevel::getInstance()->main(),
-        i18n("Could not read project file: %1").arg(m_info->m_projectURL.prettyURL()));
+        i18n("Could not read project file: %1").tqarg(m_info->m_projectURL.prettyURL()));
     return false;
   }
 
@@ -363,7 +363,7 @@ bool ProjectManager::loadProjectFile()
   if (!fin.open(IO_ReadOnly))
   {
     KMessageBox::sorry(TopLevel::getInstance()->main(),
-        i18n("Could not read project file: %1").arg(m_info->m_projectURL.prettyURL()));
+        i18n("Could not read project file: %1").tqarg(m_info->m_projectURL.prettyURL()));
     return false;
   }
 
@@ -374,7 +374,7 @@ bool ProjectManager::loadProjectFile()
     KMessageBox::sorry(TopLevel::getInstance()->main(),
         i18n("This is not a valid project file.\n"
              "XML error in line %1, column %2:\n%3")
-             .arg(errorLine).arg(errorCol).arg(errorMsg));
+             .tqarg(errorLine).tqarg(errorCol).tqarg(errorMsg));
     fin.close();
     KIO::NetAccess::removeTempFile(path);
     return false;
@@ -411,7 +411,7 @@ bool ProjectManager::saveProjectFile()
     API::getInstance()->projectDom()->save(stream, 2);
     fout.close();
   } else {
-    KTempFile fout(TQString::fromLatin1("kdevelop3"));
+    KTempFile fout(TQString::tqfromLatin1("kdevelop3"));
     fout.setAutoDelete(true);
     if (fout.status() != 0) {
       KMessageBox::sorry(TopLevel::getInstance()->main(), i18n("Could not write the project file."));
@@ -486,7 +486,7 @@ bool ProjectManager::loadProjectPart()
   if (!projectService) {
     KMessageBox::sorry(TopLevel::getInstance()->main(),
         i18n("No project management plugin %1 found.")
-            .arg(m_info->m_projectPlugin));
+            .tqarg(m_info->m_projectPlugin));
     return false;
   }
 
@@ -496,7 +496,7 @@ bool ProjectManager::loadProjectPart()
   if ( !projectPart ) {
     KMessageBox::sorry(TopLevel::getInstance()->main(),
         i18n("Could not create project management plugin %1.")
-            .arg(m_info->m_projectPlugin));
+            .tqarg(m_info->m_projectPlugin));
     return false;
   }
 
@@ -536,13 +536,13 @@ bool ProjectManager::loadLanguageSupport(const TQString& lang)
   }
 
   KTrader::OfferList languageSupportOffers =
-    KTrader::self()->query(TQString::fromLatin1("KDevelop/LanguageSupport"),
-                           TQString::fromLatin1("[X-KDevelop-Language] == '%1' and [X-KDevelop-Version] == %2").arg(lang).arg(KDEVELOP_PLUGIN_VERSION));
+    KTrader::self()->query(TQString::tqfromLatin1("KDevelop/LanguageSupport"),
+                           TQString::tqfromLatin1("[X-KDevelop-Language] == '%1' and [X-KDevelop-Version] == %2").tqarg(lang).tqarg(KDEVELOP_PLUGIN_VERSION));
 
   if (languageSupportOffers.isEmpty()) {
     KMessageBox::sorry(TopLevel::getInstance()->main(),
         i18n("No language plugin for %1 found.")
-            .arg(lang));
+            .tqarg(lang));
     return false;
   }
 
@@ -556,7 +556,7 @@ bool ProjectManager::loadLanguageSupport(const TQString& lang)
   if ( !langSupport ) {
     KMessageBox::sorry(TopLevel::getInstance()->main(),
         i18n("Could not create language plugin for %1.")
-            .arg(lang));
+            .tqarg(lang));
     return false;
   }
 
