@@ -61,11 +61,11 @@ SimpleMainWindow::SimpleMainWindow(TQWidget* parent, const char *name)
     :DMainWindow(parent, name)
 {
     resize(800, 600); // starts kdevelop at 800x600 the first time
-    m_mainWindowShare = new MainWindowShare(this);
+    m_mainWindowShare = new MainWindowShare(TQT_TQOBJECT(this));
 
-    connect(m_bottomDock, TQT_SIGNAL(hidden()), this, TQT_SLOT(raiseEditor()));
-    connect(m_leftDock, TQT_SIGNAL(hidden()), this, TQT_SLOT(raiseEditor()));
-    connect(m_rightDock, TQT_SIGNAL(hidden()), this, TQT_SLOT(raiseEditor()));
+    connect(m_bottomDock, TQT_SIGNAL(hidden()), TQT_TQOBJECT(this), TQT_SLOT(raiseEditor()));
+    connect(m_leftDock, TQT_SIGNAL(hidden()), TQT_TQOBJECT(this), TQT_SLOT(raiseEditor()));
+    connect(m_rightDock, TQT_SIGNAL(hidden()), TQT_TQOBJECT(this), TQT_SLOT(raiseEditor()));
 }
 
 SimpleMainWindow::~ SimpleMainWindow( )
@@ -105,19 +105,19 @@ void SimpleMainWindow::init()
             i18n("Could Not Find Plugins") );
     }
 
-    connect(Core::getInstance(), TQT_SIGNAL(coreInitialized()), this, TQT_SLOT(slotCoreInitialized()));
-    connect(Core::getInstance(), TQT_SIGNAL(projectOpened()), this, TQT_SLOT(projectOpened()));
-    connect(Core::getInstance(), TQT_SIGNAL(projectClosed()), this, TQT_SLOT(projectClosed()));
+    connect(Core::getInstance(), TQT_SIGNAL(coreInitialized()), TQT_TQOBJECT(this), TQT_SLOT(slotCoreInitialized()));
+    connect(Core::getInstance(), TQT_SIGNAL(projectOpened()), TQT_TQOBJECT(this), TQT_SLOT(projectOpened()));
+    connect(Core::getInstance(), TQT_SIGNAL(projectClosed()), TQT_TQOBJECT(this), TQT_SLOT(projectClosed()));
     connect(Core::getInstance(), TQT_SIGNAL(contextMenu(TQPopupMenu *, const Context *)),
-        this, TQT_SLOT(contextMenu(TQPopupMenu *, const Context *)));
+        TQT_TQOBJECT(this), TQT_SLOT(contextMenu(TQPopupMenu *, const Context *)));
     connect(PartController::getInstance(), TQT_SIGNAL(partURLChanged(KParts::ReadOnlyPart *)),
-        this, TQT_SLOT(slotPartURLChanged(KParts::ReadOnlyPart * )));
+        TQT_TQOBJECT(this), TQT_SLOT(slotPartURLChanged(KParts::ReadOnlyPart * )));
     connect(PartController::getInstance(), TQT_SIGNAL(activePartChanged(KParts::Part*)),
-        this, TQT_SLOT(activePartChanged(KParts::Part*)));
+        TQT_TQOBJECT(this), TQT_SLOT(activePartChanged(KParts::Part*)));
 
     connect(PartController::getInstance(),
         TQT_SIGNAL(documentChangedState(const KURL &, DocumentState)),
-        this, TQT_SLOT(documentChangedState(const KURL&, DocumentState)));
+        TQT_TQOBJECT(this), TQT_SLOT(documentChangedState(const KURL&, DocumentState)));
 
     loadSettings();
 }
@@ -403,64 +403,64 @@ void SimpleMainWindow::createFramework()
     PartController::createInstance( this );
 
     connect(PartController::getInstance(), TQT_SIGNAL(activePartChanged(KParts::Part*)),
-        this, TQT_SLOT(createGUI(KParts::Part*)));
+        TQT_TQOBJECT(this), TQT_SLOT(createGUI(KParts::Part*)));
 }
 
 void SimpleMainWindow::createActions()
 {
     m_raiseEditor = new KAction(i18n("Raise &Editor"), ALT+Key_C,
-        this, TQT_SLOT(raiseEditor()), actionCollection(), "raise_editor");
+        TQT_TQOBJECT(this), TQT_SLOT(raiseEditor()), actionCollection(), "raise_editor");
     m_raiseEditor->setToolTip(i18n("Raise editor"));
     m_raiseEditor->setWhatsThis(i18n("<b>Raise editor</b><p>Focuses the editor."));
 
     m_lowerAllDocks = new KAction(i18n("Lower All Docks"), CTRL+SHIFT+Key_C,
-        this, TQT_SLOT(lowerAllDocks()), actionCollection(), "lower_all_docks");
+        TQT_TQOBJECT(this), TQT_SLOT(lowerAllDocks()), actionCollection(), "lower_all_docks");
 
-    new KAction(i18n("Switch to next TabWidget"), 0, this,
+    new KAction(i18n("Switch to next TabWidget"), 0, TQT_TQOBJECT(this),
         TQT_SLOT(switchToNextTabWidget()), actionCollection(), "switch_to_next_tabwidget" );
 
     m_splitHor = new KAction(i18n("Split &Horizontal"), CTRL+SHIFT+Key_T,
-        this, TQT_SLOT(slotSplitHorizontalBase()), actionCollection(), "split_h");
+        TQT_TQOBJECT(this), TQT_SLOT(slotSplitHorizontalBase()), actionCollection(), "split_h");
     m_splitHor->setIcon("view_top_bottom");
 
     m_splitVer = new KAction(i18n("Split &Vertical"), CTRL+SHIFT+Key_L,
-        this, TQT_SLOT(slotSplitVerticalBase()), actionCollection(), "split_v");
+        TQT_TQOBJECT(this), TQT_SLOT(slotSplitVerticalBase()), actionCollection(), "split_v");
     m_splitVer->setIcon("view_left_right");
 
     m_splitHor1 = new KAction(i18n("Split &Horizontal"), 0,
-        this, TQT_SLOT(slotSplitHorizontal()), actionCollection(), "split_h1");
+        TQT_TQOBJECT(this), TQT_SLOT(slotSplitHorizontal()), actionCollection(), "split_h1");
     m_splitHor1->setIcon("view_top_bottom");
 
     m_splitVer1 = new KAction(i18n("Split &Vertical"), 0,
-        this, TQT_SLOT(slotSplitVertical()), actionCollection(), "split_v1");
+        TQT_TQOBJECT(this), TQT_SLOT(slotSplitVertical()), actionCollection(), "split_v1");
     m_splitVer1->setIcon("view_left_right");
 
     m_splitHor2 = new KAction(i18n("Split &Horizontal and Open"), 0,
-        this, TQT_SLOT(slotSplitHorizontal()), actionCollection(), "split_h2");
+        TQT_TQOBJECT(this), TQT_SLOT(slotSplitHorizontal()), actionCollection(), "split_h2");
     m_splitHor2->setIcon("view_top_bottom");
 
     m_splitVer2 = new KAction(i18n("Split &Vertical and Open"), 0,
-        this, TQT_SLOT(slotSplitVertical()), actionCollection(), "split_v2");
+        TQT_TQOBJECT(this), TQT_SLOT(slotSplitVertical()), actionCollection(), "split_v2");
     m_splitVer2->setIcon("view_left_right");
 
     m_raiseLeftDock = new KAction(i18n("Switch Left Dock"), CTRL+SHIFT+ALT+Key_L,
-        this, TQT_SLOT(raiseLeftDock()), actionCollection(), "switch_left_dock");
+        TQT_TQOBJECT(this), TQT_SLOT(raiseLeftDock()), actionCollection(), "switch_left_dock");
 
     m_raiseRightDock = new KAction(i18n("Switch Right Dock"), CTRL+SHIFT+ALT+Key_R,
-        this, TQT_SLOT(raiseRightDock()), actionCollection(), "switch_right_dock");
+        TQT_TQOBJECT(this), TQT_SLOT(raiseRightDock()), actionCollection(), "switch_right_dock");
 
     m_raiseBottomDock = new KAction(i18n("Switch Bottom Dock"), CTRL+SHIFT+ALT+Key_B,
-        this, TQT_SLOT(raiseBottomDock()), actionCollection(), "switch_bottom_dock");
+        TQT_TQOBJECT(this), TQT_SLOT(raiseBottomDock()), actionCollection(), "switch_bottom_dock");
 
-    KStdAction::configureToolbars(this, TQT_SLOT(configureToolbars()),
+    KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT(configureToolbars()),
         actionCollection(), "set_configure_toolbars");
 
     m_mainWindowShare->createActions();
 
-    connect(m_mainWindowShare, TQT_SIGNAL(gotoNextWindow()), this, TQT_SLOT(gotoNextWindow()));
-    connect(m_mainWindowShare, TQT_SIGNAL(gotoPreviousWindow()), this, TQT_SLOT(gotoPreviousWindow()));
-    connect(m_mainWindowShare, TQT_SIGNAL(gotoFirstWindow()), this, TQT_SLOT(gotoFirstWindow()));
-    connect(m_mainWindowShare, TQT_SIGNAL(gotoLastWindow()), this, TQT_SLOT(gotoLastWindow()));
+    connect(m_mainWindowShare, TQT_SIGNAL(gotoNextWindow()), TQT_TQOBJECT(this), TQT_SLOT(gotoNextWindow()));
+    connect(m_mainWindowShare, TQT_SIGNAL(gotoPreviousWindow()), TQT_TQOBJECT(this), TQT_SLOT(gotoPreviousWindow()));
+    connect(m_mainWindowShare, TQT_SIGNAL(gotoFirstWindow()), TQT_TQOBJECT(this), TQT_SLOT(gotoFirstWindow()));
+    connect(m_mainWindowShare, TQT_SIGNAL(gotoLastWindow()), TQT_TQOBJECT(this), TQT_SLOT(gotoLastWindow()));
 }
 
 void SimpleMainWindow::raiseEditor()
@@ -522,7 +522,7 @@ void SimpleMainWindow::slotCoreInitialized()
 
 void SimpleMainWindow::projectOpened()
 {
-    setCaption(TQString::null);
+    setCaption(TQString());
 }
 
 void SimpleMainWindow::slotPartURLChanged(KParts::ReadOnlyPart *part)
@@ -577,9 +577,9 @@ void SimpleMainWindow::documentChangedState(const KURL &url, DocumentState state
 void SimpleMainWindow::closeTab()
 {
 //    actionCollection()->action("file_close")->activate();
-    if (sender()->isA("TQToolButton") && sender()->parent()->isA("DTabWidget"))
+    if (TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->isA(TQTOOLBUTTON_OBJECT_NAME_STRING) && TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->parent()->isA("DTabWidget"))
     {
-        DTabWidget *tab = (DTabWidget*)sender()->parent();
+        DTabWidget *tab = (DTabWidget*)TQT_TQWIDGET(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->parent();
         if (tab && tab->currentPage())
             closeTab(tab->currentPage());
     }
@@ -587,7 +587,7 @@ void SimpleMainWindow::closeTab()
 
 void SimpleMainWindow::tabContext(TQWidget *w, const TQPoint &p)
 {
-    DTabWidget *tabWidget = static_cast<DTabWidget*>(const_cast<TQObject*>(sender()));
+    DTabWidget *tabWidget = static_cast<DTabWidget*>(TQT_TQWIDGET(const_cast<TQT_BASE_OBJECT_NAME*>(sender())));
     if (!tabWidget)
         return;
 
@@ -595,7 +595,7 @@ void SimpleMainWindow::tabContext(TQWidget *w, const TQPoint &p)
     tabMenu.insertTitle(tabWidget->tabLabel(w));
 
     //Find the document on whose tab the user clicked
-    m_currentTabURL = TQString::null;
+    m_currentTabURL = TQString();
     TQPtrListIterator<KParts::Part> it(*PartController::getInstance()->parts());
     while (KParts::Part* part = it.current())
     {
@@ -633,7 +633,7 @@ void SimpleMainWindow::tabContext(TQWidget *w, const TQPoint &p)
         ++it;
     }
 
-    connect(&tabMenu, TQT_SIGNAL(activated(int)), this, TQT_SLOT(tabContextActivated(int)));
+    connect(&tabMenu, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(tabContextActivated(int)));
     tabMenu.exec(p);
 }
 
@@ -668,7 +668,7 @@ void SimpleMainWindow::configureToolbars()
 {
     saveMainWindowSettings(KGlobal::config(), "SimpleMainWindow");
     KEditToolbar dlg(factory());
-    connect(&dlg, TQT_SIGNAL(newToolbarConfig()), this, TQT_SLOT(slotNewToolbarConfig()));
+    connect(&dlg, TQT_SIGNAL(newToolbarConfig()), TQT_TQOBJECT(this), TQT_SLOT(slotNewToolbarConfig()));
     dlg.exec();
 }
 
@@ -693,7 +693,7 @@ bool SimpleMainWindow::queryExit()
 void SimpleMainWindow::setupWindowMenu()
 {
     // get the xmlgui created one instead
-    m_windowMenu = static_cast<TQPopupMenu*>(main()->child("window", "KPopupMenu"));
+    m_windowMenu = static_cast<TQPopupMenu*>(TQT_TQWIDGET(main()->child("window", "KPopupMenu")));
 
     if (!m_windowMenu)
     {
@@ -707,13 +707,13 @@ void SimpleMainWindow::setupWindowMenu()
     actionCollection()->action("file_close_all")->plug(m_windowMenu);
     actionCollection()->action("file_closeother")->plug(m_windowMenu);
 
-    TQObject::connect(m_windowMenu, TQT_SIGNAL(activated(int)), this, TQT_SLOT(openURL(int)));
-    TQObject::connect(m_windowMenu, TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(fillWindowMenu()));
+    TQObject::connect(m_windowMenu, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(openURL(int)));
+    TQObject::connect(m_windowMenu, TQT_SIGNAL(aboutToShow()), TQT_TQOBJECT(this), TQT_SLOT(fillWindowMenu()));
 }
 
 void SimpleMainWindow::openURL(int w)
 {
-    TQValueList<QPair<int, KURL> >::ConstIterator it = m_windowList.begin();
+    TQValueList<TQPair<int, KURL> >::ConstIterator it = m_windowList.begin();
     while (it != m_windowList.end())
     {
         if ((*it).first == w)
@@ -732,7 +732,7 @@ void SimpleMainWindow::openURL(int w)
 void SimpleMainWindow::fillWindowMenu()
 {
     // clear menu
-    TQValueList< QPair< int, KURL > >::ConstIterator it = m_windowList.begin();
+    TQValueList< TQPair< int, KURL > >::ConstIterator it = m_windowList.begin();
     while (it != m_windowList.end())
     {
         m_windowMenu->removeItem( (*it).first );
@@ -761,12 +761,12 @@ void SimpleMainWindow::fillWindowMenu()
     int i = 0;
 
     if (list.count() > 0)
-        m_windowList << qMakePair(m_windowMenu->insertSeparator(), KURL());
+        m_windowList << tqMakePair(m_windowMenu->insertSeparator(), KURL());
 
     while (itt != list.end())
     {
-        temp = m_windowMenu->insertItem( i < 10 ? TQString("&%1 %2").arg(i).arg((*itt).fileName()) : (*itt).fileName() );
-        m_windowList << qMakePair(temp, *itt);
+        temp = m_windowMenu->insertItem( i < 10 ? TQString("&%1 %2").tqarg(i).tqarg((*itt).fileName()) : (*itt).fileName() );
+        m_windowList << tqMakePair(temp, *itt);
         ++i;
         ++itt;
     }
@@ -900,7 +900,7 @@ void SimpleMainWindow::activePartChanged(KParts::Part *part)
 
 void SimpleMainWindow::createGUI(KParts::Part *part) {
     if ( !part )
-        setCaption( TQString::null );
+        setCaption( TQString() );
     DMainWindow::createGUI(part);
 
     m_mainWindowShare->slotGUICreated( part );
@@ -1003,7 +1003,7 @@ void SimpleMainWindow::setCaption(const TQString &caption)
 
 void SimpleMainWindow::projectClosed()
 {
-    DMainWindow::setCaption(TQString::null);
+    DMainWindow::setCaption(TQString());
 }
 
 #include "simplemainwindow.moc"
