@@ -22,8 +22,9 @@
 class RssSensor : public Sensor
 {
     Q_OBJECT
+  TQ_OBJECT
 public:
-    RssSensor( const TQString &source, int interval, const TQString &format, const TQString &encoding=TQString::null );
+    RssSensor( const TQString &source, int interval, const TQString &format, const TQString &encoding=TQString() );
 
     ~RssSensor();
 
