@@ -54,6 +54,7 @@ class UMLOperation;
  */
 class AssociationWidget : public WidgetBase, public LinkWidget {
     Q_OBJECT
+  TQ_OBJECT
 public:
     /**
      * Enumeration used for stating where a line is on a widget.
@@ -1011,7 +1012,7 @@ public slots:
     /**
      * This slot is entered when an event has occurred on the views display,
      * most likely a mouse event.  Before it sends out that mouse event all
-     * children should make sure that they don't have a menu active or there
+     * tqchildren should make sure that they don't have a menu active or there
      * could be more than one popup menu displayed.
      */
     void slotRemovePopupMenu();
