@@ -52,12 +52,12 @@ CppWriter::CppWriter()
     VECTOR_METHOD_REMOVE = "int i, size = %VARNAME%.size();\nfor ( i = 0; i < size; i++) {\n\t%ITEMCLASS% item = %VARNAME%.at(i);\n\tif(item == remove_object) {\n\t\tvector<%ITEMCLASS%>::iterator it = %VARNAME%.begin() + i;\n\t\t%VARNAME%.erase(it);\n\t\treturn;\n\t}\n }"; // for std::vector
     VECTOR_METHOD_INIT = TQString(); // nothing to be done
     /*
-        VECTOR_METHOD_APPEND = "%VARNAME%.append(&add_object);"; // Qt lib implementation
-        VECTOR_METHOD_REMOVE = "%VARNAME%.removeRef(&remove_object);"; // Qt lib implementation
-        VECTOR_METHOD_INIT = "%VARNAME%.setAutoDelete(false);"; // Qt library
+        VECTOR_METHOD_APPEND = "%VARNAME%.append(&add_object);"; // TQt lib implementation
+        VECTOR_METHOD_REMOVE = "%VARNAME%.removeRef(&remove_object);"; // TQt lib implementation
+        VECTOR_METHOD_INIT = "%VARNAME%.setAutoDelete(false);"; // TQt library
     */
 
-    OBJECT_METHOD_INIT = "%VARNAME% = new %ITEMCLASS%( );"; // Qt library
+    OBJECT_METHOD_INIT = "%VARNAME% = new %ITEMCLASS%( );"; // TQt library
 
     // boolean config params
     INLINE_ASSOCIATION_METHODS = false;
@@ -627,7 +627,7 @@ void CppWriter::writeAttributeMethods(UMLAttributeList *attribs,
         // from what I can tell, this IS the default behavior for
         // cleanName. I dunno why its not working -b.t.
         methodBaseName = methodBaseName.stripWhiteSpace();
-        methodBaseName.replace(0,1,methodBaseName.at(0).upper());
+        methodBaseName.replace(0,1,methodBaseName.tqat(0).upper());
 
         writeSingleAttributeAccessorMethods(at->getTypeName(), varName,
                                             methodBaseName, at->getDoc(), Uml::chg_Changeable, isHeaderMethod,
