@@ -175,10 +175,10 @@ UMLObject *createUMLObject(Uml::Object_Type type,
                     }
                     int wantNamespace = KMessageBox::Yes;
                     if (pl == Uml::pl_Cpp) {
-                        /* We know std and Qt are namespaces */
-                        if (scopeName != "std" && scopeName != "Qt") {
+                        /* We know std and TQt are namespaces */
+                        if (scopeName != "std" && scopeName != "TQt") {
                             wantNamespace = KMessageBox::questionYesNo(NULL,
-                                        i18n("Is the scope %1 a namespace or a class?").arg(scopeName),
+                                        i18n("Is the scope %1 a namespace or a class?").tqarg(scopeName),
                                         i18n("C++ Import Requests Your Help"),
                                         i18n("Namespace"), i18n("Class"));
                         }
