@@ -24,7 +24,7 @@
 #include <tqstring.h>
 #include <tqptrlist.h>
 
-#if defined( Q_OS_WIN32 ) || defined( Q_CC_SUN )
+#if defined( Q_OS_WIN32 ) || defined( TQ_CC_SUN )
 
 #ifndef _THROW0
 #  define _THROW0()
@@ -177,9 +177,9 @@ enum NodeType
 TQString nodeTypeToString( int type );
 
 
-#if defined(CPPPARSER_QUICK_ALLOCATOR)
+#if defined(CPPPARSER_TQUICK_ALLOCATOR)
 
-#include <quick_allocator.h>
+#include <tquick_allocator.h>
 
 #define DECLARE_ALLOC(tp) \
     void * operator new(std::size_t) \
@@ -232,7 +232,7 @@ public:
     void getEndPosition( int* line, int* col ) const;
 
 #ifndef CPPPARSER_NO_CHILDREN
-    TQPtrList<AST> children() { return m_children; }
+    TQPtrList<AST> tqchildren() { return m_tqchildren; }
     void appendChild( AST* child );
     void removeChild( AST* child );
 #endif
@@ -266,7 +266,7 @@ private:
     int m_endLine, m_endColumn;
     Slice m_slice;
 #ifndef CPPPARSER_NO_CHILDREN
-    TQPtrList<AST> m_children;
+    TQPtrList<AST> m_tqchildren;
 #endif
     TQString m_comment;
 
