@@ -31,7 +31,7 @@
 #if defined( KDEVELOP_BGPARSER )
 #include <tqthread.h>
 
-class KDevTread: public QThread
+class KDevTread: public TQThread
 {
 public:
     static void yield()
@@ -101,7 +101,7 @@ struct LexerData
                 return scope[ name ];
         }
 
-        return TQString::null;
+        return TQString();
     }
 
 };
@@ -143,7 +143,7 @@ void Lexer::reset()
     m_index = 0;
     m_size = 0;
     m_tokens.clear();
-    m_source = TQString::null;
+    m_source = TQString();
     m_ptr = 0;
     m_endPtr = 0;
     m_startLine = false;
@@ -175,7 +175,7 @@ int Lexer::toInt( const Token& token )
 	int i = s[0] == 'L' ? 2 : 1; // wide char ?
 	if( s[i] == '\\' ){
 	    // escaped char
-	    int c = s[i+1].unicode();
+	    int c = s[i+1].tqunicode();
 	    switch( c ) {
 	    case '0':
 		return 0;
@@ -186,7 +186,7 @@ int Lexer::toInt( const Token& token )
 		return c;
 	    }
 	} else {
-	    return s[i].unicode();
+	    return s[i].tqunicode();
 	}
     } else {
 	return 0;
@@ -374,21 +374,21 @@ void Lexer::nextToken( Token& tk, bool stopOnNewline )
                 TQString tokText = tok.text();
                 TQString str = (tok == Token_identifier && d->hasBind(tokText)) ? d->apply( tokText ) : tokText;
                 if( str == ide ){
-                    //Problem p( i18n("unsafe use of macro '%1'").arg(ide), m_currentLine, m_currentColumn );
+                    //Problem p( i18n("unsafe use of macro '%1'").tqarg(ide), m_currentLine, m_currentColumn );
                     //m_driver->addProblem( m_driver->currentFileName(), p );
                     m_driver->removeMacro( ide );
-                    // str = TQString::null;
+                    // str = TQString();
                 }
 
                 if( stringify ) {
-                    textToInsert.append( TQString::fromLatin1("\"") + str + TQString::fromLatin1("\" ") );
+                    textToInsert.append( TQString::tqfromLatin1("\"") + str + TQString::tqfromLatin1("\" ") );
                 } else if( merge ){
                     textToInsert.truncate( textToInsert.length() - 1 );
                     textToInsert.append( str );
                 } else if( tok == Token_ellipsis && d->hasBind("...") ){
                     textToInsert.append( ellipsisArg );
                 } else {
-                    textToInsert.append( str + TQString::fromLatin1(" ") );
+                    textToInsert.append( str + TQString::tqfromLatin1(" ") );
                 }
             }
 
@@ -408,7 +408,7 @@ void Lexer::nextToken( Token& tk, bool stopOnNewline )
 	    tk.setStartPosition( startLine, startColumn );
 	    tk.setEndPosition( m_currentLine, m_currentColumn );
 	} else if( m_skipWordsEnabled ){
-	    TQMap< TQString, QPair<SkipType, TQString> >::Iterator pos = m_words.find( ide );
+	    TQMap< TQString, TQPair<SkipType, TQString> >::Iterator pos = m_words.find( ide );
 	    if( pos != m_words.end() ){
 		if( (*pos).first == SkipWordAndArguments ){
 		    readWhiteSpaces();
@@ -424,9 +424,9 @@ void Lexer::nextToken( Token& tk, bool stopOnNewline )
 		}
 	    } else if( /*qt_rx.exactMatch(ide) ||*/
 		ide.endsWith("EXPORT") ||
-		(ide.startsWith("Q_EXPORT") && ide != "Q_EXPORT_INTERFACE") ||
-		ide.startsWith("QM_EXPORT") ||
-		ide.startsWith("QM_TEMPLATE")){
+		(ide.startsWith("TQ_EXPORT") && ide != "TQ_EXPORT_INTERFACE") ||
+		ide.startsWith("TQM_EXPORT") ||
+		ide.startsWith("TQM_TEMPLATE")){
 
 		readWhiteSpaces();
 		if( currentChar() == '(' )
@@ -465,7 +465,7 @@ void Lexer::nextToken( Token& tk, bool stopOnNewline )
 	tk.setStartPosition( startLine, startColumn );
 	tk.setEndPosition( m_currentLine, m_currentColumn );
     } else {
-	tk = CREATE_TOKEN( ch.unicode(), currentPosition(), 1 );
+	tk = CREATE_TOKEN( ch.tqunicode(), currentPosition(), 1 );
 	nextChar();
 	tk.setStartPosition( startLine, startColumn );
 	tk.setEndPosition( m_currentLine, m_currentColumn );
@@ -504,7 +504,7 @@ void Lexer::resetSkipWords()
 
 void Lexer::addSkipWord( const TQString& word, SkipType skipType, const TQString& str )
 {
-    m_words[ word ] = qMakePair( skipType, str );
+    m_words[ word ] = tqMakePair( skipType, str );
 }
 
 void Lexer::skip( int l, int r )
@@ -808,7 +808,7 @@ int Lexer::macroPrimary()
 {
     readWhiteSpaces( false );
     int result = 0;
-    switch( currentChar().unicode() ) {
+    switch( currentChar().tqunicode() ) {
     case '(':
 	nextChar();
 	result = macroExpression();
@@ -996,7 +996,7 @@ int Lexer::macroExpression()
 }
 
 // *IMPORTANT*
-// please, don't include lexer.moc here, because Lexer isn't a TQObject class!!
+// please, don't include lexer.tqmoc here, because Lexer isn't a TQObject class!!
 // if you have problem while recompiling try to remove cppsupport/.deps,
 // cppsupport/Makefile.in and rerun automake/autoconf
 
