@@ -60,11 +60,11 @@ ClassifierListPage::ClassifierListPage(TQWidget* parent, UMLClassifier* classifi
     int margin = fontMetrics().height();
     setMinimumSize(310,330);
 
-    //main layout contains our two group boxes, the list and the documentation
+    //main tqlayout contains our two group boxes, the list and the documentation
     TQVBoxLayout* mainLayout = new TQVBoxLayout( this );
     mainLayout->setSpacing(10);
 
-    //top group box, contains a vertical layout with list box above and buttons below
+    //top group box, contains a vertical tqlayout with list box above and buttons below
     m_pItemListGB = new TQGroupBox(typeName, this );
     TQVBoxLayout* listVBoxLayout = new TQVBoxLayout( m_pItemListGB );
     listVBoxLayout->setMargin(margin);
@@ -95,10 +95,10 @@ ClassifierListPage::ClassifierListPage(TQWidget* parent, UMLClassifier* classifi
 
     //the action buttons
     KButtonBox* buttonBox = new KButtonBox(m_pItemListGB);
-    buttonBox->addButton( newItemType, this, TQT_SLOT(slotNewListItem()) );
+    buttonBox->addButton( newItemType, TQT_TQOBJECT(this), TQT_SLOT(slotNewListItem()) );
     m_pDeleteListItemButton = buttonBox->addButton( i18n("&Delete"),
-                              this, TQT_SLOT(slotDelete()) );
-    m_pPropertiesButton = buttonBox->addButton( i18n("&Properties"), this, TQT_SLOT(slotProperties()) );
+                              TQT_TQOBJECT(this), TQT_SLOT(slotDelete()) );
+    m_pPropertiesButton = buttonBox->addButton( i18n("&Properties"), TQT_TQOBJECT(this), TQT_SLOT(slotProperties()) );
     listVBoxLayout->addWidget(buttonBox);
 
     mainLayout->addWidget(m_pItemListGB);
@@ -201,7 +201,7 @@ void ClassifierListPage::slotClicked(TQListBoxItem*item) {
     // focus and so at least one item is always selected; this doesn't happen, if
     // there are no items of course;
     //
-    // for more information see Qt doc for void TQListBox::clearSelection()
+    // for more information see TQt doc for void TQListBox::clearSelection()
     UMLClassifierListItem* listItem;
     if (item == NULL) {
         if (m_pItemListLB->count() == 0) {
