@@ -138,9 +138,9 @@ void UMLOperationDialog::setupDialog() {
     buttonLayout->addWidget( m_pDownButton );
 
     KButtonBox* buttonBox = new KButtonBox(m_pParmsGB);
-    buttonBox->addButton( i18n("Ne&w Parameter..."), this, TQT_SLOT(slotNewParameter()) );
-    m_pDeleteButton = buttonBox->addButton( i18n("&Delete"), this, TQT_SLOT(slotDeleteParameter()) );
-    m_pPropertiesButton = buttonBox->addButton( i18n("&Properties"), this,
+    buttonBox->addButton( i18n("Ne&w Parameter..."), TQT_TQOBJECT(this), TQT_SLOT(slotNewParameter()) );
+    m_pDeleteButton = buttonBox->addButton( i18n("&Delete"), TQT_TQOBJECT(this), TQT_SLOT(slotDeleteParameter()) );
+    m_pPropertiesButton = buttonBox->addButton( i18n("&Properties"), TQT_TQOBJECT(this),
                           TQT_SLOT(slotParameterProperties()) );
     parmsLayout->addWidget(buttonBox);
 
@@ -463,7 +463,7 @@ bool UMLOperationDialog::apply()
     if( classifier != 0L &&
             classifier->checkOperationSignature(name, m_pOperation->getParmList(), m_pOperation) )
     {
-        TQString msg = TQString(i18n("An operation with that signature already exists in %1.\n")).arg(classifier->getName())
+        TQString msg = TQString(i18n("An operation with that signature already exists in %1.\n")).tqarg(classifier->getName())
                       +
                       TQString(i18n("Choose a different name or parameter list." ));
         KMessageBox::error(this, msg, i18n("Operation Name Invalid"), false);
