@@ -176,7 +176,7 @@ bool LinePath::insertPoint( int pointIndex, const TQPoint &point ) {
         line -> setZ( -2 );
         line -> setPoints( point.x(), point.y(), ep.x(), ep.y() );
         line -> setPen( getPen() );
-        line -> setVisible( true );
+        line -> tqsetVisible( true );
         m_LineList.insert( 1, line );
         if (!bLoading)
             setupSelected();
@@ -191,7 +191,7 @@ bool LinePath::insertPoint( int pointIndex, const TQPoint &point ) {
         line -> setPoints( point.x(), point.y(), ep.x(), ep.y() );
         line -> setZ( -2 );
         line -> setPen( getPen() );
-        line -> setVisible( true );
+        line -> tqsetVisible( true );
         m_LineList.append( line );
         if (!bLoading)
             setupSelected();
@@ -205,7 +205,7 @@ bool LinePath::insertPoint( int pointIndex, const TQPoint &point ) {
     line -> setPoints( point.x(), point.y(), ep.x(), ep.y() );
     line -> setZ( -2 );
     line -> setPen( getPen() );
-    line -> setVisible( true );
+    line -> tqsetVisible( true );
     m_LineList.insert( pointIndex, line );
     if (!bLoading)
         setupSelected();
@@ -277,7 +277,7 @@ bool LinePath::setStartEndPoints( const TQPoint &start, const TQPoint &end ) {
         line -> setPoints( start.x(), start.y(), end.x(), end.y() );
         line -> setZ( -2 );
         line -> setPen( getPen() );
-        line -> setVisible( true );
+        line -> tqsetVisible( true );
         m_LineList.append( line );
         return true;
     }
@@ -374,7 +374,7 @@ void LinePath::setLineColor( const TQColor &color ) {
     }
 
     if( getAssocType() == Uml::at_Aggregation )
-        if (m_pClearPoly) m_pClearPoly -> setBrush( TQBrush( Qt::white ) );
+        if (m_pClearPoly) m_pClearPoly -> setBrush( TQBrush( TQt::white ) );
         else if( getAssocType() == Uml::at_Composition )
             if (m_pClearPoly) m_pClearPoly -> setBrush( TQBrush( color ) );
 
@@ -467,7 +467,7 @@ void LinePath::setupSelected() {
 TQPen LinePath::getPen() {
     Uml::Association_Type type = getAssocType();
     if( type == Uml::at_Dependency || type == Uml::at_Realization || type == Uml::at_Anchor )
-        return TQPen( getLineColor(), getLineWidth(), Qt::DashLine );
+        return TQPen( getLineColor(), getLineWidth(), TQt::DashLine );
     return TQPen( getLineColor(), getLineWidth() );
 }
 
@@ -644,7 +644,7 @@ void LinePath::growList(LineList &list, int by) {
         TQCanvasLine * line = new TQCanvasLine( getCanvas() );
         line -> setZ( 0 );
         line -> setPen( pen );
-        line -> setVisible( true );
+        line -> tqsetVisible( true );
         list.append( line );
     }
 }
@@ -665,8 +665,8 @@ void LinePath::createHeadLines() {
     case Uml::at_Realization:
         growList(m_HeadList, 3);
         m_pClearPoly = new TQCanvasPolygon( canvas );
-        m_pClearPoly -> setVisible( true );
-        m_pClearPoly -> setBrush( TQBrush( Qt::white ) );
+        m_pClearPoly -> tqsetVisible( true );
+        m_pClearPoly -> setBrush( TQBrush( TQt::white ) );
         m_pClearPoly -> setZ( -1 );
         break;
 
@@ -674,9 +674,9 @@ void LinePath::createHeadLines() {
     case Uml::at_Aggregation:
         growList(m_HeadList, 4);
         m_pClearPoly = new TQCanvasPolygon( canvas );
-        m_pClearPoly -> setVisible( true );
+        m_pClearPoly -> tqsetVisible( true );
         if( getAssocType() == Uml::at_Aggregation )
-            m_pClearPoly -> setBrush( TQBrush( Qt::white ) );
+            m_pClearPoly -> setBrush( TQBrush( TQt::white ) );
         else
             m_pClearPoly -> setBrush( TQBrush( getLineColor() ) );
         m_pClearPoly -> setZ( -1 );
@@ -815,7 +815,7 @@ Uml::Association_Type LinePath::getAssocType() {
 
 TQColor LinePath::getLineColor() {
     if( !m_pAssociation )
-        return Qt::black;
+        return TQt::black;
     return m_pAssociation -> getLineColor();
 }
 
