@@ -64,7 +64,7 @@ void MessageWidget::init() {
     m_pOw[Uml::A] = m_pOw[Uml::B] = NULL;
     m_pFText = NULL;
     m_nY = 0;
-    setVisible(true);
+    tqsetVisible(true);
 }
 
 MessageWidget::~MessageWidget() {
@@ -94,9 +94,9 @@ void MessageWidget::draw(TQPainter& p, int offsetX, int offsetY) {
     }
 }
 
-void MessageWidget::drawSolidArrowhead(TQPainter& p, int x, int y, Qt::ArrowType direction) {
+void MessageWidget::drawSolidArrowhead(TQPainter& p, int x, int y, TQt::ArrowType direction) {
     int arrowheadExtentX = 4;
-    if (direction == Qt::RightArrow) {
+    if (direction == TQt::RightArrow) {
         arrowheadExtentX = -arrowheadExtentX;
     }
     TQPointArray points;
@@ -106,10 +106,10 @@ void MessageWidget::drawSolidArrowhead(TQPainter& p, int x, int y, Qt::ArrowType
 }
 
 void MessageWidget::drawArrow(TQPainter& p, int x, int y, int w,
-                              Qt::ArrowType direction, bool useDottedLine /* = false */) {
+                              TQt::ArrowType direction, bool useDottedLine /* = false */) {
     int arrowheadStartX = x;
     int arrowheadExtentX = 4;
-    if (direction == Qt::RightArrow) {
+    if (direction == TQt::RightArrow) {
         arrowheadStartX += w;
         arrowheadExtentX = -arrowheadExtentX;
     }
@@ -135,7 +135,7 @@ void MessageWidget::drawSynchronous(TQPainter& p, int offsetX, int offsetY) {
     bool messageOverlaps = m_pOw[Uml::A] -> messageOverlap( getY(), this );
 
     if(m_pOw[Uml::A] == m_pOw[Uml::B]) {
-        p.fillRect( offsetX, offsetY, 17, h,  TQBrush(Qt::white) );              //box
+        p.fillRect( offsetX, offsetY, 17, h,  TQBrush(TQt::white) );              //box
         p.drawRect(offsetX, offsetY, 17, h);                                    //box
         offsetX += 17;
         w -= 17;
@@ -146,7 +146,7 @@ void MessageWidget::drawSynchronous(TQPainter& p, int offsetX, int offsetY) {
         // draw line segment parallel to (and at the right of) the life line
         p.drawLine(offsetX + w, offsetY, offsetX + w, lowerLineY);
         // draw lower line segment (back to the life line)
-        drawArrow(p, offsetX, lowerLineY, w, Qt::LeftArrow);
+        drawArrow(p, offsetX, lowerLineY, w, TQt::LeftArrow);
         offsetX -= 17;
         offsetY -= 3;
     } else if(x1 < x2) {
@@ -156,11 +156,11 @@ void MessageWidget::drawSynchronous(TQPainter& p, int offsetX, int offsetY) {
         }
         TQPen pen = p.pen();
         int startX = offsetX + w - 16;
-        p.fillRect(startX, offsetY, 17, h,  TQBrush(Qt::white));         //box
+        p.fillRect(startX, offsetY, 17, h,  TQBrush(TQt::white));         //box
         p.drawRect(startX, offsetY, 17, h);                             //box
         p.drawLine(offsetX, offsetY + 4, startX, offsetY + 4);          //arrow line
-        drawSolidArrowhead(p, startX - 1, offsetY + 4, Qt::RightArrow);
-        drawArrow(p, offsetX, offsetY + h - 3, w - 16, Qt::LeftArrow, true); // return arrow
+        drawSolidArrowhead(p, startX - 1, offsetY + 4, TQt::RightArrow);
+        drawArrow(p, offsetX, offsetY + h - 3, w - 16, TQt::LeftArrow, true); // return arrow
         if (messageOverlaps)  {
             offsetX -= 8; //reset for drawSelected()
         }
@@ -169,11 +169,11 @@ void MessageWidget::drawSynchronous(TQPainter& p, int offsetX, int offsetY) {
             w -=8;
         }
         TQPen pen = p.pen();
-        p.fillRect( offsetX, offsetY, 17, h,  TQBrush(Qt::white) );              //box
+        p.fillRect( offsetX, offsetY, 17, h,  TQBrush(TQt::white) );              //box
         p.drawRect(offsetX, offsetY, 17, h);                                    //box
         p.drawLine(offsetX + 18, offsetY + 4, offsetX + w, offsetY + 4);        //arrow line
-        drawSolidArrowhead(p, offsetX + 17, offsetY + 4, Qt::LeftArrow);
-        drawArrow(p, offsetX + 18, offsetY + h - 3, w - 18, Qt::RightArrow, true); // return arrow
+        drawSolidArrowhead(p, offsetX + 17, offsetY + 4, TQt::LeftArrow);
+        drawArrow(p, offsetX + 18, offsetY + h - 3, w - 18, TQt::RightArrow, true); // return arrow
     }
 
     if(m_bSelected) {
@@ -200,7 +200,7 @@ void MessageWidget::drawAsynchronous(TQPainter& p, int offsetX, int offsetY) {
         // draw line segment parallel to (and at the right of) the life line
         p.drawLine(offsetX + w, offsetY, offsetX + w, lowerLineY);
         // draw lower line segment (back to the life line)
-        drawArrow(p, offsetX, lowerLineY, w, Qt::LeftArrow);
+        drawArrow(p, offsetX, lowerLineY, w, TQt::LeftArrow);
         if (messageOverlapsA)  {
             offsetX -= 7; //reset for drawSelected()
         }
@@ -209,7 +209,7 @@ void MessageWidget::drawAsynchronous(TQPainter& p, int offsetX, int offsetY) {
             offsetX += 7;
             w -= 7;
         }
-        drawArrow(p, offsetX, offsetY + 4, w, Qt::RightArrow);
+        drawArrow(p, offsetX, offsetY + 4, w, TQt::RightArrow);
         if (messageOverlapsA)  {
             offsetX -= 7;
         }
@@ -217,7 +217,7 @@ void MessageWidget::drawAsynchronous(TQPainter& p, int offsetX, int offsetY) {
         if (messageOverlapsA)  {
             w -= 7;
         }
-        drawArrow(p, offsetX, offsetY + 4, w, Qt::LeftArrow);
+        drawArrow(p, offsetX, offsetY + 4, w, TQt::LeftArrow);
     }
 
     if (m_bSelected)
@@ -238,7 +238,7 @@ void MessageWidget::drawCreation(TQPainter& p, int offsetX, int offsetY) {
             offsetX += 7;
             w -= 7;
         }
-        drawArrow(p, offsetX, lineY, w, Qt::RightArrow);
+        drawArrow(p, offsetX, lineY, w, TQt::RightArrow);
         if (messageOverlapsA)  {
             offsetX -= 7;
         }
@@ -246,7 +246,7 @@ void MessageWidget::drawCreation(TQPainter& p, int offsetX, int offsetY) {
         if (messageOverlapsA)  {
             w -= 7;
         }
-        drawArrow(p, offsetX, lineY, w, Qt::LeftArrow);
+        drawArrow(p, offsetX, lineY, w, TQt::LeftArrow);
     }
 
     if (m_bSelected)
@@ -353,7 +353,7 @@ void MessageWidget::calculateWidget() {
     setMessageText(m_pFText);
     calculateDimensions();
 
-    setVisible(true);
+    tqsetVisible(true);
 
     setX(m_nPosX);
     setY(m_nY);
@@ -447,7 +447,7 @@ bool MessageWidget::activate(IDChangeLog * Log /*= 0*/) {
         if (op) {
             // If the UMLOperation is set, m_CustomOp isn't used anyway.
             // Just setting it empty for the sake of sanity.
-            m_CustomOp = TQString::null;
+            m_CustomOp = TQString();
         }
     }
 
@@ -464,7 +464,7 @@ bool MessageWidget::activate(IDChangeLog * Log /*= 0*/) {
     m_pFText -> setText("");
     m_pFText->setActivated();
     TQString messageText = m_pFText->getText();
-    m_pFText->setVisible( messageText.length() > 1 );
+    m_pFText->tqsetVisible( messageText.length() > 1 );
 
     connect(m_pOw[Uml::A], TQT_SIGNAL(sigWidgetMoved(Uml::IDType)), this, TQT_SLOT(slotWidgetMoved(Uml::IDType)));
     connect(m_pOw[Uml::B], TQT_SIGNAL(sigWidgetMoved(Uml::IDType)), this, TQT_SLOT(slotWidgetMoved(Uml::IDType)));
