@@ -407,7 +407,7 @@ int stringToDirection(TQString input, Uml::Parameter_Direction & result) {
     return dirLen;
 }
 
-Parse_Status parseTemplate(TQString t, NameAndType& nmTp, UMLClassifier *owningScope) {
+Parse_tqStatus parseTemplate(TQString t, NameAndType& nmTp, UMLClassifier *owningScope) {
 
     UMLDoc *pDoc = UMLApp::app()->getDocument();
 
@@ -430,7 +430,7 @@ Parse_Status parseTemplate(TQString t, NameAndType& nmTp, UMLClassifier *owningS
     return PS_OK;
 }
 
-Parse_Status parseAttribute(TQString a, NameAndType& nmTp, UMLClassifier *owningScope,
+Parse_tqStatus parseAttribute(TQString a, NameAndType& nmTp, UMLClassifier *owningScope,
                             Uml::Visibility *vis /* = 0 */) {
     UMLDoc *pDoc = UMLApp::app()->getDocument();
 
@@ -494,7 +494,7 @@ Parse_Status parseAttribute(TQString a, NameAndType& nmTp, UMLClassifier *owning
     return PS_OK;
 }
 
-Parse_Status parseOperation(TQString m, OpDescriptor& desc, UMLClassifier *owningScope) {
+Parse_tqStatus parseOperation(TQString m, OpDescriptor& desc, UMLClassifier *owningScope) {
     UMLDoc *pDoc = UMLApp::app()->getDocument();
 
     m = m.simplifyWhiteSpace();
@@ -546,7 +546,7 @@ Parse_Status parseOperation(TQString m, OpDescriptor& desc, UMLClassifier *ownin
     TQStringList args = TQStringList::split( TQRegExp("\\s*,\\s*"), arglist);
     for (TQStringList::Iterator lit = args.begin(); lit != args.end(); ++lit) {
         NameAndType nmTp;
-        Parse_Status ps = parseAttribute(*lit, nmTp, owningScope);
+        Parse_tqStatus ps = parseAttribute(*lit, nmTp, owningScope);
         if (ps)
             return ps;
         desc.m_args.append(nmTp);
@@ -554,7 +554,7 @@ Parse_Status parseOperation(TQString m, OpDescriptor& desc, UMLClassifier *ownin
     return PS_OK;
 }
 
-TQString psText(Parse_Status value) {
+TQString psText(Parse_tqStatus value) {
     const TQString text[] = {
                                i18n("OK"), i18n("Empty"), i18n("Malformed argument"),
                                i18n("Unknown argument type"), i18n("Illegal method name"),
@@ -602,7 +602,7 @@ TQString progLangToString(Uml::Programming_Language pl) {
         default:
             break;
     }
-    return TQString::null;
+    return TQString();
 }
 
 Uml::Programming_Language stringToProgLang(TQString str) {
