@@ -650,7 +650,7 @@ void RefactoringAssistant::movableDropEvent (TQListViewItem* parentItem, TQListV
         UMLOperation *op = static_cast<UMLOperation*>(movingObject);
         if(newClassifier->checkOperationSignature(op->getName(), op->getParmList()))
         {
-            TQString msg = TQString(i18n("An operation with that signature already exists in %1.\n")).arg(newClassifier->getName())
+            TQString msg = TQString(i18n("An operation with that signature already exists in %1.\n")).tqarg(newClassifier->getName())
                           +
                           TQString(i18n("Choose a different name or parameter list." ));
             KMessageBox::error(this, msg, i18n("Operation Name Invalid"), false);
@@ -666,7 +666,7 @@ void RefactoringAssistant::movableDropEvent (TQListViewItem* parentItem, TQListV
         //              UMLAttribute *att = static_cast<UMLAttribute*>(movingObject);
         //              if(!newClassifier->checkAttributeSignature(att))
         //              {
-        //                      TQString msg = TQString(i18n("An attribute with that signature already exists in %1.\n")).arg(newClassifier->getName())
+        //                      TQString msg = TQString(i18n("An attribute with that signature already exists in %1.\n")).tqarg(newClassifier->getName())
         //                              +
         //                            TQString(i18n("Choose a different name or parameter list." ));
         //                      KMessageBox::error(this, msg, i18n("Operation Name Invalid"), false);
