@@ -53,10 +53,10 @@ class KTabWidget;
 class KToolBarButton;
 class KPopupMenu;
 
-// Qt forward declarations
+// TQt forward declarations
 class TQWidgetStack;
 class TQMenuData;
-class QClipboard;
+class TQClipboard;
 class TQToolButton;
 class TQCustomEvent;
 
@@ -77,6 +77,7 @@ class TQCustomEvent;
 
 class UMLApp : public KDockMainWindow {
     Q_OBJECT
+  TQ_OBJECT
 public:
     /**
      * Constructor. Calls all init functions to create the application.
@@ -339,7 +340,7 @@ protected:
 
     /**
      * Save general Options like all bar positions and status
-     * as well as the geometry and the recent file list to
+     * as well as the tqgeometry and the recent file list to
      * the configuration file.
      */
     void saveOptions();
@@ -534,7 +535,7 @@ public slots:
     /**
      * Autolayouts the current class diagram
      */
-    void slotAutolayout();
+    void slotAutotqlayout();
 
     /**
      * Changes the statusbar contents for the standard label
@@ -850,7 +851,7 @@ private:
     void readOptionState();
 
     /**
-     * Initialize Qt's global clipboard support for the application.
+     * Initialize TQt's global clipboard support for the application.
      */
     void initClip();
 
@@ -958,7 +959,7 @@ private:
     KAction* deleteSelectedWidget;
     KAction* deleteDiagram;
 #ifdef HAVE_DOT
-    KAction* autolayout;
+    KAction* autotqlayout;
 #endif
 
     KAction* changeTabLeft;
