@@ -352,7 +352,7 @@ bool UMLDoc::openDocument(const KURL& url, const char* /*format =0*/) {
     KIO::NetAccess::download( url, tmpfile, UMLApp::app() );
     TQFile file( tmpfile );
     if ( !file.exists() ) {
-        KMessageBox::error(0, i18n("The file %1 does not exist.").arg(d.path()), i18n("Load Error"));
+        KMessageBox::error(0, i18n("The file %1 does not exist.").tqarg(d.path()), i18n("Load Error"));
         m_doc_url.setFileName(i18n("Untitled"));
         m_bLoading = false;
         newDocument();
@@ -377,7 +377,7 @@ bool UMLDoc::openDocument(const KURL& url, const char* /*format =0*/) {
         KTar archive(tmpfile, mimetype);
         if (archive.open(IO_ReadOnly) == false)
         {
-            KMessageBox::error(0, i18n("The file %1 seems to be corrupted.").arg(d.path()), i18n("Load Error"));
+            KMessageBox::error(0, i18n("The file %1 seems to be corrupted.").tqarg(d.path()), i18n("Load Error"));
             m_doc_url.setFileName(i18n("Untitled"));
             m_bLoading = false;
             newDocument();
@@ -419,7 +419,7 @@ bool UMLDoc::openDocument(const KURL& url, const char* /*format =0*/) {
             entry = const_cast<KArchiveEntry*>(rootDir->entry(*it));
             if (entry == 0)
             {
-                KMessageBox::error(0, i18n("There was no XMI file found in the compressed file %1.").arg(d.path()), i18n("Load Error"));
+                KMessageBox::error(0, i18n("There was no XMI file found in the compressed file %1.").tqarg(d.path()), i18n("Load Error"));
                 m_doc_url.setFileName(i18n("Untitled"));
                 m_bLoading = false;
                 newDocument();
@@ -431,7 +431,7 @@ bool UMLDoc::openDocument(const KURL& url, const char* /*format =0*/) {
             fileEntry = dynamic_cast<KArchiveFile*>(entry);
             if (fileEntry == 0)
             {
-                KMessageBox::error(0, i18n("There was no XMI file found in the compressed file %1.").arg(d.path()), i18n("Load Error"));
+                KMessageBox::error(0, i18n("There was no XMI file found in the compressed file %1.").tqarg(d.path()), i18n("Load Error"));
                 m_doc_url.setFileName(i18n("Untitled"));
                 m_bLoading = false;
                 newDocument();
@@ -445,20 +445,20 @@ bool UMLDoc::openDocument(const KURL& url, const char* /*format =0*/) {
             TQFile xmi_file(tmp_dir.name() + *it);
             if( !xmi_file.open( IO_ReadOnly ) )
             {
-                KMessageBox::error(0, i18n("There was a problem loading the extracted file: %1").arg(d.path()), i18n("Load Error"));
+                KMessageBox::error(0, i18n("There was a problem loading the extracted file: %1").tqarg(d.path()), i18n("Load Error"));
                 m_doc_url.setFileName(i18n("Untitled"));
                 m_bLoading = false;
                 newDocument();
                 return false;
             }
-            status = loadFromXMI( xmi_file, ENC_UNKNOWN );
+            status = loadFromXMI( *TQT_TQIODEVICE(&xmi_file), ENC_UNKNOWN );
 
             // close the extracted file and the temporary directory
             xmi_file.close();
             tmp_dir.unlink();
 
         } else {
-            KMessageBox::error(0, i18n("There was no XMI file found in the compressed file %1.").arg(d.path()), i18n("Load Error"));
+            KMessageBox::error(0, i18n("There was no XMI file found in the compressed file %1.").tqarg(d.path()), i18n("Load Error"));
             m_doc_url.setFileName(i18n("Untitled"));
             m_bLoading = false;
             newDocument();
@@ -469,23 +469,23 @@ bool UMLDoc::openDocument(const KURL& url, const char* /*format =0*/) {
     } else {
         // no, it seems to be an ordinary file
         if( !file.open( IO_ReadOnly ) ) {
-            KMessageBox::error(0, i18n("There was a problem loading file: %1").arg(d.path()), i18n("Load Error"));
+            KMessageBox::error(0, i18n("There was a problem loading file: %1").tqarg(d.path()), i18n("Load Error"));
             m_doc_url.setFileName(i18n("Untitled"));
             m_bLoading = false;
             newDocument();
             return false;
         }
         if (filetype.endsWith(".mdl"))
-            status = Import_Rose::loadFromMDL(file);
+            status = Import_Rose::loadFromMDL(*TQT_TQIODEVICE(&file));
         else
-            status = loadFromXMI( file, ENC_UNKNOWN );
+            status = loadFromXMI( *TQT_TQIODEVICE(&file), ENC_UNKNOWN );
     }
 
     file.close();
     KIO::NetAccess::removeTempFile( tmpfile );
     if( !status )
     {
-        KMessageBox::error(0, i18n("There was a problem loading file: %1").arg(d.path()), i18n("Load Error"));
+        KMessageBox::error(0, i18n("There was a problem loading file: %1").tqarg(d.path()), i18n("Load Error"));
         m_bLoading = false;
         newDocument();
         return false;
@@ -553,7 +553,7 @@ bool UMLDoc::saveDocument(const KURL& url, const char * /* format */) {
         // now check if we can write to the file
         if (archive->open(IO_WriteOnly) == false)
         {
-            KMessageBox::error(0, i18n("There was a problem saving file: %1").arg(d.path()), i18n("Save Error"));
+            KMessageBox::error(0, i18n("There was a problem saving file: %1").tqarg(d.path()), i18n("Save Error"));
             return false;
         }
 
@@ -562,27 +562,27 @@ bool UMLDoc::saveDocument(const KURL& url, const char * /* format */) {
         KTempFile tmp_xmi_file;
         file.setName(tmp_xmi_file.name());
         if( !file.open( IO_WriteOnly ) ) {
-            KMessageBox::error(0, i18n("There was a problem saving file: %1").arg(d.path()), i18n("Save Error"));
+            KMessageBox::error(0, i18n("There was a problem saving file: %1").tqarg(d.path()), i18n("Save Error"));
             return false;
         }
-        saveToXMI(file); // save XMI to this file...
+        saveToXMI(*TQT_TQIODEVICE(&file)); // save XMI to this file...
         file.close(); // ...and close it
 
         // now add this file to the archive, but without the extension
-        TQString tmpQString = url.fileName();
+        TQString tmpTQString = url.fileName();
         if (fileFormat == "tgz")
         {
-            tmpQString.replace(TQRegExp("\\.tgz$"), "");
+            tmpTQString.replace(TQRegExp("\\.tgz$"), "");
         } else {
-            tmpQString.replace(TQRegExp("\\.tar\\.bz2$"), "");
+            tmpTQString.replace(TQRegExp("\\.tar\\.bz2$"), "");
         }
-        archive->addLocalFile(tmp_xmi_file.name(), tmpQString);
+        archive->addLocalFile(tmp_xmi_file.name(), tmpTQString);
         archive->close();
 
 #if KDE_IS_VERSION(3,4,89)
         if (!archive->closeSucceeded())
         {
-            KMessageBox::error(0, i18n("There was a problem saving file: %1").arg(d.path()), i18n("Save Error"));
+            KMessageBox::error(0, i18n("There was a problem saving file: %1").tqarg(d.path()), i18n("Save Error"));
             return false;
         }
 #endif
@@ -617,10 +617,10 @@ bool UMLDoc::saveDocument(const KURL& url, const char * /* format */) {
 
         // lets open the file for writing
         if( !file.open( IO_WriteOnly ) ) {
-            KMessageBox::error(0, i18n("There was a problem saving file: %1").arg(d.path()), i18n("Save Error"));
+            KMessageBox::error(0, i18n("There was a problem saving file: %1").tqarg(d.path()), i18n("Save Error"));
             return false;
         }
-        saveToXMI(file); // save the xmi stuff to it
+        saveToXMI(*TQT_TQIODEVICE(&file)); // save the xmi stuff to it
         file.close();
         tmpfile.close();
 
@@ -630,7 +630,7 @@ bool UMLDoc::saveDocument(const KURL& url, const char * /* format */) {
         } else {
             // now remove the original file
             if ( KIO::NetAccess::file_move( tmpfile.name(), d.path(), -1, true ) == false ) {
-                KMessageBox::error(0, i18n("There was a problem saving file: %1").arg(d.path()), i18n("Save Error"));
+                KMessageBox::error(0, i18n("There was a problem saving file: %1").tqarg(d.path()), i18n("Save Error"));
                 m_doc_url.setFileName(i18n("Untitled"));
                 return false;
             }
@@ -638,7 +638,7 @@ bool UMLDoc::saveDocument(const KURL& url, const char * /* format */) {
     }
     if( !uploaded )
     {
-        KMessageBox::error(0, i18n("There was a problem uploading file: %1").arg(d.path()), i18n("Save Error"));
+        KMessageBox::error(0, i18n("There was a problem uploading file: %1").tqarg(d.path()), i18n("Save Error"));
         m_doc_url.setFileName(i18n("Untitled"));
     }
     setModified(false);
@@ -1096,7 +1096,7 @@ void UMLDoc::removeDiagram(Uml::IDType id) {
         kError()<<"Request to remove diagram " << ID2STR(id) << ": Diagram not found!"<<endl;
         return;
     }
-    if (KMessageBox::warningContinueCancel(0, i18n("Are you sure you want to delete diagram %1?").arg(umlview->getName()), i18n("Delete Diagram"),KGuiItem( i18n("&Delete"), "editdelete")) == KMessageBox::Continue) {
+    if (KMessageBox::warningContinueCancel(0, i18n("Are you sure you want to delete diagram %1?").tqarg(umlview->getName()), i18n("Delete Diagram"),KGuiItem( i18n("&Delete"), "editdelete")) == KMessageBox::Continue) {
         removeView(umlview);
         emit sigDiagramRemoved(id);
         setModified(true);
@@ -1213,7 +1213,7 @@ void UMLDoc::saveToXMI(TQIODevice& file) {
 
     TQDomElement root = doc.createElement( "XMI" );
     root.setAttribute( "xmi.version", "1.2" );
-    TQDateTime now = TQDateTime::currentDateTime();
+    TQDateTime now = TQDateTime::tqcurrentDateTime();
     root.setAttribute( "timestamp", now.toString(Qt::ISODate));
     root.setAttribute( "verified", "false");
     root.setAttribute( "xmlns:UML", "http://schema.omg.org/spec/UML/1.3");
@@ -1915,7 +1915,7 @@ void UMLDoc::print(KPrinter * pPrinter) {
     for(int i = 0;i < count;i++) {
         if(i>0)
             pPrinter -> newPage();
-        TQString diagram = i18n("kde-uml-Diagram") + TQString("%1").arg(i);
+        TQString diagram = i18n("kde-uml-Diagram") + TQString("%1").tqarg(i);
         TQString sID = pPrinter -> option(diagram);
         Uml::IDType id = STR2ID(sID);
         printView = findView(id);
@@ -2101,7 +2101,7 @@ void UMLDoc::slotAutoSave() {
     }
     KURL tempURL = m_doc_url;
     if( tempURL.fileName() == i18n("Untitled") ) {
-        tempURL.setPath( TQDir::homeDirPath() + i18n("/autosave%1").arg(".xmi") );
+        tempURL.setPath( TQDir::homeDirPath() + i18n("/autosave%1").tqarg(".xmi") );
         saveDocument( tempURL );
         m_doc_url.setFileName( i18n("Untitled") );
         m_modified = true;
@@ -2148,7 +2148,7 @@ void UMLDoc::addToUndoStack() {
         buffer->open(IO_WriteOnly);
         TQDataStream* undoData = new TQDataStream();
         undoData->setDevice(buffer);
-        saveToXMI(*buffer);
+        saveToXMI(*TQT_TQIODEVICE(buffer));
         buffer->close();
         undoStack.prepend(undoData);
 
@@ -2196,7 +2196,7 @@ void UMLDoc::loadUndoData() {
     TQDataStream* undoData = undoStack.getFirst();
     TQBuffer* buffer = static_cast<TQBuffer*>( undoData->device() );
     buffer->open(IO_ReadOnly);
-    loadFromXMI(*buffer);
+    loadFromXMI(*TQT_TQIODEVICE(buffer));
     buffer->close();
 
     setModified(true, false);
@@ -2235,7 +2235,7 @@ void UMLDoc::loadRedoData() {
         redoStack.removeFirst();
         TQBuffer* buffer = static_cast<TQBuffer*>( redoData->device() );
         buffer->open(IO_ReadOnly);
-        loadFromXMI(*buffer);
+        loadFromXMI(*TQT_TQIODEVICE(buffer));
         buffer->close();
 
         setModified(true, false);
