@@ -59,6 +59,7 @@ class ToolBarStateFactory;
  */
 class UMLView : public TQCanvasView {
     Q_OBJECT
+  TQ_OBJECT
 public:
     friend class UMLViewImageExporterModel;
 
@@ -705,7 +706,7 @@ public:
     void resetPastePoint();
 
     /**
-     * Called by the view or any of its children when they start a cut
+     * Called by the view or any of its tqchildren when they start a cut
      * operation.
      */
     void setStartedCut() {
@@ -901,7 +902,7 @@ public:
     }
 
     /**
-     * Emit the sigRemovePopupMenu Qt signal.
+     * Emit the sigRemovePopupMenu TQt signal.
      */
     void emitRemovePopupMenu() {
         emit sigRemovePopupMenu();
@@ -1119,7 +1120,7 @@ protected:
     UMLWidgetList m_SelectedList;
 
     /**
-     *  Flag if view/children started cut operation.
+     *  Flag if view/tqchildren started cut operation.
      */
     bool m_bStartedCut;
 
@@ -1151,7 +1152,7 @@ private:
     bool m_bActivated;
 
     /**
-     * Status of a popupmenu on view.
+     * tqStatus of a popupmenu on view.
      * true - a popup is on view
      */
     bool m_bPopupShowing;
