@@ -42,6 +42,7 @@ class TQFontMetrics;
  */
 class UMLWidget : public WidgetBase, public TQCanvasRectangle {
     Q_OBJECT
+  TQ_OBJECT
 public:
     friend class UMLWidgetController;
 
@@ -184,7 +185,7 @@ public:
     void setView(UMLView * v);
 
     /**
-     * Activate the object after serializing it from a QDataStream
+     * Activate the object after serializing it from a TQDataStream
      *
      * @param ChangeLog
      * @return  true for success
@@ -465,7 +466,7 @@ public:
     /**
      * Set the m_bActivated flag of a widget but does not perform the Activate method
      *
-     * @param Active Status of activation is to be set.
+     * @param Active tqStatus of activation is to be set.
      */
     void setActivated(bool Active = true);
 
@@ -542,7 +543,7 @@ protected:
     /**
      * Overrides default method.
      *
-     * @param p Device on which the shape has to be drawn.
+     * @param p Device on which the shape.has to be drawn.
      */
     virtual void drawShape(TQPainter &p );
 
@@ -666,7 +667,7 @@ public slots:
     /**
      * This slot is entered when an event has occurred on the views display,
      * most likely a mouse event.  Before it sends out that mouse event all
-     * children should make sure that they don't have a menu active or there
+     * tqchildren should make sure that they don't have a menu active or there
      * could be more than one popup menu displayed.
      */
     virtual void slotRemovePopupMenu();
