@@ -22,6 +22,7 @@
 class ClearcaseFileinfoProvider : public KDevVCSFileInfoProvider
 {
   Q_OBJECT
+  TQ_OBJECT
 public:
     ClearcaseFileinfoProvider(ClearcasePart *parent);
 
@@ -31,7 +32,7 @@ public:
     const VCSFileInfoMap *status( const TQString &dirPath ) ;
 
     // -- Async interface for requesting data
-    bool requestStatus( const TQString &dirPath, void *callerData, bool recursive = true, bool checkRepos = true );
+    bool requesttqStatus( const TQString &dirPath, void *callerData, bool recursive = true, bool checkRepos = true );
 
 
 private:
