@@ -321,45 +321,45 @@ void CvsServicePart::contextMenu( TQPopupMenu *popup, const Context *context )
             popup->insertSeparator();
 
         int id = subMenu->insertItem( actionCommit->text(), this, TQT_SLOT(slotCommit()) );
-        subMenu->setWhatsThis(id, i18n("<b>Commit file(s)</b><p>Commits file to repository if modified."));
+        subMenu->tqsetWhatsThis(id, i18n("<b>Commit file(s)</b><p>Commits file to repository if modified."));
         // CvsService let to do log and diff operations only on one file (or directory) at time
         if (m_urls.count() == 1)
         {
             id = subMenu->insertItem( actionDiff->text(), this, TQT_SLOT(slotDiff()) );
-            subMenu->setWhatsThis(id, i18n("<b>Build difference</b><p>Builds difference between releases."));
+            subMenu->tqsetWhatsThis(id, i18n("<b>Build difference</b><p>Builds difference between releases."));
             id = subMenu->insertItem( actionLog->text(), this, TQT_SLOT(slotLog()) );
-            subMenu->setWhatsThis(id, i18n("<b>Generate log</b><p>Produces log for this file."));
+            subMenu->tqsetWhatsThis(id, i18n("<b>Generate log</b><p>Produces log for this file."));
             id = subMenu->insertItem( actionAnnotate->text(), this, TQT_SLOT(slotAnnotate()) );
-            subMenu->setWhatsThis(id, i18n("<b>Generate Annotate</b><p>Produces annotation output for this file."));
+            subMenu->tqsetWhatsThis(id, i18n("<b>Generate Annotate</b><p>Produces annotation output for this file."));
         }
         id = subMenu->insertItem( actionEditors->text(), this, TQT_SLOT(slotEditors()) );
-        subMenu->setWhatsThis(id, i18n("<b>Show editors</b><p>Shows the list of users who are editing files."));
+        subMenu->tqsetWhatsThis(id, i18n("<b>Show editors</b><p>Shows the list of users who are editing files."));
         id = subMenu->insertItem( actionEdit->text(), this, TQT_SLOT(slotEdit()) );
-        subMenu->setWhatsThis(id, i18n("<b>Mark as beeing edited</b><p>Mark the files as beeing edited."));
+        subMenu->tqsetWhatsThis(id, i18n("<b>Mark as beeing edited</b><p>Mark the files as beeing edited."));
         id = subMenu->insertItem( actionUnEdit->text(), this, TQT_SLOT(slotUnEdit()) );
-        subMenu->setWhatsThis(id, i18n("<b>Remove editing mark</b><p>Remove the editing mark from the files."));
+        subMenu->tqsetWhatsThis(id, i18n("<b>Remove editing mark</b><p>Remove the editing mark from the files."));
         id = subMenu->insertItem( actionAdd->text(), this, TQT_SLOT(slotAdd()) );
-        subMenu->setWhatsThis(id, i18n("<b>Add to repository</b><p>Adds file to repository."));
+        subMenu->tqsetWhatsThis(id, i18n("<b>Add to repository</b><p>Adds file to repository."));
         id = subMenu->insertItem( actionAddBinary->text(), this, TQT_SLOT(slotAddBinary()) );
-        subMenu->setWhatsThis(id, i18n("<b>Add to repository as binary</b><p>Adds file to repository as binary (-kb option)."));
+        subMenu->tqsetWhatsThis(id, i18n("<b>Add to repository as binary</b><p>Adds file to repository as binary (-kb option)."));
         id = subMenu->insertItem( actionRemove->text(), this, TQT_SLOT(slotRemove()) );
-        subMenu->setWhatsThis(id, i18n("<b>Remove from repository</b><p>Removes file(s) from repository."));
+        subMenu->tqsetWhatsThis(id, i18n("<b>Remove from repository</b><p>Removes file(s) from repository."));
 
         subMenu->insertSeparator();
         id = subMenu->insertItem( actionTag->text(), this, TQT_SLOT(slotTag()) );
-        subMenu->setWhatsThis(id, i18n("<b>Make tag/branch</b><p>Tags/branches selected file(s)."));
+        subMenu->tqsetWhatsThis(id, i18n("<b>Make tag/branch</b><p>Tags/branches selected file(s)."));
         id = subMenu->insertItem( actionUnTag->text(), this, TQT_SLOT(slotUnTag()) );
-        subMenu->setWhatsThis(id, i18n("<b>Delete tag</b><p>Delete tag from selected file(s)."));
+        subMenu->tqsetWhatsThis(id, i18n("<b>Delete tag</b><p>Delete tag from selected file(s)."));
         id = subMenu->insertItem( actionUpdate->text(), this, TQT_SLOT(slotUpdate()) );
-        subMenu->setWhatsThis(id, i18n("<b>Update/revert to another release</b><p>Updates/reverts file(s) to another release."));
+        subMenu->tqsetWhatsThis(id, i18n("<b>Update/revert to another release</b><p>Updates/reverts file(s) to another release."));
         id = subMenu->insertItem( actionRemoveSticky->text(), this, TQT_SLOT(slotRemoveSticky()) );
-        subMenu->setWhatsThis(id, i18n("<b>Remove sticky flag</b><p>Removes sticky flag from file(s)."));
+        subMenu->tqsetWhatsThis(id, i18n("<b>Remove sticky flag</b><p>Removes sticky flag from file(s)."));
 
         subMenu->insertSeparator();
         id = subMenu->insertItem( actionAddToIgnoreList->text(), this, TQT_SLOT(slotAddToIgnoreList()) );
-        subMenu->setWhatsThis(id, i18n("<b>Ignore in CVS operations</b><p>Ignore file(s) by adding it to .cvsignore file."));
+        subMenu->tqsetWhatsThis(id, i18n("<b>Ignore in CVS operations</b><p>Ignore file(s) by adding it to .cvsignore file."));
         id = subMenu->insertItem( actionRemoveFromIgnoreList->text(), this, TQT_SLOT(slotRemoveFromIgnoreList()) );
-        subMenu->setWhatsThis(id, i18n("<b>Do not ignore in CVS operations</b><p>Do not ignore file(s) by removing\nit from .cvsignore file."));
+        subMenu->tqsetWhatsThis(id, i18n("<b>Do not ignore in CVS operations</b><p>Do not ignore file(s) by removing\nit from .cvsignore file."));
 
         // Now insert in parent menu
         popup->insertItem( i18n("CvsService"), subMenu );
