@@ -211,7 +211,7 @@ bool CvsServicePartImpl::isRegisteredInRepository( const TQString &projectDirect
             kdDebug(9006) << k_funcinfo << " Error: " << cvsdir.path() << " is not a valid CVS directory " << endl;
             return false;
         }
-        CVSEntry entry = cvsdir.fileStatus( url.fileName() );
+        CVSEntry entry = cvsdir.filetqStatus( url.fileName() );
         return entry.isValid();
     }
 }
@@ -318,7 +318,7 @@ KDevMainWindow *CvsServicePartImpl::mainWindow() const
 
 TQString CvsServicePartImpl::projectDirectory() const
 {
-    return m_part->project() ? m_part->project()->projectDirectory() : TQString::null;
+    return m_part->project() ? m_part->project()->projectDirectory() : TQString();
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -639,7 +639,7 @@ void CvsServicePartImpl::diff( const KURL::List& urlList )
         return;
     
     CVSDir cvsdir = CVSDir( urlList[0].directory() );
-    CVSEntry entry = cvsdir.fileStatus( urlList[0].fileName() );
+    CVSEntry entry = cvsdir.filetqStatus( urlList[0].fileName() );
 
     DiffDialog dlg(entry);
     if (dlg.exec() != TQDialog::Accepted)
@@ -971,7 +971,7 @@ void CvsServicePartImpl::slotCheckoutFinished( bool exitStatus, int )
         << exitStatus << endl;
     // Return a null string if the operation was not succesfull
     if (!exitStatus)
-        modulePath = TQString::null;
+        modulePath = TQString();
 
     kdDebug(9006) << "   I'll emit modulePath == " << modulePath << endl;
 
