@@ -223,7 +223,7 @@ void subversionCore::diff( const KURL::List& list, const TQString& where){
 			if ( where=="HEAD"){
 				diffTo=i18n("the current svn HEAD version.");
 			}
-			KMessageBox::information( 0, i18n("No differences between the file and %1").arg(diffTo), i18n("No difference") );
+			KMessageBox::information( 0, i18n("No differences between the file and %1").tqarg(diffTo), i18n("No difference") );
 		}
 		diffresult.clear();
 	}
@@ -496,7 +496,7 @@ bool subversionCore::clientInfo( KURL path_or_url, bool recurse, TQMap< KURL, Sv
 void subversionCore::slotEndCheckout( KIO::Job * job ) {
 	if ( job->error() ) {
 		job->showErrorDialog( m_part->mainWindow()->main() );
-		emit checkoutFinished( TQString::null );
+		emit checkoutFinished( TQString() );
 	} else
 		emit checkoutFinished(wcPath);
 }
@@ -700,7 +700,7 @@ void subversionCore::slotDiffResult( KIO::Job * job )
 			p->start();
 			
 		} else { //else do it with message box
-			KMessageBox::information( NULL, i18n("You do not have kompare installed. We recommend you install kompare to view differences graphically.") + "\nhttp://www.caffeinated.me.uk/kompare/" , TQString::null , "userDoesNotWantKompare" );
+			KMessageBox::information( NULL, i18n("You do not have kompare installed. We recommend you install kompare to view differences graphically.") + "\nhttp://www.caffeinated.me.uk/kompare/" , TQString() , "userDoesNotWantKompare" );
 			Subversion_Diff df;
 			for ( TQStringList::Iterator it2 = diffList.begin();it2 != diffList.end() ; ++it2 ) {
 				df.text->append( *it2 );
