@@ -223,7 +223,7 @@ svn_error_t* kio_svnProtocol::checkAuth(svn_auth_cred_simple_t **cred, void *bat
 	p->info.url = p->myURL;
 	p->info.username = username; //( const char* )svn_auth_get_parameter( p->ctx->auth_baton, SVN_AUTH_PARAM_DEFAULT_USERNAME );
 	if (realm) {
-		p->info.prompt = i18n("Username and Password for %1.").arg(realm);
+		p->info.prompt = i18n("Username and Password for %1.").tqarg(realm);
 	}
 
 //	if ( !p->checkCachedAuthentication( p->info ) ){
@@ -246,7 +246,7 @@ void kio_svnProtocol::get(const KURL& url ){
 	kdDebug(9036) << "kio_svn::get(const KURL& url)" << endl ;
 
 	TQString remoteServer = url.host();
-	infoMessage(i18n("Looking for %1...").arg( remoteServer ) );
+	infoMessage(i18n("Looking for %1...").tqarg( remoteServer ) );
 
 	apr_pool_t *subpool = svn_pool_create (pool);
 	kbaton *bt = (kbaton*)apr_pcalloc(subpool, sizeof(*bt));
@@ -1261,7 +1261,7 @@ void kio_svnProtocol::svn_switch_relocate( const KURL &wc, const KURL &origUrl,
 	}
 	m_counter = 0L;
 	setMetaData(TQString::number( counter() ).rightJustify( 10,'0' )+ "string",
-				TQString("switched to %1").arg( toUrl ) );
+				TQString("switched to %1").tqarg( toUrl ) );
 	finished();
 	svn_pool_destroy( subpool );
 }
@@ -1384,7 +1384,7 @@ void kio_svnProtocol::commit2(bool recurse, bool keeplocks, const KURL::List& wc
 
 			TQString userstring = i18n ( "Nothing to commit." );
 			if ( SVN_IS_VALID_REVNUM( commit_info->revision ) )
-				userstring = i18n( "Committed revision %1." ).arg(commit_info->revision);
+				userstring = i18n( "Committed revision %1." ).tqarg(commit_info->revision);
 			setMetaData(TQString::number( m_counter ).rightJustify( 10,'0' )+ "path", nurl.path() );
 			setMetaData(TQString::number( m_counter ).rightJustify( 10,'0' )+ "action", "0" );
 			setMetaData(TQString::number( m_counter ).rightJustify( 10,'0' )+ "kind", "0" );
@@ -1584,7 +1584,7 @@ void kio_svnProtocol::svn_copy( const KURL &srcUrl, int srcRev, const TQString &
 	
 	if( commit_info ){
 		setMetaData(TQString::number( counter() ).rightJustify( 10,'0' )+ "string",
-					i18n("Copied Revision %1").arg( commit_info->revision) );
+					i18n("Copied Revision %1").tqarg( commit_info->revision) );
 	} else {
 		setMetaData(TQString::number( counter() ).rightJustify( 10,'0' )+ "string",
 					i18n("Copied") );
@@ -1750,7 +1750,7 @@ svn_error_t *kio_svnProtocol::clientCertSSLPrompt(
 // 		kdWarning()<<" Communication with dcop failed - fail to get certfile "<<endl;
 // 		return SVN_NO_ERROR;
 // 	}
-// 	if (replyType != "TQString") {
+// 	if (replyType != TQSTRING_OBJECT_NAME_STRING) {
 // 		kdWarning()<<" unexpected reply type "<<endl;
 // 		return SVN_NO_ERROR;
 // 	}
@@ -1867,7 +1867,7 @@ svn_error_t *kio_svnProtocol::commitLogPrompt( const char **log_msg, const char
 		return err;
 	}
 
-	if ( replyType != "TQString" ) {
+	if ( replyType != TQSTRING_OBJECT_NAME_STRING ) {
 		kdWarning() << "Unexpected reply type" << endl;
 		svn_error_t *err = svn_error_create( SVN_ERR_EXTERNAL_PROGRAM, NULL,
 											 apr_pstrdup( pool, "Fail to call kded_kdevsvnd via DCOP." ) );
@@ -1900,42 +1900,42 @@ void kio_svnProtocol::notify(void *baton, const char *path, svn_wc_notify_action
 	switch ( action ) {
 		case svn_wc_notify_add : //add
 			if (mime_type && (svn_mime_type_is_binary (mime_type)))
-				userstring = i18n( "A (bin) %1" ).arg( path );
+				userstring = i18n( "A (bin) %1" ).tqarg( path );
 			else
-				userstring = i18n( "A %1" ).arg( path );
+				userstring = i18n( "A %1" ).tqarg( path );
 			break;
 		case svn_wc_notify_copy: //copy
-			userstring = i18n( "Copied %1 " ).arg( path );
+			userstring = i18n( "Copied %1 " ).tqarg( path );
 			break;
 		case svn_wc_notify_delete: //delete
 			nb->received_some_change = TRUE;
-			userstring = i18n( "D %1" ).arg( path );
+			userstring = i18n( "D %1" ).tqarg( path );
 			break;
 		case svn_wc_notify_restore : //restore
-			userstring=i18n( "Restored %1." ).arg( path );
+			userstring=i18n( "Restored %1." ).tqarg( path );
 			break;
 		case svn_wc_notify_revert : //revert
-			userstring=i18n( "Reverted %1." ).arg( path );
+			userstring=i18n( "Reverted %1." ).tqarg( path );
 			break;
 		case svn_wc_notify_failed_revert: //failed revert
-			userstring=i18n( "Failed to revert %1.\nTry updating instead." ).arg( path );
+			userstring=i18n( "Failed to revert %1.\nTry updating instead." ).tqarg( path );
 			break;
 		case svn_wc_notify_resolved: //resolved
-			userstring=i18n( "Resolved conflicted state of %1." ).arg( path );
+			userstring=i18n( "Resolved conflicted state of %1." ).tqarg( path );
 			break;
 		case svn_wc_notify_skip: //skip
 			if ( content_state == svn_wc_notify_state_missing )
-				userstring=i18n("Skipped missing target %1.").arg( path );
+				userstring=i18n("Skipped missing target %1.").tqarg( path );
 			else
-				userstring=i18n("Skipped  %1.").arg( path );
+				userstring=i18n("Skipped  %1.").tqarg( path );
 			break;
 		case svn_wc_notify_update_delete: //update_delete
 			nb->received_some_change = TRUE;
-			userstring=i18n( "D %1" ).arg( path );
+			userstring=i18n( "D %1" ).tqarg( path );
 			break;
 		case svn_wc_notify_update_add: //update_add
 			nb->received_some_change = TRUE;
-			userstring=i18n( "A %1" ).arg( path );
+			userstring=i18n( "A %1" ).tqarg( path );
 			break;
 		case svn_wc_notify_update_update: //update_update
 			{
@@ -1980,25 +1980,25 @@ void kio_svnProtocol::notify(void *baton, const char *path, svn_wc_notify_action
 					if (SVN_IS_VALID_REVNUM (revision)) {
 						if (nb->is_export) {
 							if ( nb->in_external )
-								userstring = i18n("Exported external at revision %1.").arg( revision );
+								userstring = i18n("Exported external at revision %1.").tqarg( revision );
 							else
-								userstring = i18n("Exported revision %1.").arg( revision );
+								userstring = i18n("Exported revision %1.").tqarg( revision );
 						} else if (nb->is_checkout) {
 							if ( nb->in_external )
-								userstring = i18n("Checked out external at revision %1.").arg( revision );
+								userstring = i18n("Checked out external at revision %1.").tqarg( revision );
 							else
-								userstring = i18n("Checked out revision %1.").arg( revision);
+								userstring = i18n("Checked out revision %1.").tqarg( revision);
 						} else {
 							if (nb->received_some_change) {
 								if ( nb->in_external )
-									userstring=i18n("Updated external to revision %1.").arg( revision );
+									userstring=i18n("Updated external to revision %1.").tqarg( revision );
 								else
-									userstring = i18n("Updated to revision %1.").arg( revision);
+									userstring = i18n("Updated to revision %1.").tqarg( revision);
 							} else {
 								if ( nb->in_external )
-									userstring = i18n("External at revision %1.").arg( revision );
+									userstring = i18n("External at revision %1.").tqarg( revision );
 								else
-									userstring = i18n("At revision %1.").arg( revision);
+									userstring = i18n("At revision %1.").tqarg( revision);
 							}
 						}
 					} else  /* no revision */ {
@@ -2026,30 +2026,30 @@ void kio_svnProtocol::notify(void *baton, const char *path, svn_wc_notify_action
 			break;
 		case svn_wc_notify_update_external: //update_external
 			nb->in_external = TRUE;
-			userstring = i18n("Fetching external item into %1." ).arg( path );
+			userstring = i18n("Fetching external item into %1." ).tqarg( path );
 			break;
 		case svn_wc_notify_status_completed: //status_completed
 			if (SVN_IS_VALID_REVNUM (revision))
-				userstring = i18n( "Status against revision: %1.").arg( revision );
+				userstring = i18n( "Status against revision: %1.").tqarg( revision );
 			break;
 		case svn_wc_notify_status_external: //status_external
-             userstring = i18n("Performing status on external item at %1.").arg( path );
+             userstring = i18n("Performing status on external item at %1.").tqarg( path );
 			break;
 		case svn_wc_notify_commit_modified: //commit_modified
-			userstring = i18n( "Sending %1").arg( path );
+			userstring = i18n( "Sending %1").tqarg( path );
 			break;
 		case svn_wc_notify_commit_added: //commit_added
 			if (mime_type && svn_mime_type_is_binary (mime_type)) {
-				userstring = i18n( "Adding (bin) %1.").arg( path );
+				userstring = i18n( "Adding (bin) %1.").tqarg( path );
 			} else {
-				userstring = i18n( "Adding %1.").arg( path );
+				userstring = i18n( "Adding %1.").tqarg( path );
 			}
 			break;
 		case svn_wc_notify_commit_deleted: //commit_deleted
-			userstring = i18n( "Deleting %1.").arg( path );
+			userstring = i18n( "Deleting %1.").tqarg( path );
 			break;
 		case svn_wc_notify_commit_replaced: //commit_replaced
-			userstring = i18n( "Replacing %1.").arg( path );
+			userstring = i18n( "Replacing %1.").tqarg( path );
 			break;
 		case svn_wc_notify_commit_postfix_txdelta: //commit_postfix_txdelta
 			if (! nb->sent_first_txdelta) {
@@ -2062,7 +2062,7 @@ void kio_svnProtocol::notify(void *baton, const char *path, svn_wc_notify_action
 
 			break;
 		case svn_wc_notify_blame_revision: //blame_revision
-			userstring = i18n("Blame %1.").arg(path);
+			userstring = i18n("Blame %1.").tqarg(path);
 			break;
 		default:
 			break;
