@@ -184,7 +184,7 @@ KWiFiManagerApp::slotLogESSID (TQString essid)
   if (!log_file.open (IO_WriteOnly | IO_Append))
     kdDebug () << "Logging failed!" << endl;
   TQTextStream stream (&log_file);
-  stream << TQDateTime::currentDateTime().toString ().latin1 ();
+  stream << TQDateTime::tqcurrentDateTime().toString ().latin1 ();
   stream << " Entering network: " << essid.latin1() << endl;
   log_file.close ();
 }
@@ -262,7 +262,7 @@ KWiFiManagerApp::slotChangeTrayIcon ()
     }
   else if (((str == 0) && (mode == 2)) || (!validdata))
     {
-      sstrength2.setText( TQString::fromLatin1("0") );
+      sstrength2.setText( TQString::tqfromLatin1("0") );
       ICON = strength->OOR_DOWN;
       if (led->state == true)
 	led->Off ();
@@ -286,7 +286,7 @@ KWiFiManagerApp::slotChangeTrayIcon ()
     labelfont.setStretch( TQFont::Condensed );
     labelfont.setBold( true );
     sstrength2.setFont( labelfont );
-    sstrength2.setFixedSize( sstrength2.sizeHint() );
+    sstrength2.setFixedSize( sstrength2.tqsizeHint() );
       }
     TQPixmap labeltemp = TQPixmap::grabWidget( &sstrength2 );
     labeltemp.setMask( labeltemp.createHeuristicMask() );
@@ -304,43 +304,43 @@ KWiFiManagerApp::initActions ()
   KConfig* config = kapp->config();
   if (config->hasGroup("General"))
 	config->setGroup("General");
-  fileDisableRadio = new KToggleAction (i18n ("&Disable Radio"), 0, this,
+  fileDisableRadio = new KToggleAction (i18n ("&Disable Radio"), 0, TQT_TQOBJECT(this),
 		     TQT_SLOT (slotDisableRadio ()), actionCollection (), "disable_radio");
   fileDisableRadio->setChecked( false );
 
   settingsUseAlternateCalc =
-    new KToggleAction (i18n ("&Use Alternate Strength Calculation"), 0, this,
+    new KToggleAction (i18n ("&Use Alternate Strength Calculation"), 0, TQT_TQOBJECT(this),
 		       TQT_SLOT (slotToggleStrengthCalc ()), actionCollection (), "use_alt_calculation");
 
   settingsUseAlternateCalc->setChecked( config->readBoolEntry("useAlternateStrengthCalculation") );
   slotToggleStrengthCalc();  //set to value saved by KConfig
 
   settingsShowStatsNoise =
-    new KToggleAction (i18n ("Show &Noise Graph in Statistics Window"), 0, this,
+    new KToggleAction (i18n ("Show &Noise Graph in Statistics Window"), 0, TQT_TQOBJECT(this),
 		       TQT_SLOT (slotShowStatsNoise ()), actionCollection (), "show_stats_noise");
 
   settingsShowStatsNoise->setChecked( config->readBoolEntry("showStatsNoise") );
   slotShowStatsNoise();  //set to value saved by KConfig
 
-  settingsShowStrengthNumber = new KToggleAction (i18n ("&Show Strength Number in System Tray"), 0, this,
+  settingsShowStrengthNumber = new KToggleAction (i18n ("&Show Strength Number in System Tray"), 0, TQT_TQOBJECT(this),
                        TQT_SLOT (slotToggleShowStrengthNumber ()), actionCollection (), "show_strength_number_in_tray");
   settingsShowStrengthNumber->setChecked( config->readBoolEntry("showStrengthNumberInTray") );
   slotToggleShowStrengthNumber (); //set to value saved by KConfig
 
-  KStdAction::quit (this, TQT_SLOT (slotFileQuit ()), actionCollection ());
+  KStdAction::quit (TQT_TQOBJECT(this), TQT_SLOT (slotFileQuit ()), actionCollection ());
 
-  new KAction (i18n ("Configuration &Editor..."), 0, this,
+  new KAction (i18n ("Configuration &Editor..."), 0, TQT_TQOBJECT(this),
 	       TQT_SLOT (slotStartConfigEditor ()), actionCollection (), "configuration_editor");
-  new KAction (i18n ("Connection &Statistics"), 0, this,
+  new KAction (i18n ("Connection &Statistics"), 0, TQT_TQOBJECT(this),
 			       TQT_SLOT (slotStartStatViewer ()), actionCollection (), "connection_statistics");
-  settingsAcousticScanning = new KToggleAction (i18n ("&Acoustic Scanning"), 0, this,
+  settingsAcousticScanning = new KToggleAction (i18n ("&Acoustic Scanning"), 0, TQT_TQOBJECT(this),
 			    TQT_SLOT (slotToggleTric ()),
 			    actionCollection (), "acoustic_scanning");
   settingsAcousticScanning->setChecked( config->readBoolEntry("acousticScanning") );
 #ifdef WITHOUT_ARTS
   settingsAcousticScanning->setEnabled( false);
 #endif
-  settingsStayInSystrayOnClose = new KToggleAction (i18n ("Stay in System &Tray on Close"), 0, this,
+  settingsStayInSystrayOnClose = new KToggleAction (i18n ("Stay in System &Tray on Close"), 0, TQT_TQOBJECT(this),
 						    TQT_SLOT (slotToggleStayInSystray()),
 						    actionCollection (), "stay_in_systray_on_close");
   settingsStayInSystrayOnClose->setChecked( config->readBoolEntry("stayInSystrayOnClose") );
@@ -360,10 +360,10 @@ KWiFiManagerApp::initView ()
   view = new TQWidget (this, "mainwidget");
   view->setBackgroundMode (PaletteBackground);
   setCentralWidget (view);
-  TQGridLayout *zentrallayout = new TQGridLayout (view);
-  zentrallayout->setMargin( KDialog::marginHint() );
+  TQGridLayout *zentraltqlayout = new TQGridLayout (view);
+  zentraltqlayout->setMargin( KDialog::marginHint() );
   speedmeter = new Speed (view, device);
-  status = new Status (view, device);
+  status = new tqStatus (view, device);
   location = new Locator (view, device);
   strength = new Strength (view, device);
   pictogram = new Picture (view, device);
@@ -377,25 +377,25 @@ KWiFiManagerApp::initView ()
   strength->setMinimumSize (strength->mySizeHint());
   speedmeter->setMinimumHeight (60);
   status->setMinimumHeight (60);
-  zentrallayout->addWidget (pictogram, 0, 0);
-  zentrallayout->addWidget (strength, 1, 0);
-  zentrallayout->addWidget (speedmeter, 0, 1);
-  zentrallayout->addMultiCellWidget (status, 1, 2, 1, 1);
-  zentrallayout->addWidget (scan, 2, 0);
-  zentrallayout->addMultiCellWidget (location, 3, 3, 0, 1, Qt::AlignLeft);
+  zentraltqlayout->addWidget (pictogram, 0, 0);
+  zentraltqlayout->addWidget (strength, 1, 0);
+  zentraltqlayout->addWidget (speedmeter, 0, 1);
+  zentraltqlayout->addMultiCellWidget (status, 1, 2, 1, 1);
+  zentraltqlayout->addWidget (scan, 2, 0);
+  zentraltqlayout->addMultiCellWidget (location, 3, 3, 0, 1, TQt::AlignLeft);
   connect (device, TQT_SIGNAL (interfaceChanged ()), this, TQT_SLOT (slotChangeWindowCaption ()));
   connect (device, TQT_SIGNAL (strengthChanged ()), this, TQT_SLOT (slotChangeTrayIcon ()));
-  connect (device, TQT_SIGNAL (strengthChanged ()), strength, TQT_SLOT (repaint ()));
-  connect (device, TQT_SIGNAL (statusChanged ()), status, TQT_SLOT (repaint ()));
-  connect (device, TQT_SIGNAL (speedChanged ()), speedmeter, TQT_SLOT (repaint ()));
-  connect (device, TQT_SIGNAL (modeChanged ()), pictogram, TQT_SLOT (repaint ()));
+  connect (device, TQT_SIGNAL (strengthChanged ()), strength, TQT_SLOT (tqrepaint ()));
+  connect (device, TQT_SIGNAL (statusChanged ()), status, TQT_SLOT (tqrepaint ()));
+  connect (device, TQT_SIGNAL (speedChanged ()), speedmeter, TQT_SLOT (tqrepaint ()));
+  connect (device, TQT_SIGNAL (modeChanged ()), pictogram, TQT_SLOT (tqrepaint ()));
   connect (device, TQT_SIGNAL (essidChanged (TQString)), this, TQT_SLOT (slotLogESSID (TQString)));
-  connect (device, TQT_SIGNAL (essidChanged (TQString)), location, TQT_SLOT (repaint ()));
-  connect (device, TQT_SIGNAL (statusChanged ()), location, TQT_SLOT (repaint ()));
+  connect (device, TQT_SIGNAL (essidChanged (TQString)), location, TQT_SLOT (tqrepaint ()));
+  connect (device, TQT_SIGNAL (statusChanged ()), location, TQT_SLOT (tqrepaint ()));
   connect (device, TQT_SIGNAL (txPowerChanged ()), this, TQT_SLOT (slotTXPowerChanged ()));
   connect (device, TQT_SIGNAL (txPowerChanged ()), this, TQT_SLOT (slotChangeTrayIcon ()));
-  connect (device, TQT_SIGNAL (txPowerChanged ()), pictogram, TQT_SLOT (repaint ()));
-  connect (device, TQT_SIGNAL (txPowerChanged ()), strength, TQT_SLOT (repaint ()));
+  connect (device, TQT_SIGNAL (txPowerChanged ()), pictogram, TQT_SLOT (tqrepaint ()));
+  connect (device, TQT_SIGNAL (txPowerChanged ()), strength, TQT_SLOT (tqrepaint ()));
   connect (scan,  TQT_SIGNAL (clicked()), this, TQT_SLOT (slotNetworkScan()));
 }
 
@@ -427,7 +427,7 @@ KWiFiManagerApp::slotStartStatViewer ()
   delete statistik;
   statistik = new Statistics (device, showStatsNoise);
   statistik->setFixedSize (590, 300);
-  connect(device,TQT_SIGNAL(statsUpdated()),statistik,TQT_SLOT(repaint()));
+  connect(device,TQT_SIGNAL(statsUpdated()),statistik,TQT_SLOT(tqrepaint()));
   statistik->show ();
 }
 
@@ -618,7 +618,7 @@ TQStringList usedInterfacesList()
   for ( QCStringList::Iterator it = apps.begin(); it != apps.end(); ++it )
     {
         TQCString &clientId = *it;
-        if ( qstrncmp(clientId, "kwifimanager", 12) != 0 )
+        if ( tqstrncmp(clientId, "kwifimanager", 12) != 0 )
             continue;
 
 	DCOPRef ask( clientId, "dcop_interface" );
