@@ -21,7 +21,7 @@
 class Interface_wireless;
 class TQSize;
 
-class Picture:public QWidget
+class Picture:public TQWidget
 {
 public:
   Picture (TQWidget * parent, Interface_wireless * device);
