@@ -33,14 +33,14 @@ GroupwareWizard::GroupwareWizard( TQWidget *parent, const char *name )
 {
   setCaption( i18n( "KDE Groupware Wizard" ) );
 
-  TQVBoxLayout *layout = new TQVBoxLayout( this );
+  TQVBoxLayout *tqlayout = new TQVBoxLayout( this );
 
   mOverViewPage = new OverViewPage( this );
 
-  layout->addWidget( mOverViewPage );
+  tqlayout->addWidget( mOverViewPage );
 
   connect( mOverViewPage, TQT_SIGNAL( cancel() ),
-           qApp, TQT_SLOT( quit() ) );
+           tqApp, TQT_SLOT( quit() ) );
 
   resize( 400, 200 );
 }
