@@ -24,9 +24,10 @@
 
 #include <tqwidget.h>
 
-class OverViewPage : public QWidget
+class OverViewPage : public TQWidget
 {
   Q_OBJECT
+  TQ_OBJECT
 
   public:
     OverViewPage( TQWidget *parent, const char *name = 0 );
