@@ -74,13 +74,13 @@ class SetupLDAPSearchAccount : public KConfigPropagator::Change
       bool hasMyServer = false;
       uint selHosts = c.readNumEntry("NumSelectedHosts", 0);
       for ( uint i = 0 ; i < selHosts && !hasMyServer; ++i )
-        if ( c.readEntry( TQString("SelectedHost%1").arg(i) ) == host )
+        if ( c.readEntry( TQString("SelectedHost%1").tqarg(i) ) == host )
           hasMyServer = true;
       if ( !hasMyServer ) {
         c.writeEntry( "NumSelectedHosts", selHosts + 1 );
-        c.writeEntry( TQString("SelectedHost%1").arg(selHosts), host);
-        c.writeEntry( TQString("SelectedBase%1").arg(selHosts), basedn);
-        c.writeEntry( TQString("SelectedPort%1").arg(selHosts), "389");
+        c.writeEntry( TQString("SelectedHost%1").tqarg(selHosts), host);
+        c.writeEntry( TQString("SelectedBase%1").tqarg(selHosts), basedn);
+        c.writeEntry( TQString("SelectedPort%1").tqarg(selHosts), "389");
       }
     }
 
@@ -200,18 +200,18 @@ class SynchronizeScalixAccount : public KConfigPropagator::Change
 
     void apply()
     {
-      TQMessageBox *msg = new TQMessageBox( qApp->mainWidget() );
+      TQMessageBox *msg = new TQMessageBox( tqApp->mainWidget() );
       msg->setText( "Preparing initial synchronization with Scalix server..." );
       msg->show();
-      qApp->processEvents();
+      tqApp->processEvents();
       sleep( 1 );
-      qApp->processEvents();
+      tqApp->processEvents();
 
       TQString error;
       TQCString dcopService;
       int result = KDCOPServiceStarter::self()->
-        findServiceFor( "DCOP/ResourceBackend/IMAP", TQString::null,
-                        TQString::null, &error, &dcopService );
+        findServiceFor( "DCOP/ResourceBackend/IMAP", TQString(),
+                        TQString(), &error, &dcopService );
       if ( result != 0 ) {
         KMessageBox::error( 0, i18n( "Unable to start KMail to trigger initial synchronization with Scalix server" ) );
         delete msg;
@@ -458,7 +458,7 @@ TQString ScalixWizard::validate()
        mPasswordEdit->text().isEmpty() )
     return i18n( "Please fill in all fields." );
 
-  return TQString::null;
+  return TQString();
 }
 
 void ScalixWizard::usrReadConfig()
